@@ -22,10 +22,10 @@
 #ifndef KDEVPLATFORM_BREAKPOINTDETAILS_H
 #define KDEVPLATFORM_BREAKPOINTDETAILS_H
 
-#include <QtGui/QWidget>
-#include "../debuggerexport.h"
+#include <QWidget>
+#include "debuggerexport.h"
 
-class QLineEdit;
+class QSpinBox;
 class QLabel;
 
 namespace KDevelop {
@@ -35,18 +35,19 @@ class KDEVPLATFORMDEBUGGER_EXPORT BreakpointDetails : public QWidget
 {
     Q_OBJECT
 public:
-    BreakpointDetails(QWidget *parent);
+    explicit BreakpointDetails(QWidget *parent);
 
     void setItem(Breakpoint *b);
 
 private Q_SLOTS:
     void showExplanation(const QString& link);
-    void textEdited(const QString& text);
+
+    void setIgnoreHits(int ignoreHits);
 
 private:
-    QLabel* status_;
-    QLabel* hits_;
-    QLineEdit* ignore_;
+    QLabel* m_status;
+    QLabel* m_hits;
+    QSpinBox* m_ignore;
     Breakpoint* m_currentBreakpoint;
 };
 
