@@ -22,58 +22,80 @@
 
 #include "breakpointmodel.h"
 
+#include <QIcon>
 #include <QPixmap>
-#include <KIcon>
+
 #include <KParts/PartManager>
-#include <KDebug>
-#include <KLocale>
+#include <KLocalizedString>
 #include <KTextEditor/Document>
 #include <ktexteditor/movinginterface.h>
 
 #include "../interfaces/icore.h"
+#include "../interfaces/idebugcontroller.h"
 #include "../interfaces/idocumentcontroller.h"
 #include "../interfaces/idocument.h"
 #include "../interfaces/ipartcontroller.h"
+#include <interfaces/idebugsession.h>
+#include <interfaces/ibreakpointcontroller.h>
+#include <interfaces/isession.h>
+#include "util/debug.h"
 #include "breakpoint.h"
+#include <KConfigCore/KSharedConfig>
 #include <KConfigGroup>
 #include <QAction>
 #include <QMenu>
+#include <QMessageBox>
 
 #define IF_DEBUG(x)
 
 using namespace KDevelop;
 using namespace KTextEditor;
 
+namespace {
+
+IBreakpointController* breakpointController()
+{
+    KDevelop::ICore* core = KDevelop::ICore::self();
+    if (!core) {
+        return nullptr;
+    }
+    IDebugController* controller = core->debugController();
+    if (!controller) {
+        return nullptr;
+    }
+    IDebugSession* session = controller->currentSession();
+    return session ? session->breakpointController() : nullptr;
+}
+
+} // anonymous namespace
+
 BreakpointModel::BreakpointModel(QObject* parent)
     : QAbstractTableModel(parent),
       m_dontUpdateMarks(false)
 {
-    connect(this, SIGNAL(dataChanged(QModelIndex,QModelIndex)), SLOT(updateMarks()));
+    connect(this, &BreakpointModel::dataChanged, this, &BreakpointModel::updateMarks);
 
     if (KDevelop::ICore::self()->partController()) { //TODO remove if
         foreach(KParts::Part* p, KDevelop::ICore::self()->partController()->parts())
             slotPartAdded(p);
         connect(KDevelop::ICore::self()->partController(),
-                SIGNAL(partAdded(KParts::Part*)),
+                &IPartController::partAdded,
                 this,
-                SLOT(slotPartAdded(KParts::Part*)));
+                &BreakpointModel::slotPartAdded);
     }
 
 
     connect (KDevelop::ICore::self()->documentController(),
-             SIGNAL(textDocumentCreated(KDevelop::IDocument*)),
+             &IDocumentController::textDocumentCreated,
              this,
-             SLOT(textDocumentCreated(KDevelop::IDocument*)));
+             &BreakpointModel::textDocumentCreated);
     connect (KDevelop::ICore::self()->documentController(),
-                SIGNAL(documentSaved(KDevelop::IDocument*)),
-                SLOT(documentSaved(KDevelop::IDocument*)));
-    load();
+                &IDocumentController::documentSaved,
+                this, &BreakpointModel::documentSaved);
 }
 
 BreakpointModel::~BreakpointModel()
 {
-    save();
-
     qDeleteAll(m_breakpoints);
 }
 
@@ -84,7 +106,7 @@ void BreakpointModel::slotPartAdded(KParts::Part* part)
         MarkInterface *iface = dynamic_cast<MarkInterface*>(doc);
         if( !iface )
             return;
-        
+
         iface->setMarkDescription((MarkInterface::MarkTypes)BreakpointMark, i18n("Breakpoint"));
         iface->setMarkPixmap((MarkInterface::MarkTypes)BreakpointMark, *breakpointPixmap());
         iface->setMarkPixmap((MarkInterface::MarkTypes)PendingBreakpointMark, *pendingBreakpointPixmap());
@@ -100,8 +122,9 @@ void BreakpointModel::textDocumentCreated(KDevelop::IDocument* doc)
     KTextEditor::MarkInterface *iface =
         qobject_cast<KTextEditor::MarkInterface*>(doc->textDocument());
 
-    if( iface ) {
-        connect (doc->textDocument(), SIGNAL(
+    if (iface) {
+        // can't use new signal slot syntax here, MarkInterface is not a QObject
+        connect(doc->textDocument(), SIGNAL(
                      markChanged(KTextEditor::Document*,
                                  KTextEditor::Mark,
                                  KTextEditor::MarkInterface::MarkChangeAction)),
@@ -118,19 +141,21 @@ void BreakpointModel::markContextMenuRequested(Document* document, Mark mark, co
 {
 
     int type = mark.type;
-    kDebug() << type;
+    qCDebug(DEBUGGER) << type;
 
     /* Is this a breakpoint mark, to begin with? */
     if (!(type & AllBreakpointMarks)) return;
 
     Breakpoint *b = breakpoint(document->url(), mark.line);
-    Q_ASSERT(b);
-    if (!b) return;
+    if (!b) {
+        QMessageBox::critical(nullptr, i18n("Breakpoint not found"), i18n("Couldn't find breakpoint at %1:%2", document->url().toString(), mark.line));
+        return;
+    }
 
     QMenu menu;
-    QAction deleteAction(KIcon("edit-delete"), i18n("&Delete Breakpoint"), 0);
-    QAction disableAction(KIcon("dialog-cancel"), i18n("&Disable Breakpoint"), 0);
-    QAction enableAction(KIcon("dialog-ok-apply"), i18n("&Enable Breakpoint"), 0);
+    QAction deleteAction(QIcon::fromTheme("edit-delete"), i18n("&Delete Breakpoint"), 0);
+    QAction disableAction(QIcon::fromTheme("dialog-cancel"), i18n("&Disable Breakpoint"), 0);
+    QAction enableAction(QIcon::fromTheme("dialog-ok-apply"), i18n("&Enable Breakpoint"), 0);
     menu.addAction(&deleteAction);
     if (b->enabled()) {
         menu.addAction(&disableAction);
@@ -150,18 +175,18 @@ void BreakpointModel::markContextMenuRequested(Document* document, Mark mark, co
 }
 
 
-QVariant 
+QVariant
 BreakpointModel::headerData(int section, Qt::Orientation orientation,
                                  int role) const
 {
     if (orientation == Qt::Vertical)
         return QVariant();
-    
+
     if (role == Qt::DecorationRole ) {
         if (section == 0)
-            return KIcon("dialog-ok-apply");
+            return QIcon::fromTheme("dialog-ok-apply");
         else if (section == 1)
-            return KIcon("system-switch-user");
+            return QIcon::fromTheme("system-switch-user");
     }
 
     if (role == Qt::DisplayRole) {
@@ -175,7 +200,7 @@ BreakpointModel::headerData(int section, Qt::Orientation orientation,
         if (section == 0) return i18n("Active status");
         if (section == 1) return i18n("State");
         return headerData(section, orientation, Qt::DisplayRole);
-        
+
     }
     return QVariant();
 }
@@ -188,7 +213,7 @@ Qt::ItemFlags BreakpointModel::flags(const QModelIndex &index) const
 
     if (index.column() == 0)
         return static_cast<Qt::ItemFlags>(
-            Qt::ItemIsEnabled | Qt::ItemIsSelectable 
+            Qt::ItemIsEnabled | Qt::ItemIsSelectable
             | Qt::ItemIsEditable | Qt::ItemIsUserCheckable);
 
     if (index.column() == Breakpoint::LocationColumn
@@ -211,16 +236,22 @@ bool KDevelop::BreakpointModel::removeRows(int row, int count, const QModelIndex
     if (count < 1 || (row < 0) || (row + count) > rowCount(parent))
         return false;
 
+    IBreakpointController* controller = breakpointController();
+
     beginRemoveRows(parent, row, row+count-1);
     for (int i=0; i < count; ++i) {
-        Breakpoint *b = m_breakpoints.at(row);
+        Breakpoint* b = m_breakpoints.at(row);
+        b->m_deleted = true;
+        if (controller)
+            controller->breakpointAboutToBeDeleted(row);
         m_breakpoints.removeAt(row);
-        IF_DEBUG ( kDebug() << m_breakpoints; )
-        b->setDeleted();
-        emit breakpointDeleted(b);
+        b->m_model = 0;
+        // To be changed: the controller is currently still responsible for deleting the breakpoint
+        // object
     }
     endRemoveRows();
     updateMarks();
+    scheduleSave();
     return true;
 }
 
@@ -254,9 +285,45 @@ bool KDevelop::BreakpointModel::setData(const QModelIndex& index, const QVariant
     return false;
 }
 
+void BreakpointModel::updateState(int row, Breakpoint::BreakpointState state)
+{
+    Breakpoint* breakpoint = m_breakpoints.at(row);
+    if (state != breakpoint->m_state) {
+        breakpoint->m_state = state;
+        reportChange(breakpoint, Breakpoint::StateColumn);
+    }
+}
+
+void BreakpointModel::updateHitCount(int row, int hitCount)
+{
+    Breakpoint* breakpoint = m_breakpoints.at(row);
+    if (hitCount != breakpoint->m_hitCount) {
+        breakpoint->m_hitCount = hitCount;
+        reportChange(breakpoint, Breakpoint::HitCountColumn);
+    }
+}
+
+void BreakpointModel::updateErrorText(int row, const QString& errorText)
+{
+    Breakpoint* breakpoint = m_breakpoints.at(row);
+    if (breakpoint->m_errorText != errorText) {
+        breakpoint->m_errorText = errorText;
+        reportChange(breakpoint, Breakpoint::StateColumn);
+    }
+
+    if (!errorText.isEmpty()) {
+        emit error(row, errorText);
+    }
+}
+
+void BreakpointModel::notifyHit(int row)
+{
+    emit hit(row);
+}
+
 void BreakpointModel::markChanged(
-    KTextEditor::Document *document, 
-    KTextEditor::Mark mark, 
+    KTextEditor::Document *document,
+    KTextEditor::Mark mark,
     KTextEditor::MarkInterface::MarkChangeAction action)
 {
     int type = mark.type;
@@ -274,8 +341,9 @@ void BreakpointModel::markChanged(
         KTextEditor::MovingInterface *moving = qobject_cast<KTextEditor::MovingInterface*>(document);
         if (moving) {
             KTextEditor::MovingCursor* cursor = moving->newMovingCursor(KTextEditor::Cursor(mark.line, 0));
+            // can't use new signal/slot syntax here, MovingInterface is not a QObject
             connect(document, SIGNAL(aboutToDeleteMovingInterfaceContent(KTextEditor::Document*)),
-                    this, SLOT(aboutToDeleteMovingInterfaceContent(KTextEditor::Document*)));
+                    this, SLOT(aboutToDeleteMovingInterfaceContent(KTextEditor::Document*)), Qt::UniqueConnection);
             breakpoint->setMovingCursor(cursor);
         }
     } else {
@@ -298,29 +366,29 @@ void BreakpointModel::markChanged(
 
 const QPixmap* BreakpointModel::breakpointPixmap()
 {
-  static QPixmap pixmap=KIcon("script-error").pixmap(QSize(22,22), QIcon::Active, QIcon::Off);
+  static QPixmap pixmap=QIcon::fromTheme("script-error").pixmap(QSize(22,22), QIcon::Active, QIcon::Off);
   return &pixmap;
 }
 
 const QPixmap* BreakpointModel::pendingBreakpointPixmap()
 {
-  static QPixmap pixmap=KIcon("script-error").pixmap(QSize(22,22), QIcon::Normal, QIcon::Off);
+  static QPixmap pixmap=QIcon::fromTheme("script-error").pixmap(QSize(22,22), QIcon::Normal, QIcon::Off);
   return &pixmap;
 }
 
 const QPixmap* BreakpointModel::reachedBreakpointPixmap()
 {
-  static QPixmap pixmap=KIcon("script-error").pixmap(QSize(22,22), QIcon::Selected, QIcon::Off);
+  static QPixmap pixmap=QIcon::fromTheme("script-error").pixmap(QSize(22,22), QIcon::Selected, QIcon::Off);
   return &pixmap;
 }
 
 const QPixmap* BreakpointModel::disabledBreakpointPixmap()
 {
-  static QPixmap pixmap=KIcon("script-error").pixmap(QSize(22,22), QIcon::Disabled, QIcon::Off);
+  static QPixmap pixmap=QIcon::fromTheme("script-error").pixmap(QSize(22,22), QIcon::Disabled, QIcon::Off);
   return &pixmap;
 }
 
-void BreakpointModel::toggleBreakpoint(const KUrl& url, const KTextEditor::Cursor& cursor)
+void BreakpointModel::toggleBreakpoint(const QUrl& url, const KTextEditor::Cursor& cursor)
 {
     Breakpoint *b = breakpoint(url, cursor.line());
     if (b) {
@@ -338,7 +406,14 @@ void BreakpointModel::reportChange(Breakpoint* breakpoint, Breakpoint::Column co
         Q_ASSERT(idx.isValid()); // make sure we don't pass invalid indices to dataChanged()
         emit dataChanged(idx, idx);
     }
-    emit breakpointChanged(breakpoint, column);
+
+    if (IBreakpointController* controller = breakpointController()) {
+        int row = m_breakpoints.indexOf(breakpoint);
+        Q_ASSERT(row != -1);
+        controller->breakpointModelChanged(row, ColumnFlags(1 << column));
+    }
+
+    scheduleSave();
 }
 
 uint BreakpointModel::breakpointType(Breakpoint *breakpoint)
@@ -367,7 +442,7 @@ void KDevelop::BreakpointModel::updateMarks()
         KTextEditor::MarkInterface *mark = qobject_cast<KTextEditor::MarkInterface*>(doc->textDocument());
         if (!mark) continue;
         uint type = breakpointType(breakpoint);
-        IF_DEBUG( kDebug() << type << breakpoint->url() << mark->mark(breakpoint->line()); )
+        IF_DEBUG( qCDebug(DEBUGGER) << type << breakpoint->url() << mark->mark(breakpoint->line()); )
 
         doc->textDocument()->blockSignals(true);
         if (mark->mark(breakpoint->line()) & AllBreakpointMarks) {
@@ -389,7 +464,7 @@ void KDevelop::BreakpointModel::updateMarks()
         doc->textDocument()->blockSignals(true);
         foreach (KTextEditor::Mark *m, mark->marks()) {
             if (!(m->type & AllBreakpointMarks)) continue;
-            IF_DEBUG( kDebug() << m->line << m->type; )
+            IF_DEBUG( qCDebug(DEBUGGER) << m->line << m->type; )
             foreach (Breakpoint *breakpoint, m_breakpoints) {
                 if (breakpoint->kind() != Breakpoint::CodeBreakpoint) continue;
                 if (doc->url() == breakpoint->url() && m->line == breakpoint->line()) {
@@ -405,7 +480,7 @@ void KDevelop::BreakpointModel::updateMarks()
 
 void BreakpointModel::documentSaved(KDevelop::IDocument* doc)
 {
-    IF_DEBUG( kDebug(); )
+    IF_DEBUG( qCDebug(DEBUGGER); )
     foreach (Breakpoint *breakpoint, m_breakpoints) {
         if (breakpoint->movingCursor()) {
             if (breakpoint->movingCursor()->document() != doc->textDocument()) continue;
@@ -427,12 +502,12 @@ void BreakpointModel::aboutToDeleteMovingInterfaceContent(KTextEditor::Document*
 
 void BreakpointModel::load()
 {
-    KConfigGroup breakpoints = KGlobal::config()->group("breakpoints");
+    KConfigGroup breakpoints = ICore::self()->activeSession()->config()->group("Breakpoints");
     int count = breakpoints.readEntry("number", 0);
     if (count == 0)
         return;
 
-    beginInsertRows(QModelIndex(), 0, count);
+    beginInsertRows(QModelIndex(), 0, count - 1);
     for (int i = 0; i < count; ++i) {
         if (!breakpoints.group(QString::number(i)).readEntry("kind", "").isEmpty()) {
             new Breakpoint(this, breakpoints.group(QString::number(i)));
@@ -443,7 +518,9 @@ void BreakpointModel::load()
 
 void BreakpointModel::save()
 {
-    KConfigGroup breakpoints = KGlobal::config()->group("breakpoints");
+    m_dirty = false;
+
+    KConfigGroup breakpoints = ICore::self()->activeSession()->config()->group("Breakpoints");
     breakpoints.writeEntry("number", m_breakpoints.count());
     int i = 0;
     foreach (Breakpoint *b, m_breakpoints) {
@@ -454,6 +531,15 @@ void BreakpointModel::save()
     breakpoints.sync();
 }
 
+void BreakpointModel::scheduleSave()
+{
+    if (m_dirty)
+        return;
+
+    m_dirty = true;
+    QTimer::singleShot(0, this, SLOT(save()));
+}
+
 QList<Breakpoint*> KDevelop::BreakpointModel::breakpoints() const
 {
     return m_breakpoints;
@@ -473,7 +559,7 @@ Breakpoint* BreakpointModel::addCodeBreakpoint()
     return n;
 }
 
-Breakpoint* BreakpointModel::addCodeBreakpoint(const KUrl& url, int line)
+Breakpoint* BreakpointModel::addCodeBreakpoint(const QUrl& url, int line)
 {
     Breakpoint* n = addCodeBreakpoint();
     n->setLocation(url, line);
@@ -536,10 +622,15 @@ Breakpoint* BreakpointModel::addAccessWatchpoint(const QString& expression)
 void BreakpointModel::registerBreakpoint(Breakpoint* breakpoint)
 {
     Q_ASSERT(!m_breakpoints.contains(breakpoint));
+    int row = m_breakpoints.size();
     m_breakpoints << breakpoint;
+    if (IBreakpointController* controller = breakpointController()) {
+        controller->breakpointAdded(row);
+    }
+    scheduleSave();
 }
 
-Breakpoint* BreakpointModel::breakpoint(const KUrl& url, int line) {
+Breakpoint* BreakpointModel::breakpoint(const QUrl& url, int line) {
     foreach (Breakpoint *b, m_breakpoints) {
         if (b->url() == url && b->line() == line) {
             return b;
@@ -547,5 +638,3 @@ Breakpoint* BreakpointModel::breakpoint(const KUrl& url, int line) {
     }
     return 0;
 }
-
-#include "breakpointmodel.moc"
