@@ -33,27 +33,30 @@
 #include <QMenu>
 #include <QApplication>
 #include <QClipboard>
+#include <QIcon>
+#include <QResizeEvent>
+#include <QAction>
 
-#include <KAction>
 #include <KStandardAction>
-#include <KDebug>
 #include <KLocalizedString>
-#include <KIcon>
 #include <KTextEditor/Cursor>
 
 #include <interfaces/icore.h>
 #include <interfaces/idebugcontroller.h>
 #include <interfaces/idocumentcontroller.h>
+#include "util/debug.h"
 #include "framestackmodel.h"
 
 namespace KDevelop {
 
 FramestackWidget::FramestackWidget(IDebugController* controller, QWidget* parent)
-: QSplitter(Qt::Horizontal, parent), m_session(0)
+    : AutoOrientedSplitter(Qt::Horizontal, parent), m_session(0)
 {
     connect(controller,
-            SIGNAL(currentSessionChanged(KDevelop::IDebugSession*)),
-            SLOT(currentSessionChanged(KDevelop::IDebugSession*)));
+            &IDebugController::currentSessionChanged,
+            this, &FramestackWidget::currentSessionChanged);
+
+    //TODO: shouldn't this signal be in IDebugController? Otherwise we are effectively depending on it being a DebugController here
     connect(controller, SIGNAL(raiseFramestackViews()), SIGNAL(requestRaise()));
 
     setWhatsThis(i18n("<b>Frame stack</b>"
@@ -64,7 +67,7 @@ FramestackWidget::FramestackWidget(IDebugController* controller, QWidget* parent
                       "program. By clicking on an item you "
                       "can see the values in any of the "
                       "previous calling functions."));
-    setWindowIcon(KIcon("view-list-text"));
+    setWindowIcon(QIcon::fromTheme("view-list-text"));
     m_threadsWidget = new QWidget(this);
     m_threads = new QListView(m_threadsWidget);
     m_frames = new QTreeView(this);
@@ -76,88 +79,77 @@ FramestackWidget::FramestackWidget(IDebugController* controller, QWidget* parent
 
     m_framesContextMenu = new QMenu(m_frames);
 
-    KAction *selectAllAction = KStandardAction::selectAll(m_frames);
-    selectAllAction->setShortcut(KShortcut()); //FIXME: why does CTRL-A conflict with Katepart (while CTRL-Cbelow doesn't) ?
+    QAction* selectAllAction = KStandardAction::selectAll(m_frames);
+    selectAllAction->setShortcut(QKeySequence()); //FIXME: why does CTRL-A conflict with Katepart (while CTRL-Cbelow doesn't) ?
     selectAllAction->setShortcutContext(Qt::WidgetWithChildrenShortcut);
-    connect(selectAllAction, SIGNAL(triggered()), SLOT(selectAll()));
+    connect(selectAllAction, &QAction::triggered, this, &FramestackWidget::selectAll);
     m_framesContextMenu->addAction(selectAllAction);
 
-    KAction *copyAction = KStandardAction::copy(m_frames);
+    QAction* copyAction = KStandardAction::copy(m_frames);
     copyAction->setShortcutContext(Qt::WidgetWithChildrenShortcut);
-    connect(copyAction, SIGNAL(triggered()), SLOT(copySelection()));
+    connect(copyAction, &QAction::triggered, this, &FramestackWidget::copySelection);
     m_framesContextMenu->addAction(copyAction);
     addAction(copyAction);
 
-    connect(m_frames, SIGNAL(customContextMenuRequested(QPoint)), SLOT(frameContextMenuRequested(QPoint)));
+    connect(m_frames, &QTreeView::customContextMenuRequested, this, &FramestackWidget::frameContextMenuRequested);
 
     m_threadsWidget->setLayout(new QVBoxLayout());
     m_threadsWidget->layout()->addWidget(new QLabel(i18n("Threads:")));
     m_threadsWidget->layout()->addWidget(m_threads);
-    m_threadsWidget->hide();
     addWidget(m_threadsWidget);
     addWidget(m_frames);
 
     setStretchFactor(1, 3);
-    connect(m_frames->verticalScrollBar(), SIGNAL(valueChanged(int)), this, SLOT(checkFetchMoreFrames()));
+    connect(m_frames->verticalScrollBar(), &QScrollBar::valueChanged, this, &FramestackWidget::checkFetchMoreFrames);
 
     // Show the selected frame when clicked, even if it has previously been selected
-    connect(m_frames, SIGNAL(clicked(QModelIndex)), SLOT(frameSelectionChanged(QModelIndex)));
+    connect(m_frames, &QTreeView::clicked, this, &FramestackWidget::frameSelectionChanged);
+
+    currentSessionChanged(controller->currentSession());
 }
 
-FramestackWidget::~FramestackWidget() {}
+FramestackWidget::~FramestackWidget()
+{
+}
 
 void FramestackWidget::currentSessionChanged(KDevelop::IDebugSession* session)
 {
-    kDebug() << "Adding session:" << isVisible();
-
     m_session = session;
 
     m_threads->setModel(session ? session->frameStackModel() : 0);
     m_frames->setModel(session ? session->frameStackModel() : 0);
 
     if (session) {
-        connect(session->frameStackModel(), SIGNAL(dataChanged(QModelIndex,QModelIndex)),
-                this, SLOT(checkFetchMoreFrames()));
-        connect(session->frameStackModel(), SIGNAL(currentThreadChanged(int)),
-                SLOT(currentThreadChanged(int)));
+        connect(session->frameStackModel(), &IFrameStackModel::dataChanged,
+                this, &FramestackWidget::checkFetchMoreFrames);
+        connect(session->frameStackModel(), &IFrameStackModel::currentThreadChanged,
+                this, &FramestackWidget::currentThreadChanged);
         currentThreadChanged(session->frameStackModel()->currentThread());
-        connect(session->frameStackModel(), SIGNAL(currentFrameChanged(int)),
-                SLOT(currentFrameChanged(int)));
+        connect(session->frameStackModel(), &IFrameStackModel::currentFrameChanged,
+                this, &FramestackWidget::currentFrameChanged);
         currentFrameChanged(session->frameStackModel()->currentFrame());
-        connect(session, SIGNAL(stateChanged(KDevelop::IDebugSession::DebuggerState)),
-                SLOT(sessionStateChanged(KDevelop::IDebugSession::DebuggerState)));
+        connect(session, &IDebugSession::stateChanged,
+                this, &FramestackWidget::sessionStateChanged);
 
-        connect(m_threads->selectionModel(), SIGNAL(currentChanged(QModelIndex,QModelIndex)),
-                this, SLOT(setThreadShown(QModelIndex)));
+        connect(m_threads->selectionModel(), &QItemSelectionModel::currentChanged,
+                this, &FramestackWidget::setThreadShown);
 
         // Show the selected frame, independent of the means by which it has been selected
-        connect(m_frames->selectionModel(), SIGNAL(currentChanged(QModelIndex,QModelIndex)),
-                this, SLOT(frameSelectionChanged(QModelIndex)));
-    }
+        connect(m_frames->selectionModel(), &QItemSelectionModel::currentChanged,
+                this, &FramestackWidget::frameSelectionChanged);
 
-    if (isVisible()) {
-        showEvent(0);
+        sessionStateChanged(session->state());
     }
 }
 
-void KDevelop::FramestackWidget::hideEvent(QHideEvent* e)
-{
-    QWidget::hideEvent(e);
-}
-
-void KDevelop::FramestackWidget::showEvent(QShowEvent* e)
-{
-    QWidget::showEvent(e);
-}
-
-void KDevelop::FramestackWidget::setThreadShown(const QModelIndex& current)
+void FramestackWidget::setThreadShown(const QModelIndex& current)
 {
     if (!current.isValid())
         return;
     m_session->frameStackModel()->setCurrentThread(current);
 }
 
-void KDevelop::FramestackWidget::checkFetchMoreFrames()
+void FramestackWidget::checkFetchMoreFrames()
 {
     int val = m_frames->verticalScrollBar()->value();
     int max = m_frames->verticalScrollBar()->maximum();
@@ -168,7 +160,7 @@ void KDevelop::FramestackWidget::checkFetchMoreFrames()
     }
 }
 
-void KDevelop::FramestackWidget::currentThreadChanged(int thread)
+void FramestackWidget::currentThreadChanged(int thread)
 {
     if (thread != -1) {
         IFrameStackModel* model = m_session->frameStackModel();
@@ -176,7 +168,7 @@ void KDevelop::FramestackWidget::currentThreadChanged(int thread)
         m_threads->selectionModel()->select(idx, QItemSelectionModel::ClearAndSelect | QItemSelectionModel::Rows);
         m_threadsWidget->setVisible(model->rowCount() > 1);
         m_frames->setRootIndex(idx);
-        m_frames->header()->setResizeMode(0, QHeaderView::ResizeToContents);
+        m_frames->header()->setSectionResizeMode(0, QHeaderView::ResizeToContents);
     } else {
         m_threadsWidget->hide();
         m_threads->selectionModel()->clear();
@@ -184,7 +176,7 @@ void KDevelop::FramestackWidget::currentThreadChanged(int thread)
     }
 }
 
-void KDevelop::FramestackWidget::currentFrameChanged(int frame)
+void FramestackWidget::currentFrameChanged(int frame)
 {
     if (frame != -1) {
         IFrameStackModel* model = m_session->frameStackModel();
@@ -203,7 +195,7 @@ void FramestackWidget::frameSelectionChanged(const QModelIndex& current /* previ
     IFrameStackModel::FrameItem f = m_session->frameStackModel()->frame(current);
     /* If line is -1, then it's not a source file at all.  */
     if (f.line != -1) {
-        QPair<KUrl, int> file = m_session->convertToLocalUrl(qMakePair(f.file, f.line));
+        QPair<QUrl, int> file = m_session->convertToLocalUrl(qMakePair(f.file, f.line));
         ICore::self()->documentController()->openDocument(file.first, KTextEditor::Cursor(file.second, 0), IDocumentController::DoNotFocus);
     }
 
@@ -220,12 +212,14 @@ void FramestackWidget::copySelection()
     QClipboard *cb = QApplication::clipboard();
     QModelIndexList indexes = m_frames->selectionModel()->selectedRows();
     QString content;
-    Q_FOREACH( QModelIndex index, indexes) {
+    Q_FOREACH(const QModelIndex& index, indexes) {
         IFrameStackModel::FrameItem frame = m_session->frameStackModel()->frame(index);
         if (frame.line == -1) {
-            content += QString("#%1 %2() at %3\n").arg(frame.nr).arg(frame.name).arg(frame.file.pathOrUrl(KUrl::RemoveTrailingSlash));
+            content += i18nc("#frame function() at file", "#%1 %2() at %3\n",
+                frame.nr, frame.name, frame.file.url(QUrl::PreferLocalFile | QUrl::StripTrailingSlash));
         } else {
-            content += QString("#%1 %2() at %3:%4\n").arg(frame.nr).arg(frame.name).arg(frame.file.pathOrUrl(KUrl::RemoveTrailingSlash)).arg(frame.line+1);
+            content += i18nc("#frame function() at file:line", "#%1 %2() at %3:%4\n",
+                frame.nr, frame.name, frame.file.url(QUrl::PreferLocalFile | QUrl::StripTrailingSlash), frame.line+1);
         }
     }
     cb->setText(content);
@@ -245,4 +239,3 @@ void FramestackWidget::sessionStateChanged(KDevelop::IDebugSession::DebuggerStat
 
 }
 
-#include "framestackwidget.moc"
