@@ -24,10 +24,9 @@
 #ifndef KDEVPLATFORM_FRAMESTACKWIDGET_H
 #define KDEVPLATFORM_FRAMESTACKWIDGET_H
 
-#include <QSplitter>
-
-#include "../debuggerexport.h"
+#include <debugger/debuggerexport.h>
 #include <debugger/interfaces/idebugsession.h>
+#include <util/autoorientedsplitter.h>
 
 class QMenu;
 class QTreeView;
@@ -37,17 +36,14 @@ class QListView;
 namespace KDevelop {
 class IDebugController;
 
-class KDEVPLATFORMDEBUGGER_EXPORT FramestackWidget : public QSplitter
+class KDEVPLATFORMDEBUGGER_EXPORT FramestackWidget : public AutoOrientedSplitter
 {
     Q_OBJECT
     public:
-        FramestackWidget( IDebugController* controller, QWidget *parent=0 );
+        explicit FramestackWidget( IDebugController* controller, QWidget *parent=0 );
         virtual ~FramestackWidget();
     Q_SIGNALS:
         void requestRaise();
-    protected:
-        virtual void showEvent(QShowEvent* );
-        virtual void hideEvent(QHideEvent* );
     private Q_SLOTS:
         void currentSessionChanged(KDevelop::IDebugSession* session);
 
