@@ -21,12 +21,11 @@
 #ifndef KDEVPLATFORM_IDEBUGSESSION_H
 #define KDEVPLATFORM_IDEBUGSESSION_H
 
+#include <debugger/debuggerexport.h>
+
 #include <QtCore/QObject>
 #include <QtCore/QAbstractItemModel>
-#include "../debuggerexport.h"
-#include <KUrl>
-
-class KUrl;
+#include <QUrl>
 
 namespace KDevelop {
 
@@ -96,7 +95,7 @@ public:
      * The default implementation just returns the url and is sufficient for
      * local debuggers. Remote debuggers can implement a path mapping mechanism.
      */
-    virtual QPair<KUrl, int> convertToLocalUrl(const QPair<KUrl, int> &remoteUrl) const;
+    virtual QPair<QUrl, int> convertToLocalUrl(const QPair<QUrl, int> &remoteUrl) const;
 
     /**
      * Returns the remote Url for a source file used in the current debug session.
@@ -104,11 +103,34 @@ public:
      * The default implementation just returns the url and is sufficient for
      * local debuggers. Remote debuggers can implement a path mapping mechanism.
      */
-    virtual QPair<KUrl, int> convertToRemoteUrl(const QPair<KUrl, int> &localUrl) const;
+    virtual QPair<QUrl, int> convertToRemoteUrl(const QPair<QUrl, int> &localUrl) const;
 
-    IBreakpointController *breakpointController() const;
-    IVariableController *variableController() const;    
-    IFrameStackModel *frameStackModel() const; 
+    /**
+     * @return the breakpoint controller of this session
+     *
+     * @note Implementations must ensure that a breakpoint controller always exists (even if it
+     * is a dummy stub implementation that does nothing), and that it does not change during
+     * the lifetime of a session.
+     */
+    virtual IBreakpointController* breakpointController() const = 0;
+
+    /**
+     * @return the variable controller of this session
+     *
+     * @note Implementations must ensure that a variable controller always exists (even if it
+     * is a dummy stub implementation that does nothing), and that it does not change during
+     * the lifetime of a session.
+     */
+    virtual IVariableController* variableController() const = 0;
+
+    /**
+     * @return the frame stack model of this session
+     *
+     * @note Implementations must ensure that a frame stack model always exists (even if it
+     * is a dummy stub implementation that does nothing), and that it does not change during
+     * the lifetime of a session.
+     */
+    virtual IFrameStackModel* frameStackModel() const = 0;
 
 public Q_SLOTS:
     virtual void restartDebugger() = 0;
@@ -125,7 +147,8 @@ public Q_SLOTS:
 
 Q_SIGNALS:
     void stateChanged(KDevelop::IDebugSession::DebuggerState state);
-    void showStepInSource(const KUrl& file, int line, const QString &addr);
+    void showStepInSource(const QUrl& file, int line, const QString &addr);
+    void showStepInDisassemble(const QString &addr);
     void clearExecutionPoint();
     void finished();
 
@@ -142,7 +165,7 @@ Q_SIGNALS:
 public:
     using QObject::event; // prevent hiding of base method.
 
-    KUrl currentUrl() const;
+    QUrl currentUrl() const;
     int currentLine() const;
     QString currentAddr() const;
     
@@ -150,8 +173,8 @@ protected:
 
     // Clear the position before running code
     void clearCurrentPosition();
-    // Set new position and emit showStepInSource signal
-    void setCurrentPosition(const KUrl& url, int line, const QString& addr);
+    /// Sets new position and emits showStepInSource or showStepInDisassemble (if source file is unavailable) signal
+    void setCurrentPosition(const QUrl& url, int line, const QString& addr);
 
     /** Raises the specified event. Should be used instead of
         emitting 'event' directly, since this method can perform
@@ -163,21 +186,14 @@ protected:
     virtual void raiseEvent(event_t e);
     friend class FrameStackModel;
     
-    virtual IFrameStackModel* createFrameStackModel() = 0;
-
-    IBreakpointController *m_breakpointController;
-    IVariableController *m_variableController;    
-    mutable IFrameStackModel *m_frameStackModel;
-
 private Q_SLOTS:
     void slotStateChanged(KDevelop::IDebugSession::DebuggerState state);
 
 private: //TODO use d-pointer
     // Current position in debugged program, gets set when the state changes
-    KUrl m_url;
+    QUrl m_url;
     int m_line;
     QString m_addr;
-
 };
 
 }
