@@ -1,7 +1,7 @@
 /*
    Copyright 2009 Aleix Pol Gonzalez <aleixpol@kde.org>
    Copyright 2010 Benjamin Port <port.benjamin@gmail.com>
-   
+
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License version 2 as published by the Free Software Foundation.
@@ -18,7 +18,9 @@
 */
 
 #include "documentationview.h"
+
 #include <QAction>
+#include <QIcon>
 #include <QVBoxLayout>
 #include <QLabel>
 #include <QComboBox>
@@ -26,86 +28,91 @@
 #include <QCompleter>
 #include <QLayout>
 #include <QTextBrowser>
-#include <KLineEdit>
-#include <KDebug>
-#include <KIcon>
-#include <KLocale>
+
+#include <QLineEdit>
+#include <KLocalizedString>
+
 #include <interfaces/icore.h>
 #include <interfaces/idocumentationprovider.h>
 #include <interfaces/idocumentationproviderprovider.h>
 #include <interfaces/idocumentationcontroller.h>
 #include <interfaces/iplugincontroller.h>
 #include "documentationfindwidget.h"
+#include "debug.h"
+
+Q_LOGGING_CATEGORY(DOCUMENTATION, "kdevplatform.documentation")
+
 
 using namespace KDevelop;
 
 DocumentationView::DocumentationView(QWidget* parent, ProvidersModel* m)
     : QWidget(parent), mProvidersModel(m)
 {
-    setWindowIcon(KIcon("documentation"));
+    setWindowIcon(QIcon::fromTheme("documentation"));
     setWindowTitle(i18n("Documentation"));
 
     setLayout(new QVBoxLayout(this));
     layout()->setMargin(0);
     layout()->setSpacing(0);
-    
+
     //TODO: clean this up, simply use addAction as that will create a toolbar automatically
-    //      use custom KAction's with createWidget for mProviders and mIdentifiers
+    //      use custom QAction's with createWidget for mProviders and mIdentifiers
     mActions=new KToolBar(this);
     // set window title so the QAction from QToolBar::toggleViewAction gets a proper name set
     mActions->setWindowTitle(i18n("Documentation Tool Bar"));
     mActions->setToolButtonStyle(Qt::ToolButtonIconOnly);
     int iconSize=style()->pixelMetric(QStyle::PM_SmallIconSize);
     mActions->setIconSize(QSize(iconSize, iconSize));
-    
+
     mFindDoc = new DocumentationFindWidget;
     mFindDoc->hide();
-    
-    mBack=mActions->addAction(KIcon("go-previous"), i18n("Back"));
-    mForward=mActions->addAction(KIcon("go-next"), i18n("Forward"));
-    mFind=mActions->addAction(KIcon("edit-find"), i18n("Find"), mFindDoc, SLOT(show()));
+
+    mBack=mActions->addAction(QIcon::fromTheme("go-previous"), i18n("Back"));
+    mForward=mActions->addAction(QIcon::fromTheme("go-next"), i18n("Forward"));
+    mFind=mActions->addAction(QIcon::fromTheme("edit-find"), i18n("Find"), mFindDoc, SLOT(startSearch()));
     mActions->addSeparator();
-    mActions->addAction(KIcon("go-home"), i18n("Home"), this, SLOT(showHome()));
+    mActions->addAction(QIcon::fromTheme("go-home"), i18n("Home"), this, SLOT(showHome()));
     mProviders=new QComboBox(mActions);
-    mProviders->setFocusPolicy(Qt::NoFocus);
-    
-    mIdentifiers=new KLineEdit(mActions);
-    mIdentifiers->setClearButtonShown(true);
+
+    mIdentifiers=new QLineEdit(mActions);
+    mIdentifiers->setClearButtonEnabled(true);
     mIdentifiers->setCompleter(new QCompleter(mIdentifiers));
 //     mIdentifiers->completer()->setCompletionMode(QCompleter::UnfilteredPopupCompletion);
     mIdentifiers->completer()->setCaseSensitivity(Qt::CaseInsensitive);
 
     /* vertical size policy should be left to the style. */
     mIdentifiers->setSizePolicy(QSizePolicy::Expanding, mIdentifiers->sizePolicy().verticalPolicy());
-    connect(mIdentifiers, SIGNAL(returnPressed()), SLOT(changedSelection()));
-    connect(mIdentifiers->completer(), SIGNAL(activated(QModelIndex)), SLOT(changeProvider(QModelIndex)));
-    
+    connect(mIdentifiers, &QLineEdit::returnPressed, this, &DocumentationView::changedSelection);
+    connect(mIdentifiers->completer(), static_cast<void(QCompleter::*)(const QModelIndex&)>(&QCompleter::activated), this, &DocumentationView::changeProvider);
+    QWidget::setTabOrder(mProviders, mIdentifiers);
+
     mActions->addWidget(mProviders);
     mActions->addWidget(mIdentifiers);
-    
+
     mBack->setEnabled(false);
     mForward->setEnabled(false);
-    connect(mBack, SIGNAL(triggered()), this, SLOT(browseBack()));
-    connect(mForward, SIGNAL(triggered()), this, SLOT(browseForward()));
+    connect(mBack, &QAction::triggered, this, &DocumentationView::browseBack);
+    connect(mForward, &QAction::triggered, this, &DocumentationView::browseForward);
     mCurrent=mHistory.end();
-    
+
     layout()->addWidget(mActions);
     layout()->addWidget(new QWidget(this));
     layout()->addWidget(mFindDoc);
-    
+
     QMetaObject::invokeMethod(this, "initialize", Qt::QueuedConnection);
 }
 
 void DocumentationView::initialize()
 {
     mProviders->setModel(mProvidersModel);
-    connect(mProviders, SIGNAL(activated(int)), SLOT(changedProvider(int)));
-    foreach(KDevelop::IDocumentationProvider* p, mProvidersModel->providers()) {
-        connect(dynamic_cast<QObject*>(p), SIGNAL(addHistory(KSharedPtr<KDevelop::IDocumentation>)),
-                SLOT(addHistory(KSharedPtr<KDevelop::IDocumentation>)));
+    connect(mProviders, static_cast<void (QComboBox::*)(int)>(&QComboBox::activated), this, &DocumentationView::changedProvider);
+    foreach (IDocumentationProvider* p, mProvidersModel->providers()) {
+        // can't use new signal/slot syntax here, IDocumentation is not a QObject
+        connect(dynamic_cast<QObject*>(p), SIGNAL(addHistory(KDevelop::IDocumentation::Ptr)),
+                this, SLOT(addHistory(KDevelop::IDocumentation::Ptr)));
     }
-    connect(mProvidersModel, SIGNAL(providersChanged()), this, SLOT(emptyHistory()));
-    
+    connect(mProvidersModel, &ProvidersModel::providersChanged, this, &DocumentationView::emptyHistory);
+
     if(mProvidersModel->rowCount()>0)
         changedProvider(0);
 }
@@ -115,7 +122,7 @@ void DocumentationView::browseBack()
     mCurrent--;
     mBack->setEnabled(mCurrent!=mHistory.begin());
     mForward->setEnabled(true);
-    
+
     updateView();
 }
 
@@ -130,8 +137,8 @@ void DocumentationView::browseForward()
 
 void DocumentationView::showHome()
 {
-    KDevelop::IDocumentationProvider* prov=mProvidersModel->provider(mProviders->currentIndex());
-    
+    auto prov = mProvidersModel->provider(mProviders->currentIndex());
+
     showDocumentation(prov->homePage());
 }
 
@@ -142,24 +149,24 @@ void DocumentationView::changedSelection()
 
 void DocumentationView::changeProvider(const QModelIndex& idx)
 {
-    if(idx.isValid())
-    {
-        KDevelop::IDocumentationProvider* prov=mProvidersModel->provider(mProviders->currentIndex());
-        KSharedPtr<KDevelop::IDocumentation> doc=prov->documentationForIndex(idx);
-        if(doc)
+    if (idx.isValid()) {
+        IDocumentationProvider* prov = mProvidersModel->provider(mProviders->currentIndex());
+        auto doc = prov->documentationForIndex(idx);
+        if (doc) {
             showDocumentation(doc);
+        }
     }
 }
 
-void DocumentationView::showDocumentation(KSharedPtr< KDevelop::IDocumentation > doc)
+void DocumentationView::showDocumentation(const IDocumentation::Ptr& doc)
 {
-    kDebug(9529) << "showing" << doc->name();
-    
+    qCDebug(DOCUMENTATION) << "showing" << doc->name();
+
     addHistory(doc);
     updateView();
 }
 
-void DocumentationView::addHistory(KSharedPtr< KDevelop::IDocumentation > doc)
+void DocumentationView::addHistory(const IDocumentation::Ptr& doc)
 {
     mBack->setEnabled( !mHistory.isEmpty() );
     mForward->setEnabled(false);
@@ -200,23 +207,24 @@ void DocumentationView::updateView()
     mProviders->setCurrentIndex(mProvidersModel->rowForProvider((*mCurrent)->provider()));
     mIdentifiers->completer()->setModel((*mCurrent)->provider()->indexModel());
     mIdentifiers->setText((*mCurrent)->name());
-    
+
     QLayoutItem* lastview=layout()->takeAt(1);
     Q_ASSERT(lastview);
-    
+
     if(lastview->widget()->parent()==this)
         lastview->widget()->deleteLater();
-    
+
     delete lastview;
-    
+
     mFindDoc->setEnabled(false);
     QWidget* w=(*mCurrent)->documentationWidget(mFindDoc, this);
     Q_ASSERT(w);
-    
+    QWidget::setTabOrder(mIdentifiers, w);
+
     mFind->setEnabled(mFindDoc->isEnabled());
     if(!mFindDoc->isEnabled())
         mFindDoc->hide();
-    
+
     QLayoutItem* findW=layout()->takeAt(1);
     layout()->addWidget(w);
     layout()->addItem(findW);
@@ -226,7 +234,7 @@ void DocumentationView::changedProvider(int row)
 {
     mIdentifiers->completer()->setModel(mProvidersModel->provider(row)->indexModel());
     mIdentifiers->clear();
-    
+
     showHome();
 }
 
@@ -236,9 +244,9 @@ ProvidersModel::ProvidersModel(QObject* parent)
     : QAbstractListModel(parent)
     , mProviders(ICore::self()->documentationController()->documentationProviders())
 {
-    connect(ICore::self()->pluginController(), SIGNAL(pluginUnloaded(KDevelop::IPlugin*)), SLOT(unloaded(KDevelop::IPlugin*)));
-    connect(ICore::self()->pluginController(), SIGNAL(pluginLoaded(KDevelop::IPlugin*)), SLOT(loaded(KDevelop::IPlugin*)));
-    connect(ICore::self()->documentationController(), SIGNAL(providersChanged()), SLOT(reloadProviders()));
+    connect(ICore::self()->pluginController(), &IPluginController::unloadingPlugin, this, &ProvidersModel::unloaded);
+    connect(ICore::self()->pluginController(), &IPluginController::pluginLoaded, this, &ProvidersModel::loaded);
+    connect(ICore::self()->documentationController(), &IDocumentationController::providersChanged, this, &ProvidersModel::reloadProviders);
 }
 
 void ProvidersModel::reloadProviders()
@@ -251,6 +259,9 @@ void ProvidersModel::reloadProviders()
 
 QVariant ProvidersModel::data(const QModelIndex& index, int role) const
 {
+    if (index.row() >= mProviders.count() || index.row() < 0)
+        return QVariant();
+
     QVariant ret;
     switch (role)
     {
@@ -264,31 +275,32 @@ QVariant ProvidersModel::data(const QModelIndex& index, int role) const
     return ret;
 }
 
-void ProvidersModel::unloaded(KDevelop::IPlugin* p)
+void ProvidersModel::removeProviders(const QList<KDevelop::IDocumentationProvider*> &prov)
 {
-    IDocumentationProvider* prov=p->extension<IDocumentationProvider>();
-    int idx=-1;
-    if (prov)
-        idx = mProviders.indexOf(prov);
+    if (prov.isEmpty())
+        return;
+
+    int idx = mProviders.indexOf(prov.first());
 
     if (idx>=0) {
-        beginRemoveRows(QModelIndex(), idx, idx);
-        mProviders.removeAt(idx);
+        beginRemoveRows(QModelIndex(), idx, idx + prov.count()-1);
+        for(int i=0, c=prov.count(); i<c; ++i)
+            mProviders.removeAt(idx);
         endRemoveRows();
-        emit providersChanged();
     }
 
+    emit providersChanged();
+}
+
+void ProvidersModel::unloaded(IPlugin* p)
+{
+    IDocumentationProvider* prov=p->extension<IDocumentationProvider>();
+    if (prov)
+        removeProviders(QList<IDocumentationProvider*>() << prov);
+
     IDocumentationProviderProvider* provProv=p->extension<IDocumentationProviderProvider>();
     if (provProv) {
-        foreach (IDocumentationProvider* p, provProv->providers()) {
-            idx = mProviders.indexOf(p);
-            if (idx>=0) {
-                beginRemoveRows(QModelIndex(), idx, idx);
-                mProviders.removeAt(idx);
-                endRemoveRows();
-            }
-        }
-        emit providersChanged();
+        removeProviders(provProv->providers());
     }
 }
 
@@ -302,17 +314,21 @@ void ProvidersModel::loaded(IPlugin* p)
         endInsertRows();
         emit providersChanged();
     }
+
     IDocumentationProviderProvider* provProv=p->extension<IDocumentationProviderProvider>();
     if (provProv) {
-        beginInsertRows(QModelIndex(), 0, 0);
+        beginInsertRows(QModelIndex(), 0, provProv->providers().count()-1);
         mProviders.append(provProv->providers());
         endInsertRows();
         emit providersChanged();
     }
 }
 
+int ProvidersModel::rowCount(const QModelIndex& parent) const
+{
+    return parent.isValid() ? 0 : mProviders.count();
+}
+
 int ProvidersModel::rowForProvider(IDocumentationProvider* provider) { return mProviders.indexOf(provider); }
 IDocumentationProvider* ProvidersModel::provider(int pos) const { return mProviders[pos]; }
 QList< IDocumentationProvider* > ProvidersModel::providers() { return mProviders; }
-int ProvidersModel::rowCount(const QModelIndex&) const { return mProviders.count(); }
-
