@@ -17,18 +17,18 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 #include "ipartcontroller.h"
-#include <klibloader.h>
+
 #include <QFile>
-#include <kservice.h>
-#include <kmimetypetrader.h>
-#include <kparts/factory.h>
-#include <kmimetype.h>
-#include <kparts/part.h>
-#include <kdebug.h>
+
+#include <KMimeTypeTrader>
+#include <KParts/Part>
+#include <KParts/ReadOnlyPart>
+#include <KService>
+
 
 namespace KDevelop {
-    
-IPartController::IPartController( QWidget* toplevel ) 
+
+IPartController::IPartController( QWidget* toplevel )
     : KParts::PartManager( toplevel, 0 )
 {
 }
@@ -61,10 +61,10 @@ KPluginFactory* IPartController::findPartFactory ( const QString& mimetype, cons
         {
             ptr = offers.first();
         }
-        KPluginLoader loader( QFile::encodeName( ptr->library() ) );
+        KPluginLoader loader( ptr->library() );
         return loader.factory();
     }
-                                                                                                  
+
     return 0;
 }
 
@@ -95,5 +95,4 @@ KParts::Part* IPartController::createPart ( const QString& mimetype, const QStri
 
 }
 
-#include "ipartcontroller.moc"
 
