@@ -26,19 +26,18 @@
  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  Boston, MA 02110-1301, USA.
 */
+
 #include "iplugin.h"
-#include <kglobal.h>
-#include <kglobalsettings.h>
-#include <kcomponentdata.h>
-#include <kiconloader.h>
-#include <kmainwindow.h>
-#include <kxmlguiwindow.h>
-#include <kxmlguifactory.h>
-#include <kactioncollection.h>
-#include <kdebug.h>
+
+#include <KActionCollection>
+#include <KMainWindow>
+#include <KXmlGuiWindow>
+#include <KXMLGUIFactory>
+
 #include "icore.h"
 #include "iplugincontroller.h"
 #include "iprojectcontroller.h"
+#include "iproject.h"
 #include "contextmenuextension.h"
 
 namespace KDevelop
@@ -48,44 +47,43 @@ class IPluginPrivate
 {
 public:
     IPluginPrivate(IPlugin *q)
-        : q(q), iconLoader(0)
+        : q(q)
     {}
 
     ~IPluginPrivate()
     {
-        delete iconLoader;
     }
 
-    void _k_guiClientAdded(KXMLGUIClient *client)
+    void guiClientAdded(KXMLGUIClient *client)
     {
-	if (client != q)
-	    return;
+        if (client != q)
+            return;
 
-	q->initializeGuiState();
-	_k_updateState();
+        q->initializeGuiState();
+        updateState();
     }
 
-    void _k_updateState()
+    void updateState()
     {
-	const int projectCount =
-	    ICore::self()->projectController()->projectCount();
+        const int projectCount =
+            ICore::self()->projectController()->projectCount();
 
-	IPlugin::ReverseStateChange reverse = IPlugin::StateNoReverse;
-	if (! projectCount)
-	    reverse = IPlugin::StateReverse;
+        IPlugin::ReverseStateChange reverse = IPlugin::StateNoReverse;
+        if (! projectCount)
+            reverse = IPlugin::StateReverse;
 
-	q->stateChanged(QLatin1String("has_project"), reverse);
+        q->stateChanged(QLatin1String("has_project"), reverse);
     }
 
     IPlugin *q;
     ICore *core;
-    KIconLoader* iconLoader;
-    QStringList m_extensions;
+    QVector<QByteArray> m_extensions;
 };
 
-IPlugin::IPlugin( const KComponentData &instance, QObject *parent )
-        : QObject( parent ),
-	  KXMLGUIClient(), d( new IPluginPrivate(this) )
+IPlugin::IPlugin( const QString &componentName, QObject *parent )
+    : QObject(parent)
+    , KXMLGUIClient()
+    , d(new IPluginPrivate(this))
 {
     // The following cast is safe, there's no component in KDevPlatform that
     // creates plugins except the plugincontroller. The controller passes
@@ -94,24 +92,26 @@ IPlugin::IPlugin( const KComponentData &instance, QObject *parent )
     // This is the only way to pass the Core pointer to the plugin during its
     // creation so plugins have access to ICore during their creation.
     d->core = static_cast<KDevelop::ICore*>(parent);
-    setComponentData( instance );
 
+    setComponentName(componentName, componentName);
+
+    auto clientAdded = [=] (KXMLGUIClient* client) {
+        d->guiClientAdded(client);
+    };
     foreach (KMainWindow* mw, KMainWindow::memberList()) {
         KXmlGuiWindow* guiWindow = qobject_cast<KXmlGuiWindow*>(mw);
         if (! guiWindow)
             continue;
 
-        connect(guiWindow->guiFactory(), SIGNAL(clientAdded(KXMLGUIClient*)),
-		this, SLOT(_k_guiClientAdded(KXMLGUIClient*)));
+        connect(guiWindow->guiFactory(), &KXMLGUIFactory::clientAdded,
+                this, clientAdded);
     }
 
-    connect(ICore::self()->projectController(),
-	    SIGNAL(projectOpened(KDevelop::IProject*)),
-	    this, SLOT(_k_updateState()));
-
-    connect(ICore::self()->projectController(),
-	    SIGNAL(projectClosed(KDevelop::IProject*)),
-	    this, SLOT(_k_updateState()));
+    auto updateState = [=] { d->updateState(); };
+    connect(ICore::self()->projectController(), &IProjectController::projectOpened,
+            this, updateState);
+    connect(ICore::self()->projectController(), &IProjectController::projectClosed,
+            this, updateState);
 }
 
 IPlugin::~IPlugin()
@@ -121,26 +121,6 @@ IPlugin::~IPlugin()
 
 void IPlugin::unload()
 {
-    ICore::self()->pluginController()->pluginUnloading(this);
-}
-
-KIconLoader *IPlugin::iconLoader() const
-{
-    if ( d->iconLoader == 0 ) {
-        d->iconLoader = new KIconLoader( componentData().componentName(), componentData().dirs() );
-        d->iconLoader->addAppDir( "kdevelop" );
-        connect(KGlobalSettings::self(), SIGNAL(iconChanged(int)),
-                this, SLOT(newIconLoader()));
-    }
-
-    return d->iconLoader;
-}
-
-void IPlugin::newIconLoader() const
-{
-    if (d->iconLoader) {
-        d->iconLoader->reconfigure( componentData().componentName(), componentData().dirs() );
-    }
 }
 
 ICore *IPlugin::core() const
@@ -150,18 +130,18 @@ ICore *IPlugin::core() const
 
 }
 
-QStringList KDevelop::IPlugin::extensions( ) const
+QVector<QByteArray> KDevelop::IPlugin::extensions( ) const
 {
-  return d->m_extensions;
+    return d->m_extensions;
 }
 
-void KDevelop::IPlugin::addExtension( const QString& ext )
+void KDevelop::IPlugin::addExtension( const QByteArray& ext )
 {
     d->m_extensions << ext;
 }
 
 KDevelop::ContextMenuExtension KDevelop::IPlugin::contextMenuExtension(
-        KDevelop::Context* )
+    KDevelop::Context* )
 {
     return KDevelop::ContextMenuExtension();
 }
@@ -169,26 +149,28 @@ KDevelop::ContextMenuExtension KDevelop::IPlugin::contextMenuExtension(
 void KDevelop::IPlugin::initializeGuiState()
 { }
 
-class CustomXmlGUIClient : public KXMLGUIClient {
-    public:
-        CustomXmlGUIClient(const KComponentData& data) {
-            setComponentData(data);
-        }
-        void setXmlFile(QString file) {
-            KXMLGUIClient::setXMLFile(file);
-        }
+class CustomXmlGUIClient : public KXMLGUIClient
+{
+public:
+    CustomXmlGUIClient(const QString& componentName) {
+        // TODO KF5: Get rid off this
+        setComponentName(componentName, componentName);
+    }
+    void setXmlFile(QString file) {
+        KXMLGUIClient::setXMLFile(file);
+    }
 };
 
 KXMLGUIClient* KDevelop::IPlugin::createGUIForMainWindow(Sublime::MainWindow* window)
 {
-    CustomXmlGUIClient* ret = new CustomXmlGUIClient(componentData());
+    CustomXmlGUIClient* ret = new CustomXmlGUIClient(componentName());
     QString file;
     createActionsForMainWindow(window, file, *ret->actionCollection());
 
     if(!ret->actionCollection()->isEmpty()) {
         Q_ASSERT(!file.isEmpty()); //A file must have been set
         ret->setXmlFile(file);
-    }else{
+    } else {
         delete ret;
         ret = 0;
     }
@@ -209,6 +191,23 @@ QString KDevelop::IPlugin::errorDescription() const
     return QString();
 }
 
-#include "iplugin.moc"
+int KDevelop::IPlugin::configPages() const
+{
+    return 0;
+}
 
+KDevelop::ConfigPage* KDevelop::IPlugin::configPage (int, QWidget*)
+{
+    return nullptr;
+}
 
+int KDevelop::IPlugin::perProjectConfigPages() const
+{
+    return 0;
+}
+
+KDevelop::ConfigPage* KDevelop::IPlugin::perProjectConfigPage(int, const ProjectConfigOptions&, QWidget*)
+{
+    return nullptr;
+}
+#include "moc_iplugin.cpp"
