@@ -27,15 +27,12 @@ Boston, MA 02110-1301, USA.
 #include <QtCore/QObject>
 #include <QtCore/QList>
 
-#include <kplugininfo.h>
-#include <kurl.h>
-#include <kservice.h>
+#include <KPluginMetaData>
 
 #include "iplugin.h"
 #include "interfacesexport.h"
 
 class QExtensionManager;
-class KMenu;
 
 namespace KDevelop
 {
@@ -77,14 +74,19 @@ public:
         Project ///< Indicates that the plugin is loaded with the first opened project
     };
 
-    IPluginController( QObject* parent = 0 );
+    explicit IPluginController( QObject* parent = 0 );
 
     virtual ~IPluginController();
 
     /**
      * Get the plugin info for a loaded plugin
      */
-    virtual KPluginInfo pluginInfo( const IPlugin* ) const = 0;
+    virtual KPluginMetaData pluginInfo(const IPlugin*) const = 0;
+
+    /**
+     * Find the KPluginMetaData structure for the given @p pluginId.
+     */
+    virtual KPluginMetaData infoForPluginId(const QString &pluginId) const = 0;
 
     /**
      * Get a list of currently loaded plugins
@@ -123,7 +125,7 @@ public:
      * @param constraints A map of constraints on other plugin info properties.
      * @return A KDevelop extension plugin for given service type or 0 if no plugin supports it
      */
-    Q_SCRIPTABLE virtual IPlugin *pluginForExtension(const QString &extension, const QString& pluginName = {}, const QVariantMap& constraints = {} ) = 0;
+    Q_SCRIPTABLE virtual IPlugin *pluginForExtension(const QString &extension, const QString& pluginName = {}, const QVariantMap& constraints = QVariantMap()) = 0;
 
      /**
      * Retrieve a list of plugins which supports the given extension interface.
@@ -134,7 +136,7 @@ public:
      * @param constraints A map of constraints on other plugin info properties.
      * @return A KDevelop extension plugin for given service type or 0 if no plugin supports it
      */
-    virtual QList<IPlugin*> allPluginsForExtension(const QString &extension, const QVariantMap& constraints = {}) = 0;
+    virtual QList<IPlugin*> allPluginsForExtension(const QString &extension, const QVariantMap& constraints = QVariantMap()) = 0;
 
      /**
      * Retrieve the plugin which supports given extension interface and
@@ -147,7 +149,8 @@ public:
      * @param pluginName The name of the plugin to load if multiple plugins for the extension exist, corresponds to the X-KDE-PluginInfo-Name
      * @return Pointer to the extension interface or 0 if no plugin supports it
       */
-    template<class Extension> Extension* extensionForPlugin( const QString &extension = "", const QString &pluginName = "") {
+    template<class Extension> Extension* extensionForPlugin( const QString &extension = {}, const QString &pluginName = {})
+    {
         QString ext;
         if( extension.isEmpty() ) {
             ext = qobject_interface_iid<Extension*>();
@@ -171,7 +174,7 @@ public:
      * @param constraints A map of constraints on other plugin info properties.
      * @return The list of plugin offers.
      */
-    virtual KPluginInfo::List queryExtensionPlugins(const QString &extension, const QVariantMap& constraints = {}) const = 0;
+    virtual QVector<KPluginMetaData> queryExtensionPlugins(const QString &extension, const QVariantMap& constraints = QVariantMap()) const = 0;
 
     virtual QList<ContextMenuExtension> queryPluginsForContextMenuExtensions( KDevelop::Context* context ) const = 0;
 
