@@ -22,13 +22,12 @@ Boston, MA 02110-1301, USA.
 
 #include "interfacesexport.h"
 #include <QtCore/QObject>
+#include <QUrl>
 
 #include <ksharedconfig.h>
-#include <kurl.h>
 
-struct QUuid;
+class QUuid;
 class QString;
-class KUrl;
 
 namespace KDevelop
 {
@@ -42,7 +41,7 @@ class KDEVPLATFORMINTERFACES_EXPORT ISession : public QObject
 {
     Q_OBJECT
 public:
-    ISession( QObject* parent = 0 );
+    explicit ISession( QObject* parent = 0 );
     virtual ~ISession();
 
     /**
@@ -52,10 +51,10 @@ public:
      */
     virtual QString description() const = 0;
     virtual QString name() const = 0;
-    virtual KUrl::List containedProjects() const = 0;
-    virtual void updateContainedProjects() = 0;
-    virtual KUrl pluginDataArea( const IPlugin* ) = 0;
-    virtual KSharedConfig::Ptr config() = 0;
+    virtual QList<QUrl> containedProjects() const = 0;
+    virtual void setContainedProjects( const QList<QUrl>& projects ) = 0;
+    virtual QUrl pluginDataArea( const IPlugin* ) = 0;
+    virtual KSharedConfigPtr config() = 0;
     virtual QUuid id() const = 0;
 
     /**
@@ -65,9 +64,14 @@ public:
      */
     virtual void setTemporary(bool temp) = 0;
     virtual bool isTemporary() const = 0;
+
+Q_SIGNALS:
+    void sessionUpdated( KDevelop::ISession* session );
 };
 
 }
 
+Q_DECLARE_METATYPE( KDevelop::ISession* )
+
 #endif
 
