@@ -19,37 +19,78 @@
 #ifndef KDEVPLATFORM_ISOURCEFORMATTER_H
 #define KDEVPLATFORM_ISOURCEFORMATTER_H
 
-#include <QtGui/QWidget>
-#include <QtCore/QStringList>
-#include <KDE/KMimeType>
+#include <QWidget>
+#include <QStringList>
+#include <QMimeType>
 
 #include "interfacesexport.h"
 
+class QUrl;
+
 namespace KDevelop
 {
 
 class KDEVPLATFORMINTERFACES_EXPORT SourceFormatterStyle
 {
 public:
-	SourceFormatterStyle() : m_usePreview(false) {};
-	SourceFormatterStyle( const QString& name ) : m_name(name) {}
-	void setContent( const QString& content ) { m_content = content; }
-	void setCaption( const QString& caption ) { m_caption = caption; }
-	QString content() const { return m_content; }
-	QString caption() const { return m_caption; }
-	QString name() const { return m_name; }
-	QString description() const { return m_description; }
-	void setDescription( const QString& desc ) { m_description = desc; }
-	bool usePreview() const { return m_usePreview; }
-	void setUsePreview(bool use) { m_usePreview = use; }
+	struct MimeHighlightPair {
+		QString mimeType;
+		QString highlightMode;
+	};
+	typedef QVector<MimeHighlightPair> MimeList;
+
+	SourceFormatterStyle();
+	explicit SourceFormatterStyle( const QString& name );
+	void setContent( const QString& content );
+	void setCaption( const QString& caption );
+	QString content() const;
+	QString caption() const;
+	QString name() const;
+	QString description() const;
+	void setDescription( const QString& desc );
+	bool usePreview() const;
+	void setUsePreview(bool use);
+
+	void setMimeTypes( const MimeList& types );
+	void setMimeTypes( const QStringList& types );
+
+	/// Provides the possibility to the item to return a better-suited
+	/// code sample. If empty, the default is used.
+	QString overrideSample() const;
+	void setOverrideSample( const QString& sample );
+
+	MimeList mimeTypes() const;
+	/// mime types as a QVariantList, type and mode separated by | in strings
+	QVariant mimeTypesVariant() const;
+	bool supportsLanguage(const QString& language) const;
+
+	/// get the language / highlight mode for a given @p mime
+	QString modeForMimetype(const QMimeType& mime) const;
+
+	/// Copy content, mime types and code sample from @p other.
+    void copyDataFrom(SourceFormatterStyle *other);
+
 private:
 	bool m_usePreview;
 	QString m_name;
 	QString m_caption;
 	QString m_content;
 	QString m_description;
+	QString m_overrideSample;
+	MimeList m_mimeTypes;
 };
 
+/**
+ * @brief An object describing a style associated with a plugin
+ *        which can deal with this style.
+ */
+struct SourceFormatterStyleItem {
+	QString engine;
+	SourceFormatterStyle style;
+};
+
+typedef QVector<SourceFormatterStyleItem> SourceFormatterItemList;
+
 /**
 * @short A widget to edit a style
 * A plugin should inherit this widget to create a widget to
@@ -61,7 +102,7 @@ class KDEVPLATFORMINTERFACES_EXPORT SettingsWidget : public QWidget
 		Q_OBJECT
 
 	public:
-		SettingsWidget(QWidget *parent = 0);
+		explicit SettingsWidget(QWidget *parent = 0);
 		virtual ~SettingsWidget();
 
 		/** This function is called after the creation of the dialog.
@@ -110,10 +151,6 @@ class KDEVPLATFORMINTERFACES_EXPORT ISourceFormatter
 		*/
 		virtual QString description() = 0;
 
-		/** \return The highlighting mode for Kate corresponding to this mime.
-		*/
-		virtual QString highlightModeForMime(const KMimeType::Ptr &mime) = 0;
-		
 		/** Formats using the current style.
 		 * @param text The text to format
 		 * @param url The URL to which the text belongs (its contents must not be changed).
@@ -122,7 +159,7 @@ class KDEVPLATFORMINTERFACES_EXPORT ISourceFormatter
 		 *
 		 * If the source-formatter cannot work correctly with the context, it will just return the input text.
 		*/
-		virtual QString formatSource(const QString &text, const KUrl& url, const KMimeType::Ptr &mime, const QString& leftContext = QString(), const QString& rightContext = QString()) = 0;
+		virtual QString formatSource(const QString &text, const QUrl& url, const QMimeType &mime, const QString& leftContext = QString(), const QString& rightContext = QString()) = 0;
 
 		/**
 		 * Format with the given style, this is mostly for the kcm to format the preview text
@@ -131,8 +168,8 @@ class KDEVPLATFORMINTERFACES_EXPORT ISourceFormatter
 		 */
 		virtual QString formatSourceWithStyle( SourceFormatterStyle,
 											   const QString& text,
-											   const KUrl& url,
-											   const KMimeType::Ptr &mime,
+											   const QUrl& url,
+											   const QMimeType &mime,
 											   const QString& leftContext = QString(),
 											   const QString& rightContext = QString() ) = 0;
 
@@ -142,11 +179,11 @@ class KDEVPLATFORMINTERFACES_EXPORT ISourceFormatter
 
 		/** \return The widget to edit a style.
 		*/
-		virtual SettingsWidget* editStyleWidget(const KMimeType::Ptr &mime) = 0;
+		virtual SettingsWidget* editStyleWidget(const QMimeType &mime) = 0;
 
 		/** \return The text used in the config dialog to preview the current style.
 		*/
-		virtual QString previewText(const KMimeType::Ptr &mime) = 0;
+		virtual QString previewText(const SourceFormatterStyle& style, const QMimeType &mime) = 0;
 
 		struct Indentation {
 			Indentation() : indentationTabWidth(0), indentWidth(0) {
@@ -155,7 +192,7 @@ class KDEVPLATFORMINTERFACES_EXPORT ISourceFormatter
 			bool isValid() const {
 				return indentationTabWidth != 0 || indentWidth != 0;
 			}
-			
+
 			// The length of one tab used for indentation.
 			// Zero if unknown, -1 if tabs should not be used for indentation
 			int indentationTabWidth;
@@ -167,7 +204,7 @@ class KDEVPLATFORMINTERFACES_EXPORT ISourceFormatter
 
 		/** \return The indentation of the style applicable for the given url.
 		*/
-		virtual Indentation indentation(const KUrl& url) = 0;
+		virtual Indentation indentation(const QUrl& url) = 0;
 
 		/** \return A string representing the map. Values are written in the form
 		* key=value and separated with ','.
@@ -188,6 +225,7 @@ class KDEVPLATFORMINTERFACES_EXPORT ISourceFormatter
 }
 
 Q_DECLARE_INTERFACE(KDevelop::ISourceFormatter, "org.kdevelop.ISourceFormatter")
+Q_DECLARE_TYPEINFO(KDevelop::SourceFormatterStyle::MimeHighlightPair, Q_MOVABLE_TYPE);
 
 #endif // KDEVPLATFORM_ISOURCEFORMATTER_H
 // kate: indent-mode cstyle; space-indent off; tab-width 4;
