@@ -27,7 +27,7 @@
 class QAction;
 
 template<class T>
-class KSharedPtr;
+class QExplicitlySharedDataPointer;
 
 namespace KParts {
     class MainWindow;
@@ -129,16 +129,6 @@ public:
     /*! @p status must implement KDevelop::IStatus */
     virtual void registerStatus(QObject* status) = 0;
 
-    /**
-     * Shows an assistant popup at bottom within the current central widget
-     * @p assistant the assistant that will be shown in a popup */
-    virtual void popUpAssistant(const KSharedPtr<IAssistant>& assistant) = 0;
-
-    /**
-     * Hides the assistant if it is currently being shown
-     */
-    virtual void hideAssistant() = 0;
-    
     /**
      * This is meant to be used by IDocument subclasses to initialize the
      * Sublime::Document.
@@ -157,7 +147,23 @@ public:
     /** @return area for currently active sublime mainwindow or 0 if
     no sublime mainwindow is active.*/
     virtual Sublime::Area *activeArea() = 0;
-        
+
+    /**
+     * Widget which is currently responsible for consuming special events in the UI
+     * (such as shortcuts)
+     *
+     * @sa IToolViewActionListener
+     * @return QWidget implementing the IToolViewActionListener interface
+     */
+    virtual QWidget* activeToolViewActionListener() const = 0;
+
+    /**
+     * @returns all areas in the shell
+     *
+     * @note there will be one per mainwindow, of each type, plus the default ones.
+     */
+    virtual QList<Sublime::Area*> allAreas() const = 0;
+
 protected:
     IUiController();
 };
