@@ -24,40 +24,35 @@
 #include "backgroundparser.h"
 
 #include <QList>
-#include <QFile>
-#include <QTimer>
 #include <QMutex>
-#include <QWaitCondition>
 #include <QMutexLocker>
+#include <QPointer>
+#include <QTimer>
 #include <QThread>
-#include <QtCore/QWeakPointer>
 
-#include <kdebug.h>
-#include <kglobal.h>
-#include <kconfiggroup.h>
-#include <ksharedconfig.h>
-#include <klocale.h>
+#include <KConfigGroup>
+#include <KSharedConfig>
+#include <KLocalizedString>
 
 #include <ktexteditor/document.h>
 
-#include <threadweaver/State.h>
-#include <threadweaver/ThreadWeaver.h>
-#include <threadweaver/JobCollection.h>
-#include <threadweaver/DebuggingAids.h>
+#include <ThreadWeaver/State>
+#include <ThreadWeaver/ThreadWeaver>
+#include <ThreadWeaver/DebuggingAids>
 
+#include <interfaces/icore.h>
+#include <interfaces/idocumentcontroller.h>
 #include <interfaces/ilanguagecontroller.h>
-#include <interfaces/ilanguage.h>
+#include <interfaces/ilanguagesupport.h>
+#include <interfaces/isession.h>
+#include <interfaces/iproject.h>
+#include <interfaces/iprojectcontroller.h>
 
-#include "../interfaces/ilanguagesupport.h"
+#include "util/debug.h"
 
 #include "parsejob.h"
-#include "parserdependencypolicy.h"
 #include <editor/modificationrevisionset.h>
-#include <interfaces/icore.h>
-#include <qcoreapplication.h>
-#include <interfaces/idocumentcontroller.h>
-#include <interfaces/isession.h>
-#include <interfaces/iprojectcontroller.h>
+
 
 const bool separateThreadForHighPriority = true;
 
@@ -102,12 +97,12 @@ inline bool isValidURL(const KDevelop::IndexedString& url)
     if (url.isEmpty()) {
         return false;
     }
-    KUrl original = url.toUrl();
-    if (!original.isValid()) {
+    QUrl original = url.toUrl();
+    if (!original.isValid() || original.isRelative() || original.fileName().isEmpty()) {
+        qCWarning(LANGUAGE) << "INVALID URL ENCOUNTERED:" << url << original;
         return false;
     }
-    KUrl cleaned = original;
-    cleaned.cleanPath();
+    QUrl cleaned = original.adjusted(QUrl::NormalizePathSegments);
     return original == cleaned;
 }
 }
@@ -132,7 +127,7 @@ public:
 
         ThreadWeaver::setDebugLevel(true, 1);
 
-        QObject::connect(&m_timer, SIGNAL(timeout()), m_parser, SLOT(parseDocuments()));
+        QObject::connect(&m_timer, &QTimer::timeout, m_parser, &BackgroundParser::parseDocuments);
     }
 
     void startTimerThreadSafe() {
@@ -141,14 +136,8 @@ public:
 
     ~BackgroundParserPrivate()
     {
-        suspend();
-
-        m_weaver.dequeue();
-        m_weaver.requestAbort();
-        m_weaver.finish();
-
         // Release dequeued jobs
-        QHashIterator<IndexedString, ParseJob*> it = m_parseJobs;
+        QHashIterator<IndexedString, ThreadWeaver::QObjectDecorator*> it = m_parseJobs;
         while (it.hasNext()) {
             it.next();
             delete it.value();
@@ -162,14 +151,16 @@ public:
             return;
         // Create delayed jobs, that is, jobs for documents which have been changed
         // by the user.
-        QList<ParseJob*> jobs;
+        QList<ThreadWeaver::JobPointer> jobs;
 
         // Before starting a new job, first wait for all higher-priority ones to finish.
         // That way, parse job priorities can be used for dependency handling.
         int bestRunningPriority = BackgroundParser::WorstPriority;
-        foreach (const ParseJob* job, m_parseJobs) {
-            if (job->respectsSequentialProcessing() && job->parsePriority() < bestRunningPriority) {
-                bestRunningPriority = job->parsePriority();
+        foreach (const ThreadWeaver::QObjectDecorator* decorator, m_parseJobs) {
+            const ParseJob* parseJob = dynamic_cast<const ParseJob*>(decorator->job());
+            Q_ASSERT(parseJob);
+            if (parseJob->respectsSequentialProcessing() && parseJob->parsePriority() < bestRunningPriority) {
+                bestRunningPriority = parseJob->parsePriority();
             }
         }
 
@@ -207,18 +198,19 @@ public:
                     continue;
                 }
 
-                kDebug(9505) << "creating parse-job" << it->toUrl() << "new count of active parse-jobs:" << m_parseJobs.count() + 1;
-                const QString elidedPathString = elidedPathLeft(it->toUrl().toLocalFile(), 70);
+                qCDebug(LANGUAGE) << "creating parse-job" << *it << "new count of active parse-jobs:" << m_parseJobs.count() + 1;
+                const QString elidedPathString = elidedPathLeft(it->str(), 70);
                 emit m_parser->showMessage(m_parser, i18n("Parsing: %1", elidedPathString));
 
-                ParseJob* job = createParseJob(*it, parsePlan.features(), parsePlan.notifyWhenReady(), parsePlan.priority());
+                ThreadWeaver::QObjectDecorator* decorator = createParseJob(*it, parsePlan.features(), parsePlan.notifyWhenReady(), parsePlan.priority());
 
                 if(m_parseJobs.count() == m_threads+1 && !specialParseJob)
-                    specialParseJob = job; //This parse-job is allocated into the reserved thread
+                    specialParseJob = decorator; //This parse-job is allocated into the reserved thread
 
-                if(job) {
-                    job->setSequentialProcessingFlags(parsePlan.sequentialProcessingFlags());
-                    jobs.append(job);
+                if (decorator) {
+                    ParseJob* parseJob = dynamic_cast<ParseJob*>(decorator->job());
+                    parseJob->setSequentialProcessingFlags(parsePlan.sequentialProcessingFlags());
+                    jobs.append(ThreadWeaver::JobPointer(decorator));
                     // update the currently best processed priority, if the created job respects sequential processing
                     if (   parsePlan.sequentialProcessingFlags() & ParseJob::RespectsSequentialProcessing
                         && parsePlan.priority() < bestRunningPriority)
@@ -252,7 +244,7 @@ public:
 
         // Ok, enqueueing is fine because m_parseJobs contains all of the jobs now
 
-        foreach (ParseJob* job, jobs)
+        foreach (ThreadWeaver::JobPointer job, jobs)
             m_weaver.enqueue(job);
 
         m_parser->updateProgressBar();
@@ -265,21 +257,18 @@ public:
         }
     }
 
-    ParseJob* createParseJob(const IndexedString& url, TopDUContext::Features features, const QList<QWeakPointer<QObject> >& notifyWhenReady, int priority = 0)
+    ThreadWeaver::QObjectDecorator* createParseJob(const IndexedString& url, TopDUContext::Features features, const QList<QPointer<QObject> >& notifyWhenReady, int priority = 0)
     {
         ///FIXME: use IndexedString in the other APIs as well! Esp. for createParseJob!
-        KUrl kUrl = url.toUrl();
-        QList<ILanguage*> languages = m_languageController->languagesForUrl(kUrl);
-        foreach (ILanguage* language, languages) {
+        QUrl qUrl = url.toUrl();
+        auto languages = m_languageController->languagesForUrl(qUrl);
+        foreach (const auto& language, languages) {
             if(!language) {
-                kWarning() << "got zero language for" << kUrl;
+                qCWarning(LANGUAGE) << "got zero language for" << qUrl;
                 continue;
             }
-            if(!language->languageSupport()) {
-                kWarning() << "language has no language support assigned:" << language->name();
-                continue;
-            }
-            ParseJob* job = language->languageSupport()->createParseJob(url);
+
+            ParseJob* job = language->createParseJob(url);
             if (!job) {
                 continue; // Language part did not produce a valid ParseJob.
             }
@@ -288,33 +277,35 @@ public:
             job->setMinimumFeatures(features);
             job->setNotifyWhenReady(notifyWhenReady);
 
-            QObject::connect(job, SIGNAL(done(ThreadWeaver::Job*)),
-                                m_parser, SLOT(parseComplete(ThreadWeaver::Job*)));
-            QObject::connect(job, SIGNAL(failed(ThreadWeaver::Job*)),
-                                m_parser, SLOT(parseComplete(ThreadWeaver::Job*)));
-            QObject::connect(job, SIGNAL(progress(KDevelop::ParseJob*,float,QString)),
-                                m_parser, SLOT(parseProgress(KDevelop::ParseJob*,float,QString)), Qt::QueuedConnection);
+            ThreadWeaver::QObjectDecorator* decorator = new ThreadWeaver::QObjectDecorator(job);
 
-            m_parseJobs.insert(url, job);
+            QObject::connect(decorator, &ThreadWeaver::QObjectDecorator::done,
+                             m_parser, &BackgroundParser::parseComplete);
+            QObject::connect(decorator, &ThreadWeaver::QObjectDecorator::failed,
+                             m_parser, &BackgroundParser::parseComplete);
+            QObject::connect(job, &ParseJob::progress,
+                             m_parser, &BackgroundParser::parseProgress, Qt::QueuedConnection);
+
+            m_parseJobs.insert(url, decorator);
 
             ++m_maxParseJobs;
 
             // TODO more thinking required here to support multiple parse jobs per url (where multiple language plugins want to parse)
-            return job;
+            return decorator;
         }
 
         if(languages.isEmpty())
-            kDebug() << "found no languages for url" << kUrl;
+            qCDebug(LANGUAGE) << "found no languages for url" << qUrl;
         else
-            kDebug() << "could not create parse-job for url" << kUrl;
+            qCDebug(LANGUAGE) << "could not create parse-job for url" << qUrl;
 
         //Notify that we failed
-        typedef QWeakPointer<QObject> Notify;
+        typedef QPointer<QObject> Notify;
         foreach(const Notify& n, notifyWhenReady)
             if(n)
                 QMetaObject::invokeMethod(n.data(), "updateReady", Qt::QueuedConnection, Q_ARG(KDevelop::IndexedString, url), Q_ARG(KDevelop::ReferencedTopDUContext, ReferencedTopDUContext()));
 
-        return 0;
+        return nullptr;
     }
 
 
@@ -325,14 +316,14 @@ public:
         KConfigGroup config(ICore::self()->activeSession()->config(), "Background Parser");
 
         // stay backwards compatible
-        KConfigGroup oldConfig(KGlobal::config(), "Background Parser");
+        KConfigGroup oldConfig(KSharedConfig::openConfig(), "Background Parser");
 #define BACKWARDS_COMPATIBLE_ENTRY(entry, default) \
 config.readEntry(entry, oldConfig.readEntry(entry, default))
 
         m_delay = BACKWARDS_COMPATIBLE_ENTRY("Delay", 500);
         m_timer.setInterval(m_delay);
         m_threads = 0;
-        m_parser->setThreadCount(BACKWARDS_COMPATIBLE_ENTRY("Number of Threads", 1));
+        m_parser->setThreadCount(BACKWARDS_COMPATIBLE_ENTRY("Number of Threads", QThread::idealThreadCount()));
 
         resume();
 
@@ -345,8 +336,8 @@ config.readEntry(entry, oldConfig.readEntry(entry, default))
 
     void suspend()
     {
-        bool s = m_weaver.state().stateId() == ThreadWeaver::Suspended ||
-                 m_weaver.state().stateId() == ThreadWeaver::Suspending;
+        bool s = m_weaver.state()->stateId() == ThreadWeaver::Suspended ||
+                 m_weaver.state()->stateId() == ThreadWeaver::Suspending;
 
         if (s) { // Already suspending
             return;
@@ -358,8 +349,8 @@ config.readEntry(entry, oldConfig.readEntry(entry, default))
 
     void resume()
     {
-        bool s = m_weaver.state().stateId() == ThreadWeaver::Suspended ||
-                 m_weaver.state().stateId() == ThreadWeaver::Suspending;
+        bool s = m_weaver.state()->stateId() == ThreadWeaver::Suspended ||
+                 m_weaver.state()->stateId() == ThreadWeaver::Suspending;
 
         if (m_timer.isActive() && !s) { // Not suspending
             return;
@@ -373,16 +364,16 @@ config.readEntry(entry, oldConfig.readEntry(entry, default))
     ILanguageController* m_languageController;
 
     //Current parse-job that is executed in the additional thread
-    QWeakPointer<ParseJob> specialParseJob;
+    QPointer<QObject> specialParseJob;
 
     QTimer m_timer;
     int m_delay;
     int m_threads;
 
     bool m_shuttingDown;
-    
+
     struct DocumentParseTarget {
-        QWeakPointer<QObject> notifyWhenReady;
+        QPointer<QObject> notifyWhenReady;
         int priority;
         TopDUContext::Features features;
         ParseJob::SequentialProcessingFlags sequentialProcessingFlags;
@@ -423,8 +414,8 @@ config.readEntry(entry, oldConfig.readEntry(entry, default))
             return ret;
         }
 
-        QList<QWeakPointer<QObject> > notifyWhenReady() const {
-            QList<QWeakPointer<QObject> > ret;
+        QList<QPointer<QObject> > notifyWhenReady() const {
+            QList<QPointer<QObject> > ret;
 
             foreach(const DocumentParseTarget &target, targets)
                 if(target.notifyWhenReady)
@@ -438,7 +429,7 @@ config.readEntry(entry, oldConfig.readEntry(entry, default))
     // The documents ordered by priority
     QMap<int, QSet<IndexedString> > m_documentsForPriority;
     // Currently running parse jobs
-    QHash<IndexedString, ParseJob*> m_parseJobs;
+    QHash<IndexedString, ThreadWeaver::QObjectDecorator*> m_parseJobs;
     // A change tracker for each managed document
     QHash<IndexedString, DocumentChangeTracker*> m_managed;
     // The url for each managed document. Those may temporarily differ from the real url.
@@ -446,8 +437,7 @@ config.readEntry(entry, oldConfig.readEntry(entry, default))
     // Projects currently in progress of loading
     QSet<IProject*> m_loadingProjects;
 
-    ThreadWeaver::Weaver m_weaver;
-    ParserDependencyPolicy m_dependencyPolicy;
+    ThreadWeaver::Queue m_weaver;
 
     QMutex m_mutex;
 
@@ -458,7 +448,7 @@ config.readEntry(entry, oldConfig.readEntry(entry, default))
 };
 
 inline uint qHash(const BackgroundParserPrivate::DocumentParseTarget& target) {
-    return target.features * 7 + target.priority * 13 + target.sequentialProcessingFlags * 17 
+    return target.features * 7 + target.priority * 13 + target.sequentialProcessingFlags * 17
                                + reinterpret_cast<size_t>(target.notifyWhenReady.data());
 };
 
@@ -466,22 +456,22 @@ BackgroundParser::BackgroundParser(ILanguageController *languageController)
     : QObject(languageController), d(new BackgroundParserPrivate(this, languageController))
 {
     Q_ASSERT(ICore::self()->documentController());
-    connect(ICore::self()->documentController(), SIGNAL(documentLoaded(KDevelop::IDocument*)), this, SLOT(documentLoaded(KDevelop::IDocument*)));
-    connect(ICore::self()->documentController(), SIGNAL(documentUrlChanged(KDevelop::IDocument*)), this, SLOT(documentUrlChanged(KDevelop::IDocument*)));
-    connect(ICore::self()->documentController(), SIGNAL(documentClosed(KDevelop::IDocument*)), this, SLOT(documentClosed(KDevelop::IDocument*)));
-    connect(ICore::self(), SIGNAL(aboutToShutdown()), this, SLOT(aboutToQuit()));
+    connect(ICore::self()->documentController(), &IDocumentController::documentLoaded, this, &BackgroundParser::documentLoaded);
+    connect(ICore::self()->documentController(), &IDocumentController::documentUrlChanged, this, &BackgroundParser::documentUrlChanged);
+    connect(ICore::self()->documentController(), &IDocumentController::documentClosed, this, &BackgroundParser::documentClosed);
+    connect(ICore::self(), &ICore::aboutToShutdown, this, &BackgroundParser::aboutToQuit);
 
     bool connected = QObject::connect(ICore::self()->projectController(),
-                                      SIGNAL(projectAboutToBeOpened(KDevelop::IProject*)),
-                                      this, SLOT(projectAboutToBeOpened(KDevelop::IProject*)));
+                                      &IProjectController::projectAboutToBeOpened,
+                                      this, &BackgroundParser::projectAboutToBeOpened);
     Q_ASSERT(connected);
     connected = QObject::connect(ICore::self()->projectController(),
-                                 SIGNAL(projectOpened(KDevelop::IProject*)),
-                                 this, SLOT(projectOpened(KDevelop::IProject*)));
+                                 &IProjectController::projectOpened,
+                                 this, &BackgroundParser::projectOpened);
     Q_ASSERT(connected);
     connected = QObject::connect(ICore::self()->projectController(),
-                                 SIGNAL(projectOpeningAborted(KDevelop::IProject*)),
-                                 this, SLOT(projectOpeningAborted(KDevelop::IProject*)));
+                                 &IProjectController::projectOpeningAborted,
+                                 this, &BackgroundParser::projectOpeningAborted);
     Q_ASSERT(connected);
     Q_UNUSED(connected);
 }
@@ -501,19 +491,6 @@ QString BackgroundParser::statusName() const
     return i18n("Background Parser");
 }
 
-void BackgroundParser::clear(QObject* parent)
-{
-    QMutexLocker lock(&d->m_mutex);
-
-    QHashIterator<IndexedString, ParseJob*> it = d->m_parseJobs;
-    while (it.hasNext()) {
-        it.next();
-        if (it.value()->parent() == parent) {
-            it.value()->requestAbort();
-        }
-    }
-}
-
 void BackgroundParser::loadSettings()
 {
     d->loadSettings();
@@ -534,7 +511,7 @@ void BackgroundParser::revertAllRequests(QObject* notifyWhenReady)
         d->m_documentsForPriority[it.value().priority()].remove(it.key());
 
         foreach ( const BackgroundParserPrivate::DocumentParseTarget& target, (*it).targets ) {
-            if ( target.notifyWhenReady.data() == notifyWhenReady ) {
+            if ( notifyWhenReady && target.notifyWhenReady.data() == notifyWhenReady ) {
                 (*it).targets.remove(target);
             }
         }
@@ -553,7 +530,7 @@ void BackgroundParser::revertAllRequests(QObject* notifyWhenReady)
 
 void BackgroundParser::addDocument(const IndexedString& url, TopDUContext::Features features, int priority, QObject* notifyWhenReady, ParseJob::SequentialProcessingFlags flags)
 {
-//     kDebug(9505) << "BackgroundParser::addDocument" << url.toUrl();
+//     qCDebug(LANGUAGE) << "BackgroundParser::addDocument" << url.toUrl();
     Q_ASSERT(isValidURL(url));
     QMutexLocker lock(&d->m_mutex);
     {
@@ -561,7 +538,7 @@ void BackgroundParser::addDocument(const IndexedString& url, TopDUContext::Featu
         target.priority = priority;
         target.features = features;
         target.sequentialProcessingFlags = flags;
-        target.notifyWhenReady = QWeakPointer<QObject>(notifyWhenReady);
+        target.notifyWhenReady = QPointer<QObject>(notifyWhenReady);
 
         QHash<IndexedString, BackgroundParserPrivate::DocumentParsePlan>::iterator it = d->m_documents.find(url);
 
@@ -572,7 +549,7 @@ void BackgroundParser::addDocument(const IndexedString& url, TopDUContext::Featu
             it.value().targets << target;
             d->m_documentsForPriority[it.value().priority()].insert(url);
         }else{
-//             kDebug(9505) << "BackgroundParser::addDocument: queuing" << cleanedUrl;
+//             qCDebug(LANGUAGE) << "BackgroundParser::addDocument: queuing" << cleanedUrl;
             d->m_documents[url].targets << target;
             d->m_documentsForPriority[d->m_documents[url].priority()].insert(url);
             ++d->m_maxParseJobs; //So the progress-bar waits for this document
@@ -619,30 +596,27 @@ void BackgroundParser::parseDocuments()
     d->parseDocumentsInternal();
 }
 
-void BackgroundParser::parseComplete(ThreadWeaver::Job* job)
+void BackgroundParser::parseComplete(const ThreadWeaver::JobPointer& job)
 {
-    if (ParseJob* parseJob = qobject_cast<ParseJob*>(job)) {
+    auto decorator = dynamic_cast<ThreadWeaver::QObjectDecorator*>(job.data());
+    Q_ASSERT(decorator);
+    ParseJob* parseJob = dynamic_cast<ParseJob*>(decorator->job());
+    Q_ASSERT(parseJob);
+    emit parseJobFinished(parseJob);
 
-        emit parseJobFinished(parseJob);
+    {
+        QMutexLocker lock(&d->m_mutex);
 
-        {
-            {
-                QMutexLocker lock(&d->m_mutex);
+        d->m_parseJobs.remove(parseJob->document());
 
-                d->m_parseJobs.remove(parseJob->document());
+        d->m_jobProgress.remove(parseJob);
 
-                d->m_jobProgress.remove(parseJob);
-
-                ++d->m_doneParseJobs;
-                updateProgressBar();
-            }
-            //Unlock the mutex before deleting the parse-job, because the parse-job
-            //has a virtual destructor that may lock the duchain, leading to deadlocks
-            delete parseJob;
-        }
-        //Continue creating more parse-jobs
-        QMetaObject::invokeMethod(this, "parseDocuments", Qt::QueuedConnection);
+        ++d->m_doneParseJobs;
+        updateProgressBar();
     }
+
+    //Continue creating more parse-jobs
+    QMetaObject::invokeMethod(this, "parseDocuments", Qt::QueuedConnection);
 }
 
 void BackgroundParser::disableProcessing()
@@ -706,7 +680,7 @@ void BackgroundParser::updateProgressBar()
 {
     if (d->m_doneParseJobs >= d->m_maxParseJobs) {
         if(d->m_doneParseJobs > d->m_maxParseJobs) {
-            kDebug() << "m_doneParseJobs larger than m_maxParseJobs:" << d->m_doneParseJobs << d->m_maxParseJobs;
+            qCDebug(LANGUAGE) << "m_doneParseJobs larger than m_maxParseJobs:" << d->m_doneParseJobs << d->m_maxParseJobs;
         }
         d->m_doneParseJobs = 0;
         d->m_maxParseJobs = 0;
@@ -719,17 +693,13 @@ void BackgroundParser::updateProgressBar()
     }
 }
 
-ParserDependencyPolicy* BackgroundParser::dependencyPolicy() const
-{
-    return &d->m_dependencyPolicy;
-}
-
 ParseJob* BackgroundParser::parseJobForDocument(const IndexedString& document) const
 {
     Q_ASSERT(isValidURL(document));
 
     QMutexLocker lock(&d->m_mutex);
-    return d->m_parseJobs.value(document, 0);
+    auto decorator = d->m_parseJobs.value(document);
+    return decorator ? dynamic_cast<ParseJob*>(decorator->job()) : nullptr;
 }
 
 void BackgroundParser::setThreadCount(int threadCount)
@@ -756,7 +726,7 @@ void BackgroundParser::setDelay(int miliseconds)
 QList< IndexedString > BackgroundParser::managedDocuments()
 {
     QMutexLocker l(&d->m_mutex);
-    
+
     return d->m_managed.keys();
 }
 
@@ -789,7 +759,7 @@ void BackgroundParser::documentClosed(IDocument* document)
         IndexedString url(d->m_managedTextDocumentUrls[textDocument]);
         Q_ASSERT(d->m_managed.contains(url));
 
-        kDebug() << "removing" << url.str() << "from background parser";
+        qCDebug(LANGUAGE) << "removing" << url.str() << "from background parser";
         delete d->m_managed[url];
         d->m_managedTextDocumentUrls.remove(textDocument);
         d->m_managed.remove(url);
@@ -802,33 +772,33 @@ void BackgroundParser::documentLoaded( IDocument* document )
     if(document->textDocument() && document->textDocument()->url().isValid())
     {
         KTextEditor::Document* textDocument = document->textDocument();
-        
+
         IndexedString url(document->url());
         // Some debugging because we had issues with this
-        
+
         if(d->m_managed.contains(url) && d->m_managed[url]->document() == textDocument)
         {
-            kDebug() << "Got redundant documentLoaded from" << document->url() << textDocument;
+            qCDebug(LANGUAGE) << "Got redundant documentLoaded from" << document->url() << textDocument;
             return;
         }
-        
-        kDebug() << "Creating change tracker for " << document->url();
-        
-        
+
+        qCDebug(LANGUAGE) << "Creating change tracker for " << document->url();
+
+
         Q_ASSERT(!d->m_managed.contains(url));
         Q_ASSERT(!d->m_managedTextDocumentUrls.contains(textDocument));
-        
+
         d->m_managedTextDocumentUrls[textDocument] = url;
         d->m_managed.insert(url, new DocumentChangeTracker(textDocument));
     }else{
-        kDebug() << "NOT creating change tracker for" << document->url();
+        qCDebug(LANGUAGE) << "NOT creating change tracker for" << document->url();
     }
 }
 
 void BackgroundParser::documentUrlChanged(IDocument* document)
 {
     documentClosed(document);
-    
+
     // Only call documentLoaded if the file wasn't renamed to a filename that is already tracked.
     if(document->textDocument() && !d->m_managed.contains(IndexedString(document->textDocument()->url())))
         documentLoaded(document);
@@ -858,5 +828,4 @@ void BackgroundParser::projectOpeningAborted(IProject* project)
 Q_DECLARE_TYPEINFO(KDevelop::BackgroundParserPrivate::DocumentParseTarget, Q_MOVABLE_TYPE);
 Q_DECLARE_TYPEINFO(KDevelop::BackgroundParserPrivate::DocumentParsePlan, Q_MOVABLE_TYPE);
 
-#include "backgroundparser.moc"
 
