@@ -29,7 +29,7 @@
 #include <QtCore/QMutex>
 #include <QtCore/QHash>
 
-#include "../languageexport.h"
+#include <language/languageexport.h>
 #include <interfaces/istatus.h>
 #include <language/duchain/topducontext.h>
 #include "parsejob.h"
@@ -38,8 +38,9 @@ class QMutex;
 
 namespace ThreadWeaver
 {
-class Weaver;
 class Job;
+class QObjectDecorator;
+class Weaver;
 }
 
 namespace KDevelop
@@ -65,10 +66,10 @@ class KDEVPLATFORMLANGUAGE_EXPORT BackgroundParser : public QObject, public ISta
     Q_INTERFACES( KDevelop::IStatus )
 
 public:
-    BackgroundParser(ILanguageController *languageController);
+    explicit BackgroundParser(ILanguageController *languageController);
     ~BackgroundParser();
 
-    virtual QString statusName() const;
+    virtual QString statusName() const override;
 
     enum {
         BestPriority = -10000,  ///Best possible job-priority. No jobs should actually have this.
@@ -78,11 +79,6 @@ public:
         WorstPriority = 100000  ///Worst possible job-priority.
     };
 
-    /**
-     * Abort or dequeue all current running jobs with the specified @p parent.
-     */
-    Q_SCRIPTABLE void clear(QObject* parent);
-
     /**
      * Queries the background parser as to whether there is currently
      * a parse job for @p document, and if so, returns it.
@@ -93,11 +89,6 @@ public:
      */
     Q_SCRIPTABLE ParseJob* parseJobForDocument(const IndexedString& document) const;
 
-    /**
-     * The dependency policy which applies to all jobs (it is applied automatically).
-     */
-    Q_SCRIPTABLE ParserDependencyPolicy* dependencyPolicy() const;
-
     /**
      * Set how many ThreadWeaver threads the background parser should set up and use.
      */
@@ -137,11 +128,11 @@ Q_SIGNALS:
     void parseJobFinished(KDevelop::ParseJob* job);
 
     // Implementations of IStatus signals
-    void clearMessage( KDevelop::IStatus* );
-    void showMessage( KDevelop::IStatus*, const QString & message, int timeout = 0);
-    void hideProgress( KDevelop::IStatus* );
-    void showProgress( KDevelop::IStatus*, int minimum, int maximum, int value);
-    void showErrorMessage( const QString&, int );
+    void clearMessage( KDevelop::IStatus* ) override;
+    void showMessage( KDevelop::IStatus*, const QString & message, int timeout = 0) override;
+    void hideProgress( KDevelop::IStatus* ) override;
+    void showProgress( KDevelop::IStatus*, int minimum, int maximum, int value) override;
+    void showErrorMessage( const QString&, int ) override;
 
 public Q_SLOTS:
 
@@ -157,6 +148,7 @@ public Q_SLOTS:
 
     ///Reverts all requests that were made for the given notification-target.
     ///priorities and requested features will be reverted as well.
+    ///When @p notifyWhenReady is set to a nullptr, all requests will be reverted.
     void revertAllRequests(QObject* notifyWhenReady);
 
     /**
@@ -202,9 +194,12 @@ public Q_SLOTS:
     ///You need to check whether @param url is queued before calling this function.
     int priorityForDocument(const IndexedString& url) const;
 
-    ///Returns the number of currently active or queued jobs
+    ///Returns the number of queued jobs (not yet running nor submitted to ThreadWeaver)
     int queuedCount() const;
 
+    ///Returns true if there are no jobs running nor queued anywhere
+    bool isIdle() const;
+
     void documentClosed(KDevelop::IDocument*);
     void documentLoaded(KDevelop::IDocument*);
     void documentUrlChanged(KDevelop::IDocument*);
@@ -212,7 +207,7 @@ public Q_SLOTS:
     void loadSettings();
 
 protected Q_SLOTS:
-    void parseComplete(ThreadWeaver::Job *job);
+    void parseComplete(const ThreadWeaver::JobPointer& job);
     void parseProgress(KDevelop::ParseJob*, float value, QString text);
     void startTimer();
     void aboutToQuit();
