@@ -24,17 +24,16 @@
 #include <QMutex>
 #include <QMutexLocker>
 
-#include <kdebug.h>
 #include <ktexteditor/document.h>
 #include <ktexteditor/movinginterface.h>
 
-#include <interfaces/foregroundlock.h>
+#include <util/foregroundlock.h>
 #include <editor/modificationrevisionset.h>
-#include <duchain/indexedstring.h>
+#include <serialization/indexedstring.h>
 #include <interfaces/icore.h>
 #include <interfaces/ilanguagecontroller.h>
-#include <interfaces/ilanguage.h>
 #include "backgroundparser.h"
+#include "util/debug.h"
 #include <QApplication>
 
 // Can be used to disable the 'clever' updating logic that ignores whitespace-only changes and such.
@@ -59,15 +58,11 @@ using namespace KTextEditor;
  *             -> Maybe alter the file-modification caches directly
  * */
 
-namespace {
-    QRegExp whiteSpaceRegExp("\\s");
-};
-
 namespace KDevelop
 {
 
 DocumentChangeTracker::DocumentChangeTracker( KTextEditor::Document* document )
-    : m_needUpdate(false), m_changedRange(0), m_document(document), m_moving(0), m_whitespaceSensitivity(ILanguageSupport::Insensitive)
+    : m_needUpdate(false), m_document(document), m_moving(0), m_whitespaceSensitivity(ILanguageSupport::Insensitive)
 {
     m_url = IndexedString(document->url());
     Q_ASSERT(document);
@@ -75,25 +70,24 @@ DocumentChangeTracker::DocumentChangeTracker( KTextEditor::Document* document )
 
     // Check whether a language plugin is tracking the document which belongs to a
     // whitespace-sensitive language (e.g. python)
-    foreach ( KDevelop::ILanguage* lang, ICore::self()->languageController()->languagesForUrl(document->url()) ) {
-        if ( ! lang || ! lang->languageSupport() ) {
+    foreach (const auto& lang, ICore::self()->languageController()->languagesForUrl(document->url())) {
+        if (!lang) {
             continue;
         }
-        if ( lang->languageSupport()->whitespaceSensititivy() >= m_whitespaceSensitivity ) {
-            m_whitespaceSensitivity = lang->languageSupport()->whitespaceSensititivy();
+        if (lang->whitespaceSensititivy() >= m_whitespaceSensitivity) {
+            m_whitespaceSensitivity = lang->whitespaceSensititivy();
         }
     }
 
-    connect(document, SIGNAL(textInserted(KTextEditor::Document*,KTextEditor::Range)), SLOT(textInserted(KTextEditor::Document*,KTextEditor::Range)));
-    connect(document, SIGNAL(textRemoved(KTextEditor::Document*,KTextEditor::Range,QString)), SLOT(textRemoved(KTextEditor::Document*,KTextEditor::Range,QString)));
-    connect(document, SIGNAL(textChanged(KTextEditor::Document*,KTextEditor::Range,QString,KTextEditor::Range)), SLOT(textChanged(KTextEditor::Document*,KTextEditor::Range,QString,KTextEditor::Range)));
-    connect(document, SIGNAL(destroyed(QObject*)), SLOT(documentDestroyed(QObject*)));
-    connect(document, SIGNAL(documentSavedOrUploaded(KTextEditor::Document*,bool)), SLOT(documentSavedOrUploaded(KTextEditor::Document*,bool)));
+    connect(document, &Document::textInserted, this, &DocumentChangeTracker::textInserted);
+    connect(document, &Document::textRemoved, this, &DocumentChangeTracker::textRemoved);
+    connect(document, &Document::destroyed, this, &DocumentChangeTracker::documentDestroyed);
+    connect(document, &Document::documentSavedOrUploaded, this, &DocumentChangeTracker::documentSavedOrUploaded);
 
     m_moving = dynamic_cast<KTextEditor::MovingInterface*>(document);
     Q_ASSERT(m_moving);
-    m_changedRange = m_moving->newMovingRange(KTextEditor::Range(), KTextEditor::MovingRange::ExpandLeft | KTextEditor::MovingRange::ExpandRight);
 
+    // can't use new connect syntax here, MovingInterface is not a QObject
     connect(m_document, SIGNAL(aboutToInvalidateMovingInterfaceContent(KTextEditor::Document*)), this, SLOT(aboutToInvalidateMovingInterfaceContent(KTextEditor::Document*)));
 
     ModificationRevision::setEditorRevisionForFile(m_url, m_moving->revision());
@@ -101,32 +95,23 @@ DocumentChangeTracker::DocumentChangeTracker( KTextEditor::Document* document )
     reset();
 }
 
-QList< QPair< SimpleRange, QString > > DocumentChangeTracker::completions() const
+QList< QPair< KTextEditor::Range, QString > > DocumentChangeTracker::completions() const
 {
     VERIFY_FOREGROUND_LOCKED
 
-    QList< QPair< SimpleRange , QString > > ret;
+    QList< QPair< KTextEditor::Range , QString > > ret;
     return ret;
 }
 
-Range DocumentChangeTracker::changedRange() const
-{
-    VERIFY_FOREGROUND_LOCKED
-
-    return m_changedRange->toRange();
-}
-
 void DocumentChangeTracker::reset()
 {
     VERIFY_FOREGROUND_LOCKED
 
     // We don't reset the insertion here, as it may continue
     m_needUpdate = false;
-    m_changedRange->setRange(KTextEditor::Range::invalid());
 
     m_revisionAtLastReset = acquireRevision(m_moving->revision());
     Q_ASSERT(m_revisionAtLastReset);
-    m_textAtLastReset = m_document->text();
 }
 
 RevisionReference DocumentChangeTracker::currentRevision()
@@ -143,13 +128,6 @@ RevisionReference DocumentChangeTracker::revisionAtLastReset() const
     return m_revisionAtLastReset;
 }
 
-QString DocumentChangeTracker::textAtLastReset() const
-{
-    VERIFY_FOREGROUND_LOCKED
-
-    return m_textAtLastReset;
-}
-
 bool DocumentChangeTracker::needUpdate() const
 {
     VERIFY_FOREGROUND_LOCKED
@@ -157,7 +135,7 @@ bool DocumentChangeTracker::needUpdate() const
     return m_needUpdate;
 }
 
-bool DocumentChangeTracker::checkMergeTokens(const KTextEditor::Range& range, QString /*oldText*/, QString /*newText*/)
+bool DocumentChangeTracker::checkMergeTokens(const KTextEditor::Range& range)
 {
     ///@todo Improve this so that it notices when we wrapped in/out of a line-comment
     ///@todo Improve this so that it really checks whether some merge-able tokens have been moved together
@@ -171,42 +149,8 @@ bool DocumentChangeTracker::checkMergeTokens(const KTextEditor::Range& range, QS
     return false;
 }
 
-void DocumentChangeTracker::textChanged( Document* document, Range /*oldRange*/, QString oldText, Range newRange )
+void DocumentChangeTracker::updateChangedRange()
 {
-    m_currentCleanedInsertion.clear();
-
-    QString newText = document->text(newRange);
-
-    QString oldTextWithoutWhitespace = oldText;
-    oldTextWithoutWhitespace.remove(whiteSpaceRegExp);
-
-    QString newTextWithoutWhitespace = newText;
-    newTextWithoutWhitespace.remove(whiteSpaceRegExp);
-
-    if(oldTextWithoutWhitespace.isEmpty() && newTextWithoutWhitespace.isEmpty() && checkMergeTokens(newRange, oldText, newText))
-    {
-        // Only whitespace was changed, no update is required
-    }else{
-        m_needUpdate = true;
-    }
-
-    #ifdef ALWAYS_UPDATE
-    m_needUpdate = true;
-    #endif
-
-    m_currentCleanedInsertion.clear();
-    m_lastInsertionPosition = KTextEditor::Cursor::invalid();
-
-    updateChangedRange(newRange);
-}
-
-void DocumentChangeTracker::updateChangedRange( Range changed )
-{
-    if(m_changedRange->toRange() == KTextEditor::Range::invalid())
-        m_changedRange->setRange(changed);
-    else
-        m_changedRange->setRange(changed.encompass(m_changedRange->toRange()));
-
 //     Q_ASSERT(m_moving->revision() != m_revisionAtLastReset->revision()); // May happen after reload
 
     // When reloading, textRemoved is called with an invalid m_document->url(). For that reason, we use m_url instead.
@@ -217,31 +161,40 @@ void DocumentChangeTracker::updateChangedRange( Range changed )
         ICore::self()->languageController()->backgroundParser()->addDocument(m_url, TopDUContext::AllDeclarationsContextsAndUses);
 }
 
-void DocumentChangeTracker::textInserted( Document* document, Range range )
+static Cursor cursorAdd(Cursor c, const QString& text)
 {
-    QString text = document->text(range);
+    c.setLine(c.line() + text.count('\n'));
+    c.setColumn(c.column() + (text.length() - qMin(0, text.lastIndexOf('\n'))));
+    return c;
+}
 
+static bool whitespaceOnly(const QString& string)
+{
+    for (QChar c : string) {
+        if (!c.isSpace()) {
+            return false;
+        }
+    }
+    return true;
+}
+
+void DocumentChangeTracker::textInserted( Document* document, const Cursor& cursor, const QString& text)
+{
     if ( m_whitespaceSensitivity == ILanguageSupport::Sensitive ) {
         m_needUpdate = true;
     }
 
+    /// TODO: get this data from KTextEditor directly, make its signal public
+    Range range(cursor, cursorAdd(cursor, text));
+
     if ( ! m_needUpdate ) {
-        QString textWithoutWhitespace = text;
-        textWithoutWhitespace.remove(whiteSpaceRegExp);
-        bool changeIsWhitespaceOnly = textWithoutWhitespace.isEmpty() && checkMergeTokens(range, "", text);
+        bool changeIsWhitespaceOnly = whitespaceOnly(text) && checkMergeTokens(range);
         if ( m_whitespaceSensitivity == ILanguageSupport::IndentOnly && changeIsWhitespaceOnly ) {
             // The language requires a document to be re-parsed if the indentation changes (e.g. python),
             // so do some special checks here to see if that is the case.
             if ( changeIsWhitespaceOnly ) {
-                QString fromLineBeginning = document->text(Range(Cursor(range.start().line(), 0), range.end()));
-                bool inIndent = true;
-                for ( int i = fromLineBeginning.length() - 1; i >= 0; --i ) {
-                    if ( ! fromLineBeginning.at(i).isSpace() ) {
-                        inIndent = false;
-                        break;
-                    }
-                }
-                if ( inIndent ) {
+                QString fromLineBeginning = document->text(Range(Cursor(cursor.line(), 0), range.end() - Cursor{0, 1}));
+                if ( fromLineBeginning.trimmed().isEmpty() ) {
                     m_needUpdate = true;
                 }
             }
@@ -256,26 +209,30 @@ void DocumentChangeTracker::textInserted( Document* document, Range range )
     m_needUpdate = true;
     #endif
 
-    if(m_lastInsertionPosition == KTextEditor::Cursor::invalid() || m_lastInsertionPosition == range.start())
+    if(!m_lastInsertionPosition.isValid() || m_lastInsertionPosition == cursor)
     {
         m_currentCleanedInsertion.append(text);
         m_lastInsertionPosition = range.end();
     }
 
-    updateChangedRange(range);
+    updateChangedRange();
 }
 
-void DocumentChangeTracker::textRemoved( Document* /*document*/, Range oldRange, QString oldText )
+void DocumentChangeTracker::textRemoved( Document* document, const Range& oldRange, const QString& oldText )
 {
-    QString text = oldText;
-
-    QString textWithoutWhitespace = text;
-    textWithoutWhitespace.remove(whiteSpaceRegExp);
-
-    if(textWithoutWhitespace.isEmpty() && checkMergeTokens(Range(oldRange.start(), oldRange.start()), oldText, ""))
+    if (whitespaceOnly(oldText) && checkMergeTokens(Range(oldRange.start(), oldRange.start())))
     {
-        // Only whitespace was changed, no update is required
-    }else{
+        // Only whitespace was changed, no update is required eventually
+        if ( m_whitespaceSensitivity == ILanguageSupport::Sensitive ) {
+            m_needUpdate = true;
+        }
+        else if ( m_whitespaceSensitivity == ILanguageSupport::IndentOnly ) {
+            // check text from the beginning of the line
+            if ( document->text({{oldRange.start().line(), 0}, oldRange.end()}).trimmed().isEmpty() ) {
+                m_needUpdate = true;
+            }
+        }
+    } else {
         m_needUpdate = true; // If we've inserted something else than whitespace, an update is required
     }
 
@@ -286,7 +243,7 @@ void DocumentChangeTracker::textRemoved( Document* /*document*/, Range oldRange,
     m_currentCleanedInsertion.clear();
     m_lastInsertionPosition = KTextEditor::Cursor::invalid();
 
-    updateChangedRange(oldRange);
+    updateChangedRange();
 }
 
 void DocumentChangeTracker::documentSavedOrUploaded(KTextEditor::Document* doc,bool)
@@ -298,7 +255,6 @@ void DocumentChangeTracker::documentDestroyed( QObject* )
 {
     m_document = 0;
     m_moving = 0;
-    m_changedRange = 0;
 }
 
 DocumentChangeTracker::~DocumentChangeTracker()
@@ -320,7 +276,7 @@ MovingInterface* DocumentChangeTracker::documentMovingInterface() const
 void DocumentChangeTracker::aboutToInvalidateMovingInterfaceContent ( Document* )
 {
     // Release all revisions! They must not be used any more.
-    kDebug() << "clearing all revisions";
+    qCDebug(LANGUAGE) << "clearing all revisions";
     m_revisionLocks.clear();
     m_revisionAtLastReset = RevisionReference();
     ModificationRevision::setEditorRevisionForFile(m_url, 0);
@@ -351,22 +307,22 @@ KDevelop::CursorInRevision DocumentChangeTracker::transformBetweenRevisions(KDev
     return cursor;
 }
 
-RangeInRevision DocumentChangeTracker::transformToRevision(SimpleRange range, qint64 toRevision) const
+RangeInRevision DocumentChangeTracker::transformToRevision(KTextEditor::Range range, qint64 toRevision) const
 {
     return transformBetweenRevisions(RangeInRevision::castFromSimpleRange(range), -1, toRevision);
 }
 
-CursorInRevision DocumentChangeTracker::transformToRevision(SimpleCursor cursor, qint64 toRevision, MovingCursor::InsertBehavior behavior) const
+CursorInRevision DocumentChangeTracker::transformToRevision(KTextEditor::Cursor cursor, qint64 toRevision, MovingCursor::InsertBehavior behavior) const
 {
     return transformBetweenRevisions(CursorInRevision::castFromSimpleCursor(cursor), -1, toRevision, behavior);
 }
 
-SimpleRange DocumentChangeTracker::transformToCurrentRevision(RangeInRevision range, qint64 fromRevision) const
+KTextEditor::Range DocumentChangeTracker::transformToCurrentRevision(RangeInRevision range, qint64 fromRevision) const
 {
     return transformBetweenRevisions(range, fromRevision, -1).castToSimpleRange();
 }
 
-SimpleCursor DocumentChangeTracker::transformToCurrentRevision(CursorInRevision cursor, qint64 fromRevision, MovingCursor::InsertBehavior behavior) const
+KTextEditor::Cursor DocumentChangeTracker::transformToCurrentRevision(CursorInRevision cursor, qint64 fromRevision, MovingCursor::InsertBehavior behavior) const
 {
     return transformBetweenRevisions(cursor, fromRevision, -1, behavior).castToSimpleCursor();
 }
@@ -431,7 +387,7 @@ void DocumentChangeTracker::unlockRevision(qint64 revision)
     QMap< qint64, int >::iterator it = m_revisionLocks.find(revision);
     if(it == m_revisionLocks.end())
     {
-        kDebug() << "cannot unlock revision" << revision << ", probably the revisions have been cleared";
+        qCDebug(LANGUAGE) << "cannot unlock revision" << revision << ", probably the revisions have been cleared";
         return;
     }
     --(*it);
@@ -518,23 +474,23 @@ CursorInRevision RevisionLockerAndClearer::transformFromRevision(const KDevelop:
     return m_p->m_tracker->transformBetweenRevisions(cursor, fromRevision, toRevision, behavior);
 }
 
-SimpleRange RevisionLockerAndClearer::transformToCurrentRevision(const KDevelop::RangeInRevision& range) const
+KTextEditor::Range RevisionLockerAndClearer::transformToCurrentRevision(const KDevelop::RangeInRevision& range) const
 {
     return transformToRevision(range, KDevelop::RevisionLockerAndClearer::Ptr()).castToSimpleRange();
 }
 
-SimpleCursor RevisionLockerAndClearer::transformToCurrentRevision(const KDevelop::CursorInRevision& cursor,
+KTextEditor::Cursor RevisionLockerAndClearer::transformToCurrentRevision(const KDevelop::CursorInRevision& cursor,
                                                                   MovingCursor::InsertBehavior behavior) const
 {
     return transformToRevision(cursor, KDevelop::RevisionLockerAndClearer::Ptr(), behavior).castToSimpleCursor();
 }
 
-RangeInRevision RevisionLockerAndClearer::transformFromCurrentRevision(const KDevelop::SimpleRange& range) const
+RangeInRevision RevisionLockerAndClearer::transformFromCurrentRevision(const KTextEditor::Range& range) const
 {
     return transformFromRevision(RangeInRevision::castFromSimpleRange(range), RevisionReference());
 }
 
-CursorInRevision RevisionLockerAndClearer::transformFromCurrentRevision(const KDevelop::SimpleCursor& cursor,
+CursorInRevision RevisionLockerAndClearer::transformFromCurrentRevision(const KTextEditor::Cursor& cursor,
                                                                         MovingCursor::InsertBehavior behavior) const
 {
     return transformFromRevision(CursorInRevision::castFromSimpleCursor(cursor), RevisionReference(), behavior);
