@@ -22,12 +22,13 @@
 #ifndef KDEVPLATFORM_DOCUMENTCHANGETRACKER_H
 #define KDEVPLATFORM_DOCUMENTCHANGETRACKER_H
 
-#include "../languageexport.h"
+#include <language/languageexport.h>
+#include <QExplicitlySharedDataPointer>
+#include <QPointer>
 #include <QPair>
-#include <language/editor/simplerange.h>
 #include <ktexteditor/movingrange.h>
 #include <language/editor/rangeinrevision.h>
-#include <language/duchain/indexedstring.h>
+#include <serialization/indexedstring.h>
 #include <language/interfaces/ilanguagesupport.h>
 
 namespace KTextEditor
@@ -51,9 +52,9 @@ class RevisionLockerAndClearerPrivate;
  * Helper class that locks a revision, and clears it on its destruction within the foreground thread.
  * Just delete it using deleteLater().
  * */
-class KDEVPLATFORMLANGUAGE_EXPORT RevisionLockerAndClearer : public KShared {
+class KDEVPLATFORMLANGUAGE_EXPORT RevisionLockerAndClearer : public QSharedData {
 public:
-    typedef KSharedPtr<RevisionLockerAndClearer> Ptr;
+    typedef QExplicitlySharedDataPointer<RevisionLockerAndClearer> Ptr;
 
     ~RevisionLockerAndClearer();
 
@@ -82,12 +83,12 @@ public:
     /**
       * Transforms the given range from this revision into the current revision.
       */
-    SimpleRange transformToCurrentRevision(const RangeInRevision& range) const;
+    KTextEditor::Range transformToCurrentRevision(const RangeInRevision& range) const;
 
     /**
     * Transforms the given cursor from this revision into the current revision.
     */
-    SimpleCursor transformToCurrentRevision(const CursorInRevision& cursor,
+    KTextEditor::Cursor transformToCurrentRevision(const CursorInRevision& cursor,
                                             KTextEditor::MovingCursor::InsertBehavior behavior = KTextEditor::MovingCursor::StayOnInsert) const;
 
     /**
@@ -105,12 +106,12 @@ public:
     /**
     * Transforms the given range from the current revision into this revision.
     */
-    RangeInRevision transformFromCurrentRevision(const SimpleRange& range) const;
+    RangeInRevision transformFromCurrentRevision(const KTextEditor::Range& range) const;
 
     /**
     * Transforms the given cursor from the current revision into this revision.
     */
-    CursorInRevision transformFromCurrentRevision(const SimpleCursor& cursor,
+    CursorInRevision transformFromCurrentRevision(const KTextEditor::Cursor& cursor,
                                                   KTextEditor::MovingCursor::InsertBehavior behavior = KTextEditor::MovingCursor::StayOnInsert) const;
 
 private:
@@ -142,14 +143,14 @@ class KDEVPLATFORMLANGUAGE_EXPORT DocumentChangeTracker : public QObject
 {
     Q_OBJECT
 public:
-    DocumentChangeTracker( KTextEditor::Document* document );
+    explicit DocumentChangeTracker( KTextEditor::Document* document );
     virtual ~DocumentChangeTracker();
 
     /**
      * Completions of the users current edits that are supposed to complete
      * not-yet-finished statements, like for example for-loops for parsing.
      * */
-    virtual QList<QPair<KDevelop::SimpleRange, QString> > completions() const;
+    virtual QList<QPair<KTextEditor::Range, QString> > completions() const;
 
     /**
      * Resets the tracking to the current revision.
@@ -167,21 +168,11 @@ public:
      * */
     RevisionReference revisionAtLastReset() const;
 
-    /**
-     * Returns the document text at the last reset
-     * */
-    QString textAtLastReset() const;
-
     /**
      * Returns the current revision (which is not locked by the tracker)
      * */
     RevisionReference currentRevision();
 
-    /**
-     * Returns the range that was changed since the last reset
-     * */
-    virtual KTextEditor::Range changedRange() const;
-
     /**
      * Whether the changes that happened since the last reset are significant enough to require an update
      * */
@@ -226,16 +217,15 @@ public:
     RangeInRevision transformBetweenRevisions(RangeInRevision range, qint64 fromRevision, qint64 toRevision) const;
     CursorInRevision transformBetweenRevisions(CursorInRevision cursor, qint64 fromRevision, qint64 toRevision, KTextEditor::MovingCursor::InsertBehavior behavior = KTextEditor::MovingCursor::StayOnInsert) const;
 
-    SimpleRange transformToCurrentRevision(RangeInRevision range, qint64 fromRevision) const;
-    SimpleCursor transformToCurrentRevision(CursorInRevision cursor, qint64 fromRevision, KTextEditor::MovingCursor::InsertBehavior behavior = KTextEditor::MovingCursor::StayOnInsert) const;
+    KTextEditor::Range transformToCurrentRevision(RangeInRevision range, qint64 fromRevision) const;
+    KTextEditor::Cursor transformToCurrentRevision(CursorInRevision cursor, qint64 fromRevision, KTextEditor::MovingCursor::InsertBehavior behavior = KTextEditor::MovingCursor::StayOnInsert) const;
 
     /// Transform the range from the current revision into the given one
-    RangeInRevision transformToRevision(SimpleRange range, qint64 toRevision) const;
+    RangeInRevision transformToRevision(KTextEditor::Range range, qint64 toRevision) const;
     /// Transform the cursor from the current revision into the given one
-    CursorInRevision transformToRevision(SimpleCursor cursor, qint64 toRevision, KTextEditor::MovingCursor::InsertBehavior behavior = KTextEditor::MovingCursor::StayOnInsert) const;
+    CursorInRevision transformToRevision(KTextEditor::Cursor cursor, qint64 toRevision, KTextEditor::MovingCursor::InsertBehavior behavior = KTextEditor::MovingCursor::StayOnInsert) const;
 
 protected:
-    QString m_textAtLastReset;
     RevisionReference m_revisionAtLastReset;
     bool m_needUpdate;
     QString m_currentCleanedInsertion;
@@ -246,17 +236,15 @@ protected:
     KTextEditor::MovingInterface* m_moving;
     KDevelop::IndexedString m_url;
 
-    void updateChangedRange(KTextEditor::Range changed);
+    void updateChangedRange();
 public slots:
-    virtual void textInserted( KTextEditor::Document*,KTextEditor::Range );
-    virtual void textRemoved( KTextEditor::Document* document, KTextEditor::Range oldRange, QString oldText );
-    virtual void textChanged( KTextEditor::Document* document, KTextEditor::Range oldRange, QString oldText, KTextEditor::Range newRange );
+    virtual void textInserted( KTextEditor::Document* document, const KTextEditor::Cursor& position, const QString& inserted );
+    virtual void textRemoved( KTextEditor::Document* document, const KTextEditor::Range& range, const QString& oldText );
     void documentDestroyed( QObject* );
     void aboutToInvalidateMovingInterfaceContent ( KTextEditor::Document* document );
     void documentSavedOrUploaded(KTextEditor::Document*,bool);
 private:
-
-    virtual bool checkMergeTokens(const KTextEditor::Range& range, QString oldText, QString newText);
+    bool checkMergeTokens(const KTextEditor::Range& range);
 
     friend class RevisionLockerAndClearerPrivate;
     void lockRevision(qint64 revision);
