@@ -22,36 +22,34 @@
 
 #include "parsejob.h"
 
-#include <cassert>
-#include <fcntl.h>
-#include <sys/stat.h>
-#include <sys/mman.h>
-
 #include <QFile>
 #include <QByteArray>
 #include <QMutex>
 #include <QMutexLocker>
+#include <threadweaver/qobjectdecorator.h>
 #include <QApplication>
+#include <QDebug>
 
-#include <kdebug.h>
-#include <klocale.h>
+#include <KLocalizedString>
+#include <KFormat>
 #include <ktexteditor/movinginterface.h>
 
 #include "backgroundparser.h"
-#include "parserdependencypolicy.h"
+#include "util/debug.h"
 #include "duchain/topducontext.h"
 
 #include "duchain/duchainlock.h"
 #include "duchain/duchain.h"
 #include "duchain/parsingenvironment.h"
 
-#include <interfaces/foregroundlock.h>
+#include <util/foregroundlock.h>
 #include <interfaces/icore.h>
 #include <interfaces/ilanguagecontroller.h>
 #include <codegen/coderepresentation.h>
 #include <duchain/declaration.h>
 #include <duchain/use.h>
 #include <interfaces/icodehighlighting.h>
+#include <duchain/problem.h>
 
 
 using namespace KTextEditor;
@@ -69,8 +67,8 @@ public:
     ParseJobPrivate(const IndexedString& url_, ILanguageSupport* languageSupport_) :
           url( url_ )
         , languageSupport( languageSupport_ )
+        , abortRequested( 0 )
         , hasReadContents( false )
-        , abortRequested( false )
         , aborted( false )
         , features( TopDUContext::VisibleDeclarationsAndContexts )
         , parsePriority( 0 )
@@ -87,31 +85,33 @@ public:
     IndexedString url;
     ILanguageSupport* languageSupport;
 
-    QMutex abortMutex;
-
     ParseJob::Contents contents;
 
+    QAtomicInt abortRequested;
+
     bool hasReadContents : 1;
-    volatile bool abortRequested : 1;
     bool aborted : 1;
     TopDUContext::Features features;
-    QList<QWeakPointer<QObject> > notify;
-    QWeakPointer<DocumentChangeTracker> tracker;
+    QList<QPointer<QObject> > notify;
+    QPointer<DocumentChangeTracker> tracker;
     RevisionReference revision;
     RevisionReference previousRevision;
 
     int parsePriority;
     ParseJob::SequentialProcessingFlags sequentialProcessingFlags;
+    ThreadWeaver::QObjectDecorator* decorator;
 };
 
 ParseJob::ParseJob( const IndexedString& url, KDevelop::ILanguageSupport* languageSupport )
-        : ThreadWeaver::JobSequence(),
+        : ThreadWeaver::Sequence(),
         d(new ParseJobPrivate(url, languageSupport))
-{}
+{
+    d->decorator = new ThreadWeaver::QObjectDecorator(this);
+}
 
 ParseJob::~ParseJob()
 {
-    typedef QWeakPointer<QObject> QObjectPointer;
+    typedef QPointer<QObject> QObjectPointer;
     foreach(const QObjectPointer &p, d->notify) {
         if(p) {
             QMetaObject::invokeMethod(p.data(), "updateReady", Qt::QueuedConnection, Q_ARG(KDevelop::IndexedString, d->url), Q_ARG(KDevelop::ReferencedTopDUContext, d->duContext));
@@ -201,25 +201,21 @@ ReferencedTopDUContext ParseJob::duChain() const
 
 bool ParseJob::abortRequested() const
 {
-    QMutexLocker lock(&d->abortMutex);
-
-    return d->abortRequested;
+    return d->abortRequested.load();
 }
 
 void ParseJob::requestAbort()
 {
-    QMutexLocker lock(&d->abortMutex);
-
-    d->abortRequested = true;
+    d->abortRequested = 1;
 }
 
 void ParseJob::abortJob()
 {
     d->aborted = true;
-    setFinished(true);
+    setStatus(Status_Aborted);
 }
 
-void ParseJob::setNotifyWhenReady(const QList< QWeakPointer< QObject > >& notify
+void ParseJob::setNotifyWhenReady(const QList<QPointer< QObject > >& notify
 ) {
     d->notify = notify;
 }
@@ -252,7 +248,7 @@ KDevelop::ProblemPointer ParseJob::readContents()
     if(artificialCodeRepresentationExists(document())) {
         CodeRepresentation::Ptr repr = createCodeRepresentation(document());
         d->contents.contents = repr->text().toUtf8();
-        kDebug() << "took contents for " << document().str() << " from artificial code-representation";
+        qCDebug(LANGUAGE) << "took contents for " << document().str() << " from artificial code-representation";
         return KDevelop::ProblemPointer();
     }
 
@@ -268,7 +264,7 @@ KDevelop::ProblemPointer ParseJob::readContents()
             t->reset(); // Reset the tracker to the current revision
             Q_ASSERT(t->revisionAtLastReset());
 
-            d->contents.contents = t->textAtLastReset().toUtf8();
+            d->contents.contents = t->document()->text().toUtf8();
             d->contents.modification = KDevelop::ModificationRevision( lastModified, t->revisionAtLastReset()->revision() );
 
             d->revision = t->acquireRevision(d->contents.modification.revision);
@@ -280,15 +276,17 @@ KDevelop::ProblemPointer ParseJob::readContents()
 
         static const int maximumFileSize = 5 * 1024 * 1024; // 5 MB
         if (fileInfo.size() > maximumFileSize) {
+            KFormat f;
+
             KDevelop::ProblemPointer p(new Problem());
-            p->setSource(KDevelop::ProblemData::Disk);
+            p->setSource(IProblem::Disk);
             p->setDescription(i18nc("%1: filename", "Skipped file that is too large: '%1'", localFile ));
             p->setExplanation(i18nc("%1: file size, %2: limit file size",
                                     "The file is %1 and exceeds the limit of %2.",
-                                    KGlobal::locale()->formatByteSize(fileInfo.size()),
-                                    KGlobal::locale()->formatByteSize(maximumFileSize)));
-            p->setFinalLocation(DocumentRange(document(), SimpleRange::invalid()));
-            kWarning( 9007 ) << p->description() << p->explanation();
+                                    f.formatByteSize(fileInfo.size()),
+                                    f.formatByteSize(maximumFileSize)));
+            p->setFinalLocation(DocumentRange(document(), KTextEditor::Range::invalid()));
+            qCWarning(LANGUAGE) << p->description() << p->explanation();
             return p;
         }
         QFile file( localFile );
@@ -296,7 +294,7 @@ KDevelop::ProblemPointer ParseJob::readContents()
         if ( !file.open( QIODevice::ReadOnly ) )
         {
             KDevelop::ProblemPointer p(new Problem());
-            p->setSource(KDevelop::ProblemData::Disk);
+            p->setSource(IProblem::Disk);
             p->setDescription(i18n( "Could not open file '%1'", localFile ));
             switch (file.error()) {
               case QFile::ReadError:
@@ -311,9 +309,9 @@ KDevelop::ProblemPointer ParseJob::readContents()
               default:
                   break;
             }
-            p->setFinalLocation(DocumentRange(document(), SimpleRange::invalid()));
+            p->setFinalLocation(DocumentRange(document(), KTextEditor::Range::invalid()));
 
-            kWarning( 9007 ) << "Could not open file" << document().str() << "(path" << localFile << ")" ;
+            qCWarning(LANGUAGE) << "Could not open file" << document().str() << "(path" << localFile << ")" ;
 
             return p;
         }
@@ -324,12 +322,6 @@ KDevelop::ProblemPointer ParseJob::readContents()
         file.close();
     }
 
-    // To make the parsing more robust, we add some zeroes to the end of the buffer.
-    d->contents.contents.push_back((char)0);
-    d->contents.contents.push_back((char)0);
-    d->contents.contents.push_back((char)0);
-    d->contents.contents.push_back((char)0);
-
     return KDevelop::ProblemPointer();
 }
 
@@ -344,7 +336,7 @@ struct MovingRangeTranslator : public DUChainVisitor
     MovingRangeTranslator(qint64 _source, qint64 _target, MovingInterface* _moving) : source(_source), target(_target), moving(_moving) {
     }
 
-    virtual void visit(DUContext* context) {
+    virtual void visit(DUContext* context) override {
         translateRange(context);
         ///@todo Also map import-positions
         // Translate uses
@@ -357,7 +349,7 @@ struct MovingRangeTranslator : public DUChainVisitor
         }
     }
 
-    virtual void visit(Declaration* declaration) {
+    virtual void visit(Declaration* declaration) override {
         translateRange(declaration);
     }
 
@@ -392,7 +384,7 @@ void ParseJob::translateDUChainToRevision(TopDUContext* context)
 
     if(targetRevision == -1)
     {
-        kDebug() << "invalid target revision" << targetRevision;
+        qCDebug(LANGUAGE) << "invalid target revision" << targetRevision;
         return;
     }
 
@@ -408,14 +400,14 @@ void ParseJob::translateDUChainToRevision(TopDUContext* context)
 
         if(sourceRevision == -1)
         {
-            kDebug() << "invalid source revision" << sourceRevision;
+            qCDebug(LANGUAGE) << "invalid source revision" << sourceRevision;
             return;
         }
     }
 
     if(sourceRevision > targetRevision)
     {
-        kDebug() << "for document" << document().str() << ": source revision is higher than target revision:" << sourceRevision << " > " << targetRevision;
+        qCDebug(LANGUAGE) << "for document" << document().str() << ": source revision is higher than target revision:" << sourceRevision << " > " << targetRevision;
         return;
     }
 
@@ -424,19 +416,19 @@ void ParseJob::translateDUChainToRevision(TopDUContext* context)
     {
         if(!d->previousRevision)
         {
-            kDebug() << "not translating because there is no valid predecessor-revision";
+            qCDebug(LANGUAGE) << "not translating because there is no valid predecessor-revision";
             return;
         }
 
         if(sourceRevision != d->previousRevision->revision() || !d->previousRevision->valid())
         {
-            kDebug() << "not translating because the document revision does not match the tracker start revision (maybe the document was cleared)";
+            qCDebug(LANGUAGE) << "not translating because the document revision does not match the tracker start revision (maybe the document was cleared)";
             return;
         }
 
         if(!t->holdingRevision(sourceRevision) || !t->holdingRevision(targetRevision))
         {
-            kDebug() << "lost one of the translation revisions, not doing the map";
+            qCDebug(LANGUAGE) << "lost one of the translation revisions, not doing the map";
             return;
         }
 
@@ -481,8 +473,8 @@ bool ParseJob::isUpdateRequired(const IndexedString& languageString)
         if (file->language() != languageString) {
             continue;
         }
-        if (!file->needsUpdate() && file->featuresSatisfied(minimumFeatures())) {
-            kDebug() << "Already up to date" << document().str();
+        if (!file->needsUpdate(environment()) && file->featuresSatisfied(minimumFeatures())) {
+            qCDebug(LANGUAGE) << "Already up to date" << document().str();
             setDuChain(file->topContext());
             lock.unlock();
             highlightDUChain();
@@ -493,6 +485,11 @@ bool ParseJob::isUpdateRequired(const IndexedString& languageString)
     return !abortRequested();
 }
 
+const ParsingEnvironment* ParseJob::environment() const
+{
+    return nullptr;
+}
+
 void ParseJob::highlightDUChain()
 {
     ENSURE_CHAIN_NOT_LOCKED
@@ -510,15 +507,23 @@ void ParseJob::highlightDUChain()
 
 ControlFlowGraph* ParseJob::controlFlowGraph()
 {
-    return 0;
+    return nullptr;
 }
 
 DataAccessRepository* ParseJob::dataAccessInformation()
 {
-    return 0;
+    return nullptr;
 }
 
+bool ParseJob::hasTracker() const
+{
+    return d->tracker;
+}
+
+ThreadWeaver::QObjectDecorator* ParseJob::decorator() const
+{
+    return d->decorator;
+}
 
 }
 
-#include "parsejob.moc"
