@@ -23,17 +23,22 @@
 #ifndef KDEVPLATFORM_PARSEJOB_H
 #define KDEVPLATFORM_PARSEJOB_H
 
-#include <QtCore/QWeakPointer>
-#include <KDE/KUrl>
+#include <QPointer>
 
-#include <threadweaver/JobSequence.h>
+#include <ThreadWeaver/Sequence>
 
-#include "../duchain/indexedstring.h"
+#include <serialization/indexedstring.h>
 #include <language/duchain/topducontext.h>
 #include <language/editor/modificationrevision.h>
 
+namespace ThreadWeaver {
+class QObjectDecorator;
+}
+
 namespace KDevelop
 {
+
+class ParsingEnvironment;
 class ControlFlowGraph;
 class DataAccessRepository;
 class BackgroundParser;
@@ -45,7 +50,7 @@ class ReferencedTopDUContext;
  *
  * In your language plugin, don't forget to use acquire an UrlParseLock before starting to the actual parsing.
  */
-class KDEVPLATFORMLANGUAGE_EXPORT ParseJob : public ThreadWeaver::JobSequence
+class KDEVPLATFORMLANGUAGE_EXPORT ParseJob : public QObject, public ThreadWeaver::Sequence
 {
     Q_OBJECT
 
@@ -74,7 +79,7 @@ public:
         RespectsSequentialProcessing = 2,
         FullSequentialProcessing = 3
     };
-    Q_DECLARE_FLAGS(SequentialProcessingFlags, SequentialProcessingFlag);
+    Q_DECLARE_FLAGS(SequentialProcessingFlags, SequentialProcessingFlag)
 
     ///Sets the priority of this parse job. This is just for the purpose of
     ///reading it later, and does not affect the actual behaviour in any way.
@@ -131,7 +136,7 @@ public:
     * The notification is guaranteed to be called once the parse-job finishes, from within its destructor.
     * The given top-context may be invalid if the update failed.
     */
-    Q_SCRIPTABLE void setNotifyWhenReady(const QList<QWeakPointer<QObject> >& notify);
+    Q_SCRIPTABLE void setNotifyWhenReady(const QList<QPointer<QObject> >& notify);
 
     /// Sets the du-context that was created by this parse-job
     Q_SCRIPTABLE virtual void setDuChain(ReferencedTopDUContext duChain);
@@ -139,14 +144,14 @@ public:
     Q_SCRIPTABLE virtual ReferencedTopDUContext duChain() const;
 
     /// Overridden to allow jobs to determine if they've been requested to abort
-    Q_SCRIPTABLE virtual void requestAbort();
+    Q_SCRIPTABLE virtual void requestAbort() override;
     /// Determine if the job has been requested to abort
     Q_SCRIPTABLE bool abortRequested() const;
     /// Sets success to false, causing failed() to be emitted
     Q_SCRIPTABLE void abortJob();
 
     /// Overridden to convey whether the job succeeded or not.
-    Q_SCRIPTABLE virtual bool success() const;
+    Q_SCRIPTABLE virtual bool success() const override;
 
     /// Set the minimum features the resulting top-context should have
     Q_SCRIPTABLE void setMinimumFeatures(TopDUContext::Features features);
@@ -169,15 +174,17 @@ public:
 
     /// Returns whether there is minimum features set up for some url
     static bool hasStaticMinimumFeatures();
-    
+
     ///Returns a structure containing information about data accesses in the parsed file.
     /// It's up to the caller to remove the returned instance
     virtual KDevelop::DataAccessRepository* dataAccessInformation();
-    
+
     ///Returns a control flow graph for the code in the parsed file.
     /// It's up to the caller to remove the returned instance
     virtual KDevelop::ControlFlowGraph* controlFlowGraph();
 
+    ThreadWeaver::QObjectDecorator* decorator() const;
+
 Q_SIGNALS:
     /**Can be used to give progress feedback to the background-parser. @param value should be between 0 and 1, where 0 = 0% and 1 = 100%
      * @param text may be a text that describes the current state of parsing
@@ -185,6 +192,14 @@ Q_SIGNALS:
     void progress(KDevelop::ParseJob*, float value, const QString& text);
 
 protected:
+    /**
+     * Should return an environment for this parse job.
+     *
+     * This is then used to check whether existing cached data of previous parse jobs need an update.
+     * The default implementation returns a nullptr.
+     */
+    virtual const ParsingEnvironment* environment() const;
+
     /**
      * Checks whether there is already an up to date context available for the
      * current document. If so, it returns true and ensures that the document
@@ -220,7 +235,9 @@ private:
     class ParseJobPrivate* const d;
 };
 
-Q_DECLARE_OPERATORS_FOR_FLAGS(ParseJob::SequentialProcessingFlags);
-
 }
+
+Q_DECLARE_OPERATORS_FOR_FLAGS(KDevelop::ParseJob::SequentialProcessingFlags)
+Q_DECLARE_METATYPE(KDevelop::ParseJob*)
+
 #endif
