@@ -17,6 +17,7 @@
 */
 
 #include "parseprojectjob.h"
+#include "util/debug.h"
 #include <interfaces/icore.h>
 #include <interfaces/ilanguagecontroller.h>
 #include <interfaces/iruncontroller.h>
@@ -31,7 +32,7 @@
 using namespace KDevelop;
 
 bool ParseProjectJob::doKill() {
-    kDebug() << "stopping project parse job";
+    qCDebug(LANGUAGE) << "stopping project parse job";
     deleteLater();
     return true;
 }
@@ -48,7 +49,7 @@ ParseProjectJob::ParseProjectJob(IProject* project, bool forceUpdate)
     , m_forceUpdate(forceUpdate)
     , m_project(project)
 {
-    connect(project, SIGNAL(destroyed(QObject*)), SLOT(deleteNow()));
+    connect(project, &IProject::destroyed, this, &ParseProjectJob::deleteNow);
 
     if (!ICore::self()->projectController()->parseAllProjectSources()) {
         // In case we don't want to parse the whole project, still add all currently open files that belong to the project to the background-parser
@@ -96,7 +97,7 @@ void ParseProjectJob::start() {
         return;
     }
 
-    kDebug() << "starting project parse job";
+    qCDebug(LANGUAGE) << "starting project parse job";
 
     TopDUContext::Features processingLevel = m_filesToParse.size() < ICore::self()->languageController()->completionSettings()->minFilesForSimplifiedParsing() ?
                                     TopDUContext::VisibleDeclarationsAndContexts : TopDUContext::SimplifiedVisibleDeclarationsAndContexts;
@@ -143,4 +144,3 @@ void ParseProjectJob::start() {
     }
 }
 
-#include "parseprojectjob.moc"
