@@ -24,10 +24,10 @@
 
 #include <QTest>
 #include <QElapsedTimer>
+#include <QTemporaryFile>
 #include <QApplication>
 
-#include <qtest_kde.h>
-#include <KTextEditor/EditorChooser>
+#include <KTextEditor/Editor>
 #include <KTextEditor/View>
 
 #include <tests/autotestshell.h>
@@ -43,7 +43,7 @@
 #include "testlanguagesupport.h"
 #include "testparsejob.h"
 
-QTEST_KDEMAIN(TestBackgroundparser, GUI)
+QTEST_MAIN(TestBackgroundparser)
 
 #define QVERIFY_RETURN(statement, retval) \
 do { if (!QTest::qVerify((statement), #statement, "", __FILE__, __LINE__)) return retval; } while (0)
@@ -77,7 +77,7 @@ void JobPlan::parseJobCreated(ParseJob* job)
     TestParseJob* testJob = dynamic_cast<TestParseJob*>(job);
     Q_ASSERT(testJob);
 
-    kDebug() << "assigning propierties for created job" << testJob->document().toUrl();
+    qDebug() << "assigning propierties for created job" << testJob->document().toUrl();
     testJob->duration_ms = jobForUrl(testJob->document()).m_duration;
 
     m_createdJobs.append(testJob->document());
@@ -128,7 +128,7 @@ JobPrototype JobPlan::jobForUrl(const IndexedString& url)
 
 void JobPlan::updateReady(const IndexedString& url, const ReferencedTopDUContext& /*context*/)
 {
-    kDebug() << "update ready on " << url.toUrl();
+    qDebug() << "update ready on " << url.toUrl();
 
     const JobPrototype job = jobForUrl(url);
     QVERIFY(job.m_url.toUrl().isValid());
@@ -164,9 +164,13 @@ void TestBackgroundparser::initTestCase()
   langController->backgroundParser()->setThreadCount(4);
 
   TestLanguageSupport* testLang = new TestLanguageSupport();
-  connect(testLang, SIGNAL(parseJobCreated(KDevelop::ParseJob*)),
-          &m_jobPlan, SLOT(parseJobCreated(KDevelop::ParseJob*)));
+  connect(testLang, &TestLanguageSupport::parseJobCreated,
+          &m_jobPlan, &JobPlan::parseJobCreated);
   langController->addTestLanguage(testLang, QStringList() << "text/plain");
+
+  const auto languages = langController->languagesForUrl(QUrl::fromLocalFile("/foo.txt"));
+  QCOMPARE(languages.size(), 1);
+  QCOMPARE(languages.first(), testLang);
 }
 
 void TestBackgroundparser::cleanupTestCase()
@@ -186,11 +190,11 @@ void TestBackgroundparser::testParseOrdering_foregroundThread()
     // foreground thread (active document being edited, ...) running all the time.
 
     // the long-running high-prio job
-    m_jobPlan.addJob(JobPrototype(KUrl("test_fgt_hp.txt"), -500, ParseJob::IgnoresSequentialProcessing, 630));
+    m_jobPlan.addJob(JobPrototype(QUrl::fromLocalFile("/test_fgt_hp.txt"), -500, ParseJob::IgnoresSequentialProcessing, 630));
 
     // several small background jobs
     for ( int i = 0; i < 10; i++ ) {
-        m_jobPlan.addJob(JobPrototype(KUrl("test_fgt_lp__" + QString::number(i) + ".txt"), i, ParseJob::FullSequentialProcessing, 40));
+        m_jobPlan.addJob(JobPrototype(QUrl::fromLocalFile("/test_fgt_lp__" + QString::number(i) + ".txt"), i, ParseJob::FullSequentialProcessing, 40));
     }
 
     // not enough time if the small jobs run after the large one
@@ -202,11 +206,11 @@ void TestBackgroundparser::testParseOrdering_noSequentialProcessing()
     m_jobPlan.clear();
     for ( int i = 0; i < 20; i++ ) {
         // create jobs with no sequential processing, and different priorities
-        m_jobPlan.addJob(JobPrototype(KUrl("test_nsp1__" + QString::number(i) + ".txt"), i, ParseJob::IgnoresSequentialProcessing, i));
+        m_jobPlan.addJob(JobPrototype(QUrl::fromLocalFile("/test_nsp1__" + QString::number(i) + ".txt"), i, ParseJob::IgnoresSequentialProcessing, i));
     }
     for ( int i = 0; i < 8; i++ ) {
         // create a few more jobs with the same priority
-        m_jobPlan.addJob(JobPrototype(KUrl("test_nsp2__" + QString::number(i) + ".txt"), 10, ParseJob::IgnoresSequentialProcessing, i));
+        m_jobPlan.addJob(JobPrototype(QUrl::fromLocalFile("/test_nsp2__" + QString::number(i) + ".txt"), 10, ParseJob::IgnoresSequentialProcessing, i));
     }
     QVERIFY(m_jobPlan.runJobs(1000));
 }
@@ -216,10 +220,10 @@ void TestBackgroundparser::testParseOrdering_lockup()
     m_jobPlan.clear();
     for ( int i = 3; i > 0; i-- ) {
         // add 3 jobs which do not care about sequential processing, at 4 threads it should take no more than 1s to process them
-        m_jobPlan.addJob(JobPrototype(KUrl("test" + QString::number(i) + ".txt"), i, ParseJob::IgnoresSequentialProcessing, 200));
+        m_jobPlan.addJob(JobPrototype(QUrl::fromLocalFile("/test" + QString::number(i) + ".txt"), i, ParseJob::IgnoresSequentialProcessing, 200));
     }
     // add one job which requires sequential processing with high priority
-    m_jobPlan.addJob(JobPrototype(KUrl("test_hp.txt"), -200, ParseJob::FullSequentialProcessing, 200));
+    m_jobPlan.addJob(JobPrototype(QUrl::fromLocalFile("/test_hp.txt"), -200, ParseJob::FullSequentialProcessing, 200));
     // verify that the low-priority nonsequential jobs are run simultaneously with the other one.
     QVERIFY(m_jobPlan.runJobs(700));
 }
@@ -231,12 +235,12 @@ void TestBackgroundparser::testParseOrdering_simple()
         // the job with priority i should be at place i in the finished list
         // (lower priority value -> should be parsed first)
         ParseJob::SequentialProcessingFlags flags = ParseJob::FullSequentialProcessing;
-        m_jobPlan.addJob(JobPrototype(KUrl("test" + QString::number(i) + ".txt"),
+        m_jobPlan.addJob(JobPrototype(QUrl::fromLocalFile("/test" + QString::number(i) + ".txt"),
                                       i, flags));
     }
     // also add a few jobs which ignore the processing
     for ( int i = 0; i < 5; ++i ) {
-        m_jobPlan.addJob(JobPrototype(KUrl("test2-" + QString::number(i) + ".txt"),
+        m_jobPlan.addJob(JobPrototype(QUrl::fromLocalFile("/test2-" + QString::number(i) + ".txt"),
                                        BackgroundParser::NormalPriority,
                                        ParseJob::IgnoresSequentialProcessing));
     }
@@ -251,7 +255,7 @@ void TestBackgroundparser::benchmark()
     QVector<IndexedString> jobUrls;
     jobUrls.reserve(jobs);
     for ( int i = 0; i < jobs; ++i ) {
-        jobUrls << IndexedString("test" + QString::number(i) + ".txt");
+        jobUrls << IndexedString("/test" + QString::number(i) + ".txt");
     }
 
     QBENCHMARK {
@@ -269,22 +273,25 @@ void TestBackgroundparser::benchmark()
 
 void TestBackgroundparser::benchmarkDocumentChanges()
 {
-    KTextEditor::Editor* editor = KTextEditor::EditorChooser::editor();
+    KTextEditor::Editor* editor = KTextEditor::Editor::instance();
     QVERIFY(editor);
     KTextEditor::Document* doc = editor->createDocument(this);
     QVERIFY(doc);
-    doc->saveAs(KUrl("/tmp/__kdevbackgroundparsertest_benchmark.txt"));
-    
+    QTemporaryFile file;
+    QVERIFY(file.open());
+    doc->saveAs(QUrl::fromLocalFile(file.fileName()));
+
     DocumentChangeTracker tracker(doc);
-    
+
     doc->setText("hello world");
     // required for proper benchmark results
     doc->createView(0);
     QBENCHMARK {
         for ( int i = 0; i < 5000; i++ ) {
-            doc->startEditing();
-            doc->insertText(KTextEditor::Cursor(0, 0), "This is a test line.\n");
-            doc->endEditing();
+            {
+                KTextEditor::Document::EditingTransaction t(doc);
+                doc->insertText(KTextEditor::Cursor(0, 0), "This is a test line.\n");
+            }
             QApplication::processEvents();
         }
     }
@@ -292,4 +299,3 @@ void TestBackgroundparser::benchmarkDocumentChanges()
     doc->save();
 }
 
-#include "test_backgroundparser.moc"
