@@ -25,7 +25,7 @@
 
 #include <QObject>
 
-#include <language/duchain/indexedstring.h>
+#include <serialization/indexedstring.h>
 #include <language/duchain/topducontext.h>
 
 #include <language/backgroundparser/parsejob.h>
@@ -41,7 +41,7 @@ public:
     , m_flags(ParseJob::IgnoresSequentialProcessing)
     {
     }
-    JobPrototype(const KUrl& url, int priority, ParseJob::SequentialProcessingFlags flags, int duration = 0)
+    JobPrototype(const QUrl& url, int priority, ParseJob::SequentialProcessingFlags flags, int duration = 0)
     : m_url(url)
     , m_priority(priority)
     , m_duration(duration)
@@ -79,6 +79,8 @@ private slots:
     void parseJobCreated(KDevelop::ParseJob*);
 
 private:
+    friend class TestBackgroundparser;
+
     QVector<JobPrototype> m_jobs;
     QVector<IndexedString> m_finishedJobs;
     QVector<IndexedString> m_createdJobs;
