@@ -27,12 +27,11 @@
 #include <ktexteditor/codecompletioninterface.h>
 
 #include <interfaces/icore.h>
-#include <interfaces/ipartcontroller.h>
-#include <interfaces/ilanguage.h>
 #include <interfaces/ilanguagecontroller.h>
 
 #include "../duchain/duchain.h"
 #include "../duchain/topducontext.h"
+#include "util/debug.h"
 #include "codecompletionmodel.h"
 #include <interfaces/idocumentcontroller.h>
 
@@ -45,46 +44,54 @@ CodeCompletion::CodeCompletion(QObject *parent, KTextEditor::CodeCompletionModel
   KDevelop::CodeCompletionModel* kdevModel = dynamic_cast<KDevelop::CodeCompletionModel*>(aModel);
   if(kdevModel)
     kdevModel->initialize();
-  connect (KDevelop::ICore::self()->partController(), SIGNAL(partAdded(KParts::Part*)),
-    SLOT(documentLoaded(KParts::Part*)));
-  connect( KDevelop::ICore::self()->documentController(), SIGNAL(documentSaved(KDevelop::IDocument*)), SLOT(documentSaved(KDevelop::IDocument*)) );
+  connect(KDevelop::ICore::self()->documentController(), &IDocumentController::textDocumentCreated,
+          this, &CodeCompletion::textDocumentCreated);
+  connect( ICore::self()->documentController(), &IDocumentController::documentUrlChanged,
+           this, &CodeCompletion::documentUrlChanged );
   aModel->setParent(this);
+
+  // prevent deadlock
+  QMetaObject::invokeMethod(this, "checkDocuments", Qt::QueuedConnection);
 }
 
 CodeCompletion::~CodeCompletion()
 {
 }
 
+void CodeCompletion::checkDocuments()
+{
+  foreach( KDevelop::IDocument* doc, KDevelop::ICore::self()->documentController()->openDocuments() ) {
+    if (doc->textDocument()) {
+      checkDocument(doc->textDocument());
+    }
+  }
+}
+
 void CodeCompletion::viewCreated(KTextEditor::Document * document, KTextEditor::View * view)
 {
   Q_UNUSED(document);
 
   if (CodeCompletionInterface* cc = dynamic_cast<CodeCompletionInterface*>(view)) {
     cc->registerCompletionModel(m_model);
-    kDebug() << "Registered completion model";
+    qCDebug(LANGUAGE) << "Registered completion model";
   }
 }
 
-void CodeCompletion::documentSaved(KDevelop::IDocument* document)
+void CodeCompletion::documentUrlChanged(KDevelop::IDocument* document)
 {
-  // The URL may have changed, so we re-register the document
+  // The URL has changed (might have a different language now), so we re-register the document
   Document* textDocument = document->textDocument();
-  
+
   if(textDocument)
   {
-    unregisterDocument(textDocument);
     checkDocument(textDocument);
   }
 }
 
-void CodeCompletion::documentLoaded(KParts::Part* document)
+void CodeCompletion::textDocumentCreated(KDevelop::IDocument* document)
 {
-  KTextEditor::Document *textDocument = dynamic_cast<KTextEditor::Document*>(document);
-  if (textDocument) {
-    checkDocument(textDocument);
-  } else {
-    kDebug() << "Non-text editor document added";
-  }
+  Q_ASSERT(document->textDocument());
+  checkDocument(document->textDocument());
 }
 
 void CodeCompletion::unregisterDocument(Document* textDocument)
@@ -92,16 +99,18 @@ void CodeCompletion::unregisterDocument(Document* textDocument)
   foreach (KTextEditor::View* view, textDocument->views())
     if (CodeCompletionInterface* cc = dynamic_cast<CodeCompletionInterface*>(view))
       cc->unregisterCompletionModel(m_model);
-    
-  disconnect(textDocument, SIGNAL(viewCreated(KTextEditor::Document*, KTextEditor::View*)), this, SLOT(viewCreated(KTextEditor::Document*, KTextEditor::View*)));
+
+  disconnect(textDocument, &Document::viewCreated, this, &CodeCompletion::viewCreated);
 }
 
 void CodeCompletion::checkDocument(Document* textDocument)
 {
-  QList<ILanguage*> langs=ICore::self()->languageController()->languagesForUrl( textDocument->url() );
-  
-  bool found=false;
-  foreach(ILanguage* lang, langs) {
+  unregisterDocument(textDocument);
+
+  auto langs = ICore::self()->languageController()->languagesForUrl( textDocument->url() );
+
+  bool found = false;
+  foreach(const auto& lang, langs) {
     if(m_language==lang->name()) {
       found=true;
       break;
@@ -109,13 +118,12 @@ void CodeCompletion::checkDocument(Document* textDocument)
   }
   if(!found && !m_language.isEmpty())
       return;
-  
+
   foreach (KTextEditor::View* view, textDocument->views())
     viewCreated(textDocument, view);
 
-  connect(textDocument, SIGNAL(viewCreated(KTextEditor::Document*, KTextEditor::View*)), SLOT(viewCreated(KTextEditor::Document*, KTextEditor::View*)));
+  connect(textDocument, &Document::viewCreated, this, &CodeCompletion::viewCreated);
 }
 
 
-#include "codecompletion.moc"
 
