@@ -19,10 +19,9 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#ifndef KDEV_CODECOMPLETIONITEM_H
-#define KDEV_CODECOMPLETIONITEM_H
+#ifndef KDEVPLATFORM_KDEV_CODECOMPLETIONITEM_H
+#define KDEVPLATFORM_KDEV_CODECOMPLETIONITEM_H
 
-#include <ksharedptr.h>
 #include <ktexteditor/codecompletionmodel.h>
 
 #include "../duchain/duchainpointer.h"
@@ -30,7 +29,6 @@
 
 namespace KTextEditor {
   class CodeCompletionModel;
-  class Document;
   class Range;
   class Cursor;
 }
@@ -45,7 +43,7 @@ struct CompletionTreeNode;
 class CompletionTreeItem;
 class IndexedType;
 
-class KDEVPLATFORMLANGUAGE_EXPORT CompletionTreeElement : public KShared {
+class KDEVPLATFORMLANGUAGE_EXPORT CompletionTreeElement : public QSharedData {
 public:
   CompletionTreeElement();
   
@@ -93,12 +91,12 @@ struct KDEVPLATFORMLANGUAGE_EXPORT CompletionTreeNode : public CompletionTreeEle
   QVariant roleValue;
   
   ///Will append the child, and initialize it correctly to create a working tree-structure
-  void appendChild(KSharedPtr<CompletionTreeElement>);
-  void appendChildren(QList<KSharedPtr<CompletionTreeElement> >);
-  void appendChildren(QList<KSharedPtr<CompletionTreeItem> >);
+  void appendChild(QExplicitlySharedDataPointer<CompletionTreeElement>);
+  void appendChildren(QList<QExplicitlySharedDataPointer<CompletionTreeElement> >);
+  void appendChildren(QList<QExplicitlySharedDataPointer<CompletionTreeItem> >);
   
   ///@warning Do not manipulate this directly, that's bad for consistency. Use appendChild instead.
-  QList<KSharedPtr<CompletionTreeElement> > children;
+  QList<QExplicitlySharedDataPointer<CompletionTreeElement> > children;
 };
 
 class KDEVPLATFORMLANGUAGE_EXPORT CompletionTreeItem : public CompletionTreeElement
@@ -106,7 +104,7 @@ class KDEVPLATFORMLANGUAGE_EXPORT CompletionTreeItem : public CompletionTreeElem
 public:
 
   ///Execute the completion item. The default implementation does nothing.
-  virtual void execute(KTextEditor::Document* document, const KTextEditor::Range& word);
+  virtual void execute(KTextEditor::View* view, const KTextEditor::Range& word);
 
   ///Should return normal completion data, @see KTextEditor::CodeCompletionModel
   ///The default implementation returns "unimplemented", so re-implement it!
@@ -144,9 +142,11 @@ struct KDEVPLATFORMLANGUAGE_EXPORT CompletionCustomGroupNode : public Completion
   int inheritanceDepth;
 };
 
-typedef KSharedPtr<CompletionTreeItem> CompletionTreeItemPointer;
-typedef KSharedPtr<CompletionTreeElement> CompletionTreeElementPointer;
+typedef QExplicitlySharedDataPointer<CompletionTreeItem> CompletionTreeItemPointer;
+typedef QExplicitlySharedDataPointer<CompletionTreeElement> CompletionTreeElementPointer;
 
 }
 
+Q_DECLARE_METATYPE(KDevelop::CompletionTreeElementPointer);
+
 #endif
