@@ -26,16 +26,16 @@
 #include <QtCore/QPair>
 #include <QtCore/QMap>
 #include <QtCore/QPointer>
-#include <KDE/KTextEditor/CodeCompletionModel>
-#include <KDE/KSharedPtr>
+#include <QExplicitlySharedDataPointer>
+#include <QUrl>
 
 #include "../duchain/duchainpointer.h"
-#include "../languageexport.h"
+#include <language/languageexport.h>
 #include "codecompletioncontext.h"
 #include "codecompletionitem.h"
 #include <interfaces/icompletionsettings.h>
+#include <ktexteditor/codecompletionmodel.h>
 #include <ktexteditor/codecompletionmodelcontrollerinterface.h>
-#include <kdeversion.h>
 
 class QIcon;
 class QString;
@@ -48,41 +48,41 @@ class Declaration;
 class CodeCompletionWorker;
 class CompletionWorkerThread;
 
-class KDEVPLATFORMLANGUAGE_EXPORT CodeCompletionModel : public KTextEditor::CodeCompletionModel2
-, public KTextEditor::CodeCompletionModelControllerInterface3
+class KDEVPLATFORMLANGUAGE_EXPORT CodeCompletionModel : public KTextEditor::CodeCompletionModel
+                                                      , public KTextEditor::CodeCompletionModelControllerInterface
 {
   Q_OBJECT
-  Q_INTERFACES(KTextEditor::CodeCompletionModelControllerInterface3)
+  Q_INTERFACES(KTextEditor::CodeCompletionModelControllerInterface)
 
   public:
-    CodeCompletionModel(QObject* parent);
+    explicit CodeCompletionModel(QObject* parent);
     virtual ~CodeCompletionModel();
-    
+
     ///This MUST be called after the creation of this completion-model.
     ///If you use use the KDevelop::CodeCompletion helper-class, that one cares about it.
     virtual void initialize();
-    
+
     ///Entry-point for code-completion. This determines ome settings, clears the model, and then calls completionInvokedInternal for further processing.
-    virtual void completionInvoked(KTextEditor::View* view, const KTextEditor::Range& range, InvocationType invocationType);
+    virtual void completionInvoked(KTextEditor::View* view, const KTextEditor::Range& range, KTextEditor::CodeCompletionModel::InvocationType invocationType) override;
 
-    virtual QModelIndex index ( int row, int column, const QModelIndex & parent = QModelIndex() ) const;
+    virtual QModelIndex index ( int row, int column, const QModelIndex & parent = QModelIndex() ) const override;
+
+    virtual QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const override;
+    virtual int rowCount ( const QModelIndex & parent = QModelIndex() ) const override;
+    virtual QModelIndex parent ( const QModelIndex & index ) const override;
 
-    virtual QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const;
-    virtual int rowCount ( const QModelIndex & parent = QModelIndex() ) const;
-    virtual QModelIndex parent ( const QModelIndex & index ) const;
-  
     ///Use this to set whether the code-completion widget should wait for this model until it's shown
     ///This makes sense when the model takes some time but not too much time, to make the UI less flickering and
     ///annoying.
     ///The default is false
     ///@todo Remove this option, make it true by default, and make sure in CodeCompletionWorker that the whole thing cannot break
     void setForceWaitForModel(bool wait);
-    
+
     bool forceWaitForModel();
-    
+
     ///Convenience-storage for use by the inherited completion model
-    void setCompletionContext(KSharedPtr<CodeCompletionContext> completionContext);
-    KSharedPtr<CodeCompletionContext> completionContext() const;
+    void setCompletionContext(QExplicitlySharedDataPointer<CodeCompletionContext> completionContext);
+    QExplicitlySharedDataPointer<CodeCompletionContext> completionContext() const;
 
     ///Convenience-storage for use by the inherited completion model
     KDevelop::TopDUContextPointer currentTopContext() const;
@@ -94,16 +94,16 @@ class KDEVPLATFORMLANGUAGE_EXPORT CodeCompletionModel : public KTextEditor::Code
     ///Whether the completion should be fully detailed. If false, it should be simplifed, so no argument-hints,
     ///no expanding information, no type-information, etc.
     bool fullCompletion() const;
-    
-    virtual MatchReaction matchingItem(const QModelIndex& matched);
-    
-    virtual QString filterString(KTextEditor::View* view, const KTextEditor::Range& range, const KTextEditor::Cursor& position);
-    
+
+    virtual MatchReaction matchingItem(const QModelIndex& matched) override;
+
+    virtual QString filterString(KTextEditor::View* view, const KTextEditor::Range& range, const KTextEditor::Cursor& position) override;
+
     void clear();
-    
+
     ///Returns the tree-element that belogns to the index, or zero
-    KSharedPtr<CompletionTreeElement> itemForIndex(QModelIndex index) const;
-    
+    QExplicitlySharedDataPointer<CompletionTreeElement> itemForIndex(QModelIndex index) const;
+
   Q_SIGNALS:
     ///Connection from this completion-model into the background worker thread. You should emit this from within completionInvokedInternal.
     void completionsNeeded(KDevelop::DUContextPointer context, const KTextEditor::Cursor& position, KTextEditor::View* view);
@@ -113,26 +113,29 @@ class KDEVPLATFORMLANGUAGE_EXPORT CodeCompletionModel : public KTextEditor::Code
 
   protected Q_SLOTS:
     ///Connection from the background-thread into the model: This is called when the background-thread is ready
-    virtual void foundDeclarations(QList<KSharedPtr<CompletionTreeElement> > item, KSharedPtr<CodeCompletionContext> completionContext);
-    
+    virtual void foundDeclarations(const QList<QExplicitlySharedDataPointer<CompletionTreeElement>>& item,
+                                   const QExplicitlySharedDataPointer<CodeCompletionContext>& completionContext);
+
   protected:
     ///Eventually override this, determine the context or whatever, and then emit completionsNeeded(..) to continue processing in the background tread.
     ///The default-implementation does this completely, so if you don't need to do anything special, you can just leave it.
-    virtual void completionInvokedInternal(KTextEditor::View* view, const KTextEditor::Range& range, InvocationType invocationType, const KUrl& url);
+    virtual void completionInvokedInternal(KTextEditor::View* view, const KTextEditor::Range& range, KTextEditor::CodeCompletionModel::InvocationType invocationType, const QUrl& url);
 
-    virtual void executeCompletionItem2(KTextEditor::Document* document, const KTextEditor::Range& word, const QModelIndex& index) const;
-    KSharedPtr<CodeCompletionContext> m_completionContext;
-    typedef QPair<KDevelop::DeclarationPointer, KSharedPtr<CodeCompletionContext> > DeclarationContextPair;
+    virtual void executeCompletionItem(KTextEditor::View* view, const KTextEditor::Range& word, const QModelIndex& index) const override;
+
+    QExplicitlySharedDataPointer<CodeCompletionContext> m_completionContext;
+    typedef QPair<KDevelop::DeclarationPointer, QExplicitlySharedDataPointer<CodeCompletionContext> > DeclarationContextPair;
 
     mutable QMap<const CompletionTreeElement*, QPointer<QWidget> > m_navigationWidgets;
-    QList< KSharedPtr<CompletionTreeElement> > m_completionItems;
+    QList< QExplicitlySharedDataPointer<CompletionTreeElement> > m_completionItems;
 
     /// Should create a completion-worker. The worker must have no parent object,
     /// because else its thread-affinity can not be changed.
     virtual CodeCompletionWorker* createCompletionWorker() = 0;
     friend class CompletionWorkerThread;
-    
+
     CodeCompletionWorker* worker() const;
+
   private:
     bool m_forceWaitForModel;
     bool m_fullCompletion;
