@@ -27,8 +27,11 @@
 #include "../duchain/types/functiontype.h"
 #include "../duchain/types/enumeratortype.h"
 #include "../duchain/duchainutils.h"
+#include "../duchain/navigation/abstractdeclarationnavigationcontext.h"
+#include "util/debug.h"
 
 #include <KTextEditor/Document>
+#include <KTextEditor/View>
 
 
 namespace KDevelop {
@@ -39,7 +42,7 @@ const bool NormalDeclarationCompletionItem::shortenArgumentHintReturnValues = tr
 const int NormalDeclarationCompletionItem::maximumArgumentHintReturnValueLength = 30;
 const int NormalDeclarationCompletionItem::desiredTypeLength = 20;
 
-NormalDeclarationCompletionItem::NormalDeclarationCompletionItem(KDevelop::DeclarationPointer decl, KSharedPtr<CodeCompletionContext> context, int inheritanceDepth)
+NormalDeclarationCompletionItem::NormalDeclarationCompletionItem(KDevelop::DeclarationPointer decl, QExplicitlySharedDataPointer<CodeCompletionContext> context, int inheritanceDepth)
   : m_completionContext(context), m_declaration(decl), m_inheritanceDepth(inheritanceDepth) {
 }
 
@@ -47,7 +50,7 @@ KDevelop::DeclarationPointer NormalDeclarationCompletionItem::declaration() cons
   return m_declaration;
 }
 
-KSharedPtr< KDevelop::CodeCompletionContext > NormalDeclarationCompletionItem::completionContext() const {
+QExplicitlySharedDataPointer< KDevelop::CodeCompletionContext > NormalDeclarationCompletionItem::completionContext() const {
   return m_completionContext;
 }
 
@@ -73,11 +76,12 @@ QString NormalDeclarationCompletionItem::declarationName() const
     return ret;
 }
 
-void NormalDeclarationCompletionItem::execute(KTextEditor::Document* document, const KTextEditor::Range& word) {
+void NormalDeclarationCompletionItem::execute(KTextEditor::View* view, const KTextEditor::Range& word) {
 
   if( m_completionContext && m_completionContext->depth() != 0 )
     return; //Do not replace any text when it is an argument-hint
 
+  KTextEditor::Document* document = view->document();
   QString newText;
 
   {
@@ -85,16 +89,16 @@ void NormalDeclarationCompletionItem::execute(KTextEditor::Document* document, c
     if(m_declaration) {
       newText = declarationName();
     } else {
-      kDebug() << "Declaration disappeared";
+      qCDebug(LANGUAGE) << "Declaration disappeared";
       return;
     }
   }
 
   document->replaceText(word, newText);
   KTextEditor::Range newRange = word;
-  newRange.end().setColumn(newRange.start().column() + newText.length());
-  
-  executed(document, newRange);
+  newRange.setEnd(KTextEditor::Cursor(newRange.end().line(), newRange.start().column() + newText.length()));
+
+  executed(view, newRange);
 }
 
 QWidget* NormalDeclarationCompletionItem::createExpandingWidget(const KDevelop::CodeCompletionModel* model) const
@@ -114,9 +118,9 @@ QString NormalDeclarationCompletionItem::shortenedTypeString(KDevelop::Declarati
   return decl->abstractType()->toString();
 }
 
-void NormalDeclarationCompletionItem::executed(KTextEditor::Document* document, const KTextEditor::Range& word)
+void NormalDeclarationCompletionItem::executed(KTextEditor::View* view, const KTextEditor::Range& word)
 {
-  Q_UNUSED(document);
+  Q_UNUSED(view);
   Q_UNUSED(word);
 }
 
@@ -124,10 +128,10 @@ QVariant NormalDeclarationCompletionItem::data(const QModelIndex& index, int rol
 {
   DUChainReadLocker lock(DUChain::lock(), 500);
   if(!lock.locked()) {
-    kDebug(9007) << "Failed to lock the du-chain in time";
+    qCDebug(LANGUAGE) << "Failed to lock the du-chain in time";
     return QVariant();
   }
-  
+
   if(!m_declaration)
     return QVariant();
 
@@ -141,6 +145,8 @@ QVariant NormalDeclarationCompletionItem::data(const QModelIndex& index, int rol
             return functionType->AbstractType::toString();
           }
       } else if(index.column() == CodeCompletionModel::Prefix) {
+          if(m_declaration->kind() == Declaration::Namespace)
+            return QStringLiteral("namespace");
           if (m_declaration->abstractType()) {
             if(EnumeratorType::Ptr enumerator = m_declaration->type<EnumeratorType>()) {
               if(m_declaration->context()->owner() && m_declaration->context()->owner()->abstractType()) {
@@ -156,7 +162,7 @@ QVariant NormalDeclarationCompletionItem::data(const QModelIndex& index, int rol
               if (functionType->returnType()) {
                 QString ret = shortenedTypeString(m_declaration, desiredTypeLength);
                 if(shortenArgumentHintReturnValues && argumentHintDepth() && ret.length() > maximumArgumentHintReturnValueLength)
-                  return QString("...");
+                  return QStringLiteral("...");
                 else
                   return ret;
               }else if(argumentHintDepth()) {
@@ -174,6 +180,11 @@ QVariant NormalDeclarationCompletionItem::data(const QModelIndex& index, int rol
           } else {
             return "<incomplete type>";
           }
+        } else if (index.column() == CodeCompletionModel::Arguments) {
+            if (m_declaration->isFunctionDeclaration()) {
+                auto functionType = declaration()->type<FunctionType>();
+                return functionType ? functionType->partToString(FunctionType::SignatureArguments) : QVariant();
+            }
         }
       break;
     case CodeCompletionModel::BestMatchesCount:
@@ -195,6 +206,10 @@ QVariant NormalDeclarationCompletionItem::data(const QModelIndex& index, int rol
 
     case CodeCompletionModel::CompletionRole:
       return (int)completionProperties();
+    case CodeCompletionModel::ItemSelected: {
+        NavigationContextPointer ctx(new AbstractDeclarationNavigationContext(DeclarationPointer(m_declaration), TopDUContextPointer()));
+        return ctx->html(true);
+    }
     case Qt::DecorationRole:
      {
       if( index.column() == CodeCompletionModel::Icon ) {
