@@ -20,27 +20,24 @@
 #ifndef KDEVPLATFORM_APPLYCHANGESWIDGET_H
 #define KDEVPLATFORM_APPLYCHANGESWIDGET_H
 
-#include <KDE/KDialog>
-#include "../languageexport.h"
+#include <QDialog>
+#include <language/languageexport.h>
 
 namespace KTextEditor {
 class Document;
-class Range;
 }
 
-class KUrl;
-class QModelIndex;
 
 namespace KDevelop
 {
 class IndexedString;
 class ApplyChangesWidgetPrivate;
 
-class KDEVPLATFORMLANGUAGE_EXPORT ApplyChangesWidget : public KDialog
+class KDEVPLATFORMLANGUAGE_EXPORT ApplyChangesWidget : public QDialog
 {
     Q_OBJECT
     public:
-        ApplyChangesWidget(QWidget* parent=0);
+        explicit ApplyChangesWidget(QWidget* parent=0);
         ~ApplyChangesWidget();
         
         void setInformation(const QString& info);
@@ -60,18 +57,9 @@ class KDEVPLATFORMLANGUAGE_EXPORT ApplyChangesWidget : public KDialog
         void updateDiffView(int index = -1);
     
     public Q_SLOTS:
-        ///Called when a change between comparison and edition is requested
-        void switchEditView();
         ///Called to signal a change to the currently viewed index
         void indexChanged(int);
-        
-    private Q_SLOTS:
-        void change (KTextEditor::Document *document, const KTextEditor::Range &oldRange,
-                const KTextEditor::Range &newRange);
-        void insertion (KTextEditor::Document *document, const KTextEditor::Range &range);
-        void removal (KTextEditor::Document *document, const KTextEditor::Range &range, const QString &oldText);
-        void jump( const QModelIndex &);
-        
+
     private:
         ApplyChangesWidgetPrivate * d;
 };
