@@ -17,9 +17,11 @@
 */
 
 #include "coderepresentation.h"
-#include <QtCore/qfile.h>
-#include <KDE/KTextEditor/Document>
-#include <language/duchain/indexedstring.h>
+
+#include <QFile>
+#include <KTextEditor/Document>
+
+#include <serialization/indexedstring.h>
 #include <interfaces/idocumentcontroller.h>
 #include <interfaces/icore.h>
 #include <editor/modificationrevision.h>
@@ -27,27 +29,27 @@
 #include <ktexteditor/configinterface.h>
 
 namespace KDevelop {
-    
+
 static bool onDiskChangesForbidden = false;
 
 QString CodeRepresentation::rangeText(const KTextEditor::Range& range) const
 {
     Q_ASSERT(range.end().line() < lines());
-    
+
     //Easier for single line ranges which should happen most of the time
     if(range.onSingleLine())
         return QString( line( range.start().line() ).mid( range.start().column(), range.columnWidth() ) );
-    
+
     //Add up al the requested lines
     QString rangedText = line(range.start().line()).mid(range.start().column());
-    
+
     for(int i = range.start().line() + 1; i <= range.end().line(); ++i)
         rangedText += '\n' + ((i == range.end().line()) ? line(i).left(range.end().column()) : line(i));
-    
+
     return rangedText;
 }
 
-static void grepLine(const QString& identifier, const QString& lineText, int lineNumber, QVector<SimpleRange>& ret, bool surroundedByBoundary)
+static void grepLine(const QString& identifier, const QString& lineText, int lineNumber, QVector<KTextEditor::Range>& ret, bool surroundedByBoundary)
 {
     if (identifier.isEmpty())
         return;
@@ -61,55 +63,23 @@ static void grepLine(const QString& identifier, const QString& lineText, int lin
         int start = pos;
         pos += identifier.length();
         int end = pos;
-        
+
         if(!surroundedByBoundary || ( (end == lineText.length() || !lineText[end].isLetterOrNumber() || lineText[end] != '_')
                                         && (start-1 < 0 || !lineText[start-1].isLetterOrNumber() || lineText[start-1] != '_')) )
         {
-            ret << SimpleRange(lineNumber, start, lineNumber, end);
+            ret << KTextEditor::Range(lineNumber, start, lineNumber, end);
         }
     }
 }
 
-//NOTE: this is ugly, but otherwise kate might remove tabs again :-/
-// see also: https://bugs.kde.org/show_bug.cgi?id=291074
-struct EditorDisableReplaceTabs {
-  EditorDisableReplaceTabs(KTextEditor::Document* document) : m_iface(qobject_cast<KTextEditor::ConfigInterface*>(document)), m_count(0) {
-  }
-
-  void start() {
-    ++m_count;
-    if( m_count > 1 )
-      return;
-    if ( m_iface ) {
-      m_oldReplaceTabs = m_iface->configValue( "replace-tabs" );
-      m_iface->setConfigValue( "replace-tabs", false );
-    }
-  }
-
-  void end() {
-    --m_count;
-    if( m_count > 0 )
-      return;
-    
-    Q_ASSERT( m_count == 0 );
-    
-    if (m_iface)
-      m_iface->setConfigValue("replace-tabs", m_oldReplaceTabs);
-  }
-
-  KTextEditor::ConfigInterface* m_iface;
-  int m_count;
-  QVariant m_oldReplaceTabs;
-};
-
 class EditorCodeRepresentation : public DynamicCodeRepresentation {
   public:
-  EditorCodeRepresentation(KTextEditor::Document* document) : m_document(document), m_replaceTabs(document) {
+  EditorCodeRepresentation(KTextEditor::Document* document) : m_document(document) {
       m_url = IndexedString(m_document->url());
   }
-  
-  virtual QVector< SimpleRange > grep ( const QString& identifier, bool surroundedByBoundary ) const {
-      QVector< SimpleRange > ret;
+
+  virtual QVector< KTextEditor::Range > grep ( const QString& identifier, bool surroundedByBoundary ) const override {
+      QVector< KTextEditor::Range > ret;
 
       if (identifier.isEmpty())
         return ret;
@@ -119,75 +89,71 @@ class EditorCodeRepresentation : public DynamicCodeRepresentation {
 
       return ret;
   }
-  
-  QString line(int line) const {
+
+  virtual KDevEditingTransaction::Ptr makeEditTransaction() override {
+    return KDevEditingTransaction::Ptr(new KDevEditingTransaction(m_document));
+  }
+
+  QString line(int line) const override {
         if(line < 0 || line >= m_document->lines())
             return QString();
         return m_document->line(line);
   }
-  
-  virtual int lines() const {
+
+  virtual int lines() const override {
       return m_document->lines();
   }
-  
-  QString text() const {
+
+  QString text() const override {
     return m_document->text();
   }
-  
-  bool setText(const QString& text) {
-    
-    startEdit();
-    bool ret = m_document->setText(text);
-    endEdit();
+
+  bool setText(const QString& text) override {
+    bool ret;
+    {
+        KDevEditingTransaction t(m_document);
+        ret = m_document->setText(text);
+    }
     ModificationRevision::clearModificationCache(m_url);
     return ret;
   }
-  
-  bool fileExists(){
+
+  bool fileExists() override{
     return QFile(m_document->url().path()).exists();
   }
-  
-  void startEdit() {
-      m_document->startEditing();
-      m_replaceTabs.start();
-  }
-  
-  void endEdit() {
-      m_document->endEditing();
-      m_replaceTabs.end();
-  }
-  
+
   bool replace(const KTextEditor::Range& range, const QString& oldText,
-               const QString& newText, bool ignoreOldText) {
+               const QString& newText, bool ignoreOldText) override {
       QString old = m_document->text(range);
       if(oldText != old && !ignoreOldText) {
           return false;
       }
 
-      startEdit();
-      bool ret = m_document->replaceText(range, newText);
-      endEdit();
+      bool ret;
+      {
+          KDevEditingTransaction t(m_document);
+          ret = m_document->replaceText(range, newText);
+      }
 
       ModificationRevision::clearModificationCache(m_url);
 
       return ret;
   }
-  
-  virtual QString rangeText(const KTextEditor::Range& range) const {
+
+  virtual QString rangeText(const KTextEditor::Range& range) const override {
       return m_document->text(range);
   }
-  
+
   private:
     KTextEditor::Document* m_document;
     IndexedString m_url;
-    EditorDisableReplaceTabs m_replaceTabs;
 };
 
 class FileCodeRepresentation : public CodeRepresentation {
   public:
     FileCodeRepresentation(const IndexedString& document) : m_document(document) {
         QString localFile(document.toUrl().toLocalFile());
-  
+
         QFile file( localFile );
         if ( file.open(QIODevice::ReadOnly) ) {
             data = QString::fromLocal8Bit(file.readAll());
@@ -195,16 +161,16 @@ class FileCodeRepresentation : public CodeRepresentation {
         }
         m_exists = file.exists();
     }
-    
-    QString line(int line) const {
+
+    QString line(int line) const override {
         if(line < 0 || line >= lineData.size())
             return QString();
-      
+
       return lineData.at(line);
     }
-    
-    virtual QVector< SimpleRange > grep ( const QString& identifier, bool surroundedByBoundary ) const {
-        QVector< SimpleRange > ret;
+
+    virtual QVector< KTextEditor::Range > grep ( const QString& identifier, bool surroundedByBoundary ) const override {
+        QVector< KTextEditor::Range > ret;
 
         if (identifier.isEmpty())
             return ret;
@@ -214,16 +180,16 @@ class FileCodeRepresentation : public CodeRepresentation {
 
         return ret;
     }
-    
-    virtual int lines() const {
+
+    virtual int lines() const override {
         return lineData.count();
     }
-    
-    QString text() const {
+
+    QString text() const override {
       return data;
     }
-    
-    bool setText(const QString& text) {
+
+    bool setText(const QString& text) override {
       Q_ASSERT(!onDiskChangesForbidden);
       QString localFile(m_document.toUrl().toLocalFile());
 
@@ -231,7 +197,7 @@ class FileCodeRepresentation : public CodeRepresentation {
       if ( file.open(QIODevice::WriteOnly) )
       {
           QByteArray data = text.toLocal8Bit();
-          
+
           if(file.write(data) == data.size())
           {
               ModificationRevision::clearModificationCache(m_document);
@@ -240,11 +206,11 @@ class FileCodeRepresentation : public CodeRepresentation {
       }
       return false;
     }
-    
-    bool fileExists(){
+
+    bool fileExists() override{
       return m_exists;
     }
-    
+
   private:
     //We use QByteArray, because the column-numbers are measured in utf-8
     IndexedString m_document;
@@ -268,7 +234,7 @@ class ArtificialStringData : public QSharedData {
     const QStringList& lines() const {
         return m_lineData;
     }
-    
+
     private:
     QString m_data;
     QStringList m_lineData;
@@ -276,36 +242,36 @@ class ArtificialStringData : public QSharedData {
 
 class StringCodeRepresentation : public CodeRepresentation {
   public:
-    StringCodeRepresentation(KSharedPtr<ArtificialStringData> _data) : data(_data) {
+    StringCodeRepresentation(QExplicitlySharedDataPointer<ArtificialStringData> _data) : data(_data) {
       Q_ASSERT(data);
     }
-    
-    QString line(int line) const {
+
+    QString line(int line) const override {
         if(line < 0 || line >= data->lines().size())
             return QString();
-      
+
       return data->lines().at(line);
     }
-    
-    virtual int lines() const {
+
+    virtual int lines() const override {
         return data->lines().count();
     }
-    
-    QString text() const {
+
+    QString text() const override {
         return data->data();
     }
-    
-    bool setText(const QString& text) {
+
+    bool setText(const QString& text) override {
         data->setData(text);
         return true;
     }
-    
-    bool fileExists(){
+
+    bool fileExists() override{
         return false;
     }
-    
-    virtual QVector< SimpleRange > grep ( const QString& identifier, bool surroundedByBoundary ) const {
-        QVector< SimpleRange > ret;
+
+    virtual QVector< KTextEditor::Range > grep ( const QString& identifier, bool surroundedByBoundary ) const override {
+        QVector< KTextEditor::Range > ret;
 
         if (identifier.isEmpty())
             return ret;
@@ -315,15 +281,15 @@ class StringCodeRepresentation : public CodeRepresentation {
 
         return ret;
     }
-    
+
   private:
-    KSharedPtr<ArtificialStringData> data;
+    QExplicitlySharedDataPointer<ArtificialStringData> data;
 };
 
-static QHash<IndexedString, KSharedPtr<ArtificialStringData> > artificialStrings;
+static QHash<IndexedString, QExplicitlySharedDataPointer<ArtificialStringData> > artificialStrings;
 
 //Return the representation for the given URL if it exists, or an empty pointer otherwise
-static KSharedPtr<ArtificialStringData> representationForPath(const IndexedString& path)
+static QExplicitlySharedDataPointer<ArtificialStringData> representationForPath(const IndexedString& path)
 {
     if(artificialStrings.contains(path))
         return artificialStrings[path];
@@ -333,13 +299,13 @@ static KSharedPtr<ArtificialStringData> representationForPath(const IndexedStrin
         if(artificialStrings.contains(constructedPath))
             return artificialStrings[constructedPath];
         else
-            return KSharedPtr<ArtificialStringData>();
+            return QExplicitlySharedDataPointer<ArtificialStringData>();
     }
 }
 
 bool artificialCodeRepresentationExists(const IndexedString& path)
 {
-    return !representationForPath(path).isNull();
+    return representationForPath(path);
 }
 
 CodeRepresentation::Ptr createCodeRepresentation(const IndexedString& path) {
@@ -360,31 +326,30 @@ void CodeRepresentation::setDiskChangesForbidden(bool changesForbidden)
 
 QString CodeRepresentation::artificialPath(const QString& name)
 {
-    KUrl url = KUrl::fromPath(name);
-    url.cleanPath();
-
-    return "/kdev-artificial/" + url.path();
+    QUrl url = QUrl::fromLocalFile(name);
+    return QString::fromLatin1("/kdev-artificial/") + url.adjusted(QUrl::NormalizePathSegments).path();
 }
 
 InsertArtificialCodeRepresentation::InsertArtificialCodeRepresentation(const IndexedString& file,
                                                                        const QString& text)
 : m_file(file)
 {
-    if(m_file.toUrl().isRelative())
+    // make it simpler to use this by converting relative strings into artificial paths
+    if(QUrl(m_file.str()).isRelative())
     {
         m_file = IndexedString(CodeRepresentation::artificialPath(file.str()));
-        
+
         int idx = 0;
         while(artificialStrings.contains(m_file))
         {
             ++idx;
-            m_file = IndexedString(CodeRepresentation::artificialPath(QString("%1_%2").arg(idx).arg(file.str())));
+            m_file = IndexedString(CodeRepresentation::artificialPath(QStringLiteral("%1_%2").arg(idx).arg(file.str())));
         }
     }
-    
+
     Q_ASSERT(!artificialStrings.contains(m_file));
 
-    artificialStrings.insert(m_file, KSharedPtr<ArtificialStringData>(new ArtificialStringData(text)));
+    artificialStrings.insert(m_file, QExplicitlySharedDataPointer<ArtificialStringData>(new ArtificialStringData(text)));
 }
 
 IndexedString InsertArtificialCodeRepresentation::file()
@@ -409,3 +374,4 @@ QString InsertArtificialCodeRepresentation::text() {
 
 }
 
+// kate: indent-width 4;
