@@ -19,10 +19,12 @@
 #include "documentchangeset.h"
 
 #include "coderepresentation.h"
+#include "util/debug.h"
 
 #include <algorithm>
 
 #include <QStringList>
+#include <QMimeDatabase>
 
 #include <KLocalizedString>
 
@@ -44,6 +46,8 @@
 
 #include <project/projectmodel.h>
 
+#include <util/path.h>
+
 namespace KDevelop {
 
 typedef QList<DocumentChangePointer> ChangesList;
@@ -77,13 +81,13 @@ namespace
 {
 inline bool changeIsValid(const DocumentChange& change, const QStringList& textLines)
 {
-    return change.m_range.start <= change.m_range.end &&
-           change.m_range.end.line < textLines.size() &&
-           change.m_range.start.line >= 0 &&
-           change.m_range.start.column >= 0 &&
-           change.m_range.start.column <= textLines[change.m_range.start.line].length() &&
-           change.m_range.end.column >= 0 &&
-           change.m_range.end.column <= textLines[change.m_range.end.line].length();
+    return change.m_range.start() <= change.m_range.end() &&
+           change.m_range.end().line() < textLines.size() &&
+           change.m_range.start().line() >= 0 &&
+           change.m_range.start().column() >= 0 &&
+           change.m_range.start().column() <= textLines[change.m_range.start().line()].length() &&
+           change.m_range.end().column() >= 0 &&
+           change.m_range.end().column() <= textLines[change.m_range.end().line()].length();
 }
 
 inline bool duplicateChanges(const DocumentChangePointer& previous, const DocumentChangePointer& current)
@@ -96,25 +100,34 @@ inline bool duplicateChanges(const DocumentChangePointer& previous, const Docume
            (previous->m_ignoreOldText && current->m_ignoreOldText));
 }
 
-inline QString rangeText(const SimpleRange& range, const QStringList& textLines)
+inline QString rangeText(const KTextEditor::Range& range, const QStringList& textLines)
 {
     QStringList ret;
-    ret.reserve(range.end.line - range.start.line + 1);
-    for(int line = range.start.line; line <= range.end.line; ++line) {
+    ret.reserve(range.end().line() - range.start().line() + 1);
+    for(int line = range.start().line(); line <= range.end().line(); ++line) {
         const QString lineText = textLines.at(line);
         int startColumn = 0;
         int endColumn = lineText.length();
-        if (line == range.start.line) {
-            startColumn = range.start.column;
+        if (line == range.start().line()) {
+            startColumn = range.start().column();
         }
-        if (line == range.end.line) {
-            endColumn = range.end.column;
+        if (line == range.end().line()) {
+            endColumn = range.end().column();
         }
         ret << lineText.mid(startColumn, endColumn - startColumn);
     }
     return ret.join("\n");
 }
 
+// need to have it as otherwise the arguments can exceed the maximum of 10
+static QString printRange(const KTextEditor::Range& r)
+{
+    return i18nc("text range line:column->line:column", "%1:%2->%3:%4",
+                 r.start().line(), r.start().column(),
+                 r.end().line(), r.end().column());
+}
+
+
 }
 
 DocumentChangeSet::DocumentChangeSet()
@@ -186,43 +199,9 @@ void DocumentChangeSet::setActivationPolicy(DocumentChangeSet::ActivationPolicy
     d->activationPolicy = policy;
 }
 
-QHash<IndexedString, InsertArtificialCodeRepresentationPointer> DocumentChangeSet::temporaryCodeRepresentations() const
-{
-    QHash<IndexedString, InsertArtificialCodeRepresentationPointer> ret;
-
-    ChangeResult result(true);
-
-    foreach(const IndexedString &file, d->changes.keys()) {
-        CodeRepresentation::Ptr repr = createCodeRepresentation(file);
-
-        if(!repr) {
-            continue;
-        }
-
-        ChangesList sortedChangesList;
-        result = d->removeDuplicates(file, sortedChangesList);
-        if (!result) {
-            continue;
-        }
-
-        QString newText;
-
-        result = d->generateNewText(file, sortedChangesList, repr.data(), newText);
-        if (!result) {
-            continue;
-        }
-
-        InsertArtificialCodeRepresentationPointer code(
-            new InsertArtificialCodeRepresentation(IndexedString(file.toUrl().fileName()), newText) );
-        ret.insert(file, code);
-    }
-
-    return ret;
-}
-
 DocumentChangeSet::ChangeResult DocumentChangeSet::applyAllChanges()
 {
-    KUrl oldActiveDoc;
+    QUrl oldActiveDoc;
     if (IDocument* activeDoc = ICore::self()->documentController()->activeDocument()) {
         oldActiveDoc = activeDoc->url();
     }
@@ -230,14 +209,14 @@ DocumentChangeSet::ChangeResult DocumentChangeSet::applyAllChanges()
     // rename files
     QHash<IndexedString, IndexedString>::const_iterator it = d->documentsRename.constBegin();
     for(; it != d->documentsRename.constEnd(); ++it) {
-        KUrl url = it.key().toUrl();
+        QUrl url = it.key().toUrl();
         IProject* p = ICore::self()->projectController()->findProjectForUrl(url);
         if(p) {
-            QList<ProjectFileItem*> files = p->filesForUrl(url);
+            QList<ProjectFileItem*> files = p->filesForPath(it.key());
             if(!files.isEmpty()) {
                 ProjectBaseItem::RenameStatus renamed = files.first()->rename(it.value().str());
                 if(renamed == ProjectBaseItem::RenameOk) {
-                    const KUrl newUrl(url.upUrl(), it.value().str());
+                    const QUrl newUrl = Path(Path(url).parent(), it.value().str()).toUrl();
                     if (url == oldActiveDoc) {
                         oldActiveDoc = newUrl;
                     }
@@ -260,14 +239,14 @@ DocumentChangeSet::ChangeResult DocumentChangeSet::applyAllChanges()
                     }
                 } else {
                     ///FIXME: share code with project manager for the error code string representation
-                    return ChangeResult(i18n("Could not rename '%1' to '%2'", url.pathOrUrl(), it.value().str()));
+                    return ChangeResult(i18n("Could not rename '%1' to '%2'", url.toDisplayString(QUrl::PreferLocalFile), it.value().str()));
                 }
             } else {
                 //TODO: do it outside the project management?
-                kWarning() << "tried to rename file not tracked by project - not implemented";
+                qCWarning(LANGUAGE) << "tried to rename file not tracked by project - not implemented";
             }
         } else {
-            kWarning() << "tried to rename a file outside of a project - not implemented";
+            qCWarning(LANGUAGE) << "tried to rename a file outside of a project - not implemented";
         }
     }
 
@@ -281,7 +260,7 @@ DocumentChangeSet::ChangeResult DocumentChangeSet::applyAllChanges()
     foreach(const IndexedString &file, files) {
         CodeRepresentation::Ptr repr = createCodeRepresentation(file);
         if(!repr) {
-            return ChangeResult(QString("Could not create a Representation for %1").arg(file.str()));
+            return ChangeResult(QStringLiteral("Could not create a Representation for %1").arg(file.str()));
         }
 
         codeRepresentations[file] = repr;
@@ -339,43 +318,38 @@ DocumentChangeSet::ChangeResult DocumentChangeSetPrivate::replaceOldText(CodeRep
 {
     DynamicCodeRepresentation* dynamic = dynamic_cast<DynamicCodeRepresentation*>(repr);
     if(dynamic) {
-        dynamic->startEdit();
+        auto transaction = dynamic->makeEditTransaction();
         //Replay the changes one by one
 
         for(int pos = sortedChangesList.size()-1; pos >= 0; --pos) {
             const DocumentChange& change(*sortedChangesList[pos]);
-            if(!dynamic->replace(change.m_range.textRange(), change.m_oldText, change.m_newText, change.m_ignoreOldText))
+            if(!dynamic->replace(change.m_range, change.m_oldText, change.m_newText, change.m_ignoreOldText))
             {
-                QString warningString = QString("Inconsistent change in %1 at %2:%3 -> %4:%5 = %6(encountered \"%7\") -> \"%8\"")
-                    .arg(change.m_document.str())
-                    .arg(change.m_range.start.line)
-                    .arg(change.m_range.start.column)
-                    .arg(change.m_range.end.line)
-                    .arg(change.m_range.end.column)
-                    .arg(change.m_oldText)
-                    .arg(dynamic->rangeText(change.m_range.textRange()))
-                    .arg(change.m_newText);
+                QString warningString = i18nc("Inconsistent change in <filename> between <range>, found <oldText> (encountered <foundText>) -> <newText>",
+                                              "Inconsistent change in %1 between %2, found %3 (encountered \"%4\") -> \"%5\""
+                    , change.m_document.str()
+                    , printRange(change.m_range)
+                    , change.m_oldText
+                    , dynamic->rangeText(change.m_range)
+                    , change.m_newText);
 
                 if(replacePolicy == DocumentChangeSet::WarnOnFailedChange) {
-                    kWarning() << warningString;
+                    qCWarning(LANGUAGE) << warningString;
                 } else if(replacePolicy == DocumentChangeSet::StopOnFailedChange) {
-                    dynamic->endEdit();
                     return DocumentChangeSet::ChangeResult(warningString);
                 }
                 //If set to ignore failed changes just continue with the others
             }
         }
-
-        dynamic->endEdit();
         return true;
     }
 
     //For files on disk
     if (!repr->setText(newText)) {
-        QString warningString = QString("Could not replace text in the document: %1")
-            .arg(sortedChangesList.begin()->data()->m_document.str());
+        QString warningString = i18n("Could not replace text in the document: %1",
+                                     sortedChangesList.begin()->data()->m_document.str());
         if(replacePolicy == DocumentChangeSet::WarnOnFailedChange) {
-            kWarning() << warningString;
+            qCWarning(LANGUAGE) << warningString;
         }
 
         return DocumentChangeSet::ChangeResult(warningString);
@@ -398,9 +372,9 @@ DocumentChangeSet::ChangeResult DocumentChangeSetPrivate::generateNewText(const
     //Create the actual new modified file
     QStringList textLines = repr->text().split('\n');
 
-    KUrl url = file.toUrl();
+    QUrl url = file.toUrl();
 
-    KMimeType::Ptr mime = KMimeType::findByUrl(url);
+    QMimeType mime = QMimeDatabase().mimeTypeForUrl(url);
     QVector<int> removedLines;
 
     for(int pos = sortedChanges.size()-1; pos >= 0; --pos) {
@@ -410,10 +384,10 @@ DocumentChangeSet::ChangeResult DocumentChangeSetPrivate::generateNewText(const
             ((encountered = rangeText(change.m_range, textLines)) == change.m_oldText || change.m_ignoreOldText))
         {
             ///Problem: This does not work if the other changes significantly alter the context @todo Use the changed context
-            QString leftContext = QStringList(textLines.mid(0, change.m_range.start.line+1)).join("\n");
-            leftContext.chop(textLines[change.m_range.start.line].length() - change.m_range.start.column);
+            QString leftContext = QStringList(textLines.mid(0, change.m_range.start().line()+1)).join("\n");
+            leftContext.chop(textLines[change.m_range.start().line()].length() - change.m_range.start().column());
 
-            QString rightContext = QStringList(textLines.mid(change.m_range.end.line)).join("\n").mid(change.m_range.end.column);
+            QString rightContext = QStringList(textLines.mid(change.m_range.end().line())).join("\n").mid(change.m_range.end().column());
 
             if(formatter && (formatPolicy == DocumentChangeSet::AutoFormatChanges
                                 || formatPolicy == DocumentChangeSet::AutoFormatChangesKeepIndentation))
@@ -452,43 +426,42 @@ DocumentChangeSet::ChangeResult DocumentChangeSetPrivate::generateNewText(const
                         }
                         change.m_newText = newLines.join("\n");
                     } else {
-                        kDebug() << "Cannot keep the indentation because the line count has changed" << oldNewText;
+                        qCDebug(LANGUAGE) << "Cannot keep the indentation because the line count has changed" << oldNewText;
                     }
                 }
             }
 
-            QString& line = textLines[change.m_range.start.line];
-            if (change.m_range.start.line == change.m_range.end.line) {
+            QString& line = textLines[change.m_range.start().line()];
+            if (change.m_range.start().line() == change.m_range.end().line()) {
                 // simply replace existing line content
-                line.replace(change.m_range.start.column,
-                             change.m_range.end.column-change.m_range.start.column,
+                line.replace(change.m_range.start().column(),
+                             change.m_range.end().column()-change.m_range.start().column(),
                              change.m_newText);
             } else {
                 // replace first line contents
-                line.replace(change.m_range.start.column, line.length() - change.m_range.start.column,
+                line.replace(change.m_range.start().column(), line.length() - change.m_range.start().column(),
                              change.m_newText);
                 // null other lines and remember for deletion
-                for(int i = change.m_range.start.line + 1; i <= change.m_range.end.line; ++i) {
+                for(int i = change.m_range.start().line() + 1; i <= change.m_range.end().line(); ++i) {
                     textLines[i].clear();
                     removedLines << i;
                 }
             }
         }else{
-            QString warningString = QString("Inconsistent change in %1 at %2:%3 -> %4:%5"
-                                            " = \"%6\"(encountered \"%7\") -> \"%8\"")
-                                            .arg(file.str())
-                                            .arg(change.m_range.start.line)
-                                            .arg(change.m_range.start.column)
-                                            .arg(change.m_range.end.line)
-                                            .arg(change.m_range.end.column)
-                                            .arg(change.m_oldText)
-                                            .arg(encountered)
-                                            .arg(change.m_newText);
+            QString warningString = i18nc("Inconsistent change in <document> at <range>"
+                                         " = <oldText> (encountered <encountered>) -> <newText>",
+                                         "Inconsistent change in %1 at %2"
+                                         " = \"%3\"(encountered \"%4\") -> \"%5\""
+                                            , file.str()
+                                            , printRange(change.m_range)
+                                            , change.m_oldText
+                                            , encountered
+                                            , change.m_newText);
 
             if(replacePolicy == DocumentChangeSet::IgnoreFailedChange) {
                 //Just don't do the replacement
             } else if(replacePolicy == DocumentChangeSet::WarnOnFailedChange) {
-                kWarning() << warningString;
+                qCWarning(LANGUAGE) << warningString;
             } else {
                 return DocumentChangeSet::ChangeResult(warningString, sortedChanges[pos]);
             }
@@ -497,7 +470,7 @@ DocumentChangeSet::ChangeResult DocumentChangeSetPrivate::generateNewText(const
 
     if (!removedLines.isEmpty()) {
         int offset = 0;
-        qSort(removedLines);
+        std::sort(removedLines.begin(), removedLines.end());
         foreach(int l, removedLines) {
             textLines.removeAt(l - offset);
             ++offset;
@@ -511,17 +484,17 @@ DocumentChangeSet::ChangeResult DocumentChangeSetPrivate::generateNewText(const
 DocumentChangeSet::ChangeResult DocumentChangeSetPrivate::removeDuplicates(const IndexedString& file,
                                                                            ChangesList& filteredChanges)
 {
-    typedef QMultiMap<SimpleCursor, DocumentChangePointer> ChangesMap;
+    typedef QMultiMap<KTextEditor::Cursor, DocumentChangePointer> ChangesMap;
     ChangesMap sortedChanges;
 
     foreach(const DocumentChangePointer &change, changes[file]) {
-        sortedChanges.insert(change->m_range.end, change);
+        sortedChanges.insert(change->m_range.end(), change);
     }
 
     //Remove duplicates
     ChangesMap::iterator previous = sortedChanges.begin();
     for(ChangesMap::iterator it = ++sortedChanges.begin(); it != sortedChanges.end(); ) {
-        if(( *previous ) && ( *previous )->m_range.end > (*it)->m_range.start) {
+        if(( *previous ) && ( *previous )->m_range.end() > (*it)->m_range.start()) {
             //intersection
             if(duplicateChanges(( *previous ), *it)) {
                 //duplicate, remove one
@@ -532,32 +505,33 @@ DocumentChangeSet::ChangeResult DocumentChangeSetPrivate::removeDuplicates(const
             //When two changes contain each other, and the container change is set to ignore old text, then it should be safe to
             //just ignore the contained change, and apply the bigger change
             else if((*it)->m_range.contains(( *previous )->m_range) && (*it)->m_ignoreOldText  ) {
-                kDebug() << "Removing change: " << ( *previous )->m_oldText << "->" << ( *previous )->m_newText
+                qCDebug(LANGUAGE) << "Removing change: " << ( *previous )->m_oldText << "->" << ( *previous )->m_newText
                          << ", because it is contained by change: " << (*it)->m_oldText << "->" << (*it)->m_newText;
                 sortedChanges.erase(previous);
             }
             //This case is for when both have the same end, either of them could be the containing range
             else if((*previous)->m_range.contains((*it)->m_range) && (*previous)->m_ignoreOldText  ) {
-                kDebug() << "Removing change: " << (*it)->m_oldText << "->" << (*it)->m_newText
+                qCDebug(LANGUAGE) << "Removing change: " << (*it)->m_oldText << "->" << (*it)->m_newText
                          << ", because it is contained by change: " << ( *previous )->m_oldText
                          << "->" << ( *previous )->m_newText;
                 it = sortedChanges.erase(it);
                 continue;
             } else {
                 return DocumentChangeSet::ChangeResult(
-                       QString("Inconsistent change-request at %1; "
+                       i18nc("Inconsistent change-request at <document>:"
+                             "intersecting changes: "
+                             "<previous-oldText> -> <previous-newText> @<range> & "
+                             "<new-oldText> -> <new-newText> @<range>",
+                               "Inconsistent change-request at %1; "
                                "intersecting changes: "
-                               "\"%2\"->\"%3\"@%4:%5->%6:%7 & \"%8\"->\"%9\"@%10:%11->%12:%13 ")
-                        .arg(file.str(), ( *previous )->m_oldText, ( *previous )->m_newText)
-                        .arg(( *previous )->m_range.start.line)
-                        .arg(( *previous )->m_range.start.column)
-                        .arg(( *previous )->m_range.end.line)
-                        .arg(( *previous )->m_range.end.column)
-                        .arg((*it)->m_oldText, (*it)->m_newText)
-                        .arg((*it)->m_range.start.line)
-                        .arg((*it)->m_range.start.column)
-                        .arg((*it)->m_range.end.line)
-                        .arg((*it)->m_range.end.column));
+                               "\"%2\"->\"%3\"@%4 & \"%5\"->\"%6\"@%7 "
+                        , file.str()
+                        , ( *previous )->m_oldText
+                        , ( *previous )->m_newText
+                        , printRange(( *previous )->m_range)
+                        , (*it)->m_oldText
+                        , (*it)->m_newText
+                        , printRange((*it)->m_range)));
             }
 
         }
@@ -596,7 +570,7 @@ void DocumentChangeSetPrivate::updateFiles()
         // Eventually update _all_ affected files
         foreach(const IndexedString &file, changes.keys()) {
             if(!file.toUrl().isValid()) {
-                kWarning() << "Trying to apply changes to an invalid document";
+                qCWarning(LANGUAGE) << "Trying to apply changes to an invalid document";
                 continue;
             }
 
