@@ -19,6 +19,7 @@
 
 #include "templateclassgenerator.h"
 #include "archivetemplateloader.h"
+#include "util/debug.h"
 
 #include "interfaces/icore.h"
 #include <interfaces/iprojectcontroller.h>
@@ -28,6 +29,7 @@
 #include "templaterenderer.h"
 #include "sourcefiletemplate.h"
 #include "templateengine.h"
+#include <duchain/declaration.h>
 #include <duchain/duchainlock.h>
 #include <duchain/persistentsymboltable.h>
 #include <duchain/types/structuretype.h>
@@ -35,9 +37,6 @@
 #include <project/interfaces/ibuildsystemmanager.h>
 #include <project/projectmodel.h>
 
-#include <KComponentData>
-#include <KStandardDirs>
-
 #include <QFileInfo>
 
 using namespace KDevelop;
@@ -59,7 +58,7 @@ class KDevelop::TemplateClassGeneratorPrivate
 {
 public:
     SourceFileTemplate fileTemplate;
-    KUrl baseUrl;
+    QUrl baseUrl;
     TemplateRenderer renderer;
 
     QString name;
@@ -67,10 +66,10 @@ public:
     QStringList namespaces;
     QString license;
 
-    QHash<QString, KUrl> fileUrls;
-    QHash<QString, SimpleCursor> filePositions;
+    QHash<QString, QUrl> fileUrls;
+    QHash<QString, KTextEditor::Cursor> filePositions;
     ClassDescription description;
-    
+
     QList<DeclarationPointer> directBaseClasses;
     QList<DeclarationPointer> allBaseClasses;
 
@@ -102,9 +101,11 @@ void TemplateClassGeneratorPrivate::fetchSuperClasses(const DeclarationPointer&
 }
 
 
-TemplateClassGenerator::TemplateClassGenerator(const KUrl& baseUrl)
+TemplateClassGenerator::TemplateClassGenerator(const QUrl& baseUrl)
  : d(new TemplateClassGeneratorPrivate)
 {
+    Q_ASSERT(QFileInfo(baseUrl.toLocalFile()).isDir()); // assume folder
+
     d->baseUrl = baseUrl;
     d->renderer.setEmptyLinesPolicy(TemplateRenderer::TrimEmptyLines);
 }
@@ -144,9 +145,8 @@ TemplateClassGenerator::UrlHash TemplateClassGenerator::fileUrls() const
     {
         foreach (const SourceFileTemplate::OutputFile& outputFile, d->fileTemplate.outputFiles())
         {
-            KUrl url(d->baseUrl);
             QString outputName = d->renderer.render(outputFile.outputName, outputFile.identifier);
-            url.addPath(outputName);
+            QUrl url = d->baseUrl.resolved(QUrl(outputName));
             d->fileUrls.insert(outputFile.identifier, url);
         }
     }
@@ -154,29 +154,29 @@ TemplateClassGenerator::UrlHash TemplateClassGenerator::fileUrls() const
     return d->fileUrls;
 }
 
-KUrl TemplateClassGenerator::baseUrl() const
+QUrl TemplateClassGenerator::baseUrl() const
 {
     return d->baseUrl;
 }
 
-KUrl TemplateClassGenerator::fileUrl(const QString& outputFile) const
+QUrl TemplateClassGenerator::fileUrl(const QString& outputFile) const
 {
     return fileUrls().value(outputFile);
 }
 
-void TemplateClassGenerator::setFileUrl(const QString& outputFile, const KUrl& url)
+void TemplateClassGenerator::setFileUrl(const QString& outputFile, const QUrl& url)
 {
     d->fileUrls.insert(outputFile, url);
-    d->renderer.addVariable("output_file_" + outputFile.toLower(), KUrl::relativeUrl(d->baseUrl, url));
+    d->renderer.addVariable("output_file_" + outputFile.toLower(), QDir(d->baseUrl.path()).relativeFilePath(url.path()));
     d->renderer.addVariable("output_file_" + outputFile.toLower() + "_absolute", url.toLocalFile());
 }
 
-SimpleCursor TemplateClassGenerator::filePosition(const QString& outputFile) const
+KTextEditor::Cursor TemplateClassGenerator::filePosition(const QString& outputFile) const
 {
     return d->filePositions.value(outputFile);
 }
 
-void TemplateClassGenerator::setFilePosition(const QString& outputFile, const SimpleCursor& position)
+void TemplateClassGenerator::setFilePosition(const QString& outputFile, const KTextEditor::Cursor& position)
 {
     d->filePositions.insert(outputFile, position);
 }
@@ -251,7 +251,7 @@ void TemplateClassGenerator::setNamespaces(const QStringList& namespaces) const
 /// Specify license for this class
 void TemplateClassGenerator::setLicense(const QString& license)
 {
-    kDebug() << "New Class: " << d->name << "Set license: " << d->license;
+    qCDebug(LANGUAGE) << "New Class: " << d->name << "Set license: " << d->license;
     d->license = license;
     d->renderer.addVariable("license", license);
 }
