@@ -25,18 +25,18 @@
 #include "templateengine.h"
 #include "templateengine_p.h"
 #include "archivetemplateloader.h"
+#include "util/debug.h"
 
-#include <language/editor/simplecursor.h>
-#include <language/editor/simplerange.h>
-#include <language/duchain/indexedstring.h>
+#include <serialization/indexedstring.h>
 
 #include <grantlee/context.h>
 
-#include <KUrl>
-#include <KDebug>
-#include <KArchive>
-
+#include <QDebug>
+#include <QDir>
 #include <QFile>
+#include <QUrl>
+
+#include <KArchive>
 
 using namespace Grantlee;
 
@@ -46,8 +46,8 @@ public:
     NoEscapeStream();
     explicit NoEscapeStream (QTextStream* stream);
 
-    virtual QString escape (const QString& input) const;
-    virtual QSharedPointer< OutputStream > clone (QTextStream* stream) const;
+    virtual QString escape (const QString& input) const override;
+    virtual QSharedPointer< OutputStream > clone (QTextStream* stream) const override;
 };
 
 NoEscapeStream::NoEscapeStream() : OutputStream()
@@ -120,43 +120,9 @@ QVariantHash TemplateRenderer::variables() const
 
 QString TemplateRenderer::render(const QString& content, const QString& name) const
 {
-#if WITH_SMART_TRIM
     Template t = d->engine->newTemplate(content, name);
-#else
-    /*
-     * This code re-implements the functionality of Grantlee's smart trim feature, which was added in 0.1.8
-     * It follows the description from http://www.grantlee.org/apidox/classGrantlee_1_1Engine.html#smart_trim
-     * and passes the unit tests.
-     */
-    const QStringList lines = content.split('\n');
 
-    QStringList trimmedLines;
-    trimmedLines << QString();
-
-    for (QStringList::const_iterator it = lines.constBegin(); it != lines.constEnd(); ++it)
-    {
-        QString s = (*it);
-        const QString t = s.trimmed();
-        if ( (t.startsWith("{%") && t.endsWith("%}") && t.count('{') == 1 && t.count('}') == 1)
-            || (t.startsWith("{{") && t.endsWith("}}") && t.count('{') == 2 && t.count('}') == 2)
-            || (t.startsWith("{#") && t.endsWith("#}") && t.count('{') == 1 && t.count('}') == 1) )
-        {
-            trimmedLines.last() += t;
-        }
-        else
-        {
-            trimmedLines << (*it);
-        }
-    }
-
-    if (trimmedLines.first().isEmpty())
-    {
-        trimmedLines.removeFirst();
-    }
-    Template t = d->engine->newTemplate(trimmedLines.join("\n"), name);
-#endif
     QString output;
-
     QTextStream textStream(&output);
     NoEscapeStream stream(&textStream);
     t->render(&stream, &d->context);
@@ -259,20 +225,20 @@ QString TemplateRenderer::render(const QString& content, const QString& name) co
     return output;
 }
 
-QString TemplateRenderer::renderFile(const KUrl& url, const QString& name) const
+QString TemplateRenderer::renderFile(const QUrl& url, const QString& name) const
 {
     QFile file(url.toLocalFile());
     file.open(QIODevice::ReadOnly);
 
     QString content(file.readAll());
-    kDebug() << content;
+    qCDebug(LANGUAGE) << content;
 
     return render(content, name);
 }
 
 QStringList TemplateRenderer::render(const QStringList& contents) const
 {
-    kDebug() << d->context.stackHash(0);
+    qCDebug(LANGUAGE) << d->context.stackHash(0);
     QStringList ret;
     foreach (const QString& content, contents)
     {
@@ -292,20 +258,20 @@ TemplateRenderer::EmptyLinesPolicy TemplateRenderer::emptyLinesPolicy() const
 }
 
 DocumentChangeSet TemplateRenderer::renderFileTemplate(const SourceFileTemplate& fileTemplate,
-                                                       const KUrl& baseUrl,
-                                                       const QHash<QString, KUrl>& fileUrls)
+                                                       const QUrl& baseUrl,
+                                                       const QHash<QString, QUrl>& fileUrls)
 {
     DocumentChangeSet changes;
-    KUrl url(baseUrl);
+    const QDir baseDir(baseUrl.path());
 
-    url.adjustPath(KUrl::AddTrailingSlash);
     QRegExp nonAlphaNumeric("\\W");
-    for (QHash<QString,KUrl>::const_iterator it = fileUrls.constBegin(); it != fileUrls.constEnd(); ++it)
+    for (QHash<QString,QUrl>::const_iterator it = fileUrls.constBegin(); it != fileUrls.constEnd(); ++it)
     {
         QString cleanName = it.key().toLower();
         cleanName.replace(nonAlphaNumeric, "_");
-        addVariable("output_file_" + cleanName, KUrl::relativeUrl(url, it.value()));
-        addVariable("output_file_" + cleanName + "_absolute", it.value().toLocalFile());
+        const QString path = it.value().toLocalFile();
+        addVariable("output_file_" + cleanName, baseDir.relativeFilePath(path));
+        addVariable("output_file_" + cleanName + "_absolute", path);
     }
 
     const KArchiveDirectory* directory = fileTemplate.directory();
@@ -315,24 +281,24 @@ DocumentChangeSet TemplateRenderer::renderFileTemplate(const SourceFileTemplate&
         const KArchiveEntry* entry = directory->entry(outputFile.fileName);
         if (!entry)
         {
-            kWarning() << "Entry" << outputFile.fileName << "is mentioned in group" << outputFile.identifier << "but is not present in the archive";
+            qCWarning(LANGUAGE) << "Entry" << outputFile.fileName << "is mentioned in group" << outputFile.identifier << "but is not present in the archive";
             continue;
         }
 
         const KArchiveFile* file = dynamic_cast<const KArchiveFile*>(entry);
         if (!file)
         {
-            kWarning() << "Entry" << entry->name() << "is not a file";
+            qCWarning(LANGUAGE) << "Entry" << entry->name() << "is not a file";
             continue;
         }
 
-        KUrl url = fileUrls[outputFile.identifier];
+        QUrl url = fileUrls[outputFile.identifier];
         IndexedString document(url);
-        SimpleRange range(SimpleCursor(0, 0), 0);
+        KTextEditor::Range range(KTextEditor::Cursor(0, 0), 0);
 
         DocumentChange change(document, range, QString(), render(file->data(), outputFile.identifier));
         changes.addChange(change);
-        kDebug() << "Added change for file" << document.str();
+        qCDebug(LANGUAGE) << "Added change for file" << document.str();
     }
 
     return changes;
