@@ -23,7 +23,7 @@
 
 #include <QStandardItemModel>
 
-#include "../languageexport.h"
+#include <language/languageexport.h>
 
 namespace KDevelop
 {
@@ -37,7 +37,7 @@ class TemplatesModelPrivate;
  * displays them as a three-level tree structure.
  *
  * The locations for loading and storing files are determined by the typePrefix.
- * We use KStandardDirs with the "data" type and create a filter string as such:
+ * We use QStandardPaths with the GenericData type and create a filter string as such:
  * \li templates: typePrefix "/templates/"
  * \li descriptions: typePrefix "/template_descriptions/"
  * \li previews: typePrefix "/template_previews/"
@@ -105,6 +105,14 @@ public:
      **/
     QString typePrefix() const;
 
+    /**
+     * The model will include @p path during the search for template archives
+     *
+     * @param path Path to a directory that contains normal user data. The template model will search for a kdevappwizard/templates (or your model name prefix) directory
+     * inside @p path and will use them. Please note that the path has to end with a '/'.
+     */
+    void addDataPath(const QString &path);
+
 private:
     TemplatesModelPrivate* const d;
 };
