@@ -30,12 +30,6 @@
 #include "tests/autotestshell.h"
 #include "tests/testcore.h"
 
-#include <KComponentData>
-#include <KStandardDirs>
-#include <KUrl>
-
-#include <qtest_kde.h>
-
 #define CHECK_TEMPLATE_VARIABLE(name, type, val)            \
 QVERIFY(variables.contains(#name));                         \
 QCOMPARE(variables.value(#name).value<type>(), val)
@@ -50,12 +44,9 @@ void TestTemplateClassGenerator::initTestCase()
     AutoTestShell::init();
     TestCore::initialize(Core::NoUi);
 
-    KComponentData data = ICore::self()->componentData();
-    baseUrl.setDirectory(KStandardDirs::locateLocal("tmp", "test_templateclassgenerator/", data));
-
-    KStandardDirs *dirs = data.dirs();
-    bool addedDir = dirs->addResourceDir("data", CODEGEN_TESTS_DATA_DIR, true);
-    QVERIFY(addedDir);
+    // Use a temporary directory for the template work
+    tempDir.setAutoRemove(true);
+    baseUrl = QUrl::fromLocalFile(tempDir.path() + '/');
 
     // Needed for extracting description out of template archives
     TemplatesModel model("kdevcodegentest");
@@ -112,30 +103,24 @@ void TestTemplateClassGenerator::fileLabelsYaml()
 void TestTemplateClassGenerator::defaultFileUrlsCpp()
 {
     TemplateClassGenerator* generator = loadTemplate("test_cpp");
-    QHash<QString,KUrl> files = generator->fileUrls();
+    QHash<QString,QUrl> files = generator->fileUrls();
     QCOMPARE(files.size(), 2);
 
     QVERIFY(files.contains("Header"));
-    KUrl expectedHeaderUrl(baseUrl);
-    expectedHeaderUrl.addPath("ClassName.h");
-    QCOMPARE(files["Header"], expectedHeaderUrl);
+    QCOMPARE(files["Header"], baseUrl.resolved(QUrl("ClassName.h")));
 
     QVERIFY(files.contains("Implementation"));
-    KUrl expectedImplementationUrl(baseUrl);
-    expectedImplementationUrl.addPath("ClassName.cpp");
-    QCOMPARE(files["Implementation"], expectedImplementationUrl);
+    QCOMPARE(files["Implementation"], baseUrl.resolved(QUrl("ClassName.cpp")));
 }
 
 void TestTemplateClassGenerator::defaultFileUrlsYaml()
 {
     TemplateClassGenerator* generator = loadTemplate("test_yaml");
-    QHash<QString,KUrl> files = generator->fileUrls();
+    QHash<QString,QUrl> files = generator->fileUrls();
     QCOMPARE(files.size(), 1);
 
     QVERIFY(files.contains("Description"));
-    KUrl expectedHeaderUrl(baseUrl);
-    expectedHeaderUrl.addPath("ClassName.yaml");
-    QCOMPARE(files["Description"], expectedHeaderUrl);
+    QCOMPARE(files["Description"], baseUrl.resolved(QUrl("ClassName.yaml")));
 }
 
 void TestTemplateClassGenerator::customOptions()
@@ -150,12 +135,10 @@ void TestTemplateClassGenerator::templateVariablesCpp()
     setLowercaseFileNames(generator);
 
     QVariantHash variables = generator->renderer()->variables();
-    CHECK_TEMPLATE_VARIABLE(name, QString, QString("ClassName"));
+    CHECK_TEMPLATE_VARIABLE(name, QString, QStringLiteral("ClassName"));
 
-    KUrl headerUrl(baseUrl);
-    headerUrl.addPath("classname.h");
-    CHECK_TEMPLATE_VARIABLE(output_file_header, QString, QString("classname.h"));
-    CHECK_TEMPLATE_VARIABLE(output_file_header_absolute, QString, headerUrl.toLocalFile());
+    CHECK_TEMPLATE_VARIABLE(output_file_header, QString, QStringLiteral("classname.h"));
+    CHECK_TEMPLATE_VARIABLE(output_file_header_absolute, QString, baseUrl.resolved(QUrl("classname.h")).toLocalFile());
 }
 
 void TestTemplateClassGenerator::templateVariablesYaml()
@@ -164,12 +147,10 @@ void TestTemplateClassGenerator::templateVariablesYaml()
     setLowercaseFileNames(generator);
 
     QVariantHash variables = generator->renderer()->variables();
-    CHECK_TEMPLATE_VARIABLE(name, QString, QString("ClassName"));
+    CHECK_TEMPLATE_VARIABLE(name, QString, QStringLiteral("ClassName"));
 
-    KUrl fileUrl(baseUrl);
-    fileUrl.addPath("classname.yaml");
-    CHECK_TEMPLATE_VARIABLE(output_file_description, QString, QString("classname.yaml"));
-    CHECK_TEMPLATE_VARIABLE(output_file_description_absolute, QString, fileUrl.toLocalFile());
+    CHECK_TEMPLATE_VARIABLE(output_file_description, QString, QStringLiteral("classname.yaml"));
+    CHECK_TEMPLATE_VARIABLE(output_file_description_absolute, QString, baseUrl.resolved(QUrl("classname.yaml")).toLocalFile());
 }
 
 void TestTemplateClassGenerator::codeDescription()
@@ -183,22 +164,22 @@ void TestTemplateClassGenerator::codeDescription()
     QVERIFY(variables.contains("base_classes"));
     QVariantList inheritance = variables["base_classes"].toList();
     QCOMPARE(inheritance.size(), 1);
-    QCOMPARE(inheritance.first().value<InheritanceDescription>().baseType, QString("QObject"));
-    QCOMPARE(inheritance.first().value<InheritanceDescription>().inheritanceMode, QString("public"));
+    QCOMPARE(inheritance.first().value<InheritanceDescription>().baseType, QStringLiteral("QObject"));
+    QCOMPARE(inheritance.first().value<InheritanceDescription>().inheritanceMode, QStringLiteral("public"));
 
     QVERIFY(variables.contains("members"));
     QVariantList members = variables["members"].toList();
     QCOMPARE(members.size(), 3);
-    QCOMPARE(members.first().value<VariableDescription>().type, QString("QString"));
-    QCOMPARE(members.first().value<VariableDescription>().name, QString("name"));
+    QCOMPARE(members.first().value<VariableDescription>().type, QStringLiteral("QString"));
+    QCOMPARE(members.first().value<VariableDescription>().name, QStringLiteral("name"));
 
     QVERIFY(variables.contains("functions"));
     QVariantList methods = variables["functions"].toList();
     QCOMPARE(methods.size(), 2);
-    QCOMPARE(methods.first().value<FunctionDescription>().name, QString("doSomething"));
+    QCOMPARE(methods.first().value<FunctionDescription>().name, QStringLiteral("doSomething"));
     QCOMPARE(methods.first().value<FunctionDescription>().arguments.size(), 2);
     QCOMPARE(methods.first().value<FunctionDescription>().returnArguments.size(), 0);
-    QCOMPARE(methods.last().value<FunctionDescription>().name, QString("getSomeOtherNumber"));
+    QCOMPARE(methods.last().value<FunctionDescription>().name, QStringLiteral("getSomeOtherNumber"));
     QCOMPARE(methods.last().value<FunctionDescription>().arguments.size(), 0);
     QCOMPARE(methods.last().value<FunctionDescription>().returnArguments.size(), 1);
 }
@@ -224,18 +205,14 @@ void TestTemplateClassGenerator::cppOutput()
     changes.setFormatPolicy(DocumentChangeSet::NoAutoFormat);
     changes.applyAllChanges();
 
-    KUrl headerUrl = baseUrl;
-    headerUrl.addPath("classname.h");
-    QFile header(headerUrl.toLocalFile());
+    QFile header(baseUrl.resolved(QUrl("classname.h")).toLocalFile());
     QVERIFY(header.open(QIODevice::ReadOnly));
 
     QFile testHeader(CODEGEN_TESTS_EXPECTED_DIR "/classname.h");
     testHeader.open(QIODevice::ReadOnly);
     COMPARE_FILES(header, testHeader);
 
-    KUrl implementationUrl = baseUrl;
-    implementationUrl.addPath("classname.cpp");
-    QFile implementation(implementationUrl.toLocalFile());
+    QFile implementation(baseUrl.resolved(QUrl("classname.cpp")).toLocalFile());
     QVERIFY(implementation.open(QIODevice::ReadOnly));
 
     QFile testImplementation(CODEGEN_TESTS_EXPECTED_DIR "/classname.cpp");
@@ -249,9 +226,7 @@ void TestTemplateClassGenerator::yamlOutput()
     setLowercaseFileNames(generator);
     generator->generate().applyAllChanges();
 
-    KUrl yamlUrl = baseUrl;
-    yamlUrl.addPath("classname.yaml");
-    QFile yaml(yamlUrl.toLocalFile());
+    QFile yaml(baseUrl.resolved(QUrl("classname.yaml")).toLocalFile());
     QVERIFY(yaml.open(QIODevice::ReadOnly));
 
     QFile testYaml(CODEGEN_TESTS_EXPECTED_DIR "/classname.yaml");
@@ -269,10 +244,11 @@ TemplateClassGenerator* TestTemplateClassGenerator::loadTemplate (const QString&
 
     TemplateClassGenerator* generator = new TemplateClassGenerator(baseUrl);
 
-    QString tplDescription = ICore::self()->componentData().dirs()->findResource("data", "kdevcodegentest/template_descriptions/" + name + ".desktop");
+    QString tplDescription = QString(CODEGEN_DATA_DIR) + "/kdevcodegentest/templates/" + name + "/" + name + ".desktop";
     Q_ASSERT(!tplDescription.isEmpty());
     SourceFileTemplate tpl;
-    tpl.setTemplateDescription(tplDescription, "kdevcodegentest");
+    tpl.addAdditionalSearchLocation(QString(CODEGEN_TESTS_DATA_DIR) + "/kdevcodegentest/templates/");
+    tpl.setTemplateDescription(tplDescription);
     Q_ASSERT(tpl.isValid());
     generator->setTemplateDescription(tpl);
     generator->setDescription(description);
@@ -284,16 +260,15 @@ TemplateClassGenerator* TestTemplateClassGenerator::loadTemplate (const QString&
 
 void TestTemplateClassGenerator::setLowercaseFileNames(TemplateClassGenerator* generator)
 {
-    QHash<QString, KUrl> urls = generator->fileUrls();
-    QHash<QString, KUrl>::const_iterator it = urls.constBegin();
+    QHash<QString, QUrl> urls = generator->fileUrls();
+    QHash<QString, QUrl>::const_iterator it = urls.constBegin();
     for (; it != urls.constEnd(); ++it)
     {
         QString fileName = it.value().fileName().toLower();
-        KUrl base = it.value().upUrl();
-        base.addPath(fileName);
+        QUrl base = it.value().resolved(QUrl(QStringLiteral("./%1").arg(fileName)));
         generator->setFileUrl(it.key(), base);
     }
 }
 
 
-QTEST_KDEMAIN(TestTemplateClassGenerator, NoGUI)
\ No newline at end of file
+QTEST_GUILESS_MAIN(TestTemplateClassGenerator)
