@@ -18,7 +18,7 @@
 
 #include <language/languageexport.h>
 
-#include <QtGui/QValidator>
+#include <QValidator>
 
 #ifndef KDEVPLATFORM_CODEGEN_UTILITIES_H
 #define KDEVPLATFORM_CODEGEN_UTILITIES_H
@@ -40,10 +40,10 @@ namespace CodeGenUtils
 class KDEVPLATFORMLANGUAGE_EXPORT IdentifierValidator : public QValidator
 {
   public:
-    IdentifierValidator( DUContext * context);
+    explicit IdentifierValidator( DUContext * context);
     ~IdentifierValidator();
     
-    virtual State validate(QString & input, int &) const;
+    virtual State validate(QString & input, int &) const override;
       
   private:
     
