@@ -1,7 +1,7 @@
 /* This file is part of KDevelop
     Copyright 2007 David Nolden <david.nolden@kdevelop.org>
     Copyright 2009 Lior Mualem <lior.m.kde@gmail.com>
-    
+
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License version 2 as published by the Free Software Foundation.
@@ -18,11 +18,12 @@
 */
 
 #include "classdeclaration.h"
-#include <language/duchain/identifier.h>
+#include "identifier.h"
 #include <language/duchain/declaration.h>
 #include <language/duchain/appendedlist.h>
 #include <language/duchain/duchainregister.h>
-
+#include "types/structuretype.h"
+#include "util/debug.h"
 
 namespace KDevelop {
 
@@ -49,41 +50,39 @@ ClassDeclaration::ClassDeclaration(ClassDeclarationData& data)
 
 REGISTER_DUCHAIN_ITEM(ClassDeclaration);
 
-void ClassDeclaration::clearBaseClasses() {
-  bool wasInSymbolTable = inSymbolTable();
-  setInSymbolTable(false);
+void ClassDeclaration::clearBaseClasses()
+{
   d_func_dynamic()->baseClassesList().clear();
-  setInSymbolTable(wasInSymbolTable);
 }
 
-uint ClassDeclaration::baseClassesSize() const {
+uint ClassDeclaration::baseClassesSize() const
+{
   return d_func()->baseClassesSize();
 }
 
-const BaseClassInstance* ClassDeclaration::baseClasses() const {
+const BaseClassInstance* ClassDeclaration::baseClasses() const
+{
   return d_func()->baseClasses();
 }
 
-void ClassDeclaration::addBaseClass(BaseClassInstance klass) {
-  bool wasInSymbolTable = inSymbolTable();
-  setInSymbolTable(false);
+void ClassDeclaration::addBaseClass(const BaseClassInstance& klass)
+{
   d_func_dynamic()->baseClassesList().append(klass);
-  setInSymbolTable(wasInSymbolTable);
 }
 
-void ClassDeclaration::replaceBaseClass(uint n, BaseClassInstance klass) {
+void ClassDeclaration::replaceBaseClass(uint n, const BaseClassInstance& klass)
+{
   Q_ASSERT(n <= d_func()->baseClassesSize());
-  bool wasInSymbolTable = inSymbolTable();
-  setInSymbolTable(false);
   d_func_dynamic()->baseClassesList()[n] = klass;
-  setInSymbolTable(wasInSymbolTable);
 }
 
 ClassDeclaration::~ClassDeclaration()
 {
 }
 
-ClassDeclaration::ClassDeclaration(const ClassDeclaration& rhs) : ClassMemberDeclaration(*new ClassDeclarationData(*rhs.d_func())) {
+ClassDeclaration::ClassDeclaration(const ClassDeclaration& rhs)
+  : ClassMemberDeclaration(*new ClassDeclarationData(*rhs.d_func()))
+{
   d_func_dynamic()->setClassId(this);
 }
 
@@ -91,8 +90,11 @@ Declaration* ClassDeclaration::clonePrivate() const {
   return new ClassDeclaration(*this);
 }
 
-bool isPublicBaseClassInternal( const ClassDeclaration* self, ClassDeclaration* base, const KDevelop::TopDUContext* topContext, int* baseConversionLevels, int depth, QSet<const ClassDeclaration*>* checked ) {
-  
+namespace {
+bool isPublicBaseClassInternal( const ClassDeclaration* self, ClassDeclaration* base, const KDevelop::TopDUContext* topContext,
+                                int* baseConversionLevels, int depth, QSet<const ClassDeclaration*>* checked )
+{
+
   if(checked) {
     if(checked->contains(self))
       return false;
@@ -104,7 +106,7 @@ bool isPublicBaseClassInternal( const ClassDeclaration* self, ClassDeclaration*
     QSet<const ClassDeclaration*> checkedSet;
     return isPublicBaseClassInternal(self, base, topContext, baseConversionLevels, depth, &checkedSet);
   }
-  
+
   if( baseConversionLevels )
     *baseConversionLevels = 0;
 
@@ -115,7 +117,7 @@ bool isPublicBaseClassInternal( const ClassDeclaration* self, ClassDeclaration*
   {
     if( baseConversionLevels )
       ++ (*baseConversionLevels);
-    //kDebug(9007) << "public base of" << c->toString() << "is" << b.baseClass->toString();
+    //qCDebug(LANGUAGE) << "public base of" << c->toString() << "is" << b.baseClass->toString();
     if( b.access != KDevelop::Declaration::Private ) {
       int nextBaseConversion = 0;
       if( StructureType::Ptr c = b.baseClass.type<StructureType>() ) {
@@ -132,12 +134,15 @@ bool isPublicBaseClassInternal( const ClassDeclaration* self, ClassDeclaration*
   }
   return false;
 }
+}
 
-bool ClassDeclaration::isPublicBaseClass( ClassDeclaration* base, const KDevelop::TopDUContext* topContext, int* baseConversionLevels ) const {
+bool ClassDeclaration::isPublicBaseClass( ClassDeclaration* base, const KDevelop::TopDUContext* topContext, int* baseConversionLevels ) const
+{
   return isPublicBaseClassInternal( this, base, topContext, baseConversionLevels, 0, 0 );
 }
 
-QString ClassDeclaration::toString() const {
+QString ClassDeclaration::toString() const
+{
   QString ret;
   switch ( classModifier() ) {
     case ClassDeclarationData::None:
@@ -170,41 +175,24 @@ QString ClassDeclaration::toString() const {
   return ret + identifier().toString();
 }
 
-ClassDeclarationData::ClassType ClassDeclaration::classType() const {
+ClassDeclarationData::ClassType ClassDeclaration::classType() const
+{
   return d_func()->m_classType;
 }
 
-void ClassDeclaration::setClassType(ClassDeclarationData::ClassType type) {
+void ClassDeclaration::setClassType(ClassDeclarationData::ClassType type)
+{
   d_func_dynamic()->m_classType = type;
 }
 
-ClassDeclarationData::ClassModifier ClassDeclaration::classModifier() const {
+ClassDeclarationData::ClassModifier ClassDeclaration::classModifier() const
+{
   return d_func()->m_classModifier;
 }
 
-void ClassDeclaration::setClassModifier(ClassDeclarationData::ClassModifier modifier) {
+void ClassDeclaration::setClassModifier(ClassDeclarationData::ClassModifier modifier)
+{
   d_func_dynamic()->m_classModifier = modifier;
 }
 
-
-/*
-class TBase
-{
-  public:
-    void DoSomething();
-};
-
-template<class T>
-class Deriv : public T
-{
-  public:
-    void DoSomethingElse();
-};
-
-void F()
-{
-  Deriv<TBase> g;
-  g.DoSomethingElse();
-}
-*/
 }
