@@ -33,7 +33,7 @@
 #include "ducontextdata.h"
 #include "declarationid.h"
 #include "uses.h"
-#include "indexedstring.h"
+#include <serialization/indexedstring.h>
 #include "duchainregister.h"
 #include "persistentsymboltable.h"
 #include "types/identifiedtype.h"
@@ -44,7 +44,7 @@
 #include "types/typeutils.h"
 #include "types/typealiastype.h"
 #include "classdeclaration.h"
-#include "repositories/stringrepository.h"
+#include "serialization/stringrepository.h"
 #include "ducontextdynamicdata.h"
 
 namespace KDevelop
@@ -170,17 +170,12 @@ Declaration::~Declaration()
   //Only perform the actions when the top-context isn't being deleted, or when it hasn't been stored to disk
   if(persistentlyDestroying()) {
     DUCHAIN_D_DYNAMIC(Declaration);
+
     // Inserted by the builder after construction has finished.
     if( d->m_internalContext.context() )
       d->m_internalContext.context()->setOwner(0);
 
-    if (d->m_inSymbolTable && !d->m_identifier.isEmpty()) {
-      QualifiedIdentifier id = qualifiedIdentifier();
-      PersistentSymbolTable::self().removeDeclaration(id, this);
-      CodeModel::self().removeItem(url(), id);
-    }
-
-    d->m_inSymbolTable = false;
+    setInSymbolTable(false);
   }
 
   // If the parent-context already has dynamic data, like for example any temporary context,
@@ -240,8 +235,6 @@ void Declaration::rebuildDynamicData(DUContext* parent, uint ownIndex)
   m_context = parent;
   m_topContext = parent->topContext();
   m_indexInTopContext = ownIndex;
-
-  parent->m_dynamicData->addDeclarationToHash(d_func()->m_identifier.identifier(), this);
 }
 
 void Declaration::setIdentifier(const Identifier& identifier)
@@ -252,9 +245,6 @@ void Declaration::setIdentifier(const Identifier& identifier)
 
   setInSymbolTable(false);
 
-  if( m_context && !d->m_anonymousInContext )
-    m_context->changingIdentifier( this, d->m_identifier, identifier );
-
   d->m_identifier = identifier;
 
   setInSymbolTable(wasInSymbolTable);
@@ -276,7 +266,7 @@ void Declaration::setAbstractType(AbstractType::Ptr type)
   ENSURE_CAN_WRITE
   DUCHAIN_D_DYNAMIC(Declaration);
 
-  d->m_type = type ? type->indexed() : IndexedType();
+  d->m_type = type->indexed();
 
   updateCodeModel();
 }
@@ -300,17 +290,6 @@ QualifiedIdentifier Declaration::qualifiedIdentifier() const
   return ret;
 }
 
-// QString Declaration::mangledIdentifier() const
-// {
-//   //GNU mangling specs from http://theory.uwinnipeg.ca/gnu/gcc/gxxint_15.html
-//
-//   if (abstractType())
-//     return abstractType()->mangled();
-//
-//   // Error...
-//   return qualifiedIdentifier().mangled();
-// }
-
 DUContext * Declaration::context() const
 {
   //ENSURE_CAN_READ Commented out for performance reasons
@@ -326,13 +305,19 @@ void Declaration::setContext(DUContext* context, bool anonymous)
 {
   Q_ASSERT(!context || context->topContext());
 
+  DUCHAIN_D_DYNAMIC(Declaration);
+
+  if (context == m_context && anonymous == d->m_anonymousInContext) {
+    // skip costly operations below when the same context is set
+    // this happens often when updating a TopDUContext from the cache
+    return;
+  }
+
   setInSymbolTable(false);
 
   //We don't need to clear, because it's not allowed to move from one top-context into another
 //   clearOwnIndex();
 
-
-  DUCHAIN_D_DYNAMIC(Declaration);
   if (m_context && context) {
     Q_ASSERT(m_context->topContext() == context->topContext());
   }
@@ -393,14 +378,14 @@ void Declaration::allocateOwnIndex() {
   Q_ASSERT(m_indexInTopContext);
 
   if(!m_topContext->m_dynamicData->getDeclarationForIndex(m_indexInTopContext))
-    kFatal() << "Could not re-retrieve declaration" << "index:" << m_indexInTopContext;
+    qFatal("Could not re-retrieve declaration\nindex: %d", m_indexInTopContext);
 
 }
 
 const Declaration* Declaration::logicalDeclaration(const TopDUContext* topContext) const {
   ENSURE_CAN_READ
   if(isForwardDeclaration()) {
-    const ForwardDeclaration* dec = toForwardDeclaration();
+    const auto dec = static_cast<const ForwardDeclaration*>(this);
     Declaration* ret = dec->resolve(topContext);
     if(ret)
       return ret;
@@ -411,7 +396,7 @@ const Declaration* Declaration::logicalDeclaration(const TopDUContext* topContex
 Declaration* Declaration::logicalDeclaration(const TopDUContext* topContext) {
   ENSURE_CAN_READ
   if(isForwardDeclaration()) {
-    ForwardDeclaration* dec = toForwardDeclaration();
+    const auto dec = static_cast<const ForwardDeclaration*>(this);
     Declaration* ret = dec->resolve(topContext);
     if(ret)
       return ret;
@@ -434,7 +419,7 @@ DUContext * Declaration::logicalInternalContext(const TopDUContext* topContext)
     if(t) {
       AbstractType::Ptr target = t->type();
       
-      IdentifiedType* idType = dynamic_cast<IdentifiedType*>(target.unsafeData());
+      IdentifiedType* idType = dynamic_cast<IdentifiedType*>(target.data());
       if( idType ) {
         Declaration* decl = idType->declaration(topContext);
         if(decl && decl != this) {
@@ -492,10 +477,9 @@ bool Declaration::operator ==(const Declaration & other) const
 
 QString Declaration::toString() const
 {
-  return QString("%3 %4").arg(abstractType() ? abstractType()->toString() : QString("<notype>")).arg(identifier().toString());
+  return QStringLiteral("%3 %4").arg(abstractType() ? abstractType()->toString() : QStringLiteral("<notype>")).arg(identifier().toString());
 }
 
-// kate: indent-width 2;
 
 bool Declaration::isDefinition() const
 {
@@ -649,16 +633,6 @@ void Declaration::setInSymbolTable(bool inSymbolTable)
   d->m_inSymbolTable = inSymbolTable;
 }
 
-ForwardDeclaration* Declaration::toForwardDeclaration()
-{
-  return static_cast<ForwardDeclaration*>(this);
-}
-
-const ForwardDeclaration* Declaration::toForwardDeclaration() const
-{
-  return static_cast<const ForwardDeclaration*>(this);
-}
-
 TopDUContext * Declaration::topContext() const
 {
   return m_topContext;
@@ -712,7 +686,7 @@ QMap<IndexedString, QList<RangeInRevision> > Declaration::uses() const
 
   KDevVarLengthArray<IndexedTopDUContext> useContexts = DUChain::uses()->uses(id());
 
-  FOREACH_ARRAY(const IndexedTopDUContext& indexedContext, useContexts) {
+  for (const IndexedTopDUContext& indexedContext : useContexts) {
     TopDUContext* context = indexedContext.data();
     if(context) {
       QMap<RangeInRevision, bool>& ranges(tempUses[context->url()]);
@@ -762,14 +736,14 @@ bool Declaration::hasUses() const
   return ret;
 }
 
-QMap<IndexedString, QList<SimpleRange> > Declaration::usesCurrentRevision() const
+QMap<IndexedString, QList<KTextEditor::Range> > Declaration::usesCurrentRevision() const
 {
   ENSURE_CAN_READ
-  QMap<IndexedString, QMap<SimpleRange, bool> > tempUses;
+  QMap<IndexedString, QMap<KTextEditor::Range, bool> > tempUses;
 
   //First, search for uses within the own context
   {
-    QMap<SimpleRange, bool>& ranges(tempUses[topContext()->url()]);
+    QMap<KTextEditor::Range, bool>& ranges(tempUses[topContext()->url()]);
     foreach(const RangeInRevision& range, allUses(topContext(), const_cast<Declaration*>(this)))
     {
       ranges[topContext()->transformFromLocalRevision(range)] = true;
@@ -778,21 +752,21 @@ QMap<IndexedString, QList<SimpleRange> > Declaration::usesCurrentRevision() cons
 
   KDevVarLengthArray<IndexedTopDUContext> useContexts = DUChain::uses()->uses(id());
 
-  FOREACH_ARRAY(const IndexedTopDUContext& indexedContext, useContexts) {
+  for (const IndexedTopDUContext& indexedContext : useContexts) {
     TopDUContext* context = indexedContext.data();
     if(context) {
-      QMap<SimpleRange, bool>& ranges(tempUses[context->url()]);
+      QMap<KTextEditor::Range, bool>& ranges(tempUses[context->url()]);
       foreach(const RangeInRevision& range, allUses(context, const_cast<Declaration*>(this)))
         ranges[context->transformFromLocalRevision(range)] = true;
     }
   }
 
-QMap<IndexedString, QList<SimpleRange> > ret;
+QMap<IndexedString, QList<KTextEditor::Range> > ret;
 
-  for(QMap<IndexedString, QMap<SimpleRange, bool> >::const_iterator it = tempUses.constBegin(); it != tempUses.constEnd(); ++it) {
+  for(QMap<IndexedString, QMap<KTextEditor::Range, bool> >::const_iterator it = tempUses.constBegin(); it != tempUses.constEnd(); ++it) {
     if(!(*it).isEmpty()) {
-      QList<SimpleRange>& list(ret[it.key()]);
-      for(QMap<SimpleRange, bool>::const_iterator it2 = (*it).constBegin(); it2 != (*it).constEnd(); ++it2)
+      QList<KTextEditor::Range>& list(ret[it.key()]);
+      for(QMap<KTextEditor::Range, bool>::const_iterator it2 = (*it).constBegin(); it2 != (*it).constEnd(); ++it2)
         list << it2.key();
     }
   }
@@ -800,7 +774,3 @@ QMap<IndexedString, QList<SimpleRange> > ret;
 }
 
 }
-
-// kate: space-indent on; indent-width 2; tab-width 4; replace-tabs on; auto-insert-doxygen on
-
-
