@@ -23,8 +23,9 @@
 #include <QtCore/QObject>
 
 #include "topducontext.h"
+#include "parsingenvironment.h"
 
-class KUrl;
+class QUrl;
 
 namespace KDevelop
 {
@@ -36,7 +37,7 @@ class DUChainLock;
 class ParsingEnvironmentManager;
 class ParsingEnvironment;
 class ParsingEnvironmentFile;
-typedef KSharedPtr<ParsingEnvironmentFile> ParsingEnvironmentFilePointer;
+typedef QExplicitlySharedDataPointer<ParsingEnvironmentFile> ParsingEnvironmentFilePointer;
 class Definitions;
 class Uses;
 
@@ -105,19 +106,19 @@ public:
    *
    * @note The duchain must be at least read-locked locked when this is called!
    * */
-  Q_SCRIPTABLE TopDUContext* chainForDocument(const KUrl& document, bool proxyContext = false) const;
+  Q_SCRIPTABLE TopDUContext* chainForDocument(const QUrl& document, bool proxyContext = false) const;
   Q_SCRIPTABLE TopDUContext* chainForDocument(const IndexedString& document, bool proxyContext = false) const;
 
   /**
    * Return all chains for the given document that are currently in memory.
    * This does not load any chains from disk.
    * */
-  Q_SCRIPTABLE QList<TopDUContext*> chainsForDocument(const KUrl& document) const;
+  Q_SCRIPTABLE QList<TopDUContext*> chainsForDocument(const QUrl& document) const;
 
   /**
    * Return all chains for the given document that are currently in memory.
    * This does not load any chains from disk.
-   * Should be preferred over the KUrl version.
+   * Should be preferred over the QUrl version.
    * */
   Q_SCRIPTABLE QList<TopDUContext*> chainsForDocument(const IndexedString& document) const;
 
@@ -128,14 +129,14 @@ public:
    *
    * @note The duchain must be at least read-locked locked when this is called!
    * */
-  Q_SCRIPTABLE TopDUContext* chainForDocument(const KUrl& document, const ParsingEnvironment* environment, bool proxyContext = false) const;
+  Q_SCRIPTABLE TopDUContext* chainForDocument(const QUrl& document, const ParsingEnvironment* environment, bool proxyContext = false) const;
 
   /**
    * Find a chain that fits into the given environment. If no fitting chain is found, 0 is returned.
    * When no fitting chain is in memory, one may be loaded from disk.
    * @param proxyContext If this is true, only contexts are found that have an ParsingEnvironmentFile that has the proxy-flag set. Else, only content-contexts will be returned.
    *
-   * Prefer this over the KUrl version.
+   * Prefer this over the QUrl version.
    *
    * @note The duchain must be at least read-locked locked when this is called!
    * */
@@ -149,7 +150,7 @@ public:
    * 
    ** @param proxyContext If this is true, only contexts are found that have an ParsingEnvironmentFile that has the proxy-flag set. Else, only content-contexts will be returned.
    *
-   * Prefer this over the KUrl version.
+   * Prefer this over the QUrl version.
    *
    * @note The duchain must be at least read-locked locked when this is called!
    * */
@@ -171,7 +172,7 @@ public:
       return 0;
 
     {
-      SpinLock<> lock(chainsByIndexLock);
+      QMutexLocker lock(&chainsByIndexLock);
 
       if(chainsByIndex.size() > index)
       {
@@ -189,10 +190,10 @@ public:
   Q_SCRIPTABLE IndexedString urlForIndex(uint index) const;
   
   /// Only used for debugging at the moment
-  Q_SCRIPTABLE QList<KUrl> documents() const;
+  Q_SCRIPTABLE QList<QUrl> documents() const;
 
   /// Only used for debugging at the moment
-  /// Prefer that over the KUrl version for performance reasons
+  /// Prefer that over the QUrl version for performance reasons
   Q_SCRIPTABLE QList<IndexedString> indexedDocuments() const;
 
   /**
@@ -248,15 +249,7 @@ public:
   ///The duchain must not be locked when calling this
   ///@return true If the current memory state equals the disk state, else false
   bool compareToDisk();
-  
-  ///Does a big cleanup of the repositories, removing all items that are not needed any more for disk-persistency
-  ///The duchain must not be locked when calling this
-  ///@warning Only do this right after startup, or after shutdown, in a moment where indexed
-  ///         repository items are not needed any more, since the reference-counting mechanisms only respect disk persistency.
-  ///         All items that are not disk-referenced are invalidated during this step, which will lead to inconsistency, crashes,
-  ///         etc. when done in the wrong moment.
-  void finalCleanup();
-  
+
 Q_SIGNALS:
   ///Is emitted when the declaration has been selected somewhere in the user-interface, for example in the completion-list
   void declarationSelected(const KDevelop::DeclarationPointer& decl);
@@ -283,7 +276,7 @@ private:
   //These two are exported here so that the extremely frequently called chainForIndex(..) can be inlined
   static bool m_deleted;
   static std::vector<TopDUContext*> chainsByIndex;
-  static SpinLockData chainsByIndexLock;
+  static QMutex chainsByIndexLock;
   
   /// Increases the reference-count for the given top-context. The result: It will not be unloaded.
   /// Do this to prevent KDevelop from unloading a top-context that you plan to use. Don't forget calling unReferenceToContext again,
@@ -306,5 +299,3 @@ private:
 }
 
 #endif // KDEVPLATFORM_DUCHAIN_H
-
-// kate: space-indent on; indent-width 2; tab-width 4; replace-tabs on; auto-insert-doxygen on
