@@ -20,17 +20,20 @@
 #ifndef KDEVPLATFORM_DUCHAINBASE_H
 #define KDEVPLATFORM_DUCHAINBASE_H
 
-#include "../languageexport.h"
+#include <language/languageexport.h>
 #include "appendedlist.h"
 #include "duchainpointer.h"
 #include <language/editor/persistentmovingrange.h>
 #include <language/editor/rangeinrevision.h>
 
+namespace KTextEditor {
+class Cursor;
+class Range;
+}
+
 namespace KDevelop
 {
 class PersistentMovingRange;
-class SimpleCursor;
-class SimpleRange;
 class DUContext;
 class TopDUContext;
 class DUChainBase;
@@ -73,7 +76,7 @@ public:
     
     APPENDED_LISTS_STUB(DUChainBaseData)
     
-    uint classId;
+    quint16 classId;
 
     bool isDynamic() const {
       return m_dynamic;
@@ -87,6 +90,7 @@ public:
     */
     template<class T>
     void setClassId(T*) {
+      static_assert(T::Identity < std::numeric_limits<decltype(classId)>::max(), "Class ID out of bounds");
       classId = T::Identity;
     }
       
@@ -124,7 +128,7 @@ public:
    * \param url url of the document where this occurred
    * \param range range of the alias declaration's identifier
    */
-  DUChainBase(const RangeInRevision& range);
+  explicit DUChainBase(const RangeInRevision& range);
   /// Destructor
   virtual ~DUChainBase();
 
@@ -137,7 +141,7 @@ public:
    * Returns a special pointer that can be used to track the existence of a du-chain object across locking-cycles.
    * @see DUChainPointerData
    * */
-  const KSharedPtr<DUChainPointerData>& weakPointer() const;
+  const QExplicitlySharedDataPointer<DUChainPointerData>& weakPointer() const;
 
   virtual IndexedString url() const;
   
@@ -148,7 +152,7 @@ public:
   ///After this was called, the data-pointer is dynamic. It is cloned if needed.
   void makeDynamic();
   
-  DUChainBase( DUChainBaseData& dd );
+  explicit DUChainBase( DUChainBaseData& dd );
   
   ///This must only be used to change the storage-location or storage-kind(dynamic/constant) of the data, but
   ///the data must always be equal!
@@ -162,7 +166,7 @@ public:
   
   ///Returns the range assigned to this object, transformed into the current revision of the document.
   ///@warning This must only be called from the foreground thread, or with the foreground lock acquired.
-  SimpleRange rangeInCurrentRevision() const;
+  KTextEditor::Range rangeInCurrentRevision() const;
 
   ///Returns the range assigned to this object, transformed into the current revision of the document.
   ///The returned object is unique at each call, so you can use it and change it in whatever way you want.
@@ -173,17 +177,17 @@ public:
   ///in the parsed document containing this duchain object. The resulting cursor will be directly comparable to the non-translated
   ///range() members in the duchain, but only for one duchain locking cycle.
   ///@warning This must only be called from the foreground thread, or with the foreground lock acquired.
-  CursorInRevision transformToLocalRevision(const SimpleCursor& cursor) const;
+  CursorInRevision transformToLocalRevision(const KTextEditor::Cursor& cursor) const;
 
   ///Transforms the given range in the current document revision to its according position
   ///in the parsed document containing this duchain object. The resulting cursor will be directly comparable to the non-translated
   ///range() members in the duchain, but only for one duchain locking cycle.
   ///@warning This must only be called from the foreground thread, or with the foreground lock acquired.
-  RangeInRevision transformToLocalRevision(const SimpleRange& range) const;
+  RangeInRevision transformToLocalRevision(const KTextEditor::Range& range) const;
 
-  SimpleCursor transformFromLocalRevision(const CursorInRevision& cursor) const;
+  KTextEditor::Cursor transformFromLocalRevision(const CursorInRevision& cursor) const;
   
-  SimpleRange transformFromLocalRevision(const RangeInRevision& range) const;
+  KTextEditor::Range transformFromLocalRevision(const RangeInRevision& range) const;
 
 protected:
   /**
@@ -208,12 +212,10 @@ protected:
   DUChainBaseData* d_ptr;
 private:
   
-  mutable KSharedPtr<DUChainPointerData> m_ptr;
+  mutable QExplicitlySharedDataPointer<DUChainPointerData> m_ptr;
 public:
   DUCHAIN_DECLARE_DATA(DUChainBase)
 };
 }
 
 #endif // KDEVPLATFORM_DUCHAINBASE_H
-
-// kate: space-indent on; indent-width 2; tab-width 4; replace-tabs on; auto-insert-doxygen on
