@@ -22,15 +22,11 @@
 
 #include "duchainutils.h"
 
-#include <kiconloader.h>
-
-#include <algorithm>
-
-#include <interfaces/ilanguage.h>
 #include <interfaces/icore.h>
 #include <interfaces/ilanguagecontroller.h>
 
 #include "../interfaces/ilanguagesupport.h"
+#include "util/debug.h"
 
 #include "declaration.h"
 #include "classfunctiondeclaration.h"
@@ -152,7 +148,7 @@ CodeCompletionModel::CompletionProperties DUChainUtils::completionProperties(con
  * and for some reason will be loaded every time it's used(this function returns a QIcon marked "load on demand"
  * each time this is called). And the loading is very slow. Seems like a bug somewhere, it cannot be ment to be that slow.
  */
-#define RETURN_CACHED_ICON(name) {static QIcon icon(KIcon(name).pixmap(QSize(16, 16))); return icon;}
+#define RETURN_CACHED_ICON(name) {static QIcon icon(QIcon::fromTheme(name).pixmap(QSize(16, 16))); return icon;}
 
 QIcon DUChainUtils::iconForProperties(KTextEditor::CodeCompletionModel::CompletionProperties p)
 {
@@ -232,7 +228,7 @@ QIcon DUChainUtils::iconForProperties(KTextEditor::CodeCompletionModel::Completi
   else
     RETURN_CACHED_ICON("field")
 
-  return KIcon();
+  return QIcon();
 }
 
 QIcon DUChainUtils::iconForDeclaration(const Declaration* dec)
@@ -254,38 +250,37 @@ TopDUContext* DUChainUtils::contentContextFromProxyContext(TopDUContext* top)
       if(!ret)
         return 0;
       if(ret->url() != top->url())
-        kDebug() << "url-mismatch between content and proxy:" << top->url().toUrl() << ret->url().toUrl();
+        qCDebug(LANGUAGE) << "url-mismatch between content and proxy:" << top->url().toUrl() << ret->url().toUrl();
       if(ret->url() == top->url() && !ret->parsingEnvironmentFile()->isProxyContext())
         return ret;
     }
     else {
-      kDebug() << "Proxy-context imports no content-context";
+      qCDebug(LANGUAGE) << "Proxy-context imports no content-context";
     }
   } else
     return top;
   return 0;
 }
 
-TopDUContext* DUChainUtils::standardContextForUrl(const KUrl& url, bool preferProxyContext) {
+TopDUContext* DUChainUtils::standardContextForUrl(const QUrl& url, bool preferProxyContext) {
   KDevelop::TopDUContext* chosen = 0;
 
-  QList<KDevelop::ILanguage*> languages = ICore::self()->languageController()->languagesForUrl(url);
+  auto languages = ICore::self()->languageController()->languagesForUrl(url);
 
-  foreach( KDevelop::ILanguage* language, languages)
+  foreach(const auto& language, languages)
   {
     if(!chosen)
     {
-      if (language->languageSupport())
-        chosen = language->languageSupport()->standardContext(url, preferProxyContext);
+      chosen = language->standardContext(url, preferProxyContext);
     }
   }
 
   if(!chosen)
-    chosen = DUChain::self()->chainForDocument(IndexedString(url.pathOrUrl()), preferProxyContext);
+    chosen = DUChain::self()->chainForDocument(IndexedString(url), preferProxyContext);
 
   if(!chosen && preferProxyContext)
     return standardContextForUrl(url, false); // Fall back to a normal context
-  
+
   return chosen;
 }
 
@@ -307,7 +302,7 @@ Declaration* declarationUnderCursor(const CursorInRevision& c, DUContext* ctx)
   return 0;
 }
 
-Declaration* DUChainUtils::itemUnderCursor(const KUrl& url, const KDevelop::SimpleCursor& _c)
+Declaration* DUChainUtils::itemUnderCursor(const QUrl& url, const KTextEditor::Cursor& _c)
 {
   KDevelop::TopDUContext* chosen = standardContextForUrl(url);
 
@@ -333,7 +328,7 @@ Declaration* DUChainUtils::itemUnderCursor(const KUrl& url, const KDevelop::Simp
   return 0;
 }
 
-KTextEditor::Range DUChainUtils::itemRangeUnderCursor(const KUrl& url, const KDevelop::SimpleCursor& cursor)
+KTextEditor::Range DUChainUtils::itemRangeUnderCursor(const QUrl& url, const KTextEditor::Cursor& cursor)
 {
   KDevelop::TopDUContext* chosen = standardContextForUrl(url);
 
@@ -342,13 +337,19 @@ KTextEditor::Range DUChainUtils::itemRangeUnderCursor(const KUrl& url, const KDe
     DUContext* ctx = chosen->findContextAt(c);
     if (ctx) {
       Declaration* decl = declarationUnderCursor(c, ctx);
+
+      // Some declarations need to be searched in parent context
+      if (!decl && ctx->parentContext()) {
+        decl = declarationUnderCursor(c, ctx->parentContext());
+      }
+
       if (decl && decl->range().contains(c, RangeInRevision::IncludeBackEdge) ) {
-        return decl->rangeInCurrentRevision().textRange();
+        return decl->rangeInCurrentRevision();
       }
 
       for(int a = 0; a < ctx->usesCount(); ++a) {
         if( ctx->uses()[a].m_range.contains(c, RangeInRevision::IncludeBackEdge) ) {
-          return ctx->transformFromLocalRevision(ctx->uses()[a].m_range).textRange();
+          return ctx->transformFromLocalRevision(ctx->uses()[a].m_range);
         }
       }
     }
@@ -373,12 +374,12 @@ Declaration* DUChainUtils::declarationForDefinition(Declaration* definition, Top
   return definition;
 }
 
-Declaration* DUChainUtils::declarationInLine(const KDevelop::SimpleCursor& _cursor, DUContext* ctx) {
+Declaration* DUChainUtils::declarationInLine(const KTextEditor::Cursor& _cursor, DUContext* ctx) {
   if(!ctx)
     return 0;
-  
+
   CursorInRevision cursor = ctx->transformToLocalRevision(_cursor);
-  
+
   foreach(Declaration* decl, ctx->localDeclarations()) {
     if(decl->range().start.line == cursor.line)
       return decl;
@@ -462,7 +463,7 @@ KDevelop::DUContext* DUChainUtils::getArgumentContext(KDevelop::Declaration* dec
 QList<IndexedDeclaration> DUChainUtils::collectAllVersions(Declaration* decl) {
   QList<IndexedDeclaration> ret;
   ret << IndexedDeclaration(decl);
-  
+
   if(decl->inSymbolTable())
   {
     uint count;
@@ -472,14 +473,15 @@ QList<IndexedDeclaration> DUChainUtils::collectAllVersions(Declaration* decl) {
       if(!(allDeclarations[a] == IndexedDeclaration(decl)))
         ret << allDeclarations[a];
   }
-  
+
   return ret;
 }
 
-static QList<Declaration*> getInheritersInternal(const Declaration* decl, uint& maxAllowedSteps, bool collectVersions)
+///For a class, returns all classes that inherit it
+QList<Declaration*> DUChainUtils::getInheriters(const Declaration* decl, uint& maxAllowedSteps, bool collectVersions)
 {
   QList<Declaration*> ret;
-  
+
   if(!dynamic_cast<const ClassDeclaration*>(decl))
     return ret;
 
@@ -487,22 +489,22 @@ static QList<Declaration*> getInheritersInternal(const Declaration* decl, uint&
     return ret;
 
   if(decl->internalContext() && decl->internalContext()->type() == DUContext::Class)
-    FOREACH_ARRAY(const IndexedDUContext& importer, decl->internalContext()->indexedImporters()) {
-      
+    for (const IndexedDUContext& importer : decl->internalContext()->indexedImporters()) {
+
       DUContext* imp = importer.data();
-      
+
       if(!imp)
         continue;
-      
+
       if(imp->type() == DUContext::Class && imp->owner())
         ret << imp->owner();
 
       --maxAllowedSteps;
-      
+
       if(maxAllowedSteps == 0)
         return ret;
     }
-    
+
     if(maxAllowedSteps == 0)
       return ret;
 
@@ -512,53 +514,42 @@ static QList<Declaration*> getInheritersInternal(const Declaration* decl, uint&
     PersistentSymbolTable::self().declarations(decl->qualifiedIdentifier(), count, allDeclarations);
     for(uint a = 0; a < count; ++a) {
       ++maxAllowedSteps;
-      
+
       if(allDeclarations[a].data() && allDeclarations[a].data() != decl) {
-        ret += getInheritersInternal(allDeclarations[a].data(), maxAllowedSteps, false);
+        ret += getInheriters(allDeclarations[a].data(), maxAllowedSteps, false);
       }
-      
+
       if(maxAllowedSteps == 0)
         return ret;
     }
   }
-  
+
   return ret;
 }
 
-QList<Declaration*> DUChainUtils::getInheriters(const Declaration* decl, uint& maxAllowedSteps, bool collectVersions)
-{
-  auto inheriters = getInheritersInternal(decl, maxAllowedSteps, collectVersions);
-
-  // remove duplicates
-  std::sort(inheriters.begin(), inheriters.end());
-  inheriters.erase(std::unique(inheriters.begin(), inheriters.end()), inheriters.end());
-
-  return inheriters;
-}
-
 QList<Declaration*> DUChainUtils::getOverriders(const Declaration* currentClass, const Declaration* overriddenDeclaration, uint& maxAllowedSteps) {
   QList<Declaration*> ret;
-  
+
   if(maxAllowedSteps == 0)
     return ret;
-  
+
   if(currentClass != overriddenDeclaration->context()->owner() && currentClass->internalContext())
     ret += currentClass->internalContext()->findLocalDeclarations(overriddenDeclaration->identifier(), CursorInRevision::invalid(), currentClass->topContext(), overriddenDeclaration->abstractType());
-  
+
   foreach(Declaration* inheriter, getInheriters(currentClass, maxAllowedSteps))
     ret += getOverriders(inheriter, overriddenDeclaration, maxAllowedSteps);
-  
+
   return ret;
 }
 
 static bool hasUse(DUContext* context, int usedDeclarationIndex) {
   if(usedDeclarationIndex == std::numeric_limits<int>::max())
     return false;
-  
+
   for(int a = 0; a < context->usesCount(); ++a)
     if(context->uses()[a].m_declarationIndex == usedDeclarationIndex)
       return true;
-    
+
   foreach(DUContext* child, context->childContexts())
     if(hasUse(child, usedDeclarationIndex))
       return true;
@@ -572,16 +563,16 @@ bool DUChainUtils::contextHasUse(DUContext* context, Declaration* declaration) {
 static uint countUses(DUContext* context, int usedDeclarationIndex) {
   if(usedDeclarationIndex == std::numeric_limits<int>::max())
     return 0;
-  
+
   uint ret = 0;
-  
+
   for(int a = 0; a < context->usesCount(); ++a)
     if(context->uses()[a].m_declarationIndex == usedDeclarationIndex)
       ++ret;
-    
+
   foreach(DUContext* child, context->childContexts())
     ret += countUses(child, usedDeclarationIndex);
-  
+
   return ret;
 }
 
@@ -593,13 +584,13 @@ Declaration* DUChainUtils::getOverridden(const Declaration* decl) {
   const ClassFunctionDeclaration* classFunDecl = dynamic_cast<const ClassFunctionDeclaration*>(decl);
   if(!classFunDecl || !classFunDecl->isVirtual())
     return 0;
-  
+
   QList<Declaration*> decls;
 
   foreach(const DUContext::Import &import, decl->context()->importedParentContexts()) {
     DUContext* ctx = import.context(decl->topContext());
     if(ctx)
-      decls += ctx->findDeclarations(QualifiedIdentifier(decl->identifier()), 
+      decls += ctx->findDeclarations(QualifiedIdentifier(decl->identifier()),
                                             CursorInRevision::invalid(), decl->abstractType(), decl->topContext(), DUContext::DontSearchInParent);
   }
 
@@ -608,7 +599,7 @@ Declaration* DUChainUtils::getOverridden(const Declaration* decl) {
     if(foundClassFunDecl && foundClassFunDecl->isVirtual())
       return found;
   }
-    
+
   return 0;
 }
 
@@ -621,7 +612,7 @@ DUContext* DUChainUtils::getFunctionContext(Declaration* decl) {
         functionContext = ctx;
     }
   }
-  
+
   if(functionContext && functionContext->type() == DUContext::Function)
     return functionContext;
   return 0;
