@@ -33,7 +33,6 @@
 #include "duchainpointer.h"
 #include "declarationid.h"
 #include "indexedducontext.h"
-#include "localindexedducontext.h"
 
 class QWidget;
 
@@ -96,7 +95,7 @@ public:
    */
   virtual ~DUContext();
 
-  enum ContextType {
+  enum ContextType : quint8 {
     Global    /**< A context that declares functions, namespaces or classes */,
     Namespace /**< A context that declares namespace members */,
     Class     /**< A context that declares class members */,
@@ -152,7 +151,7 @@ public:
   /**
    * Find the top context.
    */
-  virtual TopDUContext* topContext() const;
+  virtual TopDUContext* topContext() const override;
 
   /**
    * Visits all duchain objects in the whole duchain.
@@ -454,6 +453,14 @@ public:
    *
    * @overload
    */
+  QList<Declaration*> findDeclarations(const IndexedIdentifier& identifier,
+                                       const CursorInRevision& position = CursorInRevision::invalid(),
+                                       const TopDUContext* topContext = 0,
+                                       SearchFlags flags = NoSearchFlags) const;
+
+  /**
+   * Prefer the version above for speed reasons.
+   */
   QList<Declaration*> findDeclarations(const Identifier& identifier,
                                        const CursorInRevision& position = CursorInRevision::invalid(),
                                        const TopDUContext* topContext = 0,
@@ -465,6 +472,15 @@ public:
    *
    * Does not search imported parent-contexts(like base-classes).
    */
+  QList<Declaration*> findLocalDeclarations(const IndexedIdentifier& identifier,
+                                            const CursorInRevision& position = CursorInRevision::invalid(),
+                                            const TopDUContext* topContext = 0,
+                                            const AbstractType::Ptr& dataType = AbstractType::Ptr(),
+                                            SearchFlags flags = NoSearchFlags) const;
+
+  /**
+   * Prefer the version above for speed reasons.
+   */
   QList<Declaration*> findLocalDeclarations(const Identifier& identifier,
                                             const CursorInRevision& position = CursorInRevision::invalid(),
                                             const TopDUContext* topContext = 0,
@@ -540,11 +556,6 @@ public:
    */
   void cleanIfNotEncountered(const QSet<DUChainBase*>& encountered);
 
-  /**
-   * Used exclusively by Declaration, do not use this.
-   */
-  void changingIdentifier( Declaration* decl, const Identifier& from, const Identifier& to );
-
    /**
     * Uses:
     * A "Use" represents any position in a document where a Declaration is used literally.
@@ -662,10 +673,9 @@ public:
    *
    * The insertion order in the hierarchy determines the order of the represented list.
    */
-  struct KDEVPLATFORMLANGUAGE_EXPORT SearchItem : public KShared
+  struct KDEVPLATFORMLANGUAGE_EXPORT SearchItem : public QSharedData
   {
-    typedef KSharedPtr<SearchItem> Ptr;
-    ///@todo find out why this KDevVarLengthArray crashes when it's resized!
+    typedef QExplicitlySharedDataPointer<SearchItem> Ptr;
     typedef KDevVarLengthArray<Ptr, 256> PtrList;
 
     /**
@@ -674,7 +684,7 @@ public:
      *
      * @param nextItem is set as next item to the last item in the chain
      */
-    SearchItem(const QualifiedIdentifier& id, Ptr nextItem = Ptr(), int start = 0);
+    SearchItem(const QualifiedIdentifier& id, const Ptr& nextItem = Ptr(), int start = 0);
 
     /**
      * Constructs a representation of the given @param id qualified identifier,
@@ -684,8 +694,8 @@ public:
      */
     SearchItem(const QualifiedIdentifier& id, const PtrList& nextItems, int start = 0);
 
-    SearchItem(bool explicitlyGlobal, Identifier id, const PtrList& nextItems);
-    SearchItem(bool explicitlyGlobal, Identifier id, Ptr nextItem);
+    SearchItem(bool explicitlyGlobal, const IndexedIdentifier& id, const PtrList& nextItems);
+    SearchItem(bool explicitlyGlobal, const IndexedIdentifier& id, const Ptr& nextItem);
 
     bool isEmpty() const;
     bool hasNext() const;
@@ -703,8 +713,8 @@ public:
      *
      * @note These functions ignore explicitly global items.
      */
-    void addToEachNode(Ptr item);
-    void addToEachNode(PtrList items);
+    void addToEachNode(const Ptr& item);
+    void addToEachNode(const PtrList& items);
 
     /**
      * Returns true if the given identifier matches one of the identifiers
@@ -717,10 +727,10 @@ public:
      */
     QList<QualifiedIdentifier> toList(const QualifiedIdentifier& prefix = QualifiedIdentifier()) const;
 
-    void addNext(Ptr other);
+    void addNext(const Ptr& other);
 
     bool isExplicitlyGlobal;
-    Identifier identifier;
+    IndexedIdentifier identifier;
     PtrList next;
   };
 
@@ -751,18 +761,13 @@ public:
    * @return whether the search was successful. If it is false, it had to be stopped
    *         for special reasons (like some flags)
    */
-  typedef KDevVarLengthArray<Declaration*, 40> DeclarationList;
+  typedef QList<Declaration*> DeclarationList;
 
   virtual bool findDeclarationsInternal(const SearchItem::PtrList& identifiers,
                                         const CursorInRevision& position, const AbstractType::Ptr& dataType,
                                         DeclarationList& ret, const TopDUContext* source, SearchFlags flags,
                                         uint depth ) const;
 
-  /**
-   * Call this after parsing is finished. It will optimize the internal vectors to reduce memory-usage.
-   */
-  void squeeze();
-
   /**
    * Returns the qualified identifier @p id with all aliases (for example namespace imports) applied
    *
@@ -797,12 +802,14 @@ protected:
                                          const TopDUContext* source,
                                          bool searchInParents = true, int currentDepth = 0) const;
 
-  /**
-   * Logic for calculating the fully qualified scope name
-   */
-  QualifiedIdentifier scopeIdentifierInternal(DUContext* context) const;
+  void findLocalDeclarationsInternal(const Identifier& identifier,
+                                     const CursorInRevision & position,
+                                     const AbstractType::Ptr& dataType,
+                                     DeclarationList& ret,
+                                     const TopDUContext* source,
+                                     SearchFlags flags ) const;
 
-  virtual void findLocalDeclarationsInternal(const Identifier& identifier,
+  virtual void findLocalDeclarationsInternal(const IndexedIdentifier& identifier,
                                              const CursorInRevision & position,
                                              const AbstractType::Ptr& dataType,
                                              DeclarationList& ret,
@@ -860,16 +867,13 @@ protected:
   virtual bool shouldSearchInParent(SearchFlags flags) const;
 
 private:
-  void rebuildDynamicData(DUContext* parent, uint ownIndex);
+  void rebuildDynamicData(DUContext* parent, uint ownIndex) override;
 
   friend class TopDUContext;
   friend class IndexedDUContext;
   friend class LocalIndexedDUContext;
   friend class TopDUContextDynamicData;
 
-  void clearDeclarationIndices();
-  void updateDeclarationIndices();
-
   DUCHAIN_DECLARE_DATA(DUContext)
   class DUContextDynamicData* m_dynamicData;
 };
@@ -883,7 +887,7 @@ private:
  *
  * @see NamespaceAliasDeclaration.
  */
-KDEVPLATFORMLANGUAGE_EXPORT Identifier& globalImportIdentifier();
+KDEVPLATFORMLANGUAGE_EXPORT const Identifier& globalImportIdentifier();
 
 /**
  * This is the identifier that can be used to search namespace-alias declarations.
@@ -893,7 +897,28 @@ KDEVPLATFORMLANGUAGE_EXPORT Identifier& globalImportIdentifier();
  *
  * @see NamespaceAliasDeclaration.
  */
-KDEVPLATFORMLANGUAGE_EXPORT Identifier& globalAliasIdentifier();
+KDEVPLATFORMLANGUAGE_EXPORT const Identifier& globalAliasIdentifier();
+
+/**
+ * This is the identifier that can be used to search namespace-import declarations,
+ * and should be used to store namespace-imports.
+ *
+ * It is stored statically for performance-reasons, so it doesn't need to be
+ * constructed every time it is used.
+ *
+ * @see NamespaceAliasDeclaration.
+ */
+KDEVPLATFORMLANGUAGE_EXPORT const IndexedIdentifier& globalIndexedImportIdentifier();
+
+/**
+ * This is the identifier that can be used to search namespace-alias declarations.
+ *
+ * It is stored statically for performance-reasons, so it doesn't need to be
+ * constructed every time it is used.
+ *
+ * @see NamespaceAliasDeclaration.
+ */
+KDEVPLATFORMLANGUAGE_EXPORT const IndexedIdentifier& globalIndexedAliasIdentifier();
 
 /**
  * Collects all uses of the given @param declarationIndex
@@ -905,6 +930,6 @@ KDEVPLATFORMLANGUAGE_EXPORT QList<RangeInRevision> allUses(DUContext* context,
 
 Q_DECLARE_TYPEINFO(KDevelop::DUContext::Import, Q_MOVABLE_TYPE);
 
-#endif // KDEVPLATFORM_DUCONTEXT_H
+KDEVPLATFORMLANGUAGE_EXPORT QDebug operator<<(QDebug dbg, const KDevelop::DUContext::Import& import);
 
-// kate: space-indent on; indent-width 2; tab-width 4; replace-tabs on; auto-insert-doxygen on
+#endif // KDEVPLATFORM_DUCONTEXT_H
