@@ -21,11 +21,12 @@
 
 #include <QtCore/QHash>
 #include "stringhelpers.h"
-#include "indexedstring.h"
 #include "appendedlist_static.h"
-#include "repositories/itemrepository.h"
+#include "serialization/itemrepository.h"
 #include "util/kdevhash.h"
+#include "util/debug.h"
 
+#include <serialization/indexedstring.h>
 #include <utility>
 
 #define ifDebug(x)
@@ -253,14 +254,17 @@ public:
 
   uint hash() const
   {
-    if( m_hash == 0 )
-    {
-      uint mhash = 0;
-      FOREACH_FUNCTION_STATIC( const IndexedIdentifier& identifier, identifiers )
-        mhash = 11*mhash + Identifier(identifier).hash();
+    if( m_hash == 0 ) {
+      KDevHash hash;
 
-      if(mhash != m_hash)
-        m_hash = mhash;//The local class may be in read-only memory, so only  change m_hash if it's actually a change
+      quint32 bitfields = m_explicitlyGlobal
+        | (m_isExpression << 1);
+      hash << bitfields << identifiersSize();
+      FOREACH_FUNCTION_STATIC( const IndexedIdentifier& identifier, identifiers ) {
+        hash << identifier.getIndex();
+      }
+
+      m_hash = hash;
     }
     return m_hash;
   }
@@ -385,7 +389,7 @@ Identifier::Identifier(const QString& id, uint start, uint* takenRange)
   dd = new IdentifierPrivate<true>;
 
   ///Extract template-parameters
-  ParamIterator paramIt("<>:", id, start);
+  ParamIterator paramIt(QStringLiteral("<>:"), id, start);
   dd->m_identifier = IndexedString(paramIt.prefix().trimmed());
   while( paramIt ) {
     appendTemplateIdentifier( IndexedTypeIdentifier(IndexedQualifiedIdentifier(QualifiedIdentifier(*paramIt))) );
@@ -676,7 +680,7 @@ QualifiedIdentifier::QualifiedIdentifier(const QString& id, bool isExpression)
       push(finishedId);
     }
   }else{
-    if (id.startsWith("::")) {
+    if (id.startsWith(QStringLiteral("::"))) {
       dd->m_explicitlyGlobal = true;
       dd->splitIdentifiers(id, 2);
     } else {
@@ -771,6 +775,7 @@ QualifiedIdentifier::~QualifiedIdentifier()
 QStringList QualifiedIdentifier::toStringList() const
 {
   QStringList ret;
+  ret.reserve(explicitlyGlobal() + count());
   if (explicitlyGlobal())
     ret.append(QString());
 
@@ -787,16 +792,18 @@ QStringList QualifiedIdentifier::toStringList() const
 
 QString QualifiedIdentifier::toString(bool ignoreExplicitlyGlobal) const
 {
+  const QString doubleColon = QStringLiteral("::");
+  
   QString ret;
   if( !ignoreExplicitlyGlobal && explicitlyGlobal() )
-    ret = "::";
+    ret = doubleColon;
 
   bool first = true;
   if(m_index) {
     FOREACH_FUNCTION_STATIC(const IndexedIdentifier& index, cd->identifiers)
     {
       if( !first )
-        ret += "::";
+        ret += doubleColon;
       else
         first = false;
 
@@ -806,7 +813,7 @@ QString QualifiedIdentifier::toString(bool ignoreExplicitlyGlobal) const
     FOREACH_FUNCTION_STATIC(const IndexedIdentifier& index, dd->identifiers)
     {
       if( !first )
-        ret += "::";
+        ret += doubleColon;
       else
         first = false;
 
@@ -820,16 +827,7 @@ QString QualifiedIdentifier::toString(bool ignoreExplicitlyGlobal) const
 QualifiedIdentifier QualifiedIdentifier::merge(const QualifiedIdentifier& base) const
 {
   QualifiedIdentifier ret(base);
-  ret.prepareWrite();
-
-  if(m_index)
-    ret.dd->identifiersList.append(cd->identifiers(), cd->identifiersSize());
-  else
-    ret.dd->identifiersList.append(dd->identifiers(), dd->identifiersSize());
-
-  if( explicitlyGlobal() )
-    ret.setExplicitlyGlobal(true);
-
+  ret.push(*this);
   return ret;
 }
 
@@ -961,12 +959,6 @@ struct Visitor
   const uint hash;
 };
 
-void QualifiedIdentifier::findByHash(uint hash, KDevVarLengthArray<QualifiedIdentifier>& target)
-{
-  Visitor v(target, hash);
-  qualifiedidentifierRepository()->visitItemsWithHash<Visitor>(v, hash);
-}
-
 uint QualifiedIdentifier::hash() const
 {
   if(m_index)
@@ -1016,13 +1008,21 @@ void QualifiedIdentifier::push(const IndexedIdentifier& id)
 
 void QualifiedIdentifier::push(const QualifiedIdentifier& id)
 {
-  if(id.isEmpty())
+  if (id.isEmpty()) {
     return;
+  }
 
   prepareWrite();
-  id.makeConstant();
 
-  dd->identifiersList.append(id.cd->identifiers(), id.cd->identifiersSize());
+  if (id.m_index) {
+    dd->identifiersList.append(id.cd->identifiers(), id.cd->identifiersSize());
+  } else {
+    dd->identifiersList.append(id.dd->identifiers(), id.dd->identifiersSize());
+  }
+
+  if (id.explicitlyGlobal()) {
+    setExplicitlyGlobal(true);
+  }
 }
 
 void QualifiedIdentifier::pop()
@@ -1059,20 +1059,30 @@ int QualifiedIdentifier::count() const
 }
 
 Identifier QualifiedIdentifier::first() const
+{
+  return indexedFirst().identifier();
+}
+
+IndexedIdentifier QualifiedIdentifier::indexedFirst() const
 {
   if( (m_index && cd->identifiersSize() == 0) || (!m_index && dd->identifiersSize() == 0) )
-    return Identifier();
+    return IndexedIdentifier();
   else
-    return at(0);
+    return indexedAt(0);
 }
 
 Identifier QualifiedIdentifier::last() const
+{
+  return indexedLast().identifier();
+}
+
+IndexedIdentifier QualifiedIdentifier::indexedLast() const
 {
   uint c = count();
   if(c)
-    return at(c-1);
+    return indexedAt(c-1);
   else
-    return Identifier();
+    return IndexedIdentifier();
 }
 
 Identifier QualifiedIdentifier::top() const
@@ -1102,10 +1112,15 @@ QualifiedIdentifier QualifiedIdentifier::mid(int pos, int len) const
 
 Identifier QualifiedIdentifier::at(int i) const
 {
-  if(m_index) {
+  return indexedAt(i).identifier();
+}
+
+IndexedIdentifier QualifiedIdentifier::indexedAt(int i) const
+{
+  if (m_index) {
     Q_ASSERT(i >= 0 && i < (int)cd->identifiersSize());
     return cd->identifiers()[i];
-  }else{
+  } else {
     Q_ASSERT(i >= 0 && i < (int)dd->identifiersSize());
     return dd->identifiers()[i];
   }
@@ -1335,12 +1350,12 @@ IndexedIdentifier& IndexedIdentifier::operator=(IndexedIdentifier&& rhs) Q_DECL_
 {
   if(shouldDoDUChainReferenceCounting(this)) {
     QMutexLocker lock(identifierRepository()->mutex());
-    ifDebug( kDebug() << "decreasing"; )
+    ifDebug( qCDebug(LANGUAGE) << "decreasing"; )
 
     decrease(identifierRepository()->dynamicItemFromIndexSimple(index)->m_refCount, index);
   } else if (shouldDoDUChainReferenceCounting(&rhs)) {
     QMutexLocker lock(identifierRepository()->mutex());
-    ifDebug( kDebug() << "decreasing"; )
+    ifDebug( qCDebug(LANGUAGE) << "decreasing"; )
 
     decrease(identifierRepository()->dynamicItemFromIndexSimple(rhs.index)->m_refCount, rhs.index);
   }
@@ -1350,7 +1365,7 @@ IndexedIdentifier& IndexedIdentifier::operator=(IndexedIdentifier&& rhs) Q_DECL_
 
   if(shouldDoDUChainReferenceCounting(this) && !(shouldDoDUChainReferenceCounting(&rhs))) {
     QMutexLocker lock(identifierRepository()->mutex());
-    ifDebug( kDebug() << "increasing"; )
+    ifDebug( qCDebug(LANGUAGE) << "increasing"; )
 
     increase(identifierRepository()->dynamicItemFromIndexSimple(index)->m_refCount, index);
   }
@@ -1425,12 +1440,12 @@ void IndexedTypeIdentifier::setIdentifier(const IndexedQualifiedIdentifier& id)
 IndexedQualifiedIdentifier::IndexedQualifiedIdentifier()
   : index(emptyConstantQualifiedIdentifierPrivateIndex())
 {
-  ifDebug( kDebug() << "(" << ++cnt << ")" << identifier().toString() << index; )
+  ifDebug( qCDebug(LANGUAGE) << "(" << ++cnt << ")" << identifier().toString() << index; )
 
   if(shouldDoDUChainReferenceCounting(this)) {
-    ifDebug( kDebug() << "increasing"; )
+    ifDebug( qCDebug(LANGUAGE) << "increasing"; )
 
-    //kDebug() << "(" << ++cnt << ")" << this << identifier().toString() << "inc" << index;
+    //qCDebug(LANGUAGE) << "(" << ++cnt << ")" << this << identifier().toString() << "inc" << index;
     QMutexLocker lock(qualifiedidentifierRepository()->mutex());
     increase(qualifiedidentifierRepository()->dynamicItemFromIndexSimple(index)->m_refCount, index);
   }
@@ -1439,10 +1454,10 @@ IndexedQualifiedIdentifier::IndexedQualifiedIdentifier()
 IndexedQualifiedIdentifier::IndexedQualifiedIdentifier(const QualifiedIdentifier& id)
   : index(id.index())
 {
-  ifDebug( kDebug() << "(" << ++cnt << ")" << identifier().toString() << index; )
+  ifDebug( qCDebug(LANGUAGE) << "(" << ++cnt << ")" << identifier().toString() << index; )
 
   if(shouldDoDUChainReferenceCounting(this)) {
-    ifDebug( kDebug() << "increasing"; )
+    ifDebug( qCDebug(LANGUAGE) << "increasing"; )
     QMutexLocker lock(qualifiedidentifierRepository()->mutex());
     increase(qualifiedidentifierRepository()->dynamicItemFromIndexSimple(index)->m_refCount, index);
   }
@@ -1451,10 +1466,10 @@ IndexedQualifiedIdentifier::IndexedQualifiedIdentifier(const QualifiedIdentifier
 IndexedQualifiedIdentifier::IndexedQualifiedIdentifier(const IndexedQualifiedIdentifier& id)
   : index(id.index)
 {
-  ifDebug( kDebug() << "(" << ++cnt << ")" << identifier().toString() << index; )
+  ifDebug( qCDebug(LANGUAGE) << "(" << ++cnt << ")" << identifier().toString() << index; )
 
   if(shouldDoDUChainReferenceCounting(this)) {
-    ifDebug( kDebug() << "increasing"; )
+    ifDebug( qCDebug(LANGUAGE) << "increasing"; )
 
     QMutexLocker lock(qualifiedidentifierRepository()->mutex());
     increase(qualifiedidentifierRepository()->dynamicItemFromIndexSimple(index)->m_refCount, index);
@@ -1469,17 +1484,17 @@ IndexedQualifiedIdentifier::IndexedQualifiedIdentifier(IndexedQualifiedIdentifie
 
 IndexedQualifiedIdentifier& IndexedQualifiedIdentifier::operator=(const QualifiedIdentifier& id)
 {
-  ifDebug( kDebug() << "(" << ++cnt << ")" << identifier().toString() << index; )
+  ifDebug( qCDebug(LANGUAGE) << "(" << ++cnt << ")" << identifier().toString() << index; )
 
   if(shouldDoDUChainReferenceCounting(this)) {
     QMutexLocker lock(qualifiedidentifierRepository()->mutex());
 
-    ifDebug( kDebug() << "decreasing"; )
+    ifDebug( qCDebug(LANGUAGE) << "decreasing"; )
     decrease(qualifiedidentifierRepository()->dynamicItemFromIndexSimple(index)->m_refCount, index);
 
     index = id.index();
 
-    ifDebug( kDebug() << index << "increasing"; )
+    ifDebug( qCDebug(LANGUAGE) << index << "increasing"; )
     increase(qualifiedidentifierRepository()->dynamicItemFromIndexSimple(index)->m_refCount, index);
   } else {
     index = id.index();
@@ -1491,17 +1506,17 @@ IndexedQualifiedIdentifier& IndexedQualifiedIdentifier::operator=(const Qualifie
 IndexedQualifiedIdentifier& IndexedQualifiedIdentifier::operator=(const IndexedQualifiedIdentifier& rhs)
 {
 
-  ifDebug( kDebug() << "(" << ++cnt << ")" << identifier().toString() << index; )
+  ifDebug( qCDebug(LANGUAGE) << "(" << ++cnt << ")" << identifier().toString() << index; )
 
   if(shouldDoDUChainReferenceCounting(this)) {
     QMutexLocker lock(qualifiedidentifierRepository()->mutex());
-    ifDebug( kDebug() << "decreasing"; )
+    ifDebug( qCDebug(LANGUAGE) << "decreasing"; )
 
     decrease(qualifiedidentifierRepository()->dynamicItemFromIndexSimple(index)->m_refCount, index);
 
     index = rhs.index;
 
-    ifDebug( kDebug() << index << "increasing"; )
+    ifDebug( qCDebug(LANGUAGE) << index << "increasing"; )
     increase(qualifiedidentifierRepository()->dynamicItemFromIndexSimple(index)->m_refCount, index);
   } else {
     index = rhs.index;
@@ -1514,12 +1529,12 @@ IndexedQualifiedIdentifier& IndexedQualifiedIdentifier::operator=(IndexedQualifi
 {
   if(shouldDoDUChainReferenceCounting(this)) {
     QMutexLocker lock(qualifiedidentifierRepository()->mutex());
-    ifDebug( kDebug() << "decreasing"; )
+    ifDebug( qCDebug(LANGUAGE) << "decreasing"; )
 
     decrease(qualifiedidentifierRepository()->dynamicItemFromIndexSimple(index)->m_refCount, index);
   } else if (shouldDoDUChainReferenceCounting(&rhs)) {
     QMutexLocker lock(qualifiedidentifierRepository()->mutex());
-    ifDebug( kDebug() << "decreasing"; )
+    ifDebug( qCDebug(LANGUAGE) << "decreasing"; )
 
     decrease(qualifiedidentifierRepository()->dynamicItemFromIndexSimple(rhs.index)->m_refCount, rhs.index);
   }
@@ -1529,7 +1544,7 @@ IndexedQualifiedIdentifier& IndexedQualifiedIdentifier::operator=(IndexedQualifi
 
   if(shouldDoDUChainReferenceCounting(this) && !(shouldDoDUChainReferenceCounting(&rhs))) {
     QMutexLocker lock(qualifiedidentifierRepository()->mutex());
-    ifDebug( kDebug() << "increasing"; )
+    ifDebug( qCDebug(LANGUAGE) << "increasing"; )
 
     increase(qualifiedidentifierRepository()->dynamicItemFromIndexSimple(index)->m_refCount, index);
   }
@@ -1539,9 +1554,9 @@ IndexedQualifiedIdentifier& IndexedQualifiedIdentifier::operator=(IndexedQualifi
 
 IndexedQualifiedIdentifier::~IndexedQualifiedIdentifier()
 {
-  ifDebug( kDebug() << "(" << ++cnt << ")" << identifier().toString() << index; )
+  ifDebug( qCDebug(LANGUAGE) << "(" << ++cnt << ")" << identifier().toString() << index; )
   if(shouldDoDUChainReferenceCounting(this)) {
-    ifDebug( kDebug() << index << "decreasing"; )
+    ifDebug( qCDebug(LANGUAGE) << index << "decreasing"; )
     QMutexLocker lock(qualifiedidentifierRepository()->mutex());
     decrease(qualifiedidentifierRepository()->dynamicItemFromIndexSimple(index)->m_refCount, index);
   }
@@ -1587,5 +1602,3 @@ QDebug operator<<(QDebug s, const KDevelop::QualifiedIdentifier& identifier)
   s.nospace() << identifier.toString();
   return s.space();
 }
-
-// kate: space-indent on; indent-width 2; tab-width 4; replace-tabs on; auto-insert-doxygen on
