@@ -18,9 +18,9 @@
 
 #include "abstractdeclarationnavigationcontext.h"
 
-#include <QtGui/QTextDocument>
+#include <QTextDocument>
 
-#include <klocale.h>
+#include <KLocalizedString>
 
 #include "../functiondeclaration.h"
 #include "../functiondefinition.h"
@@ -34,12 +34,14 @@
 #include "../types/pointertype.h"
 #include "../types/referencetype.h"
 #include "../types/typeutils.h"
+#include "../types/typesystem.h"
 #include "../persistentsymboltable.h"
+#include "util/debug.h"
 #include <interfaces/icore.h>
 #include <interfaces/idocumentationcontroller.h>
 #include <duchain/types/typealiastype.h>
+#include <duchain/types/structuretype.h>
 #include <duchain/classdeclaration.h>
-#include <typeinfo>
 
 namespace KDevelop {
 AbstractDeclarationNavigationContext::AbstractDeclarationNavigationContext( DeclarationPointer decl, KDevelop::TopDUContextPointer topContext, AbstractNavigationContext* previousContext)
@@ -71,21 +73,21 @@ QString AbstractDeclarationNavigationContext::html(bool shorten)
     modifyHtml() += i18n("<br /> lost declaration <br />");
     return currentHtml();
   }
-  
+
   if( m_previousContext ) {
     QString link = createLink( m_previousContext->name(), m_previousContext->name(), NavigationAction(m_previousContext) );
     modifyHtml() += navigationHighlight(i18n("Back to %1<br />", link));
   }
-  
-  KSharedPtr<IDocumentation> doc;
-  
+
+  QExplicitlySharedDataPointer<IDocumentation> doc;
+
   if( !shorten ) {
     doc = ICore::self()->documentationController()->documentationForDeclaration(m_declaration.data());
 
     const AbstractFunctionDeclaration* function = dynamic_cast<const AbstractFunctionDeclaration*>(m_declaration.data());
     if( function ) {
       htmlFunction();
-    } else if( m_declaration->isTypeAlias() || m_declaration->kind() == Declaration::Instance ) {
+    } else if( m_declaration->isTypeAlias() || m_declaration->type<EnumeratorType>() || m_declaration->kind() == Declaration::Instance ) {
       if( m_declaration->isTypeAlias() )
         modifyHtml() += importantHighlight("typedef ");
 
@@ -97,29 +99,40 @@ QString AbstractDeclarationNavigationContext::html(bool shorten)
         //Do not show the own name as type of typedefs
         if(useType.cast<TypeAliasType>())
           useType = useType.cast<TypeAliasType>()->type();
-      } 
-      
+      }
+
       eventuallyMakeTypeLinks( useType );
 
-      modifyHtml() += ' ' + nameHighlight(Qt::escape(declarationName(m_declaration))) + "<br>";
+      modifyHtml() += ' ' + identifierHighlight(declarationName(m_declaration).toHtmlEscaped(), m_declaration);
+
+      if(auto integralType = m_declaration->type<ConstantIntegralType>()) {
+        const QString plainValue = integralType->valueAsString();
+        if (!plainValue.isEmpty()) {
+          modifyHtml() += QStringLiteral(" = ") + plainValue;
+        }
+      }
+
+      modifyHtml() += "<br>";
     }else{
       if( m_declaration->kind() == Declaration::Type && m_declaration->abstractType().cast<StructureType>() ) {
         htmlClass();
       }
       if ( m_declaration->kind() == Declaration::Namespace ) {
-        modifyHtml() += i18n("namespace %1 <br />", nameHighlight(Qt::escape(m_declaration->qualifiedIdentifier().toString())));
+        modifyHtml() += i18n("namespace %1 ", identifierHighlight(m_declaration->qualifiedIdentifier().toString().toHtmlEscaped(), m_declaration));
+      } else if ( m_declaration->kind() == Declaration::NamespaceAlias ) {
+        modifyHtml() += identifierHighlight(declarationName(m_declaration).toHtmlEscaped(), m_declaration);
       }
 
       if(m_declaration->type<EnumerationType>()) {
         EnumerationType::Ptr enumeration = m_declaration->type<EnumerationType>();
-        modifyHtml() += i18n("enumeration %1 <br/>", Qt::escape(m_declaration->identifier().toString()) );
+        modifyHtml() += i18n("enumeration %1 ", identifierHighlight(m_declaration->identifier().toString().toHtmlEscaped(), m_declaration));
       }
 
       if(m_declaration->isForwardDeclaration()) {
         ForwardDeclaration* forwardDec = static_cast<ForwardDeclaration*>(m_declaration.data());
         Declaration* resolved = forwardDec->resolve(m_topContext.data());
         if(resolved) {
-          modifyHtml() += i18n("( resolved forward-declaration: ");
+          modifyHtml() += i18n("(resolved forward-declaration: ");
           makeLink(resolved->identifier().toString(), KDevelop::DeclarationPointer(resolved), NavigationAction::NavigateDeclaration );
           modifyHtml() += i18n(") ");
         }else{
@@ -128,19 +141,16 @@ QString AbstractDeclarationNavigationContext::html(bool shorten)
           uint count;
           const IndexedDeclaration* decls;
           PersistentSymbolTable::self().declarations(id, count, decls);
-          bool had = false;
           for(uint a = 0; a < count; ++a) {
             if(decls[a].isValid() && !decls[a].data()->isForwardDeclaration()) {
               modifyHtml() += "<br />";
               makeLink(i18n("possible resolution from"), KDevelop::DeclarationPointer(decls[a].data()), NavigationAction::NavigateDeclaration);
               modifyHtml() += ' ' + decls[a].data()->url().str();
-              had = true;
             }
           }
-          if(had)
-            modifyHtml() += "<br />";
         }
       }
+      modifyHtml() += "<br />";
     }
   }else{
     AbstractType::Ptr showType = m_declaration->abstractType();
@@ -151,13 +161,13 @@ QString AbstractDeclarationNavigationContext::html(bool shorten)
     }else  if(showType) {
       modifyHtml() += labelHighlight(i18n("Type: "));
     }
-    
+
     if(showType) {
       eventuallyMakeTypeLinks(showType);
       modifyHtml() += " ";
     }
   }
-  
+
   QualifiedIdentifier identifier = m_declaration->qualifiedIdentifier();
   if( identifier.count() > 1 ) {
     if( m_declaration->context() && m_declaration->context()->owner() )
@@ -178,10 +188,10 @@ QString AbstractDeclarationNavigationContext::html(bool shorten)
     } else {
       QualifiedIdentifier parent = identifier;
       parent.pop();
-      modifyHtml() += labelHighlight(i18n("Scope: %1 ", typeHighlight(Qt::escape(parent.toString()))));
+      modifyHtml() += labelHighlight(i18n("Scope: %1 ", typeHighlight(parent.toString().toHtmlEscaped())));
     }
   }
-  
+
   if( shorten && !m_declaration->comment().isEmpty() ) {
     QString comment = QString::fromUtf8(m_declaration->comment());
     if( comment.length() > 60 ) {
@@ -191,13 +201,13 @@ QString AbstractDeclarationNavigationContext::html(bool shorten)
     comment.replace('\n', " ");
     comment.replace("<br />", " ");
     comment.replace("<br/>", " ");
-    modifyHtml() += commentHighlight(Qt::escape(comment)) + "   ";
+    modifyHtml() += commentHighlight(comment.toHtmlEscaped()) + "   ";
   }
-  
+
 
   QString access = stringFromAccess(m_declaration);
   if( !access.isEmpty() )
-    modifyHtml() += labelHighlight(i18n("Access: %1 ", propertyHighlight(Qt::escape(access))));
+    modifyHtml() += labelHighlight(i18n("Access: %1 ", propertyHighlight(access.toHtmlEscaped())));
 
 
   ///@todo Enumerations
@@ -217,69 +227,81 @@ QString AbstractDeclarationNavigationContext::html(bool shorten)
   QString kind = declarationKind(m_declaration);
   if( !kind.isEmpty() ) {
     if( !detailsHtml.isEmpty() )
-      modifyHtml() += labelHighlight(i18n("Kind: %1 %2 ", importantHighlight(Qt::escape(kind)), detailsHtml));
+      modifyHtml() += labelHighlight(i18n("Kind: %1 %2 ", importantHighlight(kind.toHtmlEscaped()), detailsHtml));
     else
-      modifyHtml() += labelHighlight(i18n("Kind: %1 ", importantHighlight(Qt::escape(kind))));
-  } else if( !detailsHtml.isEmpty() ) {
-    modifyHtml() += labelHighlight(i18n("Modifiers: %1 ",  importantHighlight(Qt::escape(kind))));
+      modifyHtml() += labelHighlight(i18n("Kind: %1 ", importantHighlight(kind.toHtmlEscaped())));
+  }
+
+  if (m_declaration->isDeprecated()) {
+    modifyHtml() += labelHighlight(i18n("Status: %1 ", propertyHighlight(i18n("Deprecated"))));
   }
 
   modifyHtml() += "<br />";
 
   if(!shorten)
     htmlAdditionalNavigation();
-  
+
   if( !shorten ) {
     if(dynamic_cast<FunctionDefinition*>(m_declaration.data()))
       modifyHtml() += labelHighlight(i18n( "Def.: " ));
     else
       modifyHtml() += labelHighlight(i18n( "Decl.: " ));
 
-    makeLink( QString("%1 :%2").arg( KUrl(m_declaration->url().str()).fileName() ).arg( m_declaration->rangeInCurrentRevision().textRange().start().line()+1 ), m_declaration, NavigationAction::JumpToSource );
+    makeLink( QStringLiteral("%1 :%2").arg( m_declaration->url().toUrl().fileName() ).arg( m_declaration->rangeInCurrentRevision().start().line()+1 ), m_declaration, NavigationAction::JumpToSource );
     modifyHtml() += " ";
     //modifyHtml() += "<br />";
     if(!dynamic_cast<FunctionDefinition*>(m_declaration.data())) {
       if( FunctionDefinition* definition = FunctionDefinition::definition(m_declaration.data()) ) {
         modifyHtml() += labelHighlight(i18n( " Def.: " ));
-        makeLink( QString("%1 :%2").arg( KUrl(definition->url().str()).fileName() ).arg( definition->rangeInCurrentRevision().textRange().start().line()+1 ), DeclarationPointer(definition), NavigationAction::JumpToSource );
+        makeLink( QStringLiteral("%1 :%2").arg( definition->url().toUrl().fileName() ).arg( definition->rangeInCurrentRevision().start().line()+1 ), DeclarationPointer(definition), NavigationAction::JumpToSource );
       }
     }
 
     if( FunctionDefinition* definition = dynamic_cast<FunctionDefinition*>(m_declaration.data()) ) {
       if(definition->declaration()) {
         modifyHtml() += labelHighlight(i18n( " Decl.: " ));
-        makeLink( QString("%1 :%2").arg( KUrl(definition->declaration()->url().str()).fileName() ).arg( definition->declaration()->rangeInCurrentRevision().textRange().start().line()+1 ), DeclarationPointer(definition->declaration()), NavigationAction::JumpToSource );
+        makeLink( QStringLiteral("%1 :%2").arg( definition->declaration()->url().toUrl().fileName() ).arg( definition->declaration()->rangeInCurrentRevision().start().line()+1 ), DeclarationPointer(definition->declaration()), NavigationAction::JumpToSource );
       }
     }
-    
+
     modifyHtml() += " "; //The action name _must_ stay "show_uses", since that is also used from outside
     makeLink(i18n("Show uses"), "show_uses", NavigationAction(m_declaration, NavigationAction::NavigateUses));
   }
-  
-  if( !shorten && (!m_declaration->comment().isEmpty() || doc) ) {
+
+  QByteArray declarationComment = m_declaration->comment();
+  if( !shorten && (!declarationComment.isEmpty() || doc) ) {
     modifyHtml() += "<br />";
-    QString comment = QString::fromUtf8(m_declaration->comment());
-    if(comment.isEmpty() && doc) {
-      comment = doc->description();
+
+    if(doc) {
+      QString comment = doc->description();
+      connect(doc.data(), &IDocumentation::descriptionChanged, this, &AbstractDeclarationNavigationContext::contentsChanged);
+
       if(!comment.isEmpty()) {
-        connect(doc.data(), SIGNAL(descriptionChanged()), this, SIGNAL(contentsChanged()));
         modifyHtml() += "<br />" + commentHighlight(comment);
       }
-    } else if(!comment.isEmpty()) {
-      comment.replace(QRegExp("<br */>"), "\n"); //do not escape html newlines within the comment
-      comment = Qt::escape(comment);
-      comment.replace('\n', "<br />"); //Replicate newlines in html
+    }
+
+    QString comment = QString::fromUtf8(declarationComment);
+    if(!comment.isEmpty()) {
+      // if the first paragraph does not contain a tag, we assume that this is a plain-text comment
+      if (!Qt::mightBeRichText(comment)) {
+        // still might contain extra html tags for line breaks (this is the case for doxygen-style comments sometimes)
+        // let's protect them from being removed completely
+        comment.replace(QRegExp("<br */>"), "\n");
+        comment = comment.toHtmlEscaped();
+        comment.replace('\n', "<br />"); //Replicate newlines in html
+      }
       modifyHtml() += commentHighlight(comment);
       modifyHtml() += "<br />";
     }
   }
-  
+
     if(!shorten && doc) {
       modifyHtml() += "<br />" + i18n("Show documentation for ");
       makeLink( prettyQualifiedIdentifier(m_declaration).toString(), m_declaration, NavigationAction::ShowDocumentation );
     }
-  
-  
+
+
     //modifyHtml() += "<br />";
 
   addExternalHtml(m_suffix);
@@ -310,36 +332,36 @@ void AbstractDeclarationNavigationContext::htmlFunction()
     eventuallyMakeTypeLinks( type->returnType() );
   }
 
-  modifyHtml() += ' ' + nameHighlight(Qt::escape(prettyIdentifier(m_declaration).toString()));
+  modifyHtml() += ' ' + identifierHighlight(prettyIdentifier(m_declaration).toString().toHtmlEscaped(), m_declaration);
 
-  if( type->arguments().count() == 0 )
+  if( type->indexedArgumentsSize() == 0 )
   {
     modifyHtml() += "()";
   } else {
     modifyHtml() += "( ";
+
     bool first = true;
+    int firstDefaultParam = type->indexedArgumentsSize() - function->defaultParametersSize();
+    int currentArgNum = 0;
 
-    KDevelop::DUContext* argumentContext = DUChainUtils::getArgumentContext(m_declaration.data());
+    QVector<Declaration*> decls;
+    if (KDevelop::DUContext* argumentContext = DUChainUtils::getArgumentContext(m_declaration.data())) {
+      decls = argumentContext->localDeclarations(m_topContext.data());
+    }
+    foreach(const AbstractType::Ptr& argType, type->arguments()) {
+      if( !first )
+        modifyHtml() += ", ";
+      first = false;
 
-    if(argumentContext) {
-      int firstDefaultParam = argumentContext->localDeclarations(m_topContext.data()).count() - function->defaultParametersSize();
-      int currentArgNum = 0;
-
-      foreach(Declaration* argument, argumentContext->localDeclarations(m_topContext.data())) {
-        if( !first )
-          modifyHtml() += ", ";
-        first = false;
-
-        AbstractType::Ptr argType = argument->abstractType();
-
-        eventuallyMakeTypeLinks( argType );
-        modifyHtml() += ' ' + nameHighlight(Qt::escape(argument->identifier().toString()));
-
-        if( currentArgNum >= firstDefaultParam )
-          modifyHtml() += " = " + Qt::escape(function->defaultParameters()[ currentArgNum - firstDefaultParam ].str());
-
-        ++currentArgNum;
+      eventuallyMakeTypeLinks( argType );
+      if (currentArgNum < decls.size()) {
+        modifyHtml() += ' ' + identifierHighlight(decls[currentArgNum]->identifier().toString().toHtmlEscaped(), m_declaration);
       }
+
+      if( currentArgNum >= firstDefaultParam )
+        modifyHtml() += " = " + function->defaultParameters()[ currentArgNum - firstDefaultParam ].str().toHtmlEscaped();
+
+      ++currentArgNum;
     }
 
     modifyHtml() += " )";
@@ -354,7 +376,7 @@ Identifier AbstractDeclarationNavigationContext::prettyIdentifier(DeclarationPoi
   QualifiedIdentifier q = prettyQualifiedIdentifier(decl);
   if(!q.isEmpty())
     ret = q.last();
-  
+
   return ret;
 }
 
@@ -371,42 +393,42 @@ void AbstractDeclarationNavigationContext::htmlAdditionalNavigation()
   ///Check if the function overrides or hides another one
   const ClassFunctionDeclaration* classFunDecl = dynamic_cast<const ClassFunctionDeclaration*>(m_declaration.data());
   if(classFunDecl) {
-    
+
     Declaration* overridden = DUChainUtils::getOverridden(m_declaration.data());
 
     if(overridden) {
         modifyHtml() += i18n("Overrides a ");
-        makeLink(i18n("function"), QString("jump_to_overridden"), NavigationAction(DeclarationPointer(overridden), KDevelop::NavigationAction::NavigateDeclaration));
+        makeLink(i18n("function"), QStringLiteral("jump_to_overridden"), NavigationAction(DeclarationPointer(overridden), KDevelop::NavigationAction::NavigateDeclaration));
         modifyHtml() += i18n(" from ");
-        makeLink(prettyQualifiedIdentifier(DeclarationPointer(overridden->context()->owner())).toString(), QString("jump_to_overridden_container"), NavigationAction(DeclarationPointer(overridden->context()->owner()), KDevelop::NavigationAction::NavigateDeclaration));
-        
+        makeLink(prettyQualifiedIdentifier(DeclarationPointer(overridden->context()->owner())).toString(), QStringLiteral("jump_to_overridden_container"), NavigationAction(DeclarationPointer(overridden->context()->owner()), KDevelop::NavigationAction::NavigateDeclaration));
+
         modifyHtml() += "<br />";
     }else{
       //Check if this declarations hides other declarations
       QList<Declaration*> decls;
       foreach(const DUContext::Import &import, m_declaration->context()->importedParentContexts())
         if(import.context(m_topContext.data()))
-          decls += import.context(m_topContext.data())->findDeclarations(QualifiedIdentifier(m_declaration->identifier()), 
+          decls += import.context(m_topContext.data())->findDeclarations(QualifiedIdentifier(m_declaration->identifier()),
                                                 CursorInRevision::invalid(), AbstractType::Ptr(), m_topContext.data(), DUContext::DontSearchInParent);
       uint num = 0;
       foreach(Declaration* decl, decls) {
         modifyHtml() += i18n("Hides a ");
-        makeLink(i18n("function"), QString("jump_to_hide_%1").arg(num), NavigationAction(DeclarationPointer(decl), KDevelop::NavigationAction::NavigateDeclaration));
+        makeLink(i18n("function"), QStringLiteral("jump_to_hide_%1").arg(num), NavigationAction(DeclarationPointer(decl), KDevelop::NavigationAction::NavigateDeclaration));
         modifyHtml() += i18n(" from ");
-        makeLink(prettyQualifiedIdentifier(DeclarationPointer(decl->context()->owner())).toString(), QString("jump_to_hide_container_%1").arg(num), NavigationAction(DeclarationPointer(decl->context()->owner()), KDevelop::NavigationAction::NavigateDeclaration));
-        
+        makeLink(prettyQualifiedIdentifier(DeclarationPointer(decl->context()->owner())).toString(), QStringLiteral("jump_to_hide_container_%1").arg(num), NavigationAction(DeclarationPointer(decl->context()->owner()), KDevelop::NavigationAction::NavigateDeclaration));
+
         modifyHtml() += "<br />";
         ++num;
       }
     }
-    
+
     ///Show all places where this function is overridden
     if(classFunDecl->isVirtual()) {
       Declaration* classDecl = m_declaration->context()->owner();
       if(classDecl) {
         uint maxAllowedSteps = m_fullBackwardSearch ? (uint)-1 : 10;
         QList<Declaration*> overriders = DUChainUtils::getOverriders(classDecl, classFunDecl, maxAllowedSteps);
-        
+
         if(!overriders.isEmpty()) {
           modifyHtml() += i18n("Overridden in ");
           bool first = true;
@@ -414,7 +436,7 @@ void AbstractDeclarationNavigationContext::htmlAdditionalNavigation()
             if(!first)
               modifyHtml() += ", ";
             first = false;
-            
+
             QString name = prettyQualifiedIdentifier(DeclarationPointer(overrider->context()->owner())).toString();
             makeLink(name, name, NavigationAction(DeclarationPointer(overrider), NavigationAction::NavigateDeclaration));
           }
@@ -425,11 +447,11 @@ void AbstractDeclarationNavigationContext::htmlAdditionalNavigation()
       }
     }
   }
-  
+
   ///Show all classes that inherit this one
   uint maxAllowedSteps = m_fullBackwardSearch ? (uint)-1 : 10;
   QList<Declaration*> inheriters = DUChainUtils::getInheriters(m_declaration.data(), maxAllowedSteps);
-  
+
   if(!inheriters.isEmpty()) {
       modifyHtml() += i18n("Inherited by ");
       bool first = true;
@@ -437,7 +459,7 @@ void AbstractDeclarationNavigationContext::htmlAdditionalNavigation()
         if(!first)
           modifyHtml() += ", ";
         first = false;
-        
+
         QString importerName = prettyQualifiedIdentifier(DeclarationPointer(importer)).toString();
         makeLink(importerName, importerName, NavigationAction(DeclarationPointer(importer), KDevelop::NavigationAction::NavigateDeclaration));
       }
@@ -466,7 +488,7 @@ void AbstractDeclarationNavigationContext::htmlClass()
 {
   StructureType::Ptr klass = m_declaration->abstractType().cast<StructureType>();
   Q_ASSERT(klass);
-  
+
   ClassDeclaration* classDecl = dynamic_cast<ClassDeclaration*>(klass->declaration(m_topContext.data()));
   if(classDecl) {
     switch ( classDecl->classType() ) {
@@ -490,17 +512,17 @@ void AbstractDeclarationNavigationContext::htmlClass()
         break;
     }
     eventuallyMakeTypeLinks( klass.cast<AbstractType>() );
-    
+
     FOREACH_FUNCTION( const KDevelop::BaseClassInstance& base, classDecl->baseClasses ) {
-      modifyHtml() += ", " + stringFromAccess(base.access) + " " + (base.virtualInheritance ? QString("virtual") : QString()) + " ";
+      modifyHtml() += ", " + stringFromAccess(base.access) + " " + (base.virtualInheritance ? QStringLiteral("virtual") : QString()) + " ";
       eventuallyMakeTypeLinks(base.baseClass.abstractType());
     }
-    modifyHtml() += " ";
   } else {
     /// @todo How can we get here? and should this really be a class?
     modifyHtml() += "class ";
     eventuallyMakeTypeLinks( klass.cast<AbstractType>() );
   }
+  modifyHtml() += " ";
 }
 
 void AbstractDeclarationNavigationContext::htmlIdentifiedType(AbstractType::Ptr type, const IdentifiedType* idType)
@@ -509,63 +531,63 @@ void AbstractDeclarationNavigationContext::htmlIdentifiedType(AbstractType::Ptr
   Q_ASSERT(idType);
 
   if( Declaration* decl = idType->declaration(m_topContext.data()) ) {
-    
+
     //Remove the last template-identifiers, because we create those directly
     QualifiedIdentifier id = prettyQualifiedIdentifier(DeclarationPointer(decl));
     Identifier lastId = id.last();
     id.pop();
     lastId.clearTemplateIdentifiers();
     id.push(lastId);
-    
+
     if(decl->context() && decl->context()->owner()) {
-      
+
       //Also create full type-links for the context around
       AbstractType::Ptr contextType = decl->context()->owner()->abstractType();
-      IdentifiedType* contextIdType = dynamic_cast<IdentifiedType*>(contextType.unsafeData());
+      IdentifiedType* contextIdType = dynamic_cast<IdentifiedType*>(contextType.data());
       if(contextIdType && !contextIdType->equals(idType)) {
         //Create full type information for the context
         if(!id.isEmpty())
           id = id.mid(id.count()-1);
         htmlIdentifiedType(contextType, contextIdType);
-        modifyHtml() += Qt::escape("::");
+        modifyHtml() += QStringLiteral("::").toHtmlEscaped();
       }
     }
 
     //We leave out the * and & reference and pointer signs, those are added to the end
     makeLink(id.toString() , DeclarationPointer(idType->declaration(m_topContext.data())), NavigationAction::NavigateDeclaration );
   } else {
-    kDebug() << "could not resolve declaration:" << idType->declarationId().isDirect() << idType->qualifiedIdentifier().toString() << "in top-context" << m_topContext->url().str();
-    modifyHtml() += typeHighlight(Qt::escape(type->toString()));
+    qCDebug(LANGUAGE) << "could not resolve declaration:" << idType->declarationId().isDirect() << idType->qualifiedIdentifier().toString() << "in top-context" << m_topContext->url().str();
+    modifyHtml() += typeHighlight(type->toString().toHtmlEscaped());
   }
 }
 
 void AbstractDeclarationNavigationContext::eventuallyMakeTypeLinks( AbstractType::Ptr type )
 {
   type = typeToShow(type);
-  
+
   if( !type ) {
-    modifyHtml() += typeHighlight(Qt::escape("<no type>"));
+    modifyHtml() += typeHighlight(QStringLiteral("<no type>").toHtmlEscaped());
     return;
   }
 
   AbstractType::Ptr target = TypeUtils::targetTypeKeepAliases( type, m_topContext.data() );
-  const IdentifiedType* idType = dynamic_cast<const IdentifiedType*>( target.unsafeData() );
+  const IdentifiedType* idType = dynamic_cast<const IdentifiedType*>( target.data() );
+
+  qCDebug(LANGUAGE) << "making type-links for" << type->toString();
 
-  kDebug() << "making type-links for" << type->toString() << typeid(*type).name();
-  
   if( idType && idType->declaration(m_topContext.data()) ) {
     ///@todo This is C++ specific, move into subclass
-    
+
     if(target->modifiers() & AbstractType::ConstModifier)
       modifyHtml() += typeHighlight("const ");
-    
+
     htmlIdentifiedType(target, idType);
 
     //We need to exchange the target type, else template-parameters may confuse this
     SimpleTypeExchanger exchangeTarget(target, AbstractType::Ptr());
-    
+
     AbstractType::Ptr exchanged = exchangeTarget.exchange(type);
-    
+
     if(exchanged) {
       QString typeSuffixString = exchanged->toString();
       QRegExp suffixExp("\\&|\\*");
@@ -576,9 +598,9 @@ void AbstractDeclarationNavigationContext::eventuallyMakeTypeLinks( AbstractType
 
   } else {
     if(idType) {
-      kDebug() << "identified type could not be resolved:" << idType->qualifiedIdentifier() << idType->declarationId().isValid() << idType->declarationId().isDirect();
+      qCDebug(LANGUAGE) << "identified type could not be resolved:" << idType->qualifiedIdentifier() << idType->declarationId().isValid() << idType->declarationId().isDirect();
     }
-    modifyHtml() += typeHighlight(Qt::escape(type->toString()));
+    modifyHtml() += typeHighlight(type->toString().toHtmlEscaped());
   }
 }
 
@@ -587,6 +609,19 @@ DeclarationPointer AbstractDeclarationNavigationContext::declaration() const
   return m_declaration;
 }
 
+QString AbstractDeclarationNavigationContext::identifierHighlight(const QString& identifier, const DeclarationPointer& decl) const
+{
+  QString ret = nameHighlight(identifier);
+  if (!decl) {
+    return ret;
+  }
+
+  if (decl->isDeprecated()) {
+    ret = QStringLiteral("<i>") + ret + QStringLiteral("</i>");
+  }
+  return ret;
+}
+
 QString AbstractDeclarationNavigationContext::stringFromAccess(Declaration::AccessPolicy access)
 {
   switch(access) {
@@ -689,7 +724,7 @@ QStringList AbstractDeclarationNavigationContext::declarationDetails(Declaration
         details << "abstract";
     }
   }
-  
+
   return details;
 }
 
