@@ -35,22 +35,30 @@ class KDEVPLATFORMLANGUAGE_EXPORT AbstractDeclarationNavigationContext : public
   public:
     AbstractDeclarationNavigationContext( DeclarationPointer decl, KDevelop::TopDUContextPointer topContext, AbstractNavigationContext* previousContext = 0 );
 
-    virtual QString name() const;
+    virtual QString name() const override;
 
     DeclarationPointer declaration() const;
 
     ///Execute an action. For example "show_uses" shows the uses of the declaration.
     ///Returns the context pointer for the new state.
-    virtual NavigationContextPointer executeKeyAction(QString key);
+    virtual NavigationContextPointer executeKeyAction(QString key) override;
 
   protected:
-    virtual QString html(bool shorten = false);
+    virtual QString html(bool shorten = false) override;
+
     DeclarationPointer m_declaration;
 
     ///Should returns a stripped version of the declarations qualified identifier, with all implicit/redundant parts removed
     virtual QualifiedIdentifier prettyQualifiedIdentifier(DeclarationPointer decl) const;
     ///Returns a stripped version of the declarations identifier, using prettyQualifiedIdentifier
     Identifier prettyIdentifier(DeclarationPointer decl) const;
+
+    /**
+     * Return a rich-text version of the identifier @p identifier representing the declaration @p decl
+     *
+     * @note In case @p declaration is deprecated, the resulting string will get a special formatting
+     */
+    QString identifierHighlight(const QString& identifier, const DeclarationPointer& decl) const;
     
     static QString stringFromAccess(Declaration::AccessPolicy access);
     static QString stringFromAccess(DeclarationPointer decl);
