@@ -22,7 +22,7 @@
 #include "abstractnavigationcontext.h"
 #include "../../util/includeitem.h"
 #include "../../duchain/parsingenvironment.h"
-#include "../../languageexport.h"
+#include <language/languageexport.h>
 
 namespace KDevelop {
 
@@ -50,8 +50,8 @@ class KDEVPLATFORMLANGUAGE_EXPORT AbstractIncludeNavigationContext : public Abst
 public:
   AbstractIncludeNavigationContext(const IncludeItem& item, TopDUContextPointer topContext, 
                                    const ParsingEnvironmentType& type);
-  virtual QString html(bool shorten);
-  virtual QString name() const;
+  virtual QString html(bool shorten) override;
+  virtual QString name() const override;
 
 protected:
   /// Overwrite this to add language dependent information for a given file.
@@ -70,7 +70,7 @@ private:
   typedef QPair<int, uint> IdentifierPair;
   void addDeclarationsFromContext(KDevelop::DUContext* ctx, bool& first,
                                   QList<IdentifierPair>& addedDeclarations,
-                                  const QString& indent = "" );
+                                  const QString& indent = {} );
   IncludeItem m_item;
 };
 
