@@ -1,6 +1,6 @@
 /*
    Copyright 2009 David Nolden <david.nolden.kdevelop@art-master.de>
-   
+
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License version 2 as published by the Free Software Foundation.
@@ -18,16 +18,16 @@
 
 #include "problemnavigationcontext.h"
 
-#include <klocalizedstring.h>
+#include <QHBoxLayout>
+#include <QMenu>
+
+#include <KLocalizedString>
+
 #include <language/duchain/declaration.h>
 #include <language/duchain/duchainlock.h>
 #include <language/duchain/duchainutils.h>
 #include <language/duchain/problem.h>
-#include <qtextdocument.h>
-#include <qboxlayout.h>
 #include <interfaces/iassistant.h>
-#include <qmenu.h>
-#include <kaction.h>
 #include <util/richtextpushbutton.h>
 
 using namespace KDevelop;
@@ -36,7 +36,7 @@ ProblemNavigationContext::ProblemNavigationContext(ProblemPointer problem): m_pr
 {
   m_widget = 0;
 
-  KSharedPtr< IAssistant > solution = problem->solutionAssistant();
+  QExplicitlySharedDataPointer< IAssistant > solution = problem->solutionAssistant();
   if(solution && !solution->actions().isEmpty()) {
     m_widget = new QWidget;
     QHBoxLayout* layout = new QHBoxLayout(m_widget);
@@ -51,7 +51,6 @@ ProblemNavigationContext::ProblemNavigationContext(ProblemPointer problem): m_pr
     menu->setFocusPolicy(Qt::NoFocus);
     foreach(IAssistantAction::Ptr action, solution->actions()) {
       menu->addAction(action->toKAction());
-      kDebug() << "adding action" << action->description();
     }
     button->setMenu(menu);
 
@@ -89,27 +88,27 @@ QString ProblemNavigationContext::html(bool shorten)
   modifyHtml() += "<html><body><p>";
 
   modifyHtml() += i18n("Problem in <b>%1</b>:<br/>", m_problem->sourceString());
-  modifyHtml() += Qt::escape(m_problem->description());
+  modifyHtml() += m_problem->description().toHtmlEscaped();
   modifyHtml() += "<br/>";
-  modifyHtml() += "<i style=\"white-space:pre-wrap\">" + Qt::escape(m_problem->explanation()) + "</i>";
+  modifyHtml() += "<i style=\"white-space:pre-wrap\">" + m_problem->explanation().toHtmlEscaped() + "</i>";
 
-  const QList<ProblemPointer> diagnostics = m_problem->diagnostics();
+  const QVector<IProblem::Ptr> diagnostics = m_problem->diagnostics();
   if (!diagnostics.isEmpty()) {
     modifyHtml() += "<br/>";
 
     DUChainReadLocker lock;
     for (auto diagnostic : diagnostics) {
       const DocumentRange range = diagnostic->finalLocation();
-      Declaration* declaration = DUChainUtils::itemUnderCursor(range.document.toUrl(), range.start);
+      Declaration* declaration = DUChainUtils::itemUnderCursor(range.document.toUrl(), range.start());
 
-      modifyHtml() += labelHighlight(QString("%1: ").arg(diagnostic->severityString()));
+      modifyHtml() += labelHighlight(QStringLiteral("%1: ").arg(diagnostic->severityString()));
       modifyHtml() += diagnostic->description();
 
       if (declaration) {
         modifyHtml() += "<br/>";
         makeLink(declaration->toString(), KDevelop::DeclarationPointer(declaration), NavigationAction::NavigateDeclaration);
         modifyHtml() += i18n(" in ");
-        makeLink(QString("%1 :%2").arg(declaration->url().toUrl().fileName()).arg(declaration->rangeInCurrentRevision().textRange().start().line()+1), KDevelop::DeclarationPointer(declaration), NavigationAction::NavigateDeclaration);
+        makeLink(QStringLiteral("%1 :%2").arg(declaration->url().toUrl().fileName()).arg(declaration->rangeInCurrentRevision().start().line()+1), KDevelop::DeclarationPointer(declaration), NavigationAction::NavigateDeclaration);
       }
       modifyHtml() += "<br/>";
     }
@@ -118,5 +117,3 @@ QString ProblemNavigationContext::html(bool shorten)
   modifyHtml() += "</p></body></html>";
   return currentHtml();
 }
-
-
