@@ -21,7 +21,7 @@
 
 #include <language/duchain/navigation/abstractnavigationcontext.h>
 #include <language/duchain/problem.h>
-#include "../../languageexport.h"
+#include <language/languageexport.h>
 #include <qpointer.h>
 
 namespace KDevelop {
@@ -29,12 +29,12 @@ namespace KDevelop {
 class KDEVPLATFORMLANGUAGE_EXPORT ProblemNavigationContext : public AbstractNavigationContext
 {
   public:
-    ProblemNavigationContext(KDevelop::ProblemPointer problem);
+    explicit ProblemNavigationContext(KDevelop::ProblemPointer problem);
     ~ProblemNavigationContext();
-    virtual QString name() const;  
-    virtual QString html(bool shorten = false);    
-    virtual QWidget* widget() const;
-    virtual bool isWidgetMaximized() const;
+    virtual QString name() const override;  
+    virtual QString html(bool shorten = false) override;    
+    virtual QWidget* widget() const override;
+    virtual bool isWidgetMaximized() const override;
   private:
     QPointer<QWidget> m_widget;
     ProblemPointer m_problem;
