@@ -17,55 +17,49 @@
 */
 
 #include "useswidget.h"
+#include "util/debug.h"
+
+#include <QIcon>
+#include <QLabel>
+#include <QProgressBar>
+#include <QResizeEvent>
+#include <QToolButton>
+#include <QVBoxLayout>
+
+#include <KLocalizedString>
+
 #include <language/duchain/duchainlock.h>
 #include <language/duchain/duchain.h>
 #include <language/duchain/uses.h>
-#include <QVBoxLayout>
-#include <QLabel>
-#include <QCompleter>
-#include <QProgressBar>
-#include <KComboBox>
-#include <qpushbutton.h>
-#include <limits>
-#include <klocalizedstring.h>
-#include <qabstractitemview.h>
-#include <QToolButton>
+#include <language/duchain/declaration.h>
 #include <language/duchain/use.h>
-#include <kicon.h>
 #include <interfaces/icore.h>
 #include <interfaces/idocumentcontroller.h>
-#include <ktexteditor/document.h>
-#include <QFile>
 #include <interfaces/iprojectcontroller.h>
-#include <qtextdocument.h>
-#include <qevent.h>
-#include <qtextlayout.h>
+
 #include <language/duchain/duchainutils.h>
-#include "language/duchain/parsingenvironment.h"
-#include "language/duchain/types/indexedtype.h"
 #include <language/codegen/coderepresentation.h>
-#include <language/backgroundparser/parsejob.h>
 #include <interfaces/iproject.h>
-#include <interfaces/foregroundlock.h>
+#include <util/foregroundlock.h>
 
 using namespace KDevelop;
 
 
 const int tooltipContextSize = 2; //How many lines around the use are shown in the tooltip
-const bool showUsesHeader = false;
 
 ///The returned text is fully escaped
 ///@param cutOff The total count of characters that should be cut of, all in all on both sides together.
 ///@param range The range that is highlighted, and that will be preserved during cutting, given that there is enough room beside it.
-QString highlightAndEscapeUseText(QString line, uint cutOff, SimpleRange range) {
-  uint leftCutRoom = range.start.column;
-  uint rightCutRoom = line.length() - range.end.column;
+QString highlightAndEscapeUseText(QString line, int cutOff, KTextEditor::Range range)
+{
+  int leftCutRoom = range.start().column();
+  int rightCutRoom = line.length() - range.end().column();
 
-  if(range.start.column < 0 || range.end.column > line.length() || cutOff > leftCutRoom + rightCutRoom)
+  if(range.start().column() < 0 || range.end().column() > line.length() || cutOff > leftCutRoom + rightCutRoom)
     return QString(); //Not enough room for cutting off on sides
 
-  uint leftCut = 0;
-  uint rightCut = 0;
+  int leftCut = 0;
+  int rightCut = 0;
 
   if(leftCutRoom < rightCutRoom) {
     if(leftCutRoom * 2 >= cutOff) {
@@ -92,53 +86,52 @@ QString highlightAndEscapeUseText(QString line, uint cutOff, SimpleRange range)
 
   line = line.left(line.length() - rightCut);
   line = line.mid(leftCut);
-  range.start.column -= leftCut;
-  range.end.column -= leftCut;
+  range += KTextEditor::Range(0, -leftCut, 0, -leftCut);
 
-  Q_ASSERT(range.start.column >= 0 && range.end.column <= line.length());
+  Q_ASSERT(range.start().column() >= 0 && range.end().column() <= line.length());
 
   //TODO: share code with context browser
   // mixing (255, 255, 0, 100) with white yields this:
   const QColor background(251, 250, 150);
   const QColor foreground(0, 0, 0);
 
-  return "<span style=\"font-family:'monospace'\">" + Qt::escape(line.left(range.start.column))
+  return "<span style=\"font-family:'monospace'\">" + line.left(range.start().column()).toHtmlEscaped()
                     + "<span style=\"background-color:" + background.name() + ";color:" + foreground.name() + ";\">"
-                    + Qt::escape(line.mid(range.start.column, range.end.column - range.start.column))
-                    + "</span>" + Qt::escape(line.mid(range.end.column, line.length() - range.end.column)) + "</span>";
+                    + line.mid(range.start().column(), range.end().column() - range.start().column()).toHtmlEscaped()
+                    + "</span>" + line.mid(range.end().column(), line.length() - range.end().column()).toHtmlEscaped() + "</span>";
 }
 
-OneUseWidget::OneUseWidget(IndexedDeclaration declaration, IndexedString document, SimpleRange range, const CodeRepresentation& code) : m_range(new PersistentMovingRange(range, document)), m_declaration(declaration), m_document(document) {
+OneUseWidget::OneUseWidget(IndexedDeclaration declaration, IndexedString document, KTextEditor::Range range, const CodeRepresentation& code) : m_range(new PersistentMovingRange(range, document)), m_declaration(declaration), m_document(document) {
 
   //Make the sizing of this widget independent of the content, because we will adapt the content to the size
   setSizePolicy(QSizePolicy::Ignored, QSizePolicy::Fixed);
 
-  m_sourceLine = code.line(m_range->range().start.line);
+  m_sourceLine = code.line(m_range->range().start().line());
 
   m_layout = new QHBoxLayout(this);
   setLayout(m_layout);
 
   m_label = new QLabel(this);
   m_icon = new QLabel(this);
-  m_icon->setPixmap(KIcon("code-function").pixmap(16));
+  m_icon->setPixmap(QIcon::fromTheme("code-function").pixmap(16));
 
-  connect(m_label, SIGNAL(linkActivated(QString)), this, SLOT(jumpTo()));
+  connect(m_label, &QLabel::linkActivated, this, &OneUseWidget::jumpTo);
 
   DUChainReadLocker lock(DUChain::lock());
-  QString text = "<a href='open'>" + i18nc("refers to a line in source code", "Line <b>%1</b>:", range.start.line) + QString("</a>");
-  if(!m_sourceLine.isEmpty() && m_sourceLine.length() > m_range->range().end.column) {
+  QString text = "<a href='open'>" + i18nc("refers to a line in source code", "Line <b>%1</b>:", range.start().line()) + QStringLiteral("</a>");
+  if(!m_sourceLine.isEmpty() && m_sourceLine.length() > m_range->range().end().column()) {
 
     text += "&nbsp;&nbsp;" + highlightAndEscapeUseText(m_sourceLine, 0, m_range->range());
 
     //Useful tooltip:
-    int start = m_range->range().start.line - tooltipContextSize;
-    int end = m_range->range().end.line + tooltipContextSize + 1;
+    int start = m_range->range().start().line() - tooltipContextSize;
+    int end = m_range->range().end().line() + tooltipContextSize + 1;
 
     QString toolTipText;
     for(int a = start; a < end; ++a) {
-      QString lineText = code.line(a);
-      if (m_range->range().start.line <= a && m_range->range().end.line >= a) {
-        lineText = QString("<b>") + Qt::escape(lineText) + QString("</b>");
+      QString lineText = code.line(a).toHtmlEscaped();
+      if (m_range->range().start().line() <= a && m_range->range().end().line() >= a) {
+        lineText = QStringLiteral("<b>") + lineText + QStringLiteral("</b>");
       }
       if(!lineText.trimmed().isEmpty()) {
         toolTipText += lineText + "<br>";
@@ -147,7 +140,7 @@ OneUseWidget::OneUseWidget(IndexedDeclaration declaration, IndexedString documen
     if ( toolTipText.endsWith("<br>") ) {
       toolTipText.remove(toolTipText.length() - 4, 4);
     }
-    setToolTip(QString("<html><body><pre>") + toolTipText + QString("</pre></body></html>"));
+    setToolTip(QStringLiteral("<html><body><pre>") + toolTipText + QStringLiteral("</pre></body></html>"));
   }
   m_label->setText(text);
 
@@ -158,7 +151,7 @@ OneUseWidget::OneUseWidget(IndexedDeclaration declaration, IndexedString documen
 
 void OneUseWidget::jumpTo() {
         //This is used to execute the slot delayed in the event-loop, so crashes are avoided
-  ICore::self()->documentController()->openDocument(m_document.toUrl(), m_range->range().start.textCursor());
+  ICore::self()->documentController()->openDocument(m_document.toUrl(), m_range->range().start());
 }
 
 OneUseWidget::~OneUseWidget() {
@@ -168,19 +161,19 @@ void OneUseWidget::resizeEvent ( QResizeEvent * event ) {
   ///Adapt the content
   QSize size = event->size();
 
-  SimpleRange range = m_range->range();
-  
+  KTextEditor::Range range = m_range->range();
+
   int cutOff = 0;
-  int maxCutOff = m_sourceLine.length() - (range.end.column - range.start.column);
+  int maxCutOff = m_sourceLine.length() - (range.end().column() - range.start().column());
 
   //Reset so we also get more context while up-sizing
-  m_label->setText(QString("<a href='open'>") + i18nc("Refers to a line in source code", "Line <b>%1</b>", range.start.line+1)
-                 + QString("</a> %2").arg(highlightAndEscapeUseText(m_sourceLine, cutOff, range)));
+  m_label->setText(QStringLiteral("<a href='open'>") + i18nc("Refers to a line in source code", "Line <b>%1</b>", range.start().line()+1)
+                 + QStringLiteral("</a> ") + highlightAndEscapeUseText(m_sourceLine, cutOff, range));
 
   while(sizeHint().width() > size.width() && cutOff < maxCutOff) {
     //We've got to save space
-    m_label->setText(QString("<a href='open'>") + i18nc("Refers to a line in source code", "Line <b>%1</b>", range.start.line+1)
-                   + QString("</a> %2").arg(highlightAndEscapeUseText(m_sourceLine, cutOff, range)));
+    m_label->setText(QStringLiteral("<a href='open'>") + i18nc("Refers to a line in source code", "Line <b>%1</b>", range.start().line()+1)
+                   + QStringLiteral("</a> ") + highlightAndEscapeUseText(m_sourceLine, cutOff, range));
     cutOff += 5;
   }
 
@@ -227,10 +220,10 @@ NavigatableWidgetList::NavigatableWidgetList(bool allowScrolling, uint maxHeight
 
   if(m_useArrows) {
     m_previousButton = new QToolButton();
-    m_previousButton->setIcon(KIcon("go-previous"));
+    m_previousButton->setIcon(QIcon::fromTheme("go-previous"));
 
     m_nextButton = new QToolButton();
-    m_nextButton->setIcon(KIcon("go-next"));
+    m_nextButton->setIcon(QIcon::fromTheme("go-next"));
 
     m_headerLayout->addWidget(m_previousButton);
     m_headerLayout->addWidget(m_nextButton);
@@ -239,11 +232,11 @@ NavigatableWidgetList::NavigatableWidgetList(bool allowScrolling, uint maxHeight
   //hide these buttons for now, they're senseless
 
   m_layout->addLayout(m_headerLayout);
-  
+
   QHBoxLayout* spaceLayout = new QHBoxLayout;
   spaceLayout->addSpacing(10);
   spaceLayout->addLayout(m_itemLayout);
-  
+
   m_layout->addLayout(spaceLayout);
 
   if(maxHeight)
@@ -321,7 +314,7 @@ uint countUses(int usedDeclarationIndex, DUContext* context) {
 QList<OneUseWidget*> createUseWidgets(const CodeRepresentation& code, int usedDeclarationIndex, IndexedDeclaration decl, DUContext* context) {
   QList<OneUseWidget*> ret;
   VERIFY_FOREGROUND_LOCKED
-  
+
   for(int useIndex = 0; useIndex < context->usesCount(); ++useIndex)
     if(context->uses()[useIndex].m_declarationIndex == usedDeclarationIndex)
       ret << new OneUseWidget(decl, context->url(), context->transformFromLocalRevision(context->uses()[useIndex].m_range), code);
@@ -368,11 +361,11 @@ ContextUsesWidget::ContextUsesWidget(const CodeRepresentation& code, QList<Index
       }
     }
 
-    QLabel* headerLabel = new QLabel(i18nc("%1: source file", "In %1", "<a href='navigateToFunction'>" 
-                                          + Qt::escape(headerText) + "</a>: "));
+    QLabel* headerLabel = new QLabel(i18nc("%1: source file", "In %1", "<a href='navigateToFunction'>"
+                                          + headerText.toHtmlEscaped() + "</a>: "));
     addHeaderItem(headerLabel);
     setUpdatesEnabled(true);
-    connect(headerLabel, SIGNAL(linkActivated(QString)), this, SLOT(linkWasActivated(QString)));
+    connect(headerLabel, &QLabel::linkActivated, this, &ContextUsesWidget::linkWasActivated);
 }
 
 void ContextUsesWidget::linkWasActivated(QString link) {
@@ -382,7 +375,7 @@ void ContextUsesWidget::linkWasActivated(QString link) {
     if(context) {
       CursorInRevision contextStart = context->range().start;
       KTextEditor::Cursor cursor(contextStart.line, contextStart.column);
-      KUrl url = context->url().toUrl();
+      QUrl url = context->url().toUrl();
       lock.unlock();
       ForegroundLock fgLock;
       ICore::self()->documentController()->openDocument(url, cursor);
@@ -423,7 +416,7 @@ TopContextUsesWidget::TopContextUsesWidget(IndexedDeclaration declaration, QList
     QLabel* label = new QLabel(this);
     m_icon = new QLabel(this);
     m_toggleButton = new QLabel(this);
-    m_icon->setPixmap(KIcon("code-class").pixmap(16));
+    m_icon->setPixmap(QIcon::fromTheme("code-class").pixmap(16));
     labelLayout->addWidget(m_icon);
     labelLayout->addWidget(label);
     labelLayout->addWidget(m_toggleButton);
@@ -438,7 +431,7 @@ TopContextUsesWidget::TopContextUsesWidget(IndexedDeclaration declaration, QList
 
     m_toggleButton->setText("&nbsp;&nbsp; <a href='toggleCollapsed'>[" + i18nc("Refers to closing a UI element", "Collapse") + "]</a>");
 
-    connect(m_toggleButton, SIGNAL(linkActivated(QString)), this, SLOT(labelClicked()));
+    connect(m_toggleButton, &QLabel::linkActivated, this, &TopContextUsesWidget::labelClicked);
     addHeaderItem(headerWidget);
     setUpdatesEnabled(true);
 }
@@ -504,17 +497,22 @@ void TopContextUsesWidget::labelClicked() {
   }
 }
 
-UsesWidget::~UsesWidget() {
-  delete m_collector;
+UsesWidget::~UsesWidget()
+{
+    if (m_collector) {
+        m_collector->setWidget(0);
+    }
 }
 
-UsesWidget::UsesWidget(IndexedDeclaration declaration, UsesWidgetCollector* customCollector) : NavigatableWidgetList(true) {
+UsesWidget::UsesWidget(const IndexedDeclaration& declaration, QSharedPointer<UsesWidgetCollector> customCollector)
+    : NavigatableWidgetList(true)
+{
     DUChainReadLocker lock(DUChain::lock());
     setUpdatesEnabled(false);
 
     m_headerLine = new QLabel;
     redrawHeaderLine();
-    connect(m_headerLine, SIGNAL(linkActivated(QString)), this, SLOT(headerLinkActivated(QString)));
+    connect(m_headerLine, &QLabel::linkActivated, this, &UsesWidget::headerLinkActivated);
     m_layout->insertWidget(0, m_headerLine, 0, Qt::AlignTop);
 
     m_layout->setAlignment(Qt::AlignTop);
@@ -523,10 +521,10 @@ UsesWidget::UsesWidget(IndexedDeclaration declaration, UsesWidgetCollector* cust
     m_progressBar = new QProgressBar;
     addHeaderItem(m_progressBar);
 
-    if(!customCollector) {
-      m_collector = new UsesWidgetCollector(declaration);
-    }else{
-      m_collector = customCollector;
+    if (!customCollector) {
+        m_collector = QSharedPointer<UsesWidgetCollector>(new UsesWidgetCollector(declaration));
+    } else {
+        m_collector = customCollector;
     }
 
     m_collector->setProcessDeclarations(true);
@@ -588,16 +586,24 @@ void UsesWidget::UsesWidgetCollector::setWidget(UsesWidget* widget ) {
 
 
 void UsesWidget::UsesWidgetCollector::maximumProgress(uint max) {
+  if (!m_widget) {
+    return;
+  }
+
   if(m_widget->m_progressBar) {
     m_widget->m_progressBar->setMaximum(max);
     m_widget->m_progressBar->setMinimum(0);
     m_widget->m_progressBar->setValue(0);
   }else{
-    kWarning() << "maximumProgress called twice";
+    qCWarning(LANGUAGE) << "maximumProgress called twice";
   }
 }
 
 void UsesWidget::UsesWidgetCollector::progress(uint processed, uint total) {
+  if (!m_widget) {
+    return;
+  }
+
   m_widget->redrawHeaderLine();
 
   if(m_widget->m_progressBar) {
@@ -611,20 +617,26 @@ void UsesWidget::UsesWidgetCollector::progress(uint processed, uint total) {
       m_widget->setUpdatesEnabled(true);
     }
   }else{
-    kWarning() << "progress() called too often";
+    qCWarning(LANGUAGE) << "progress() called too often";
   }
 }
 
 void UsesWidget::UsesWidgetCollector::processUses( KDevelop::ReferencedTopDUContext topContext ) {
-  DUChainReadLocker lock(DUChain::lock());
-  kDebug() << "processing" << topContext->url().str();
+  if (!m_widget) {
+    return;
+  }
+
+  DUChainReadLocker lock;
+
+
+  qCDebug(LANGUAGE) << "processing" << topContext->url().str();
   TopContextUsesWidget* widget = new TopContextUsesWidget(declaration(), declarations(), topContext.data());
-  
+
   // move to back if it's just the declaration/definition
   bool toBack = widget->usesCount() == 0;
   // move to front the item belonging to the current open document
   IDocument* doc = ICore::self()->documentController()->activeDocument();
-  bool toFront = doc && doc->url().equals(topContext->url().toUrl());
+  bool toFront = doc && (doc->url() == topContext->url().toUrl());
 
   widget->setExpanded(true);
 
@@ -640,4 +652,3 @@ QSize KDevelop::UsesWidget::sizeHint() const {
 }
 
 
-#include "useswidget.moc"
