@@ -15,22 +15,21 @@
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
 */
+
 #ifndef KDEVPLATFORM_USESWIDGET_H
 #define KDEVPLATFORM_USESWIDGET_H
 
 #include <QWidget>
-#include <QLabel>
 #include <QScrollArea>
+#include <QSharedPointer>
 
-#include <language/duchain/declaration.h>
-#include <language/duchain/topducontext.h>
-#include <language/editor/cursorinrevision.h>
-#include "../../languageexport.h"
+#include <language/duchain/indexeddeclaration.h>
+#include <language/duchain/indexedtopducontext.h>
+#include <language/languageexport.h>
 #include "usescollector.h"
 #include <language/editor/persistentmovingrange.h>
 
-class KComboBox;
-class QComboBox;
+class QLabel;
 class QToolButton;
 class QVBoxLayout;
 class QHBoxLayout;
@@ -46,13 +45,13 @@ namespace KDevelop {
     class KDEVPLATFORMLANGUAGE_EXPORT OneUseWidget : public QWidget {
       Q_OBJECT
       public:
-        OneUseWidget(IndexedDeclaration declaration, IndexedString document, SimpleRange range, const CodeRepresentation& code);
+        OneUseWidget(IndexedDeclaration declaration, IndexedString document, KTextEditor::Range range, const CodeRepresentation& code);
         ~OneUseWidget();
         
       private slots:
         void jumpTo();
       private:
-        virtual void resizeEvent ( QResizeEvent * event );
+        virtual void resizeEvent ( QResizeEvent * event ) override;
         
         PersistentMovingRange::Ptr m_range;
         IndexedDeclaration m_declaration;
@@ -68,7 +67,7 @@ namespace KDevelop {
     class KDEVPLATFORMLANGUAGE_EXPORT NavigatableWidgetList : public QScrollArea {
       Q_OBJECT
       public:
-        NavigatableWidgetList(bool allowScrolling = false, uint maxHeight = 0, bool vertical = true);
+        explicit NavigatableWidgetList(bool allowScrolling = false, uint maxHeight = 0, bool vertical = true);
         ~NavigatableWidgetList();
         void addItem(QWidget* widget, int pos = -1);
         void addHeaderItem(QWidget* widget, Qt::Alignment alignment = 0);
@@ -136,16 +135,14 @@ namespace KDevelop {
               public:
               void setWidget(UsesWidget* widget );
               UsesWidgetCollector(IndexedDeclaration decl);
-              virtual void processUses(KDevelop::ReferencedTopDUContext topContext);
-              virtual void maximumProgress(uint max);
-              virtual void progress(uint processed, uint total);
+              virtual void processUses(KDevelop::ReferencedTopDUContext topContext) override;
+              virtual void maximumProgress(uint max) override;
+              virtual void progress(uint processed, uint total) override;
               UsesWidget* m_widget;
             };
-            virtual QSize sizeHint () const;
-            ///@param customCollector allows specifying an own subclass of UsesWidgetCollector. The object will be owned
-            ///@param showDeclarations whether all declarations used for the search should be shown as well in the list
-            ///by this widget, and will be deleted on destruction.
-            UsesWidget(IndexedDeclaration declaration, UsesWidgetCollector* customCollector = 0);
+            virtual QSize sizeHint () const override;
+            ///@param customCollector allows specifying an own subclass of UsesWidgetCollector.
+            explicit UsesWidget(const IndexedDeclaration& declaration, QSharedPointer<UsesWidgetCollector> customCollector = {});
             ~UsesWidget();
             void setAllExpanded(bool expanded);
             unsigned int countAllUses() const;
@@ -154,7 +151,7 @@ namespace KDevelop {
         private:
             const QString headerLineText() const;
             QLabel* m_headerLine;
-            UsesWidgetCollector* m_collector;
+            QSharedPointer<UsesWidgetCollector> m_collector;
             QProgressBar* m_progressBar;
         public slots:
             void headerLinkActivated(QString linkName);
