@@ -1,7 +1,7 @@
 /*
  * This file is part of KDevelop
  *
- * Copyright 2011 Milian Wolff <mail@milianw.de>
+ * Copyright 2011-2013 Milian Wolff <mail@milianw.de>
  * Copyright 2006 Hamish Rodda <rodda@kde.org>
  * Copyright 2007-2009 David Nolden <david.nolden.kdevelop@art-master.de>
  *
@@ -36,6 +36,10 @@
 #include <language/duchain/types/typesystemdata.h>
 #include <language/duchain/types/integraltype.h>
 #include <language/duchain/types/typeregister.h>
+#include <language/duchain/declarationdata.h>
+#include <language/duchain/duchainregister.h>
+#include <language/duchain/problem.h>
+#include <language/duchain/parsingenvironment.h>
 
 #include <language/codegen/coderepresentation.h>
 
@@ -85,6 +89,7 @@ void TestDUChain::cleanupTestCase()
   TestCore::shutdown();
 }
 
+#ifndef Q_OS_WIN
 void TestDUChain::testStringSets() {
 
   const unsigned int setCount = 8;
@@ -93,7 +98,7 @@ void TestDUChain::testStringSets() {
 
   BasicSetRepository rep("test repository");
 
-//  kDebug() << "Start repository-layout: \n" << rep.dumpDotGraph();
+//  qDebug() << "Start repository-layout: \n" << rep.dumpDotGraph();
 
   qint64 repositoryTime = 0; //Time spent on repository-operations
   qint64 genericTime = 0; //Time spend on equivalent operations with generic sets
@@ -142,12 +147,12 @@ void TestDUChain::testStringSets() {
     if(tempSet != realSets[a]) {
       QString dbg = "created set: ";
       for(std::set<Index>::const_iterator it = realSets[a].begin(); it != realSets[a].end(); ++it)
-        dbg += QString("%1 ").arg(*it);
+        dbg += QStringLiteral("%1 ").arg(*it);
       qDebug() << dbg;
 
       dbg = "repo.   set: ";
       for(std::set<Index>::const_iterator it = tempSet.begin(); it != tempSet.end(); ++it)
-        dbg += QString("%1 ").arg(*it);
+        dbg += QStringLiteral("%1 ").arg(*it);
       qDebug() << dbg;
 
       qDebug() << "DOT-Graph:\n\n" << sets[a].dumpDotGraph() << "\n\n";
@@ -182,7 +187,7 @@ void TestDUChain::testStringSets() {
             qDebug() << "SET a:";
             QString dbg = "";
             for(std::set<Index>::const_iterator it = realSets[a].begin(); it != realSets[a].end(); ++it)
-              dbg += QString("%1 ").arg(*it);
+              dbg += QStringLiteral("%1 ").arg(*it);
             qDebug() << dbg;
 
             qDebug() << "DOT-Graph:\n\n" << sets[a].dumpDotGraph() << "\n\n";
@@ -191,7 +196,7 @@ void TestDUChain::testStringSets() {
             qDebug() << "SET b:";
             QString dbg = "";
             for(std::set<Index>::const_iterator it = realSets[b].begin(); it != realSets[b].end(); ++it)
-              dbg += QString("%1 ").arg(*it);
+              dbg += QStringLiteral("%1 ").arg(*it);
             qDebug() << dbg;
 
             qDebug() << "DOT-Graph:\n\n" << sets[b].dumpDotGraph() << "\n\n";
@@ -203,12 +208,12 @@ void TestDUChain::testStringSets() {
             qDebug() << "SET difference:";
             QString dbg = "real    set: ";
             for(std::set<Index>::const_iterator it = _realDifference.begin(); it != _realDifference.end(); ++it)
-              dbg += QString("%1 ").arg(*it);
+              dbg += QStringLiteral("%1 ").arg(*it);
             qDebug() << dbg;
 
             dbg = "repo.   set: ";
             for(std::set<Index>::const_iterator it = tempSet.begin(); it != tempSet.end(); ++it)
-              dbg += QString("%1 ").arg(*it);
+              dbg += QStringLiteral("%1 ").arg(*it);
             qDebug() << dbg;
 
             qDebug() << "DOT-Graph:\n\n" << _difference.dumpDotGraph() << "\n\n";
@@ -239,7 +244,7 @@ void TestDUChain::testStringSets() {
             qDebug() << "SET a:";
             QString dbg = "";
             for(std::set<Index>::const_iterator it = realSets[a].begin(); it != realSets[a].end(); ++it)
-              dbg += QString("%1 ").arg(*it);
+              dbg += QStringLiteral("%1 ").arg(*it);
             qDebug() << dbg;
 
             qDebug() << "DOT-Graph:\n\n" << sets[a].dumpDotGraph() << "\n\n";
@@ -248,7 +253,7 @@ void TestDUChain::testStringSets() {
             qDebug() << "SET b:";
             QString dbg = "";
             for(std::set<Index>::const_iterator it = realSets[b].begin(); it != realSets[b].end(); ++it)
-              dbg += QString("%1 ").arg(*it);
+              dbg += QStringLiteral("%1 ").arg(*it);
             qDebug() << dbg;
 
             qDebug() << "DOT-Graph:\n\n" << sets[b].dumpDotGraph() << "\n\n";
@@ -260,12 +265,12 @@ void TestDUChain::testStringSets() {
             qDebug() << "SET union:";
             QString dbg = "real    set: ";
             for(std::set<Index>::const_iterator it = _realUnion.begin(); it != _realUnion.end(); ++it)
-              dbg += QString("%1 ").arg(*it);
+              dbg += QStringLiteral("%1 ").arg(*it);
             qDebug() << dbg;
 
             dbg = "repo.   set: ";
             for(std::set<Index>::const_iterator it = tempSet.begin(); it != tempSet.end(); ++it)
-              dbg += QString("%1 ").arg(*it);
+              dbg += QStringLiteral("%1 ").arg(*it);
             qDebug() << dbg;
 
             qDebug() << "DOT-Graph:\n\n" << _union.dumpDotGraph() << "\n\n";
@@ -310,7 +315,7 @@ void TestDUChain::testStringSets() {
             qDebug() << "SET a:";
             QString dbg = "";
             for(std::set<Index>::const_iterator it = realSets[a].begin(); it != realSets[a].end(); ++it)
-              dbg += QString("%1 ").arg(*it);
+              dbg += QStringLiteral("%1 ").arg(*it);
             qDebug() << dbg;
 
             qDebug() << "DOT-Graph:\n\n" << sets[a].dumpDotGraph() << "\n\n";
@@ -319,7 +324,7 @@ void TestDUChain::testStringSets() {
             qDebug() << "SET b:";
             QString dbg = "";
             for(std::set<Index>::const_iterator it = realSets[b].begin(); it != realSets[b].end(); ++it)
-              dbg += QString("%1 ").arg(*it);
+              dbg += QStringLiteral("%1 ").arg(*it);
             qDebug() << dbg;
 
             qDebug() << "DOT-Graph:\n\n" << sets[b].dumpDotGraph() << "\n\n";
@@ -331,12 +336,12 @@ void TestDUChain::testStringSets() {
             qDebug() << "SET intersection:";
             QString dbg = "real    set: ";
             for(std::set<Index>::const_iterator it = _realIntersection.begin(); it != _realIntersection.end(); ++it)
-              dbg += QString("%1 ").arg(*it);
+              dbg += QStringLiteral("%1 ").arg(*it);
             qDebug() << dbg;
 
             dbg = "repo.   set: ";
             for(std::set<Index>::const_iterator it = tempSet.begin(); it != tempSet.end(); ++it)
-              dbg += QString("%1 ").arg(*it);
+              dbg += QStringLiteral("%1 ").arg(*it);
             qDebug() << dbg;
 
             qDebug() << "DOT-Graph:\n\n" << _intersection.dumpDotGraph() << "\n\n";
@@ -357,10 +362,11 @@ void TestDUChain::testStringSets() {
              << " generic-set: " << float(genericDifferenceTime);
   }
 }
+#endif
 
 void TestDUChain::testSymbolTableValid() {
   DUChainReadLocker lock(DUChain::lock());
-  PersistentSymbolTable::self().selfAnalysis();
+  PersistentSymbolTable::self().dump(QTextStream(stdout));
 }
 
 void TestDUChain::testIndexedStrings() {
@@ -375,8 +381,8 @@ void TestDUChain::testIndexedStrings() {
     for(int b = 0; b < length; ++b)
       testString.append((char)(rand() % 6) + 'a');
     QByteArray array = testString.toUtf8();
-    //kDebug() << "checking with" << testString;
-    //kDebug() << "checking" << a;
+    //qDebug() << "checking with" << testString;
+    //qDebug() << "checking" << a;
     IndexedString indexed(array.constData(), array.size(), IndexedString::hashString(array.constData(), array.size()));
 
     QCOMPARE(indexed.str(), testString);
@@ -387,9 +393,9 @@ void TestDUChain::testIndexedStrings() {
     }
 
     if(a % (testCount/10) == 0)
-      kDebug() << a << "of" << testCount;
+      qDebug() << a << "of" << testCount;
   }
-  kDebug() << a << "successful tests";
+  qDebug() << a << "successful tests";
 }
 
 struct TestContext {
@@ -397,7 +403,7 @@ struct TestContext {
     static int number = 0;
     ++number;
     DUChainWriteLocker lock(DUChain::lock());
-    m_context = new TopDUContext(IndexedString(QString("/test1/%1").arg(number)), RangeInRevision());
+    m_context = new TopDUContext(IndexedString(QStringLiteral("/test1/%1").arg(number)), RangeInRevision());
     m_normalContext = new DUContext(RangeInRevision(), m_context);
     DUChain::self()->addDocumentChain(m_context);
     Q_ASSERT(IndexedDUContext(m_context).context() == m_context);
@@ -531,7 +537,7 @@ uint collectNaiveNodeCount(uint currentNode) {
 void TestDUChain::testImportStructure()
 {
   Timer total;
-  kDebug() << "before: " << KDevelop::RecursiveImportRepository::repository()->getDataRepository().statistics().print();
+  qDebug() << "before: " << KDevelop::RecursiveImportRepository::repository()->getDataRepository().statistics().print();
 
   ///Maintains a naive import-structure along with a real top-context import structure, and allows comparing both.
   int cycles = 5;
@@ -546,16 +552,16 @@ void TestDUChain::testImportStructure()
     for(int a = 0; a < contextCount; a++)
       allContexts << new TestContext();
     for(int c = 0; c < cycles; ++c) {
-      //kDebug() << "main-cycle" << t  << "sub-cycle" << c;
+      //qDebug() << "main-cycle" << t  << "sub-cycle" << c;
       //Add random imports and compare
       for(int a = 0; a < contextCount; a++) {
         //Import up to 5 random other contexts into each context
         int importCount = rand() % 5;
-        //kDebug()   << "cnt> " << importCount;
+        //qDebug()   << "cnt> " << importCount;
         for(int i = 0; i < importCount; ++i)
         {
           //int importNr = rand() % contextCount;
-          //kDebug() << "nmr > " << importNr;
+          //qDebug() << "nmr > " << importNr;
           //allContexts[a]->import(allContexts[importNr]);
           allContexts[a]->import(allContexts[rand() % contextCount]);
         }
@@ -587,12 +593,12 @@ void TestDUChain::testImportStructure()
       }
     }
 
-    kDebug() << "after: " << KDevelop::RecursiveImportRepository::repository()->getDataRepository().statistics().print();
+    qDebug() << "after: " << KDevelop::RecursiveImportRepository::repository()->getDataRepository().statistics().print();
 
     for(int a = 0; a < contextCount; ++a)
       delete allContexts[a];
     allContexts.clear();
-    kDebug() << "after cleanup: " << KDevelop::RecursiveImportRepository::repository()->getDataRepository().statistics().print();
+    qDebug() << "after cleanup: " << KDevelop::RecursiveImportRepository::repository()->getDataRepository().statistics().print();
   }
   qDebug() << "total ns needed for import-structure test:" << float(total.elapsed());
 }
@@ -606,14 +612,12 @@ public slots:
     for(int i = 0; i < 10000; ++i) {
       DUChainWriteLocker lock;
     }
-    qDebug() << "FINISHED lockForWrite";
   }
   void lockForRead()
   {
     for(int i = 0; i < 10000; ++i) {
       DUChainReadLocker lock;
     }
-    qDebug() << "FINISHED lockForRead";
   }
   void lockForReadWrite()
   {
@@ -625,14 +629,13 @@ public slots:
         DUChainWriteLocker lock;
       }
     }
-    qDebug() << "FINISHED lockForReadWrite";
   }
   static QSharedPointer<QThread> createWorkerThread(const char* workerSlot)
   {
     QThread* thread = new QThread;
     TestWorker* worker = new TestWorker;
     connect(thread, SIGNAL(started()), worker, workerSlot);
-    connect(thread, SIGNAL(finished()), worker, SLOT(deleteLater()));
+    connect(thread, &QThread::finished, worker, &TestWorker::deleteLater);
     worker->moveToThread(thread);
     return QSharedPointer<QThread>(thread);
   }
@@ -643,7 +646,6 @@ class ThreadList : public QVector< QSharedPointer<QThread> >
 public:
   bool join(int timeout)
   {
-    qDebug() << "joining" << size() << "threads" << timeout;
     foreach(const QSharedPointer<QThread>& thread, *this) {
       // quit event loop
       Q_ASSERT(thread->isRunning());
@@ -671,6 +673,14 @@ void TestDUChain::testLockForWrite()
     threads << TestWorker::createWorkerThread(SLOT(lockForWrite()));
   }
   threads.start();
+  QBENCHMARK {
+    {
+      DUChainWriteLocker lock;
+    }
+    {
+      DUChainReadLocker lock;
+    }
+  }
   QVERIFY(threads.join(1000));
 }
 
@@ -681,6 +691,9 @@ void TestDUChain::testLockForRead()
     threads << TestWorker::createWorkerThread(SLOT(lockForRead()));
   }
   threads.start();
+  QBENCHMARK {
+    DUChainReadLocker lock;
+  }
   QVERIFY(threads.join(1000));
 }
 
@@ -691,9 +704,159 @@ void TestDUChain::testLockForReadWrite()
     threads << TestWorker::createWorkerThread(SLOT(lockForReadWrite()));
   }
   threads.start();
+  QBENCHMARK {
+    DUChainWriteLocker lock;
+  }
   QVERIFY(threads.join(1000));
 }
 
+void TestDUChain::testProblemSerialization()
+{
+  DUChain::self()->disablePersistentStorage(false);
+
+  auto parent = ProblemPointer{new Problem};
+  parent->setDescription("parent");
+
+  auto child = ProblemPointer{new Problem};
+  child->setDescription("child");
+  parent->addDiagnostic(child);
+
+  const IndexedString url("/my/test/file");
+
+  TopDUContextPointer smartTop;
+
+  { // serialize
+    DUChainWriteLocker lock;
+    auto file = new ParsingEnvironmentFile(url);
+    auto top = new TopDUContext(url, {}, file);
+
+    top->addProblem(parent);
+    QCOMPARE(top->problems().size(), 1);
+    auto p = top->problems().first();
+    QCOMPARE(p->description(), QStringLiteral("parent"));
+    QCOMPARE(p->diagnostics().size(), 1);
+    auto c = p->diagnostics().first();
+    QCOMPARE(c->description(), QStringLiteral("child"));
+
+    DUChain::self()->addDocumentChain(top);
+    QVERIFY(DUChain::self()->chainForDocument(url));
+    smartTop = top;
+  }
+
+  DUChain::self()->storeToDisk();
+
+  ProblemPointer parent_deserialized;
+  IProblem::Ptr child_deserialized;
+
+  { // deserialize
+    DUChainWriteLocker lock;
+    QVERIFY(!smartTop);
+    auto top = DUChain::self()->chainForDocument(url);
+    QVERIFY(top);
+    smartTop = top;
+    QCOMPARE(top->problems().size(), 1);
+    parent_deserialized = top->problems().first();
+    QCOMPARE(parent_deserialized->diagnostics().size(), 1);
+    child_deserialized = parent_deserialized->diagnostics().first();
+
+    QCOMPARE(parent_deserialized->description(), QStringLiteral("parent"));
+    QCOMPARE(child_deserialized->description(), QStringLiteral("child"));
+
+    top->clearProblems();
+    QVERIFY(top->problems().isEmpty());
+
+    QCOMPARE(parent_deserialized->description(), QStringLiteral("parent"));
+    QCOMPARE(child_deserialized->description(), QStringLiteral("child"));
+
+    DUChain::self()->removeDocumentChain(top);
+
+    QCOMPARE(parent_deserialized->description(), QStringLiteral("parent"));
+    QCOMPARE(child_deserialized->description(), QStringLiteral("child"));
+
+    QVERIFY(!smartTop);
+  }
+
+  DUChain::self()->disablePersistentStorage(true);
+
+  QCOMPARE(parent->description(), QStringLiteral("parent"));
+  QCOMPARE(child->description(), QStringLiteral("child"));
+  QCOMPARE(parent_deserialized->description(), QStringLiteral("parent"));
+  QCOMPARE(child_deserialized->description(), QStringLiteral("child"));
+
+  parent->clearDiagnostics();
+  QVERIFY(parent->diagnostics().isEmpty());
+}
+
+void TestDUChain::testIdentifiers()
+{
+  QualifiedIdentifier aj("::Area::jump");
+  QCOMPARE(aj.count(), 2);
+  QCOMPARE(aj.explicitlyGlobal(), true);
+  QCOMPARE(aj.at(0), Identifier("Area"));
+  QCOMPARE(aj.at(1), Identifier("jump"));
+
+  QualifiedIdentifier aj2 = QualifiedIdentifier("Area::jump");
+  QCOMPARE(aj2.count(), 2);
+  QCOMPARE(aj2.explicitlyGlobal(), false);
+  QCOMPARE(aj2.at(0), Identifier("Area"));
+  QCOMPARE(aj2.at(1), Identifier("jump"));
+  QVERIFY(aj != aj2);
+
+  QVERIFY(QualifiedIdentifier("") == QualifiedIdentifier());
+  QVERIFY(QualifiedIdentifier("").index() == QualifiedIdentifier().index());
+
+  QualifiedIdentifier ajt("Area::jump::test");
+  QualifiedIdentifier jt("jump::test");
+  QualifiedIdentifier ajt2("Area::jump::tes");
+
+  QualifiedIdentifier t(" Area<A,B>::jump <F> ::tes<C>");
+  QCOMPARE(t.count(), 3);
+  QCOMPARE(t.at(0).templateIdentifiersCount(), 2u);
+  QCOMPARE(t.at(1).templateIdentifiersCount(), 1u);
+  QCOMPARE(t.at(2).templateIdentifiersCount(), 1u);
+  QCOMPARE(t.at(0).identifier().str(), QStringLiteral("Area"));
+  QCOMPARE(t.at(1).identifier().str(), QStringLiteral("jump"));
+  QCOMPARE(t.at(2).identifier().str(), QStringLiteral("tes"));
+
+  QualifiedIdentifier op1("operator<");
+  QualifiedIdentifier op2("operator<=");
+  QualifiedIdentifier op3("operator>");
+  QualifiedIdentifier op4("operator>=");
+  QualifiedIdentifier op5("operator()");
+  QualifiedIdentifier op6("operator( )");
+  QCOMPARE(op1.count(), 1);
+  QCOMPARE(op2.count(), 1);
+  QCOMPARE(op3.count(), 1);
+  QCOMPARE(op4.count(), 1);
+  QCOMPARE(op5.count(), 1);
+  QCOMPARE(op6.count(), 1);
+  QCOMPARE(op4.toString(), QStringLiteral("operator>="));
+  QCOMPARE(op3.toString(), QStringLiteral("operator>"));
+  QCOMPARE(op1.toString(), QStringLiteral("operator<"));
+  QCOMPARE(op2.toString(), QStringLiteral("operator<="));
+  QCOMPARE(op5.toString(), QStringLiteral("operator()"));
+  QCOMPARE(op6.toString(), QStringLiteral("operator( )"));
+  QCOMPARE(QualifiedIdentifier("Area<A,B>::jump <F> ::tes<C>").index(), t.index());
+  QCOMPARE(op4.index(), QualifiedIdentifier("operator>=").index());
+
+  QualifiedIdentifier pushTest("foo");
+  QCOMPARE(pushTest.count(), 1);
+  QCOMPARE(pushTest.toString(), QStringLiteral("foo"));
+  pushTest.push(Identifier("bar"));
+  QCOMPARE(pushTest.count(), 2);
+  QCOMPARE(pushTest.toString(), QStringLiteral("foo::bar"));
+  pushTest.push(QualifiedIdentifier("baz::asdf"));
+  QCOMPARE(pushTest.count(), 4);
+  QCOMPARE(pushTest.toString(), QStringLiteral("foo::bar::baz::asdf"));
+  QualifiedIdentifier mergeTest = pushTest.merge(QualifiedIdentifier("meh::muh"));
+  QCOMPARE(mergeTest.count(), 6);
+  QCOMPARE(mergeTest.toString(), QStringLiteral("meh::muh::foo::bar::baz::asdf"));
+  QualifiedIdentifier plusTest = QualifiedIdentifier("la::lu") + QualifiedIdentifier("ba::bu");
+  QCOMPARE(plusTest.count(), 4);
+  QCOMPARE(plusTest.toString(), QStringLiteral("la::lu::ba::bu"));
+  ///@todo create a big randomized test for the identifier repository(check that indices are the same)
+}
+
 #if 0
 
 ///NOTE: the "unit tests" below are not automated, they - so far - require
@@ -720,7 +883,7 @@ void TestDUChain::testImportCache()
   DUChainReadLocker lock(DUChain::lock());
   for(uint a = 0; a < topContextCount; ++a) {
     if(a % qMax(1u, topContextCount / 100) == 0) {
-      kDebug() << "progress:" << (a * 100) / topContextCount;
+      qDebug() << "progress:" << (a * 100) / topContextCount;
     }
     TopDUContext* context = DUChain::self()->chainForIndex(a);
     if(context) {
@@ -733,9 +896,9 @@ void TestDUChain::testImportCache()
   }
 
   QVERIFY(analyzedCount);
-  kDebug() << "average total count of imports:" << totalImportCount / analyzedCount;
-  kDebug() << "count of reachable nodes:" << reachableNodes.size();
-  kDebug() << "naive node-count:" << naiveNodeCount << "sharing compression factor:" << ((float)reachableNodes.size()) / ((float)naiveNodeCount);
+  qDebug() << "average total count of imports:" << totalImportCount / analyzedCount;
+  qDebug() << "count of reachable nodes:" << reachableNodes.size();
+  qDebug() << "naive node-count:" << naiveNodeCount << "sharing compression factor:" << ((float)reachableNodes.size()) / ((float)naiveNodeCount);
 }
 
 #endif
@@ -806,5 +969,66 @@ void TestDUChain::benchTypeRegistry_data()
   QTest::newRow("callDestructor") << 6;
 }
 
+void TestDUChain::benchDuchainReadLocker()
+{
+  QBENCHMARK {
+    DUChainReadLocker lock;
+  }
+}
+
+void TestDUChain::benchDuchainWriteLocker()
+{
+  QBENCHMARK {
+    DUChainWriteLocker lock;
+  }
+}
+
+void TestDUChain::benchDUChainItemFactory_copy()
+{
+  DUChainItemFactory<Declaration, DeclarationData> factory;
+  DeclarationData from, to;
+  from.classId = Declaration::Identity;
+
+  QFETCH(int, constant);
+
+  bool c = constant;
+
+  QBENCHMARK {
+    factory.copy(from, to, c);
+    if (constant == 2) {
+      c = !c;
+    }
+  }
+}
+
+void TestDUChain::benchDUChainItemFactory_copy_data()
+{
+  QTest::addColumn<int>("constant");
+  QTest::newRow("non-const") << 0;
+  QTest::newRow("const") << 1;
+  QTest::newRow("flip") << 2;
+}
+
+void TestDUChain::benchDeclarationQualifiedIdentifier()
+{
+  QVector<DUContext*> contexts;
+  contexts.reserve(10);
+  DUChainWriteLocker lock;
+  contexts << new TopDUContext(IndexedString("/tmp/something"), {0, 0, INT_MAX, INT_MAX});
+  for (int i = 1; i < contexts.capacity(); ++i) {
+    contexts << new DUContext({0, 0, INT_MAX, INT_MAX}, contexts.at(i-1));
+    contexts.last()->setLocalScopeIdentifier(QualifiedIdentifier(QString::number(i)));
+  }
+  auto dec = new Declaration({0, 0, 0, 1}, contexts.last());
+  dec->setIdentifier(Identifier(QStringLiteral("myDecl")));
+
+  qDebug() << "start benchmark!";
+  qint64 count = 0;
+  QBENCHMARK {
+    count += dec->qualifiedIdentifier().count();
+  }
+  QVERIFY(count > 0);
+}
+
 #include "test_duchain.moc"
 #include "moc_test_duchain.cpp"
