@@ -24,8 +24,6 @@
 
 #include <QtCore/QThread>
 
-#include <util/kdevvarlengtharray.h>
-
 #include "persistentsymboltable.h"
 #include "problem.h"
 #include "declaration.h"
@@ -36,11 +34,11 @@
 #include "declarationid.h"
 #include "namespacealiasdeclaration.h"
 #include "aliasdeclaration.h"
-#include "abstractfunctiondeclaration.h"
 #include "uses.h"
 #include "topducontextdata.h"
 #include "duchainregister.h"
 #include "topducontextdynamicdata.h"
+#include "util/debug.h"
 
 // #define DEBUG_SEARCH
 
@@ -153,8 +151,8 @@ public:
 
   ParsingEnvironmentFilePointer m_file;
 
-  KSharedPtr<IAstContainer> m_ast;
-  
+  QExplicitlySharedDataPointer<IAstContainer> m_ast;
+
   uint m_ownIndex;
 
   bool m_inDuChain;
@@ -174,7 +172,7 @@ public:
 
         if(!m_ctxt->usingImportsCache()) {
           removeImportedContextRecursion(top, top, 1, rebuild);
-  
+
           QHash<const TopDUContext*, QPair<int, const TopDUContext*> > b = top->m_local->m_recursiveImports;
           for(RecursiveImports::const_iterator it = b.constBegin(); it != b.constEnd(); ++it) {
             if(m_recursiveImports.contains(it.key()) && m_recursiveImports[it.key()].second == top)
@@ -221,7 +219,7 @@ public:
 
     QSet<QPair<TopDUContext*, const TopDUContext*> > rebuild;
     if(!m_ctxt->usingImportsCache()) {
-    
+
     removeImportedContextRecursion(context, context, 1, rebuild);
 
       QHash<const TopDUContext*, QPair<int, const TopDUContext*> > b = context->m_local->m_recursiveImports;
@@ -247,7 +245,7 @@ public:
         removeFromVector(m_importedContexts, DUContext::Import(context, m_ctxt));
 
       if(!m_ctxt->usingImportsCache()) {
-        
+
         removeImportedContextRecursion(context, context, 1, rebuild);
 
         QHash<const TopDUContext*, QPair<int, const TopDUContext*> > b = context->m_local->m_recursiveImports;
@@ -374,48 +372,6 @@ public:
   }
 };
 
-///Takes a set of conditions in the constructors, and checks with each call to operator() whether these conditions are fulfilled on the given declaration.
-///The import-structure needs to be constructed and locked when this is used
-TopDUContext::DeclarationChecker::DeclarationChecker(const TopDUContext* _top, const CursorInRevision& _position, const AbstractType::Ptr& _dataType, DUContext::SearchFlags _flags, KDevVarLengthArray<IndexedDeclaration>* _createVisibleCache)
-  : createVisibleCache(_createVisibleCache)
-  , top(_top)
-  , topDFunc(_top->d_func())
-  , position(_position)
-  , dataType(_dataType)
-  , flags(_flags)
-{
-}
-
-bool TopDUContext::DeclarationChecker::operator()(const Declaration* decl) const
-{
-  if(!decl)
-    return false;
-  
-  if (top != decl->topContext()) {
-
-    if((flags & DUContext::OnlyFunctions) && !dynamic_cast<const AbstractFunctionDeclaration*>(decl))
-      return false;
-
-    if (dataType && decl->abstractType()->indexed() != dataType->indexed())
-      // The declaration doesn't match the type filter we are applying
-      return false;
-
-  } else {
-    if((flags & DUContext::OnlyFunctions) && !dynamic_cast<const AbstractFunctionDeclaration*>(decl))
-      return false;
-
-    if (dataType && decl->abstractType() != dataType)
-      // The declaration doesn't match the type filter we are applying
-      return false;
-
-    if (decl->range().start >= position)
-      if(!decl->context() || decl->context()->type() != DUContext::Class)
-          return false; // The declaration is behind the position we're searching from, therefore not accessible
-  }
-  // Success, this declaration is accessible
-  return true;
-}
-
 const TopDUContext::IndexedRecursiveImports& TopDUContext::recursiveImportIndices() const
 {
 //   No lock-check for performance reasons
@@ -431,7 +387,7 @@ void TopDUContextData::updateImportCacheRecursion(uint baseIndex, IndexedTopDUCo
     return;
   Q_ASSERT(currentContext.index()); //The top-context must be in the repository when this is called
   if(!currentContext.data()) {
-    kDebug() << "importing invalid context";
+    qCDebug(LANGUAGE) << "importing invalid context";
     return;
   }
   visited.insert(currentContext.index());
@@ -458,7 +414,7 @@ void TopDUContextData::updateImportCacheRecursion(IndexedTopDUContext currentCon
     return;
   Q_ASSERT(currentContext.index()); //The top-context must be in the repository when this is called
   if(!currentContext.data()) {
-    kDebug() << "importing invalid context";
+    qCDebug(LANGUAGE) << "importing invalid context";
     return;
   }
   visited.insert(currentContext.index());
@@ -492,7 +448,7 @@ void TopDUContext::updateImportsCache() {
   Q_ASSERT(d_func_dynamic()->m_importsCache.contains(IndexedTopDUContext(this)));
   Q_ASSERT(usingImportsCache());
   Q_ASSERT(imports(this, CursorInRevision::invalid()));
-  
+
   if(parsingEnvironmentFile())
     parsingEnvironmentFile()->setImportsCache(d_func()->m_importsCache);
 }
@@ -579,6 +535,7 @@ TopDUContext::TopDUContext(const IndexedString& url, const RangeInRevision& rang
 , m_local(new TopDUContextLocalPrivate(this, DUChain::newTopContextIndex()))
 , m_dynamicData(new TopDUContextDynamicData(this))
 {
+  Q_ASSERT(url.toUrl().isValid() && !url.toUrl().isRelative());
   d_func_dynamic()->setClassId(this);
   setType(Global);
 
@@ -589,7 +546,7 @@ TopDUContext::TopDUContext(const IndexedString& url, const RangeInRevision& rang
   setInSymbolTable(true);
 }
 
-KSharedPtr<ParsingEnvironmentFile> TopDUContext::parsingEnvironmentFile() const {
+QExplicitlySharedDataPointer<ParsingEnvironmentFile> TopDUContext::parsingEnvironmentFile() const {
   return m_local->m_file;
 }
 
@@ -629,10 +586,10 @@ void TopDUContext::deleteSelf() {
 TopDUContext::Features TopDUContext::features() const
 {
   uint ret = d_func()->m_features;
-  
+
   if(ast())
     ret |= TopDUContext::AST;
-  
+
   return (TopDUContext::Features)ret;
 }
 
@@ -648,11 +605,11 @@ void TopDUContext::setFeatures(Features features)
     parsingEnvironmentFile()->setFeatures(this->features());
 }
 
-void TopDUContext::setAst(KSharedPtr<IAstContainer> ast)
+void TopDUContext::setAst(QExplicitlySharedDataPointer<IAstContainer> ast)
 {
   ENSURE_CAN_WRITE
   m_local->m_ast = ast;
-  
+
   if(parsingEnvironmentFile())
     parsingEnvironmentFile()->setFeatures(features());
 }
@@ -661,16 +618,16 @@ void TopDUContext::setParsingEnvironmentFile(ParsingEnvironmentFile* file)
 {
   if(m_local->m_file) //Clear the "feature satisfaction" cache
     m_local->m_file->setFeatures(Empty);
-  
+
   //We do not enforce a duchain lock here, since this is also used while loading a top-context
-  m_local->m_file = KSharedPtr<ParsingEnvironmentFile>(file);
+  m_local->m_file = QExplicitlySharedDataPointer<ParsingEnvironmentFile>(file);
 
   //Replicate features to ParsingEnvironmentFile
   if(file) {
     file->setTopContext(IndexedTopDUContext(ownIndex()));
     Q_ASSERT(file->indexedTopContext().isValid());
     file->setFeatures(d_func()->m_features);
-    
+
     file->setImportsCache(d_func()->m_importsCache);
   }
 }
@@ -683,7 +640,7 @@ struct TopDUContext::FindDeclarationsAcceptor {
   bool operator() (const QualifiedIdentifier& id) {
 
 #ifdef DEBUG_SEARCH
-    kDebug() << "accepting" << id.toString();
+    qCDebug(LANGUAGE) << "accepting" << id.toString();
 #endif
 
     PersistentSymbolTable::Declarations allDecls;
@@ -713,7 +670,7 @@ struct TopDUContext::FindDeclarationsAcceptor {
 
       if(!decl)
         continue;
-      
+
       if(!check(decl))
         continue;
 
@@ -723,7 +680,7 @@ struct TopDUContext::FindDeclarationsAcceptor {
         if(alias->aliasedDeclaration().isValid()) {
           decl = alias->aliasedDeclaration().declaration();
         } else {
-          kDebug() << "lost aliased declaration";
+          qCDebug(LANGUAGE) << "lost aliased declaration";
         }
       }
 
@@ -732,7 +689,7 @@ struct TopDUContext::FindDeclarationsAcceptor {
     }
 
     check.createVisibleCache = 0;
-    
+
     return !top->foundEnough(target, flags);
   }
 
@@ -747,9 +704,9 @@ bool TopDUContext::findDeclarationsInternal(const SearchItem::PtrList& identifie
   ENSURE_CAN_READ
 
 #ifdef DEBUG_SEARCH
-  FOREACH_ARRAY(const SearchItem::Ptr& idTree, identifiers)
+  for (const SearchItem::Ptr& idTree : identifiers)
       foreach(const QualifiedIdentifier &id, idTree->toList())
-        kDebug() << "searching item" << id.toString();
+        qCDebug(LANGUAGE) << "searching item" << id.toString();
 #endif
 
   DeclarationChecker check(this, position, dataType, flags);
@@ -769,6 +726,7 @@ struct TopDUContext::ApplyAliasesBuddyInfo {
       m_predecessor = 0;
   }
 
+  //May also be called when this is zero.
   bool alreadyImporting(IndexedQualifiedIdentifier id) {
     ApplyAliasesBuddyInfo* current = this;
     while(current) {
@@ -794,7 +752,7 @@ bool TopDUContext::applyAliases( const QualifiedIdentifier& previous, const Sear
     if(!searches.isEmpty())
       id = searches.first();
 
-    kDebug() << "maximum apply-aliases recursion reached while searching" << id;
+    qCDebug(LANGUAGE) << "maximum apply-aliases recursion reached while searching" << id;
   }
   bool foundAlias = false;
 
@@ -803,17 +761,17 @@ bool TopDUContext::applyAliases( const QualifiedIdentifier& previous, const Sear
 
   if(!id.inRepository())
     return true; //If the qualified identifier is not in the identifier repository, it cannot be registered anywhere, so there's nothing we need to do
-  
+
   if( !identifier->next.isEmpty() || canBeNamespace ) { //If it cannot be a namespace, the last part of the scope will be ignored
 
     //Search for namespace-aliases, by using globalAliasIdentifier, which is inserted into the symbol-table by NamespaceAliasDeclaration
     QualifiedIdentifier aliasId(id);
     aliasId.push(globalIndexedAliasIdentifier());
-    
+
 #ifdef DEBUG_SEARCH
-  kDebug() << "checking" << id.toString();
+  qCDebug(LANGUAGE) << "checking" << id.toString();
 #endif
-    
+
     if(aliasId.inRepository()) {
     //This iterator efficiently filters the visible declarations out of all declarations
       PersistentSymbolTable::FilteredDeclarationIterator filter = PersistentSymbolTable::self().getFilteredDeclarations(aliasId, recursiveImportIndices());
@@ -828,7 +786,7 @@ bool TopDUContext::applyAliases( const QualifiedIdentifier& previous, const Sear
           Declaration* aliasDecl = filter->data();
           if(!aliasDecl)
             continue;
-          
+
           if(!check(aliasDecl))
             continue;
 
@@ -847,11 +805,11 @@ bool TopDUContext::applyAliases( const QualifiedIdentifier& previous, const Sear
           QualifiedIdentifier importIdentifier = alias->importIdentifier();
 
           if(importIdentifier.isEmpty()) {
-            kDebug() << "found empty import";
+            qCDebug(LANGUAGE) << "found empty import";
             continue;
           }
 
-          if(buddy && buddy->alreadyImporting( importIdentifier ))
+          if(buddy->alreadyImporting( importIdentifier ))
             continue; //This import has already been applied to this search
 
           ApplyAliasesBuddyInfo info(1, buddy, importIdentifier);
@@ -862,7 +820,7 @@ bool TopDUContext::applyAliases( const QualifiedIdentifier& previous, const Sear
               return false;
           }else{
             //Create an identifiers where namespace-alias part is replaced with the alias target
-            FOREACH_ARRAY(const SearchItem::Ptr& item, identifier->next)
+            for (const SearchItem::Ptr& item : identifier->next)
               if(!applyAliases(importIdentifier, item, accept, position, canBeNamespace, &info, recursionDepth+1))
                 return false;
           }
@@ -876,7 +834,7 @@ bool TopDUContext::applyAliases( const QualifiedIdentifier& previous, const Sear
       if(!accept(id)) //We're at the end of a qualified identifier, accept it
         return false;
     } else {
-      FOREACH_ARRAY(const SearchItem::Ptr& next, identifier->next)
+      for (const SearchItem::Ptr& next : identifier->next)
         if(!applyAliases(id, next, accept, position, canBeNamespace, 0, recursionDepth+1))
           return false;
     }
@@ -892,7 +850,7 @@ bool TopDUContext::applyAliases( const QualifiedIdentifier& previous, const Sear
     importId.push(globalIndexedImportIdentifier());
 
 #ifdef DEBUG_SEARCH
-//   kDebug() << "checking imports in" << (backPointer ? id.toString() : QString("global"));
+//   qCDebug(LANGUAGE) << "checking imports in" << (backPointer ? id.toString() : QStringLiteral("global"));
 #endif
 
     if(importId.inRepository()) {
@@ -907,7 +865,7 @@ bool TopDUContext::applyAliases( const QualifiedIdentifier& previous, const Sear
           Declaration* importDecl = filter->data();
           if(!importDecl)
             continue;
-          
+
           //We must never break or return from this loop, because else we might be creating a bad cache
           if(!check(importDecl))
             continue;
@@ -917,21 +875,21 @@ bool TopDUContext::applyAliases( const QualifiedIdentifier& previous, const Sear
           NamespaceAliasDeclaration* alias = static_cast<NamespaceAliasDeclaration*>(importDecl);
 
   #ifdef DEBUG_SEARCH
-          kDebug() << "found import of" << alias->importIdentifier().toString();
+          qCDebug(LANGUAGE) << "found import of" << alias->importIdentifier().toString();
   #endif
 
           QualifiedIdentifier importIdentifier = alias->importIdentifier();
-          
+
           if(importIdentifier.isEmpty()) {
-            kDebug() << "found empty import";
+            qCDebug(LANGUAGE) << "found empty import";
             continue;
           }
 
-          if(buddy && buddy->alreadyImporting( importIdentifier ))
+          if(buddy->alreadyImporting( importIdentifier ))
             continue; //This import has already been applied to this search
 
           ApplyAliasesBuddyInfo info(2, buddy, importIdentifier);
-          
+
           if(previous != importIdentifier)
             if(!applyAliases(importIdentifier, identifier, accept, importDecl->topContext() == this ? importDecl->range().start : position, canBeNamespace, &info, recursionDepth+1))
               return false;
@@ -946,8 +904,8 @@ template<class Acceptor>
 void TopDUContext::applyAliases( const SearchItem::PtrList& identifiers, Acceptor& acceptor, const CursorInRevision& position, bool canBeNamespace ) const
 {
   QualifiedIdentifier emptyId;
-  
-  FOREACH_ARRAY(const SearchItem::Ptr& item, identifiers)
+
+  for (const SearchItem::Ptr& item : identifiers)
     applyAliases(emptyId, item, acceptor, position, canBeNamespace, 0, 0);
 }
 
@@ -958,7 +916,6 @@ TopDUContext * TopDUContext::topContext() const
 
 bool TopDUContext::deleting() const
 {
-  ///@todo remove d_func()->m_deleting, not used any more
   return m_dynamicData->m_deleting;
 }
 
@@ -1067,7 +1024,7 @@ void TopDUContext::addImportedParentContext(DUContext* context, const CursorInRe
 
   if(!dynamic_cast<TopDUContext*>(context)) {
     //We cannot do this, because of the extended way we treat top-context imports.
-    kDebug() << "tried to import a non top-context into a top-context. This is not possible.";
+    qCDebug(LANGUAGE) << "tried to import a non top-context into a top-context. This is not possible.";
     return;
   }
 
@@ -1107,14 +1064,6 @@ void TopDUContext::setInDuChain(bool b) {
   m_local->m_inDuChain = b;
 }
 
-TopDUContext::Flags TopDUContext::flags() const {
-  return d_func()->m_flags;
-}
-
-void TopDUContext::setFlags(Flags f) {
-  d_func_dynamic()->m_flags = f;
-}
-
 bool TopDUContext::isOnDisk() const {
   ///@todo Change this to releasingToDisk, and only enable it while saving a top-context to disk.
   return m_dynamicData->isOnDisk();
@@ -1198,14 +1147,14 @@ QList<RangeInRevision> allUses(TopDUContext* context, Declaration* declaration,
   return allUses(context, declarationIndex, noEmptyRanges);
 }
 
-KSharedPtr<IAstContainer> TopDUContext::ast() const
+QExplicitlySharedDataPointer<IAstContainer> TopDUContext::ast() const
 {
   return m_local->m_ast;
 }
 
 void TopDUContext::clearAst()
 {
-  setAst(KSharedPtr<IAstContainer>(0));
+  setAst(QExplicitlySharedDataPointer<IAstContainer>(0));
 }
 
 IndexedString TopDUContext::url() const {
@@ -1213,5 +1162,3 @@ IndexedString TopDUContext::url() const {
 }
 
 }
-
-// kate: space-indent on; indent-width 2; tab-width 4; replace-tabs on; auto-insert-doxygen on
