@@ -20,7 +20,7 @@
 
 #include "topducontextdynamicdata.h"
 
-#include <kstandarddirs.h>
+#include <QStandardPaths>
 #include <typeinfo>
 #include <QtCore/QFile>
 #include <QtCore/QByteArray>
@@ -33,8 +33,9 @@
 #include "ducontextdata.h"
 #include "ducontextdynamicdata.h"
 #include "duchainregister.h"
-#include "repositories/itemrepository.h"
+#include "serialization/itemrepository.h"
 #include "problem.h"
+#include "util/debug.h"
 
 //#define DEBUG_DATA_INFO
 
@@ -59,7 +60,7 @@ void saveDUChainItem(QList<ArrayWithPosition>& data, DUChainBase& item, uint& to
 {
   if(!item.d_func()->classId) {
     //If this triggers, you have probably created an own DUChainBase based class, but haven't called setClassId(this) in the constructor.
-    kError() << QString("no class-id set for data attached to a declaration of type %1").arg(typeid(item).name());
+    qCritical() << "no class-id set for data attached to a declaration of type" << typeid(item).name();
     Q_ASSERT(0);
   }
 
@@ -116,6 +117,7 @@ uint indexForParentContext(const ProblemPointer& /*problem*/)
   return 0;
 }
 
+#ifndef QT_NO_DEBUG
 void validateItem(const DUChainBaseData* const data, const uchar* const mappedData, const size_t mappedDataSize)
 {
   Q_ASSERT(!data->isDynamic());
@@ -124,10 +126,10 @@ void validateItem(const DUChainBaseData* const data, const uchar* const mappedDa
           || ((size_t)data) > ((size_t)mappedData) + mappedDataSize);
   }
 }
+#endif
 
 const char* pointerInData(const QList<ArrayWithPosition>& data, uint totalOffset)
 {
-
   for(int a = 0; a < data.size(); ++a) {
     if(totalOffset < data[a].second)
       return data[a].first.constData() + totalOffset;
@@ -184,19 +186,19 @@ struct PtrType<T*>
 };
 
 template<typename T>
-struct PtrType<KSharedPtr<T>>
+struct PtrType<QExplicitlySharedDataPointer<T>>
 {
   using value = T*;
 };
 
 template<typename T>
-constexpr bool isSharedDataItem()
+Q_DECL_CONSTEXPR bool isSharedDataItem()
 {
   return false;
 }
 
 template<>
-constexpr bool isSharedDataItem<ProblemPointer>()
+Q_DECL_CONSTEXPR bool isSharedDataItem<ProblemPointer>()
 {
   return true;
 }
@@ -264,6 +266,8 @@ void TopDUContextDynamicData::DUChainItemStorage<Item>::clearItemIndex(const Ite
       temporaryItems[realIndex-1] = nullptr;
     }
   }
+
+  Q_UNUSED(item);
 }
 
 template<class Item>
@@ -287,7 +291,7 @@ void TopDUContextDynamicData::DUChainItemStorage<Item>::storeData(uint& currentD
         offsets << ItemDataInfo();
       }
     } else {
-      offsets << ItemDataInfo(currentDataOffset, indexForParentContext(item));
+      offsets << ItemDataInfo{currentDataOffset, indexForParentContext(item)};
       saveDUChainItem(data->m_data, *item, currentDataOffset, isSharedDataItem<Item>());
     }
   }
@@ -307,7 +311,7 @@ template<typename Item>
 bool TopDUContextDynamicData::DUChainItemStorage<Item>::itemsHaveChanged() const
 {
   for (auto item : items) {
-    if (item && item->d_ptr->m_dynamic) {
+    if (item && item->d_func()->m_dynamic) {
       return true;
     }
   }
@@ -358,7 +362,7 @@ Item TopDUContextDynamicData::DUChainItemStorage<Item>::getItemForIndex(uint ind
   }
 
   if (index == 0 || index > static_cast<uint>(items.size())) {
-    kWarning() << "item index out of bounds:" << index << "count:" << items.size();
+    qCWarning(LANGUAGE) << "item index out of bounds:" << index << "count:" << items.size();
     return {};
   }
   const uint realIndex = index - 1;
@@ -381,7 +385,7 @@ Item TopDUContextDynamicData::DUChainItemStorage<Item>::getItemForIndex(uint ind
     if (!item) {
       //When this happens, the item has not been registered correctly.
       //We can stop here, because else we will get crashes later.
-      kError() << "Failed to load item with identity" << itemData->classId;
+      qCritical() << "Failed to load item with identity" << itemData->classId;
     }
 
     if (isSharedDataItem<Item>()) {
@@ -396,7 +400,7 @@ Item TopDUContextDynamicData::DUChainItemStorage<Item>::getItemForIndex(uint ind
                                     "Potentially, the context has been deleted without deleting its children.");
     item->rebuildDynamicData(parent, index);
   } else {
-    kWarning() << "invalid item for index" << index << offsets.size() << offsets.value(realIndex).dataOffset;
+    qCWarning(LANGUAGE) << "invalid item for index" << index << offsets.size() << offsets.value(realIndex).dataOffset;
   }
 
   return item;
@@ -495,11 +499,9 @@ bool TopDUContextDynamicData::fileExists(uint topContextIndex)
 QList<IndexedDUContext> TopDUContextDynamicData::loadImporters(uint topContextIndex) {
   QList<IndexedDUContext> ret;
   loadPartialData(topContextIndex, [&ret] (const TopDUContextData* topData) {
-    if(topData->m_importers()) {
-      ret.reserve(topData->m_importersSize());
-      FOREACH_FUNCTION(const IndexedDUContext& importer, topData->m_importers)
-        ret << importer;
-    }
+    ret.reserve(topData->m_importersSize());
+    FOREACH_FUNCTION(const IndexedDUContext& importer, topData->m_importers)
+      ret << importer;
   });
   return ret;
 }
@@ -507,11 +509,9 @@ QList<IndexedDUContext> TopDUContextDynamicData::loadImporters(uint topContextIn
 QList<IndexedDUContext> TopDUContextDynamicData::loadImports(uint topContextIndex) {
   QList<IndexedDUContext> ret;
   loadPartialData(topContextIndex, [&ret] (const TopDUContextData* topData) {
-    if(topData->m_importedContexts()) {
-      ret.reserve(topData->m_importedContextsSize());
-      FOREACH_FUNCTION(const DUContext::Import& import, topData->m_importedContexts)
-        ret << import.indexedContext();
-    }
+    ret.reserve(topData->m_importedContextsSize());
+    FOREACH_FUNCTION(const DUContext::Import& import, topData->m_importedContexts)
+      ret << import.indexedContext();
   });
   return ret;
 }
@@ -552,18 +552,18 @@ void TopDUContextDynamicData::loadData() const {
   m_problems.loadData(file);
 
 #ifdef USE_MMAP
-  
+
   m_mappedData = file->map(file->pos(), file->size() - file->pos());
   if(m_mappedData) {
     m_mappedFile = file;
     m_mappedDataSize = file->size() - file->pos();
     file->close(); //Close the file, so there is less open file descriptors(May be problematic)
   }else{
-    kDebug() << "Failed to map" << file->fileName();
+    qCDebug(LANGUAGE) << "Failed to map" << file->fileName();
   }
-  
+
 #endif
-  
+
   if(!m_mappedFile) {
     QByteArray data = file->readAll();
     m_data.append(qMakePair(data, (uint)data.size()));
@@ -577,7 +577,7 @@ TopDUContext* TopDUContextDynamicData::load(uint topContextIndex) {
   QFile file(pathForTopContext(topContextIndex));
   if(file.open(QIODevice::ReadOnly)) {
     if(file.size() == 0) {
-      kWarning() << "Top-context file is empty" << file.fileName();
+      qCWarning(LANGUAGE) << "Top-context file is empty" << file.fileName();
       return 0;
     }
     QVector<ItemDataInfo> contextDataOffsets;
@@ -589,30 +589,19 @@ TopDUContext* TopDUContextDynamicData::load(uint topContextIndex) {
     QByteArray topContextData = file.read(readValue);
 
     DUChainBaseData* topData = reinterpret_cast<DUChainBaseData*>(topContextData.data());
-/*    IndexedString language = static_cast<TopDUContextData*>(topData)->m_language;
-    if(!language.isEmpty()) {*/
-      ///@todo Load the language if it isn't loaded yet, problem: We're possibly not in the foreground thread!
-//     }
     TopDUContext* ret = dynamic_cast<TopDUContext*>(DUChainItemSystem::self().create(topData));
     if(!ret) {
-      kWarning() << "Cannot load a top-context, the requered language-support is probably not loaded";
+      qCWarning(LANGUAGE) << "Cannot load a top-context from file" << file.fileName() << "- the required language-support for handling ID" << topData->classId << "is probably not loaded";
       return 0;
     }
 
-    //Disable the updating flag on loading. Sometimes it may be set when the context was saved while it was updated
-    ret->setFlags( (TopDUContext::Flags) (ret->flags() & (~TopDUContext::UpdatingContext)) );
-
     TopDUContextDynamicData& target(*ret->m_dynamicData);
 
-//     kDebug() << "loaded" << ret->url().str() << ret->ownIndex() << "import-count:" << ret->importedParentContexts().size() << ret->d_func()->m_importedContextsSize();
-
     target.m_data.clear();
     target.m_dataLoaded = false;
     target.m_onDisk = true;
     ret->rebuildDynamicData(0, topContextIndex);
     target.m_topContextData.append(qMakePair(topContextData, (uint)0));
-//     kDebug() << "loaded" << ret->url().str() << ret->ownIndex() << "import-count:" << ret->importedParentContexts().size() << ret->d_func()->m_importedContextsSize();
-
     return ret;
   }else{
     return 0;
@@ -626,7 +615,7 @@ bool TopDUContextDynamicData::isOnDisk() const {
 void TopDUContextDynamicData::deleteOnDisk() {
   if(!isOnDisk())
     return;
-  kDebug() << "deleting" << m_topContext->ownIndex() << m_topContext->url().str();
+  qCDebug(LANGUAGE) << "deleting" << m_topContext->ownIndex() << m_topContext->url().str();
 
   if(!m_dataLoaded)
     loadData();
@@ -642,7 +631,7 @@ void TopDUContextDynamicData::deleteOnDisk() {
   bool successfullyRemoved = QFile::remove(filePath());
   Q_UNUSED(successfullyRemoved);
   Q_ASSERT(successfullyRemoved);
-  kDebug() << "deletion ready";
+  qCDebug(LANGUAGE) << "deletion ready";
 }
 
 QString KDevelop::TopDUContextDynamicData::filePath() const {
@@ -651,13 +640,13 @@ QString KDevelop::TopDUContextDynamicData::filePath() const {
 
 bool TopDUContextDynamicData::hasChanged() const
 {
-  return !m_onDisk || m_topContext->d_ptr->m_dynamic
+  return !m_onDisk || m_topContext->d_func()->m_dynamic
         || m_contexts.itemsHaveChanged() || m_declarations.itemsHaveChanged()
         || m_problems.itemsHaveChanged();
 }
 
 void TopDUContextDynamicData::store() {
-//   kDebug() << "storing" << m_topContext->url().str() << m_topContext->ownIndex() << "import-count:" << m_topContext->importedParentContexts().size();
+//   qCDebug(LANGUAGE) << "storing" << m_topContext->url().str() << m_topContext->ownIndex() << "import-count:" << m_topContext->importedParentContexts().size();
 
   //Check if something has changed. If nothing has changed, don't store to disk.
   bool contentDataChanged = hasChanged();
@@ -670,7 +659,7 @@ void TopDUContextDynamicData::store() {
     ///      Then we also won't need to load the data if only the meta-data changed.
   if(!m_dataLoaded)
     loadData();
-  
+
   ///If the data is mapped, and we re-write the file, we must make sure that the data is copied out of the map,
   ///even if only metadata is changed.
   ///@todo If we split up data and metadata, we don't need to do this
@@ -721,13 +710,13 @@ void TopDUContextDynamicData::store() {
 
     unmap();
 
-    KStandardDirs::makeDir(basePath());
+    QDir().mkpath(basePath());
 
     QFile file(filePath());
     if(file.open(QIODevice::WriteOnly)) {
 
       file.resize(0);
-      
+
       file.write((char*)&topContextDataSize, sizeof(uint));
       foreach(const ArrayWithPosition& pos, m_topContextData)
         file.write(pos.first.constData(), pos.second);
@@ -742,13 +731,13 @@ void TopDUContextDynamicData::store() {
       m_onDisk = true;
 
       if (file.size() == 0) {
-        kWarning() << "Saving zero size top ducontext data";
+        qCWarning(LANGUAGE) << "Saving zero size top ducontext data";
       }
       file.close();
     } else {
-      kWarning() << "Cannot open top-context for writing";
+      qCWarning(LANGUAGE) << "Cannot open top-context for writing";
     }
-//   kDebug() << "stored" << m_topContext->url().str() << m_topContext->ownIndex() << "import-count:" << m_topContext->importedParentContexts().size();
+//   qCDebug(LANGUAGE) << "stored" << m_topContext->url().str() << m_topContext->ownIndex() << "import-count:" << m_topContext->importedParentContexts().size();
 }
 
 TopDUContextDynamicData::ItemDataInfo TopDUContextDynamicData::writeDataInfo(const ItemDataInfo& info, const DUChainBaseData* data, uint& totalDataOffset) {
