@@ -20,11 +20,11 @@
 
 #include "abstracttype.h"
 
-#include "../indexedstring.h"
 #include "typesystemdata.h"
 #include "typeregister.h"
 #include "typesystem.h"
-#include "../repositories/typerepository.h"
+#include "typerepository.h"
+#include "util/debug.h"
 
 namespace KDevelop
 {
@@ -47,12 +47,12 @@ AbstractType::AbstractType( AbstractTypeData& dd )
 {
 }
 
-quint64 AbstractType::modifiers() const
+quint32 AbstractType::modifiers() const
 {
   return d_func()->m_modifiers;
 }
 
-void AbstractType::setModifiers(quint64 modifiers)
+void AbstractType::setModifiers(quint32 modifiers)
 {
   d_func_dynamic()->m_modifiers = modifiers;
 }
@@ -96,12 +96,12 @@ void AbstractType::exchangeTypes( TypeExchanger* /*exchanger */) {
 
 IndexedType AbstractType::indexed() const
 {
-  return IndexedType(AbstractType::Ptr(const_cast<AbstractType*>(this)));
+  return IndexedType(TypeRepository::indexForType(AbstractType::Ptr(const_cast<AbstractType*>(this))));
 }
 
 bool AbstractType::equals(const AbstractType* rhs) const
 {
-    //kDebug() << this << rhs << modifiers() << rhs->modifiers();
+    //qCDebug(LANGUAGE) << this << rhs << modifiers() << rhs->modifiers();
     return d_func()->typeClassId == rhs->d_func()->typeClassId && modifiers() == rhs->modifiers();
 }
 
@@ -148,5 +148,3 @@ QString AbstractType::toString(bool spaceOnLeft) const
 }
 
 }
-
-// kate: space-indent on; indent-width 2; tab-width 4; replace-tabs on; auto-insert-doxygen on
