@@ -20,8 +20,7 @@
 
 #include "arraytype.h"
 
-#include "../indexedstring.h"
-#include "../repositories/typerepository.h"
+#include "typerepository.h"
 #include "typesystemdata.h"
 #include "typeregister.h"
 #include "typesystem.h"
@@ -83,15 +82,15 @@ AbstractType::Ptr ArrayType::elementType () const
 
 void ArrayType::setElementType(AbstractType::Ptr type)
 {
-  d_func_dynamic()->m_elementType = IndexedType(type);
+  d_func_dynamic()->m_elementType = type->indexed();
 }
 
 QString ArrayType::toString() const
 {
   if (d_func()->m_dimension == 0) {
-    return QString("%1[]").arg(elementType() ? elementType()->toString() : QString("<notype>"));
+    return QStringLiteral("%1[]").arg(elementType() ? elementType()->toString() : QStringLiteral("<notype>"));
   }
-  return QString("%1[%2]").arg(elementType() ? elementType()->toString() : QString("<notype>")).arg(d_func()->m_dimension);
+  return QStringLiteral("%1[%2]").arg(elementType() ? elementType()->toString() : QStringLiteral("<notype>")).arg(d_func()->m_dimension);
 }
 
 void ArrayType::accept0 (TypeVisitor *v) const
@@ -107,7 +106,7 @@ void ArrayType::accept0 (TypeVisitor *v) const
 void ArrayType::exchangeTypes( TypeExchanger* exchanger )
 {
   TYPE_D_DYNAMIC(ArrayType);
-  d->m_elementType = IndexedType(exchanger->exchange(d->m_elementType.abstractType()));
+  d->m_elementType = exchanger->exchange( d->m_elementType.abstractType() )->indexed();
 }
 
 AbstractType::WhichType ArrayType::whichType() const
@@ -122,5 +121,3 @@ uint ArrayType::hash() const
 }
 
 }
-
-// kate: space-indent on; indent-width 2; tab-width 4; replace-tabs on; auto-insert-doxygen on
