@@ -21,6 +21,9 @@
 
 #include "constantintegraltype.h"
 
+#include <QDebug>
+
+#include "util/debug.h"
 #include "typesystemdata.h"
 #include "typeregister.h"
 
@@ -79,28 +82,28 @@ QString ConstantIntegralType::toString() const
       ret += "none";
       break;
     case TypeChar:
-      ret += QString("char(%1)").arg((char)d_func()->m_value);
+      ret += QStringLiteral("char");
       break;
     case TypeWchar_t:
-      ret += QString("wchar_t(%1)").arg((wchar_t)d_func()->m_value);
+      ret += QStringLiteral("wchar_t");
       break;
     case TypeChar16_t:
-      ret += QString("char16_t(%1)").arg((char16_t)d_func()->m_value);
+      ret += QStringLiteral("char16_t");
       break;
     case TypeChar32_t:
-      ret += QString("char32_t(%1)").arg((char32_t)d_func()->m_value);
+      ret += QStringLiteral("char32_t");
       break;
     case TypeBoolean:
       ret += d_func()->m_value ? "true" : "false";
       break;
     case TypeInt:
-      ret += (modifiers() & UnsignedModifier) ? QString("unsigned(%1)").arg((uint)d_func()->m_value) : QString("int(%1)").arg((int)d_func()->m_value);
+      ret += (modifiers() & UnsignedModifier) ? QStringLiteral("unsigned") : QStringLiteral("int");
       break;
     case TypeFloat:
-      ret += QString("float(%1)").arg( value<float>() );
+      ret += QStringLiteral("float");
       break;
     case TypeDouble:
-      ret += QString("double(%1)").arg( value<double>() );
+      ret += QStringLiteral("double");
       break;
     case TypeVoid:
       ret += "void";
@@ -113,6 +116,34 @@ QString ConstantIntegralType::toString() const
   return ret;
 }
 
+QString ConstantIntegralType::valueAsString() const
+{
+  switch(dataType()) {
+    case TypeNone:
+      return "none";
+    case TypeChar:
+      return QString::number((char)d_func()->m_value);
+    case TypeWchar_t:
+      return QString::number((wchar_t)d_func()->m_value);
+    case TypeChar16_t:
+      return QString::number((char16_t)d_func()->m_value);
+    case TypeChar32_t:
+      return QString::number((char32_t)d_func()->m_value);
+    case TypeBoolean:
+      return d_func()->m_value ? "true" : "false";
+    case TypeInt:
+      return (modifiers() & UnsignedModifier) ?
+        QString::number((uint)d_func()->m_value) :
+        QString::number((int)d_func()->m_value);
+    case TypeFloat:
+      return QString::number(value<float>());
+    case TypeDouble:
+      return QString::number(value<double>());
+    default:
+      return QString();
+  }
+}
+
 uint ConstantIntegralType::hash() const
 {
   return KDevHash(IntegralType::hash()) << d_func()->m_value;
@@ -122,7 +153,7 @@ template<>
 KDEVPLATFORMLANGUAGE_EXPORT
 void ConstantIntegralType::setValueInternal<qint64>(qint64 value) {
   if((modifiers() & UnsignedModifier)) {
-    kDebug() << "setValue(signed) called on unsigned type";
+    qCWarning(LANGUAGE) << "setValue(signed) called on unsigned type";
   }
   d_func_dynamic()->m_value = value;
 }
@@ -131,7 +162,7 @@ template<>
 KDEVPLATFORMLANGUAGE_EXPORT
 void ConstantIntegralType::setValueInternal<quint64>(quint64 value) {
   if(!(modifiers() & UnsignedModifier)) {
-    kDebug() << "setValue(unsigned) called on not unsigned type";
+    qCWarning(LANGUAGE) << "setValue(unsigned) called on not unsigned type";
   }
   d_func_dynamic()->m_value = (qint64)value;
 }
@@ -140,7 +171,7 @@ template<>
 KDEVPLATFORMLANGUAGE_EXPORT
 void ConstantIntegralType::setValueInternal<float>(float value) {
   if(dataType() != TypeFloat) {
-    kDebug() << "setValue(float) called on non-float type";
+    qCWarning(LANGUAGE) << "setValue(float) called on non-float type";
   }
   memcpy(&d_func_dynamic()->m_value, &value, sizeof(float));
 }
@@ -149,7 +180,7 @@ template<>
 KDEVPLATFORMLANGUAGE_EXPORT
 void ConstantIntegralType::setValueInternal<double>(double value) {
   if(dataType() != TypeDouble) {
-    kDebug() << "setValue(double) called on non-double type";
+    qCWarning(LANGUAGE) << "setValue(double) called on non-double type";
   }
   memcpy(&d_func_dynamic()->m_value, &value, sizeof(double));
 }
