@@ -20,8 +20,7 @@
 
 #include "pointertype.h"
 
-#include "../indexedstring.h"
-#include "../repositories/typerepository.h"
+#include "typerepository.h"
 #include "typesystemdata.h"
 #include "typeregister.h"
 #include "typesystem.h"
@@ -70,7 +69,7 @@ void PointerType::accept0 (TypeVisitor *v) const
 }
 
 void PointerType::exchangeTypes( TypeExchanger* exchanger ) {
-  d_func_dynamic()->m_baseType = IndexedType(exchanger->exchange( d_func()->m_baseType.abstractType()));
+  d_func_dynamic()->m_baseType = exchanger->exchange( d_func()->m_baseType.abstractType() )->indexed();
 }
 
 PointerType::~PointerType()
@@ -84,13 +83,13 @@ AbstractType::Ptr PointerType::baseType () const
 
 void PointerType::setBaseType(AbstractType::Ptr type)
 {
-  d_func_dynamic()->m_baseType = IndexedType(type);
+  d_func_dynamic()->m_baseType = type->indexed();
 }
 
 QString PointerType::toString() const
 {
   QString baseString = (baseType() ? baseType()->toString() : "<notype>");
-  return QString("%1*").arg(baseString) + AbstractType::toString(true);
+  return QStringLiteral("%1*").arg(baseString) + AbstractType::toString(true);
 }
 
 AbstractType::WhichType PointerType::whichType() const
@@ -104,5 +103,3 @@ uint PointerType::hash() const
 }
 
 }
-
-// kate: space-indent on; indent-width 2; tab-width 4; replace-tabs on; auto-insert-doxygen on
