@@ -20,8 +20,7 @@
 
 #include "referencetype.h"
 
-#include "../indexedstring.h"
-#include "../repositories/typerepository.h"
+#include "typerepository.h"
 #include "typesystemdata.h"
 #include "typeregister.h"
 #include "typesystem.h"
@@ -73,7 +72,7 @@ AbstractType::Ptr ReferenceType::baseType () const
 
 void ReferenceType::setBaseType(AbstractType::Ptr type)
 {
-  d_func_dynamic()->m_baseType = IndexedType(type);
+  d_func_dynamic()->m_baseType = type->indexed();
 }
 
 bool ReferenceType::isRValue() const
@@ -96,7 +95,7 @@ void ReferenceType::accept0 (TypeVisitor *v) const
 
 void ReferenceType::exchangeTypes( TypeExchanger* exchanger )
 {
-  d_func_dynamic()->m_baseType = IndexedType(exchanger->exchange(d_func()->m_baseType.abstractType()));
+  d_func_dynamic()->m_baseType = exchanger->exchange( d_func()->m_baseType.abstractType() )->indexed();
 }
 
 QString ReferenceType::toString() const
@@ -121,5 +120,3 @@ uint ReferenceType::hash() const
 }
 
 }
-
-// kate: space-indent on; indent-width 2; tab-width 4; replace-tabs on; auto-insert-doxygen on
