@@ -24,12 +24,10 @@
 
 #include <QtCore/QObject>
 #include <QtCore/QList>
-#include <QtGui/QColor>
-#include <QtCore/QWeakPointer>
+#include <QColor>
+#include <QtCore/QPointer>
 
-#include "../languageexport.h"
-
-#include <kdeversion.h>
+#include <language/languageexport.h>
 
 namespace KTextEditor {
 class Document;
@@ -81,14 +79,28 @@ class KDEVPLATFORMLANGUAGE_EXPORT ColorCache : public QObject
     /// access the default colors
     CodeHighlightingColors* defaultColors() const;
 
-    /// access the generated colors
-    /// @see validColorCount()
+    /**
+     * @returns a primary color if @p num less primaryColorCount and a supplementary color if @p num >= primaryColorCount and < validColorCount
+     * @see validColorCount()
+     * @see primaryColorCount()
+     */
     QColor generatedColor(uint num) const;
 
-    /// returns the number of valid generated colors
-    /// @see generatedColor()
+    /**
+      * @returns the number of primary and supplementary colors
+      *
+      * @see generatedColor()
+      * @see primaryColorCount()
+      */
     uint validColorCount() const;
 
+    /**
+     * @returns number of primary colors
+     *
+     * When you run out of primary colors use supplementary colors
+     */
+    uint primaryColorCount() const;
+
     /// access the foreground color
     QColor foregroundColor() const;
 
@@ -99,7 +111,7 @@ class KDEVPLATFORMLANGUAGE_EXPORT ColorCache : public QObject
 
   private slots:
     /// if necessary, adapt to the colors of this document
-    void slotDocumentActivated(KDevelop::IDocument*);
+    void slotDocumentActivated();
     /// settings got changed, update to the settings of the sender
     void slotViewSettingsChanged();
 
@@ -127,7 +139,7 @@ class KDEVPLATFORMLANGUAGE_EXPORT ColorCache : public QObject
     /// try to access the KatePart settings for the given doc or fallback to the global KDE scheme
     /// and update the colors if necessary
     /// @see generateColors(), updateColorsFromScheme()
-    void updateColorsFromDocument(KTextEditor::Document* doc);
+    void updateColorsFromView(KTextEditor::View* view);
 
     /// the default colors for the different types
     CodeHighlightingColors* m_defaultColors;
@@ -135,9 +147,10 @@ class KDEVPLATFORMLANGUAGE_EXPORT ColorCache : public QObject
     /// the generated colors
     QList<QColor> m_colors;
 
-    /// Must always be m_colors.count()-1, because the last color must be the fallback text color
     uint m_validColorCount;
 
+    uint m_primaryColorCount;
+
     /// Maybe make this configurable: An offset where to start stepping through the color wheel
     uint m_colorOffset;
 
@@ -155,8 +168,11 @@ class KDEVPLATFORMLANGUAGE_EXPORT ColorCache : public QObject
     /// Between 0 and 255, where 255 means only foreground color, and 0 only the chosen color.
     uchar m_globalColorRatio;
 
+    /// Whether declarations have to be rendered with a bold style or not.
+    bool m_boldDeclarations;
+
     /// The view we are listening to for setting changes.
-    QWeakPointer<KTextEditor::View> m_view;
+    QPointer<KTextEditor::View> m_view;
 };
 
 }
