@@ -1,5 +1,6 @@
 /***************************************************************************
  *   Copyright 2008 David Nolden  <david.nolden.kdevelop@art-master.de>    *
+ *   Copyright 2014 Kevin Funk <kfunk@kde.org>                             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU Library General Public License as       *
@@ -19,32 +20,47 @@
 
 #include "ilanguagesupport.h"
 #include "../duchain/duchain.h"
-#include "../editor/simplerange.h"
 
 #include <interfaces/icore.h>
 #include <interfaces/ilanguagecontroller.h>
-#include <backgroundparser/documentchangetracker.h>
+
+#include <QReadWriteLock>
 
 namespace KDevelop {
 
-TopDUContext* ILanguageSupport::standardContext(const KUrl& url, bool proxyContext) {
+class ILanguageSupportPrivate
+{
+public:
+    mutable QReadWriteLock lock;
+};
+
+ILanguageSupport::ILanguageSupport()
+    : d(new ILanguageSupportPrivate)
+{
+}
+
+ILanguageSupport::~ILanguageSupport()
+{
+}
+
+TopDUContext* ILanguageSupport::standardContext(const QUrl& url, bool proxyContext) {
   Q_UNUSED(proxyContext)
   return DUChain::self()->chainForDocument(url);
 }
 
-SimpleRange ILanguageSupport::specialLanguageObjectRange(const KUrl& url, const SimpleCursor& position) {
+KTextEditor::Range ILanguageSupport::specialLanguageObjectRange(const QUrl& url, const KTextEditor::Cursor& position) {
     Q_UNUSED(url)
     Q_UNUSED(position)
-    return SimpleRange::invalid();
+    return KTextEditor::Range::invalid();
 }
 
-QPair<KUrl, SimpleCursor> ILanguageSupport::specialLanguageObjectJumpCursor(const KUrl& url, const SimpleCursor& position) {
+QPair<QUrl, KTextEditor::Cursor> ILanguageSupport::specialLanguageObjectJumpCursor(const QUrl& url, const KTextEditor::Cursor& position) {
     Q_UNUSED(url)
     Q_UNUSED(position)
-    return QPair<KUrl, SimpleCursor>(KUrl(), SimpleCursor::invalid());
+    return QPair<QUrl, KTextEditor::Cursor>(QUrl(), KTextEditor::Cursor::invalid());
 }
 
-QWidget* ILanguageSupport::specialLanguageObjectNavigationWidget(const KUrl& url, const SimpleCursor& position) {
+QWidget* ILanguageSupport::specialLanguageObjectNavigationWidget(const QUrl& url, const KTextEditor::Cursor& position) {
     Q_UNUSED(url)
     Q_UNUSED(position)
     return 0;
@@ -63,16 +79,6 @@ ICreateClassHelper* ILanguageSupport::createClassHelper() const {
     return 0;
 }
 
-
-ILanguage* ILanguageSupport::language() {
-    return ICore::self()->languageController()->language(name());
-}
-
-DocumentChangeTracker* ILanguageSupport::createChangeTrackerForDocument ( KTextEditor::Document* document ) const
-{
-    return new DocumentChangeTracker(document);
-}
-
 ILanguageSupport::WhitespaceSensitivity ILanguageSupport::whitespaceSensititivy() const
 {
     return ILanguageSupport::Insensitive;
@@ -85,7 +91,12 @@ SourceFormatterItemList ILanguageSupport::sourceFormatterItems() const
 
 QString ILanguageSupport::indentationSample() const
 {
-    return "";
+    return QString();
+}
+
+QReadWriteLock* ILanguageSupport::parseLock() const
+{
+    return &d->lock;
 }
 
 }
