@@ -16,13 +16,14 @@
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
 */
-#ifndef IQUICKOPEN_H
-#define IQUICKOPEN_H
+#ifndef KDEVPLATFORM_IQUICKOPEN_H
+#define KDEVPLATFORM_IQUICKOPEN_H
 
 #include <QtCore/QSet>
-#include <KDE/KUrl>
-#include "../languageexport.h"
-#include <KDE/KLineEdit>
+
+#include <QLineEdit>
+
+#include <language/languageexport.h>
 
 class QStringList;
 
@@ -32,7 +33,7 @@ namespace KDevelop
 class QuickOpenDataProviderBase;
 class IndexedString;
 
-class KDEVPLATFORMLANGUAGE_EXPORT IQuickOpenLine : public KLineEdit
+class KDEVPLATFORMLANGUAGE_EXPORT IQuickOpenLine : public QLineEdit
 {
     Q_OBJECT
 public:
@@ -105,4 +106,4 @@ public:
 
 Q_DECLARE_INTERFACE(KDevelop::IQuickOpen, "org.kdevelop.IQuickOpen")
 
-#endif // IQuickOpen_H
+#endif // KDEVPLATFORM_IQUICKOPEN_H
