@@ -23,8 +23,8 @@
 #include "outputjob.h"
 #include "outputmodel.h"
 #include <QProcess>
+#include <QUrl>
 
-class KUrl;
 class KProcess;
 
 namespace KDevelop
@@ -60,12 +60,10 @@ public:
         CheckWorkingDirectory = 0x004, /**< Whether to check that the working directory actually exists (and not to create it if needed) */
         PortableMessages      = 0x008, /**< Whether to set LC_MESSAGES=C in the process' environment */
         DisplayStdout         = 0x010, /**< Whether to pass process' stdout to the output model */
-        AccumulateStdout      = 0x020, /**< Whether to save process' stdout to the internal byte-array buffer for further consumption */
-        DisplayStderr         = 0x040, /**< Whether to pass process' stderr to the output model */
-        AccumulateStderr      = 0x080, /**< Whether to save process' stderr to the internal byte-array buffer for further consumption */
-        NoSilentOutput        = 0x100, /**< Whether to call \ref startOutput() only if verbosity is \ref OutputJob::Verbose */
-        PostProcessOutput     = 0x200, /**< Whether to connect line maker's signals to \ref postProcessStdout() and \ref postProcessStderr() */
-        IsBuilderHint         = 0x400, /**< Whether to use builder-specific messages to talk to user (e. g. "build directory" instead of "working directory" */
+        DisplayStderr         = 0x020, /**< Whether to pass process' stderr to the output model */
+        NoSilentOutput        = 0x040, /**< Whether to call \ref startOutput() only if verbosity is \ref OutputJob::Verbose */
+        PostProcessOutput     = 0x080, /**< Whether to connect line maker's signals to \ref postProcessStdout() and \ref postProcessStderr() */
+        IsBuilderHint         = 0x100, /**< Whether to use builder-specific messages to talk to user (e. g. "build directory" instead of "working directory" */
     };
     Q_FLAGS(JobProperty JobProperties)
     Q_DECLARE_FLAGS(JobProperties, JobProperty)
@@ -93,7 +91,7 @@ public:
      *
      * @returns URL which has been set through \ref setWorkingDirectory(); empty URL if unset.
      */
-    virtual KUrl workingDirectory() const;
+    virtual QUrl workingDirectory() const;
 
     /**
      * Set a working directory for the job's process.
@@ -101,7 +99,7 @@ public:
      *
      * @param directory a valid local directory URL, or an empty URL to unset.
      */
-    void setWorkingDirectory( const KUrl& directory );
+    void setWorkingDirectory( const QUrl& directory );
 
     /**
      * Get process' command line.
@@ -249,4 +247,4 @@ private:
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(KDevelop::OutputExecuteJob::JobProperties);
 
-#endif // KDEVPLATFORM_OUTPUTEXECUTEJOB_H
\ No newline at end of file
+#endif // KDEVPLATFORM_OUTPUTEXECUTEJOB_H
