@@ -13,7 +13,8 @@
 #define KDEVPLATFORM_OUTPUTFORMATS_H
 
 #include <QString>
-#include <QRegExp>
+#include <QRegularExpression>
+#include <KLocalizedString>
 
 namespace KDevelop
 {
@@ -21,11 +22,10 @@ namespace KDevelop
 struct ActionFormat
 {
     ActionFormat() = default;
-    ActionFormat( const char* context, const char* _action, const QString& _tool, const QString& regExp, int file );
-    ActionFormat( const char* context, const char* _action, int tool, int file, const QString& regExp );
-    const char* context; // translation context for action
-    const char* action;  // translated string
-    QRegExp expression;
+    ActionFormat( const KLocalizedString& label, const QString& _tool, const QString& regExp, int file );
+    ActionFormat( const KLocalizedString& label, int tool, int file, const QString& regExp );
+    KLocalizedString label;
+    QRegularExpression expression;
     QString tool;
     int toolGroup;
     int fileGroup;
@@ -36,7 +36,7 @@ struct ErrorFormat
     ErrorFormat() = default;
     ErrorFormat( const QString& regExp, int file, int line, int text, int column=-1 );
     ErrorFormat( const QString& regExp, int file, int line, int text, const QString& comp, int column=-1 );
-    QRegExp expression;
+    QRegularExpression expression;
     int fileGroup;
     int lineGroup, columnGroup;
     int textGroup;
