@@ -18,67 +18,62 @@
 #ifndef KDEVPLATFORM_TESTLINEBUILDERFUNCTIONS_H
 #define KDEVPLATFORM_TESTLINEBUILDERFUNCTIONS_H
 
-#include <KUrl>
-
+#include <QUrl>
 #include <QString>
+#include <QFileInfo>
+
+#define PROJECTS_SOURCE_DIR
 
 namespace KDevelop
 {
 
-QString buildCppCheckErrorLine()
+static QString projectPath()
 {
     /// Use existing directory with one file
-    KUrl projecturl( PROJECTS_SOURCE_DIR"/onefileproject/" );
+    return QFileInfo(__FILE__).absolutePath() + QLatin1String("/onefileproject");
+}
 
+QString buildCppCheckErrorLine()
+{
     /// Test CPP check output
     QString outputline("[");
-    outputline.append(projecturl.path());
+    outputline.append(projectPath());
     outputline.append("main.cpp:26]: (error) Memory leak: str");
     return outputline;
 }
 
 QString buildKrazyErrorLine()
 {
-    /// Use existing directory with one file
-    KUrl projecturl( PROJECTS_SOURCE_DIR"/onefileproject/" );
-
     /// Test krazy2 output
     QString outputline("\t");
-    outputline.append(projecturl.path());
+    outputline.append(projectPath());
     outputline.append("main.cpp: line#22 (1)");
     return outputline;
 }
 
 QString buildKrazyErrorLine2()
 {
-    /// Use existing directory with one file
-    KUrl projecturl( PROJECTS_SOURCE_DIR"/onefileproject/" );
     /// Test krazy2 output
     QString outputline("\t");
-    outputline.append(projecturl.path());
+    outputline.append(projectPath());
     outputline.append("main.cpp: missing tags: email address line#2  (1)");
     return outputline;
 }
 
 QString buildKrazyErrorLine3()
 {
-    /// Use existing directory with one file
-    KUrl projecturl( PROJECTS_SOURCE_DIR"/onefileproject/" );
     /// Test krazy2 output
     QString outputline("\t");
-    outputline.append(projecturl.path());
+    outputline.append(projectPath());
     outputline.append("main.cpp: non-const ref iterator line#451 (1)");
     return outputline;
 }
 
 QString buildKrazyErrorLineNoLineInfo()
 {
-    /// Use existing directory with one file
-    KUrl projecturl( PROJECTS_SOURCE_DIR"/onefileproject/" );
-
     /// Test krazy2 output
     QString outputline("\t");
-    outputline.append(projecturl.path());
+    outputline.append(projectPath());
     outputline.append("main.cpp: missing license");
     return outputline;
 }
@@ -86,59 +81,53 @@ QString buildKrazyErrorLineNoLineInfo()
 QString buildCompilerLine()
 {
     /// Test with compiler output
-    KUrl projecturl( PROJECTS_SOURCE_DIR"/onefileproject/" );
     QString outputline;
-    outputline.append(projecturl.path());
+    outputline.append(projectPath());
     outputline.append(">make");
     return outputline;
 }
 
 QString buildCompilerErrorLine()
 {
-    KUrl projecturl( PROJECTS_SOURCE_DIR"/onefileproject/" );
     QString outputline;
-    outputline.append(projecturl.path());
+    outputline.append(projectPath());
     outputline.append("main.cpp:5:5: error: ‘RingBuffer’ was not declared in this scope");
     return outputline;
 }
 
 QString buildCompilerInformationLine()
 {
-    KUrl projecturl( PROJECTS_SOURCE_DIR"/onefileproject/" );
     QString outputline;
-    outputline.append(projecturl.path());
+    outputline.append(projectPath());
     outputline.append("main.cpp:6:14: instantiated from here");
     return outputline;
 }
 
 QString buildInfileIncludedFromFirstLine()
 {
-    KUrl projecturl( PROJECTS_SOURCE_DIR"/onefileproject/" );
     QString outputline("In file included from ");
-    outputline.append(projecturl.path());
+    outputline.append(projectPath());
     outputline.append("PriorityFactory.h:52:0,");
     return outputline;
 }
 
 QString buildInfileIncludedFromSecondLine()
 {
-    KUrl projecturl( PROJECTS_SOURCE_DIR"/onefileproject/" );
     QString outputline("    from ");
-    outputline.append(projecturl.path());
+    outputline.append(projectPath());
     outputline.append("PatchBasedInpainting.hxx:29,");
     return outputline;
 }
 
 QString buildCompilerActionLine()
 {
-    return QString("linking testCustombuild (g++)");
+    return QStringLiteral("linking testCustombuild (g++)");
 }
 
 QString buildCmakeConfigureMultiLine()
 {
-    KUrl projecturl( PROJECTS_SOURCE_DIR"/onefileproject/" );
     QString outputline;
-    outputline.append(projecturl.path());
+    outputline.append(projectPath());
     outputline.append("CMakeLists.txt:10:");
     return outputline;
 }
@@ -146,21 +135,20 @@ QString buildCmakeConfigureMultiLine()
 
 QString buildLinkerErrorLine()
 {
-    return QString("/path/to/file/Buffer.cpp:66: undefined reference to `Buffer::does_not_exist()'");
+    return QStringLiteral("/path/to/file/Buffer.cpp:66: undefined reference to `Buffer::does_not_exist()'");
 }
 
 QString buildPythonErrorLine()
 {
-    KUrl projecturl( PROJECTS_SOURCE_DIR"/onefileproject/" );
     QString outputline("File \"");
-    outputline.append(projecturl.path());
+    outputline.append(projectPath());
     outputline.append("pythonExample.py\", line 10");
     return outputline;
 }
 
 QString buildCppCheckInformationLine()
 {
-    return QString("(information) Cppcheck cannot find all the include files. Cpppcheck can check the code without the include\
+    return QStringLiteral("(information) Cppcheck cannot find all the include files. Cpppcheck can check the code without the include\
     files found. But the results will probably be more accurate if all the include files are found. Please check your project's \
     include directories and add all of them as include directories for Cppcheck. To see what files Cppcheck cannot find use --check-config.");
 }
