@@ -13,33 +13,32 @@
  ***************************************************************************/
 #include "appwizardplugin.h"
 
+#include <QAction>
+#include <QDebug>
 #include <QDir>
+#include <QDirIterator>
 #include <QFile>
 #include <QFileInfo>
+#include <QMimeType>
+#include <QMimeDatabase>
+#include <QStandardPaths>
+#include <QTemporaryDir>
 #include <QTextCodec>
 #include <QTextStream>
-#include <QDirIterator>
+#include <qplatformdefs.h>
 
-#include <ktar.h>
-#include <kzip.h>
-#include <kdebug.h>
-#include <klocale.h>
-#include <kaction.h>
-#include <ktempdir.h>
-#include <ksharedconfig.h>
-#include <kconfiggroup.h>
-#include <kmessagebox.h>
-#include <kstandarddirs.h>
+#include <KActionCollection>
+#include <KConfigGroup>
+#include <KIO/CopyJob>
+#include <KIO/DeleteJob>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KParts/MainWindow>
+#include <KPluginFactory>
+#include <KSharedConfig>
+#include <KTar>
+#include <KZip>
 #include <kmacroexpander.h>
-#include <kpluginfactory.h>
-#include <kaboutdata.h>
-#include <kpluginloader.h>
-#include <kactioncollection.h>
-#include <kmimetype.h>
-#include <kparts/mainwindow.h>
-#include <kio/copyjob.h>
-#include <kio/netaccess.h>
-#include <kde_file.h>
 
 #include <interfaces/icore.h>
 #include <interfaces/iprojectcontroller.h>
@@ -57,29 +56,24 @@
 #include "projectselectionpage.h"
 #include "projectvcspage.h"
 #include "projecttemplatesmodel.h"
+#include "debug.h"
 
-using KDevelop::IBasicVersionControl;
-using KDevelop::ICentralizedVersionControl;
-using KDevelop::IDistributedVersionControl;
-using KDevelop::IPlugin;
-using KDevelop::VcsJob;
-using KDevelop::VcsLocation;
-using KDevelop::ICore;
+using namespace KDevelop;
 
-K_PLUGIN_FACTORY(AppWizardFactory, registerPlugin<AppWizardPlugin>();)
-K_EXPORT_PLUGIN(AppWizardFactory(KAboutData("kdevappwizard","kdevappwizard", ki18n("Project Wizard"), "0.1", ki18n("Support for creating and importing projects"), KAboutData::License_GPL)))
+Q_LOGGING_CATEGORY(PLUGIN_APPWIZARD, "kdevplatform.plugins.appwizard")
+K_PLUGIN_FACTORY_WITH_JSON(AppWizardFactory, "kdevappwizard.json", registerPlugin<AppWizardPlugin>();)
 
 AppWizardPlugin::AppWizardPlugin(QObject *parent, const QVariantList &)
-    : KDevelop::IPlugin(AppWizardFactory::componentData(), parent)
+    : KDevelop::IPlugin("kdevappwizard", parent)
     , m_templatesModel(0)
 {
     KDEV_USE_EXTENSION_INTERFACE(KDevelop::ITemplateProvider);
     setXMLFile("kdevappwizard.rc");
 
     m_newFromTemplate = actionCollection()->addAction("project_new");
-    m_newFromTemplate->setIcon(KIcon("project-development-new-template"));
+    m_newFromTemplate->setIcon(QIcon::fromTheme("project-development-new-template"));
     m_newFromTemplate->setText(i18n("New From Template..."));
-    connect(m_newFromTemplate, SIGNAL(triggered(bool)), this, SLOT(slotNewProject()));
+    connect(m_newFromTemplate, &QAction::triggered, this, &AppWizardPlugin::slotNewProject);
     m_newFromTemplate->setToolTip( i18n("Generate a new project from a template") );
     m_newFromTemplate->setWhatsThis( i18n("This starts KDevelop's application wizard. "
                                           "It helps you to generate a skeleton for your "
@@ -93,6 +87,7 @@ AppWizardPlugin::~AppWizardPlugin()
 void AppWizardPlugin::slotNewProject()
 {
     model()->refresh();
+
     AppWizardDialog dlg(core()->pluginController(), m_templatesModel);
 
     if (dlg.exec() == QDialog::Accepted)
@@ -100,7 +95,7 @@ void AppWizardPlugin::slotNewProject()
         QString project = createProject( dlg.appInfo() );
         if (!project.isEmpty())
         {
-            core()->projectController()->openProject(KUrl::fromPath(project));
+            core()->projectController()->openProject(QUrl::fromLocalFile(project));
 
             KConfig templateConfig(dlg.appInfo().appTemplate);
             KConfigGroup general(&templateConfig, "General");
@@ -108,7 +103,7 @@ void AppWizardPlugin::slotNewProject()
             if (!file.isEmpty())
             {
                 file = KMacroExpander::expandMacros(file, m_variables);
-                core()->documentController()->openDocument(file);
+                core()->documentController()->openDocument(QUrl::fromUserInput(file));
             }
         } else {
             KMessageBox::error( ICore::self()->uiController()->activeMainWindow(), i18n("Could not create project from template\n"), i18n("Failed to create project") );
@@ -132,40 +127,45 @@ ICentralizedVersionControl* toCVCS(IPlugin* plugin)
 }
 
 /*! Trouble while initializing version control. Show failure message to user. */
-void vcsError(const QString &errorMsg, KTempDir &tmpdir, const KUrl &dest)
+void vcsError(const QString &errorMsg, QTemporaryDir &tmpdir, const QUrl &dest, const QString &details = QString())
 {
-    KMessageBox::error(0, errorMsg);
-    KIO::NetAccess::del(dest, 0);
-    tmpdir.unlink();
+    QString displayDetails = details;
+    if (displayDetails.isEmpty())
+    {
+        displayDetails = i18n("Please see the Version Control toolview");
+    }
+    KMessageBox::detailedError(0, errorMsg, displayDetails, i18n("Version Control System Error"));
+    KIO::del(dest)->exec();
+    tmpdir.remove();
 }
 
 /*! Setup distributed version control for a new project defined by @p info. Use @p scratchArea for temporary files  */
-bool initializeDVCS(IDistributedVersionControl* dvcs, const ApplicationInfo& info, KTempDir& scratchArea)
+bool initializeDVCS(IDistributedVersionControl* dvcs, const ApplicationInfo& info, QTemporaryDir& scratchArea)
 {
     Q_ASSERT(dvcs);
-    kDebug() << "DVCS system is used, just initializing DVCS";
+    qCDebug(PLUGIN_APPWIZARD) << "DVCS system is used, just initializing DVCS";
 
-    KUrl dest = info.location;
+    const QUrl& dest = info.location;
     //TODO: check if we want to handle KDevelop project files (like now) or only SRC dir
-    VcsJob* job = dvcs->init(dest.toLocalFile());
+    VcsJob* job = dvcs->init(dest);
     if (!job || !job->exec() || job->status() != VcsJob::JobSucceeded)
     {
         vcsError(i18n("Could not initialize DVCS repository"), scratchArea, dest);
         return false;
     }
-    kDebug() << "Initializing DVCS repository:" << dest.toLocalFile();
+    qCDebug(PLUGIN_APPWIZARD) << "Initializing DVCS repository:" << dest;
 
-    job = dvcs->add(KUrl::List(dest), KDevelop::IBasicVersionControl::Recursive);
+    job = dvcs->add({dest}, KDevelop::IBasicVersionControl::Recursive);
     if (!job || !job->exec() || job->status() != VcsJob::JobSucceeded)
     {
         vcsError(i18n("Could not add files to the DVCS repository"), scratchArea, dest);
         return false;
     }
-    job = dvcs->commit(QString("initial project import from KDevelop"), KUrl::List(dest),
+    job = dvcs->commit(QStringLiteral("initial project import from KDevelop"), {dest},
                             KDevelop::IBasicVersionControl::Recursive);
     if (!job || !job->exec() || job->status() != VcsJob::JobSucceeded)
     {
-        vcsError(i18n("Could not import project into %1.", dvcs->name()), scratchArea, dest);
+        vcsError(i18n("Could not import project into %1.", dvcs->name()), scratchArea, dest, job ? job->errorString() : QString());
         return false;
     }
 
@@ -173,24 +173,24 @@ bool initializeDVCS(IDistributedVersionControl* dvcs, const ApplicationInfo& inf
 }
 
 /*! Setup version control for a new project defined by @p info. Use @p scratchArea for temporary files  */
-bool initializeCVCS(ICentralizedVersionControl* cvcs, const ApplicationInfo& info, KTempDir& scratchArea)
+bool initializeCVCS(ICentralizedVersionControl* cvcs, const ApplicationInfo& info, QTemporaryDir& scratchArea)
 {
     Q_ASSERT(cvcs);
 
-    kDebug() << "Importing" << info.sourceLocation << "to"
+    qCDebug(PLUGIN_APPWIZARD) << "Importing" << info.sourceLocation << "to"
              << info.repository.repositoryServer();
-    VcsJob* job = cvcs->import( info.importCommitMessage, scratchArea.name(), info.repository);
+    VcsJob* job = cvcs->import( info.importCommitMessage, QUrl::fromLocalFile(scratchArea.path()), info.repository);
     if (!job || !job->exec() || job->status() != VcsJob::JobSucceeded )
     {
-    vcsError(i18n("Could not import project"), scratchArea, info.repository.repositoryServer());
+        vcsError(i18n("Could not import project"), scratchArea, QUrl::fromUserInput(info.repository.repositoryServer()));
         return false;
     }
 
-    kDebug() << "Checking out";
+    qCDebug(PLUGIN_APPWIZARD) << "Checking out";
     job = cvcs->createWorkingCopy( info.repository, info.location, IBasicVersionControl::Recursive);
     if (!job || !job->exec() || job->status() != VcsJob::JobSucceeded )
     {
-        vcsError(i18n("Could not checkout imported project"), scratchArea, info.repository.repositoryServer());
+        vcsError(i18n("Could not checkout imported project"), scratchArea, QUrl::fromUserInput(info.repository.repositoryServer()));
         return false;
     }
 
@@ -210,21 +210,27 @@ QString AppWizardPlugin::createProject(const ApplicationInfo& info)
 {
     QFileInfo templateInfo(info.appTemplate);
     if (!templateInfo.exists()) {
-        kWarning() << "Project app template does not exist:" << info.appTemplate;
+        qWarning() << "Project app template does not exist:" << info.appTemplate;
         return QString();
     }
 
     QString templateName = templateInfo.baseName();
-    kDebug() << "creating project for template:" << templateName << " with VCS:" << info.vcsPluginName;
-
-    QStringList matches = ICore::self()->componentData().dirs()->findAllResources("data", QString("kdevappwizard/templates/%1*").arg(templateName));
-    if (matches.isEmpty()) {
-        kWarning() << "Could not find project template" << templateName;
-        return QString();;
+    QString templateArchive;
+    const QStringList filters = {templateName + QStringLiteral(".*")};
+    const QStringList matchesPaths = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("kdevappwizard/templates/"), QStandardPaths::LocateDirectory);
+    foreach(const QString& matchesPath, matchesPaths) {
+        const QStringList files = QDir(matchesPath).entryList(filters);
+        if(!files.isEmpty()) {
+            templateArchive = matchesPath + files.first();
+        }
     }
-    QString templateArchive = matches.first();
 
-    KUrl dest = info.location;
+    if(templateArchive.isEmpty()) {
+        qWarning() << "Template name does not exist in the template list";
+        return QString();
+    }
+
+    QUrl dest = info.location;
 
     //prepare variable substitution hash
     m_variables.clear();
@@ -233,6 +239,8 @@ QString AppWizardPlugin::createProject(const ApplicationInfo& info)
     m_variables["APPNAMELC"] = info.name.toLower();
     m_variables["APPNAMEID"] = generateIdentifier(info.name);
     m_variables["PROJECTDIR"] = dest.toLocalFile();
+    // backwards compatibility
+    m_variables["dest"] = m_variables["PROJECTDIR"];
     m_variables["PROJECTDIRNAME"] = dest.fileName();
     m_variables["VERSIONCONTROLPLUGIN"] = info.vcsPluginName;
 
@@ -247,8 +255,8 @@ QString AppWizardPlugin::createProject(const ApplicationInfo& info)
     }
     if (arch->open(QIODevice::ReadOnly))
     {
-        KTempDir tmpdir;
-        QString unpackDir = tmpdir.name(); //the default value for all Centralized VCS
+        QTemporaryDir tmpdir;
+        QString unpackDir = tmpdir.path(); //the default value for all Centralized VCS
         IPlugin* plugin = core()->pluginController()->loadPlugin( info.vcsPluginName );
         if( info.vcsPluginName.isEmpty() || ( plugin && plugin->extension<KDevelop::IDistributedVersionControl>() ) )
         {
@@ -260,18 +268,16 @@ QString AppWizardPlugin::createProject(const ApplicationInfo& info)
         }
         else
         {
-            KUrl parentdir = dest;
-            parentdir.cd( ".." );
-            if( !QFileInfo( parentdir.toLocalFile() ).exists() )
-            {
-                QDir::root().mkpath( parentdir.toLocalFile() );
+            QUrl url = KIO::upUrl(dest);
+            if(!QFileInfo(url.toLocalFile()).exists()) {
+                QDir::root().mkpath(url.toLocalFile());
             }
         }
 
         if ( !unpackArchive( arch->directory(), unpackDir ) )
         {
             QString errorMsg = i18n("Could not create new project");
-            vcsError(errorMsg, tmpdir, KUrl(unpackDir));
+            vcsError(errorMsg, tmpdir, QUrl::fromLocalFile(unpackDir));
             return QString();
         }
 
@@ -282,7 +288,7 @@ QString AppWizardPlugin::createProject(const ApplicationInfo& info)
                 // Red Alert, serious program corruption.
                 // This should never happen, the vcs dialog presented a list of vcs
                 // systems and now the chosen system doesn't exist anymore??
-                tmpdir.unlink();
+                tmpdir.remove();
                 return QString();
             }
 
@@ -307,10 +313,10 @@ QString AppWizardPlugin::createProject(const ApplicationInfo& info)
             }
             if (!success) return QString();
         }
-        tmpdir.unlink();
+        tmpdir.remove();
     }else
     {
-        kDebug() << "failed to open template archive";
+        qCDebug(PLUGIN_APPWIZARD) << "failed to open template archive";
         return QString();
     }
 
@@ -325,25 +331,22 @@ QString AppWizardPlugin::createProject(const ApplicationInfo& info)
         projectFileName = it.next();
     }
 
-    kDebug() << "Returning" << projectFileName << QFileInfo( projectFileName ).exists() ;
+    qCDebug(PLUGIN_APPWIZARD) << "Returning" << projectFileName << QFileInfo( projectFileName ).exists() ;
 
     if( ! QFileInfo( projectFileName ).exists() )
     {
-        kDebug() << "creating .kdev4 file";
-        KSharedConfig::Ptr cfg = KSharedConfig::openConfig( projectFileName, KConfig::SimpleConfig );
+        qCDebug(PLUGIN_APPWIZARD) << "creating .kdev4 file";
+        KSharedConfigPtr cfg = KSharedConfig::openConfig( projectFileName, KConfig::SimpleConfig );
         KConfigGroup project = cfg->group( "Project" );
         project.writeEntry( "Name", info.name );
         QString manager = "KDevGenericManager";
 
         QDir d( dest.toLocalFile() );
-        foreach(const KPluginInfo& info, KDevelop::IPluginController::queryExtensionPlugins( "org.kdevelop.IProjectFileManager" ) )
-        {
-            QVariant filter = info.property("X-KDevelop-ProjectFilesFilter");
-            if( filter.isValid() )
-            {
-                if( !d.entryList( filter.toStringList() ).isEmpty() )
-                {
-                    manager = info.pluginName();
+        foreach(const KPluginMetaData& info, ICore::self()->pluginController()->queryExtensionPlugins("org.kdevelop.IProjectFileManager")) {
+            QStringList filter = KPluginMetaData::readStringList(info.rawData(), "X-KDevelop-ProjectFilesFilter");
+            if (!filter.isEmpty()) {
+                if (!d.entryList(filter).isEmpty()) {
+                    manager = info.pluginId();
                     break;
                 }
             }
@@ -352,7 +355,7 @@ QString AppWizardPlugin::createProject(const ApplicationInfo& info)
         project.sync();
         cfg->sync();
         KConfigGroup project2 = cfg->group( "Project" );
-        kDebug() << "kdev4 file contents:" << project2.readEntry("Name", "") << project2.readEntry("Manager", "" );
+        qCDebug(PLUGIN_APPWIZARD) << "kdev4 file contents:" << project2.readEntry("Name", "") << project2.readEntry("Manager", "" );
     }
 
     return projectFileName;
@@ -360,9 +363,9 @@ QString AppWizardPlugin::createProject(const ApplicationInfo& info)
 
 bool AppWizardPlugin::unpackArchive(const KArchiveDirectory *dir, const QString &dest)
 {
-    kDebug() << "unpacking dir:" << dir->name() << "to" << dest;
+    qCDebug(PLUGIN_APPWIZARD) << "unpacking dir:" << dir->name() << "to" << dest;
     const QStringList entries = dir->entries();
-    kDebug() << "entries:" << entries.join(",");
+    qCDebug(PLUGIN_APPWIZARD) << "entries:" << entries.join(",");
 
     //This extra tempdir is needed just for the files files have special names,
     //which may contain macros also files contain content with macros. So the
@@ -370,7 +373,7 @@ bool AppWizardPlugin::unpackArchive(const KArchiveDirectory *dir, const QString
     //and replace the macros is to use a tempdir and copy the file (and
     //replacing while copying). This also allows to easily remove all files, by
     //just unlinking the tempdir
-    KTempDir tdir;
+    QTemporaryDir tdir;
 
     bool ret = true;
 
@@ -391,9 +394,9 @@ bool AppWizardPlugin::unpackArchive(const KArchiveDirectory *dir, const QString
         else if (dir->entry(entry)->isFile())
         {
             const KArchiveFile *file = (KArchiveFile *)dir->entry(entry);
-            file->copyTo(tdir.name());
+            file->copyTo(tdir.path());
             QString destName = dest + '/' + file->name();
-            if (!copyFileAndExpandMacros(QDir::cleanPath(tdir.name()+'/'+file->name()),
+            if (!copyFileAndExpandMacros(QDir::cleanPath(tdir.path()+'/'+file->name()),
                     KMacroExpander::expandMacros(destName, m_variables)))
             {
                 KMessageBox::sorry(0, i18n("The file %1 cannot be created.", dest));
@@ -401,16 +404,18 @@ bool AppWizardPlugin::unpackArchive(const KArchiveDirectory *dir, const QString
             }
         }
     }
-    tdir.unlink();
+    tdir.remove();
     return ret;
 }
 
 bool AppWizardPlugin::copyFileAndExpandMacros(const QString &source, const QString &dest)
 {
-    kDebug() << "copy:" << source << "to" << dest;
-    if( KMimeType::isBinaryData(source) )
+    qCDebug(PLUGIN_APPWIZARD) << "copy:" << source << "to" << dest;
+    QMimeDatabase db;
+    QMimeType mime = db.mimeTypeForFile(source);
+    if( !mime.inherits("text/plain") )
     {
-        KIO::CopyJob* job = KIO::copy( KUrl(source), KUrl(dest), KIO::HideProgressInfo );
+        KIO::CopyJob* job = KIO::copy( QUrl::fromUserInput(source), QUrl::fromUserInput(dest), KIO::HideProgressInfo );
         if( !job->exec() )
         {
             return false;
@@ -433,10 +438,13 @@ bool AppWizardPlugin::copyFileAndExpandMacros(const QString &source, const QStri
                 QString line = input.readLine();
                 output << KMacroExpander::expandMacros(line, m_variables) << "\n";
             }
+#ifndef Q_OS_WIN
             // Preserve file mode...
-            KDE_struct_stat fmode;
-            KDE_fstat(inputFile.handle(), &fmode);
-            ::fchmod(outputFile.handle(), fmode.st_mode);
+            QT_STATBUF statBuf;
+            QT_FSTAT(inputFile.handle(), &statBuf);
+            // Unix only, won't work in Windows, maybe KIO::chmod could be used
+            ::fchmod(outputFile.handle(), statBuf.st_mode);
+#endif
             return true;
         }
         else
@@ -485,7 +493,7 @@ QStringList AppWizardPlugin::supportedMimeTypes() const
 
 QIcon AppWizardPlugin::icon() const
 {
-    return KIcon("project-development-new-template");
+    return QIcon::fromTheme("project-development-new-template");
 }
 
 QString AppWizardPlugin::name() const
