@@ -9,14 +9,17 @@
  *                                                                         *
  ***************************************************************************/
 #include "projectselectionpage.h"
+#include "debug.h"
 
 #include <QDir>
+#include <QFileDialog>
 
-#include <klineedit.h>
-#include <kcomponentdata.h>
-#include <kstandarddirs.h>
-#include <kmessagebox.h>
-#include <kdebug.h>
+#include <KColorScheme>
+#include <KConfigGroup>
+#include <KLineEdit>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KNS3/DownloadDialog>
 
 #include <interfaces/icore.h>
 #include <interfaces/iprojectcontroller.h>
@@ -25,11 +28,8 @@
 
 #include "ui_projectselectionpage.h"
 #include "projecttemplatesmodel.h"
-#include <KColorScheme>
-#include <KFileDialog>
-#include <KNS3/KNewStuffButton>
-#include <KTar>
-#include <KZip>
+
+using namespace KDevelop;
 
 ProjectSelectionPage::ProjectSelectionPage(ProjectTemplatesModel *templatesModel, AppWizardDialog *wizardDialog)
     : AppWizardPageWidget(wizardDialog), m_templatesModel(templatesModel)
@@ -43,37 +43,38 @@ ProjectSelectionPage::ProjectSelectionPage(ProjectTemplatesModel *templatesModel
     ui->locationUrl->setMode(KFile::Directory | KFile::ExistingOnly | KFile::LocalOnly );
     ui->locationUrl->setUrl(KDevelop::ICore::self()->projectController()->projectsBaseDirectory());
 
-    ui->locationValidLabel->setText(QString(" "));
-    
-    connect( ui->locationUrl->lineEdit(), SIGNAL(textEdited(QString)),
-             this, SLOT(urlEdited()));
-    connect( ui->locationUrl, SIGNAL(urlSelected(KUrl)),
-             this, SLOT(urlEdited()));
-    connect( ui->appNameEdit, SIGNAL(textEdited(QString)),
-             this, SLOT(nameChanged()) );
-    
+    ui->locationValidLabel->setText(QStringLiteral(" "));
+
+    connect( ui->locationUrl->lineEdit(), &KLineEdit::textEdited,
+             this, &ProjectSelectionPage::urlEdited);
+    connect( ui->locationUrl, &KUrlRequester::urlSelected,
+             this, &ProjectSelectionPage::urlEdited);
+    connect( ui->appNameEdit, &QLineEdit::textEdited,
+             this, &ProjectSelectionPage::nameChanged );
+
     m_listView = new KDevelop::MultiLevelListView(this);
     m_listView->setLevels(2);
     m_listView->setHeaderLabels(QStringList() << i18n("Category") << i18n("Project Type"));
     m_listView->setModel(templatesModel);
     m_listView->setLastModelsFilterBehavior(KSelectionProxyModel::ChildrenOfExactSelection);
     m_listView->setContentsMargins(0, 0, 0, 0);
-    connect (m_listView, SIGNAL(currentIndexChanged(QModelIndex,QModelIndex)), SLOT(typeChanged(QModelIndex)));
+    connect (m_listView, &MultiLevelListView::currentIndexChanged, this, &ProjectSelectionPage::typeChanged);
     ui->gridLayout->addWidget(m_listView, 0, 0, 1, 1);
     typeChanged(m_listView->currentIndex());
-    
-    connect( ui->templateType, SIGNAL(currentIndexChanged(int)),
-             this, SLOT(templateChanged(int)) );
-    
-    KNS3::Button* knsButton = new KNS3::Button(i18n("Get More Templates"), "kdevappwizard.knsrc", m_listView);
-    connect (knsButton, SIGNAL(dialogFinished(KNS3::Entry::List)), 
-             this, SLOT(templatesDownloaded(KNS3::Entry::List)));
-    m_listView->addWidget(0, knsButton);
-    
-    KPushButton* loadButton = new KPushButton(m_listView);
+
+    connect( ui->templateType, static_cast<void(QComboBox::*)(int)>(&QComboBox::currentIndexChanged),
+             this, &ProjectSelectionPage::templateChanged );
+
+    QPushButton* getMoreButton = new QPushButton(i18n("Get More Templates"), m_listView);
+    getMoreButton->setIcon(QIcon::fromTheme("get-hot-new-stuff"));
+    connect (getMoreButton, &QPushButton::clicked,
+             this, &ProjectSelectionPage::moreTemplatesClicked);
+    m_listView->addWidget(0, getMoreButton);
+
+    QPushButton* loadButton = new QPushButton(m_listView);
     loadButton->setText(i18n("Load Template From File"));
-    loadButton->setIcon(KIcon("application-x-archive"));
-    connect (loadButton, SIGNAL(clicked(bool)), this, SLOT(loadFileClicked()));
+    loadButton->setIcon(QIcon::fromTheme("application-x-archive"));
+    connect (loadButton, &QPushButton::clicked, this, &ProjectSelectionPage::loadFileClicked);
     m_listView->addWidget(0, loadButton);
 
     m_wizardDialog = wizardDialog;
@@ -95,7 +96,7 @@ void ProjectSelectionPage::typeChanged(const QModelIndex& idx)
 {
     if (!idx.model())
     {
-        kDebug() << "Index with no model";
+        qCDebug(PLUGIN_APPWIZARD) << "Index with no model";
         return;
     }
     int children = idx.model()->rowCount(idx);
@@ -121,7 +122,7 @@ void ProjectSelectionPage::itemChanged( const QModelIndex& current)
 {
     QString picPath = current.data( KDevelop::TemplatesModel::IconNameRole ).toString();
     if( picPath.isEmpty() ) {
-        KIcon icon("kdevelop");
+        QIcon icon("kdevelop");
         ui->icon->setPixmap(icon.pixmap(128, 128));
         ui->icon->setFixedHeight(128);
     } else {
@@ -133,7 +134,7 @@ void ProjectSelectionPage::itemChanged( const QModelIndex& current)
     const QVariant headerData = ui->templateType->isVisible()
                                     ? current.parent().data()
                                     : current.data();
-    ui->header->setText(QString("<h1>%1</h1>").arg(headerData.toString().trimmed()));
+    ui->header->setText(QStringLiteral("<h1>%1</h1>").arg(headerData.toString().trimmed()));
     ui->description->setText(current.data(KDevelop::TemplatesModel::CommentRole).toString());
     validateData();
 
@@ -149,11 +150,11 @@ QString ProjectSelectionPage::selectedTemplate()
         return "";
 }
 
-KUrl ProjectSelectionPage::location()
+QUrl ProjectSelectionPage::location()
 {
-    KUrl tUrl = ui->locationUrl->url();
-    tUrl.addPath( encodedAppName() );
-    return tUrl;
+    QUrl url = ui->locationUrl->url().adjusted(QUrl::StripTrailingSlash);
+    url.setPath(url.path() + '/' + encodedAppName());
+    return url;
 }
 
 QString ProjectSelectionPage::appName()
@@ -176,7 +177,7 @@ void setForeground(QLabel* label, KColorScheme::ForegroundRole role)
 
 void ProjectSelectionPage::validateData()
 {
-    KUrl url = ui->locationUrl->url();
+    QUrl url = ui->locationUrl->url();
     if( !url.isLocalFile() || url.isEmpty() )
     {
         ui->locationValidLabel->setText( i18n("Invalid location") );
@@ -216,7 +217,7 @@ void ProjectSelectionPage::validateData()
         }
     }
 
-    QDir tDir(url.toLocalFile( KUrl::RemoveTrailingSlash ));
+    QDir tDir(url.toLocalFile());
     while (!tDir.exists() && !tDir.isRoot()) {
         if (!tDir.cdUp()) {
             break;
@@ -239,7 +240,7 @@ void ProjectSelectionPage::validateData()
     QStandardItem* item = getCurrentItem();
     if( item && !item->hasChildren() )
     {
-        ui->locationValidLabel->setText( QString(" ") );
+        ui->locationValidLabel->setText( QStringLiteral(" ") );
         setForeground(ui->locationValidLabel, KColorScheme::NormalText);
         emit valid();
     } else
@@ -251,14 +252,16 @@ void ProjectSelectionPage::validateData()
     }
 
     // Check for non-empty target directory. Not an error, but need to display a warning.
-    url.addPath( encodedAppName() );
-    QFileInfo fi( url.toLocalFile( KUrl::RemoveTrailingSlash ) );
+    url.setPath( url.path() + '/' + encodedAppName() );
+    QFileInfo fi( url.toLocalFile() );
     if( fi.exists() && fi.isDir() )
     {
         if( !QDir( fi.absoluteFilePath()).entryList( QDir::NoDotAndDotDot | QDir::AllEntries ).isEmpty() )
         {
-            ui->locationValidLabel->setText( i18n("Path already exists and contains files") );
+            ui->locationValidLabel->setText( i18n("Path already exists and contains files. Open it as a project.") );
             setForeground(ui->locationValidLabel, KColorScheme::NegativeText);
+            emit invalid();
+            return;
         }
     }
 }
@@ -295,7 +298,7 @@ QStandardItem* ProjectSelectionPage::getCurrentItem() const
 
 bool ProjectSelectionPage::shouldContinue()
 {
-    QFileInfo fi(location().toLocalFile(KUrl::RemoveTrailingSlash));
+    QFileInfo fi(location().toLocalFile());
     if (fi.exists() && fi.isDir())
     {
         if (!QDir(fi.absoluteFilePath()).entryList(QDir::NoDotAndDotDot | QDir::AllEntries).isEmpty())
@@ -311,8 +314,7 @@ bool ProjectSelectionPage::shouldContinue()
 void ProjectSelectionPage::loadFileClicked()
 {
     QString filter = "application/x-desktop application/x-bzip-compressed-tar application/zip";
-    QString fileName = KFileDialog::getOpenFileName(KUrl("kfiledialog:///kdevapptemplate"), filter, this);
-
+    const QString fileName = QFileDialog::getOpenFileName(this, i18n("Load Template From File"), QString(), filter);
     if (!fileName.isEmpty())
     {
         QString destination = m_templatesModel->loadTemplateFile(fileName);
@@ -325,8 +327,12 @@ void ProjectSelectionPage::loadFileClicked()
     }
 }
 
-void ProjectSelectionPage::templatesDownloaded (const KNS3::Entry::List& entries)
+void ProjectSelectionPage::moreTemplatesClicked()
 {
+    KNS3::DownloadDialog dialog("kdevappwizard.knsrc", this);
+    dialog.exec();
+
+    auto entries = dialog.changedEntries();
     if (entries.isEmpty()) {
         return;
     }
@@ -362,5 +368,3 @@ void ProjectSelectionPage::setCurrentTemplate (const QString& fileName)
         ui->templateType->setCurrentIndex(indexes.at(2).row());
     }
 }
-
-#include "projectselectionpage.moc"
