@@ -11,7 +11,7 @@
 #define _PROJECTSELECTIONPAGE_H_
 
 #include "appwizardpagewidget.h"
-#include <knewstuff3/entry.h>
+#include "appwizarddialog.h"
 
 namespace KDevelop
 {
@@ -25,21 +25,21 @@ class ProjectSelectionPage;
 class ProjectTemplatesModel;
 class QModelIndex;
 class QStandardItem;
-class KUrl;
+class QUrl;
 
 class ProjectSelectionPage : public AppWizardPageWidget {
 Q_OBJECT
 public:
-    explicit ProjectSelectionPage(ProjectTemplatesModel *templatesModel, QWidget *parent = 0);
+    explicit ProjectSelectionPage(ProjectTemplatesModel *templatesModel, AppWizardDialog *wizardDialog);
     ~ProjectSelectionPage();
 
-    bool shouldContinue();
+    bool shouldContinue() override;
 
     QString selectedTemplate();
     QString appName();
-    KUrl location();
+    QUrl location();
 signals:
-    void locationChanged( const KUrl& );
+    void locationChanged( const QUrl& );
     void valid();
     void invalid();
 private slots:
@@ -51,7 +51,7 @@ private slots:
     void templateChanged(int);
 
     void loadFileClicked();
-    void templatesDownloaded (const KNS3::Entry::List& entries);
+    void moreTemplatesClicked();
 
 
 private:
@@ -62,7 +62,7 @@ private:
     Ui::ProjectSelectionPage *ui;
     KDevelop::MultiLevelListView* m_listView;
     ProjectTemplatesModel *m_templatesModel;
+    AppWizardDialog *m_wizardDialog;
 };
 
 #endif
-
