@@ -21,8 +21,9 @@
 #ifndef KDEVPLATFORM_PLUGIN_PROJECTVCSPAGE_H
 #define KDEVPLATFORM_PLUGIN_PROJECTVCSPAGE_H
 
-#include "appwizardpagewidget.h"
 #include <QMap>
+
+#include "appwizardpagewidget.h"
 #include <vcs/interfaces/ibasicversioncontrol.h>
 
 namespace Ui
@@ -36,25 +37,25 @@ class IPluginController;
 class VcsImportMetadataWidget;
 }
 
-class KUrl;
+class QUrl;
 
 class ProjectVcsPage : public AppWizardPageWidget
 {
     Q_OBJECT
 public:
-    ProjectVcsPage( KDevelop::IPluginController*, QWidget* parent = 0 );
+    explicit ProjectVcsPage( KDevelop::IPluginController*, QWidget* parent = 0 );
     ~ProjectVcsPage();
-    bool shouldContinue();
+    bool shouldContinue() override;
 signals:
     void valid();
     void invalid();
 public slots:
-    void setSourceLocation( const KUrl& );
+    void setSourceLocation( const QUrl& );
     void vcsTypeChanged(int);
     void validateData();
 public:
     QString pluginName() const;
-    KUrl source() const;
+    QUrl source() const;
     KDevelop::VcsLocation destination() const;
     QString commitMessage() const;
 private:
