@@ -24,13 +24,15 @@
 #include <interfaces/contextmenuextension.h>
 
 #include <QtCore/QVariant>
+#include <QLoggingCategory>
+Q_DECLARE_LOGGING_CATEGORY(PLUGIN_CODEUTILS)
 
 class CodeUtilsPlugin : public KDevelop::IPlugin
 {
     Q_OBJECT
 
 public:
-    CodeUtilsPlugin( QObject *parent, const QVariantList & = QVariantList() );
+    explicit CodeUtilsPlugin( QObject *parent, const QVariantList & = QVariantList() );
     ~CodeUtilsPlugin();
 
 private slots:
