@@ -22,12 +22,12 @@
 #ifndef KDEVPLATFORM_PLUGIN_BROWSEMANAGER_H
 #define KDEVPLATFORM_PLUGIN_BROWSEMANAGER_H
 
-#include <QObject>
 #include <QCursor>
+#include <QEvent>
 #include <QMap>
+#include <QObject>
 #include <QPointer>
-#include <qevent.h>
-#include <ktexteditor/cursor.h>
+#include <KTextEditor/Cursor>
 
 
 class QWidget;
@@ -41,16 +41,16 @@ namespace KDevelop {
     class IDocument;
 }
 
-class EditorViewWatcher : QObject {
+class EditorViewWatcher : public QObject {
     Q_OBJECT
 public:
     ///@param sameWindow If this is true, only views that are child of the same window as the given widget are registered
-    EditorViewWatcher(QObject* parent = 0);
+    explicit EditorViewWatcher(QObject* parent = 0);
     QList<KTextEditor::View*> allViews();
 private:
     ///Called for every added view. Reimplement this to catch them.
     virtual void viewAdded(KTextEditor::View*);
-    
+
 private slots:
     void viewDestroyed(QObject* view);
     void viewCreated(KTextEditor::Document*, KTextEditor::View*);
@@ -69,7 +69,7 @@ class ContextBrowserPlugin;
 class BrowseManager : public QObject {
     Q_OBJECT
     public:
-        BrowseManager(ContextBrowserPlugin* controller);
+        explicit BrowseManager(ContextBrowserPlugin* controller);
     Q_SIGNALS:
         //Emitted when browsing was started using the magic-modifier
         void startDelayedBrowsing(KTextEditor::View* view);
@@ -83,18 +83,18 @@ class BrowseManager : public QObject {
         void viewAdded(KTextEditor::View* view);
         class Watcher : public EditorViewWatcher {
             public:
-                Watcher(BrowseManager* manager);
-                virtual void viewAdded(KTextEditor::View*);
+                explicit Watcher(BrowseManager* manager);
+                virtual void viewAdded(KTextEditor::View*) override;
             private:
                 BrowseManager* m_manager;
         };
-        
+
         void resetChangedCursor();
         void setHandCursor(QWidget* widget);
-        
+
         //Installs/uninstalls the event-filter
         void applyEventFilter(QWidget* object, bool install);
-        virtual bool eventFilter(QObject * watched, QEvent * event) ;
+        virtual bool eventFilter(QObject * watched, QEvent * event) override ;
         ContextBrowserPlugin* m_plugin;
         bool m_browsing;
         int m_browsingByKey; //Whether the browsing was started because of a key
