@@ -27,12 +27,14 @@
 #include <QSet>
 #include <QMap>
 #include <QList>
+#include <QUrl>
+#include <QPointer>
 
+#include <KTextEditor/TextHintInterface>
 #include <interfaces/iplugin.h>
 #include <language/duchain/duchainpointer.h>
-#include <language/editor/simplecursor.h>
 #include <language/duchain/declaration.h>
-#include <KUrl>
+#include <language/duchain/indexedducontext.h>
 #include <language/editor/persistentmovingrange.h>
 #include <language/interfaces/iquickopen.h>
 #include <language/editor/documentcursor.h>
@@ -49,7 +51,6 @@ namespace Sublime {
 
 namespace KDevelop {
   class IDocument;
-  class ILanguage;
   class ParseJob;
   class DUContext;
   class TopDUContext;
@@ -85,27 +86,27 @@ class ContextBrowserPlugin : public KDevelop::IPlugin, public KDevelop::IContext
     Q_OBJECT
     Q_INTERFACES( KDevelop::IContextBrowser )
   public:
-    ContextBrowserPlugin(QObject *parent, const QVariantList & = QVariantList() );
+    explicit ContextBrowserPlugin(QObject *parent, const QVariantList & = QVariantList() );
     virtual ~ContextBrowserPlugin();
 
-    virtual void unload();
+    virtual void unload() override;
 
     void registerToolView(ContextBrowserView* view);
     void unRegisterToolView(ContextBrowserView* view);
     
-    virtual KDevelop::ContextMenuExtension contextMenuExtension(KDevelop::Context*);
+    virtual KDevelop::ContextMenuExtension contextMenuExtension(KDevelop::Context*) override;
 
-    virtual KXMLGUIClient* createGUIForMainWindow( Sublime::MainWindow* window );
+    virtual KXMLGUIClient* createGUIForMainWindow( Sublime::MainWindow* window ) override;
 
     ///duchain must be locked
     ///@param force When this is true, the history-entry is added, no matter whether the context is "interesting" or not
-    void updateHistory(KDevelop::DUContext* context, const KDevelop::SimpleCursor& cursorPosition,
+    void updateHistory(KDevelop::DUContext* context, const KTextEditor::Cursor& cursorPosition,
                        bool force = false);
 
     void updateDeclarationListBox(KDevelop::DUContext* context);
     void setAllowBrowsing(bool allow);
 
-    virtual void showUses(const KDevelop::DeclarationPointer& declaration);
+    virtual void showUses(const KDevelop::DeclarationPointer& declaration) override;
 
   public Q_SLOTS:
     void showUsesDelayed(const KDevelop::DeclarationPointer& declaration);
@@ -128,14 +129,15 @@ class ContextBrowserPlugin : public KDevelop::IPlugin, public KDevelop::IContext
     void viewCreated( KTextEditor::Document* , KTextEditor::View* );
     void updateViews();
 
-    void textHintRequested(const KTextEditor::Cursor&, QString&);
-
     void hideToolTip();
     void findUses();
     
-    void textInserted(KTextEditor::Document*, KTextEditor::Range);
+    void textInserted(KTextEditor::Document* doc, const KTextEditor::Cursor& cursor, const QString& text);
     void selectionChanged(KTextEditor::View*);
 
+    void historyNext();
+    void historyPrevious();
+
   private slots:
     // history browsing
     void documentJumpPerformed( KDevelop::IDocument* newDocument,
@@ -143,8 +145,6 @@ class ContextBrowserPlugin : public KDevelop::IPlugin, public KDevelop::IContext
                                 KDevelop::IDocument* previousDocument,
                                 const KTextEditor::Cursor& previousCursor);
 
-    void historyNext();
-    void historyPrevious();
     void nextMenuAboutToShow();
     void previousMenuAboutToShow();
     void actionTriggered();
@@ -159,7 +159,7 @@ class ContextBrowserPlugin : public KDevelop::IPlugin, public KDevelop::IContext
   private:
     QWidget* toolbarWidgetForMainWindow(Sublime::MainWindow* window);
     virtual void createActionsForMainWindow(Sublime::MainWindow* window, QString& xmlFile,
-                                            KActionCollection& actions);
+                                            KActionCollection& actions) override;
     void switchUse(bool forward);
     void clearMouseHover();
 
@@ -168,11 +168,11 @@ class ContextBrowserPlugin : public KDevelop::IPlugin, public KDevelop::IContext
     /** helper for updateBrowserView().
      *  Tries to find a 'specialLanguageObject' (eg macro) in @p view under cursor @c.
      *  If found returns true and sets @p pickedLanguage to the language this object belongs to */
-    KDevelop::Declaration* findDeclaration(KTextEditor::View* view, const KDevelop::SimpleCursor&, bool mouseHighlight);
+    KDevelop::Declaration* findDeclaration(KTextEditor::View* view, const KTextEditor::Cursor&, bool mouseHighlight);
     void updateForView(KTextEditor::View* view);
 
     // history browsing
-    bool isPreviousEntry(KDevelop::DUContext*, const KDevelop::SimpleCursor& cursor) const;
+    bool isPreviousEntry(KDevelop::DUContext*, const KTextEditor::Cursor& cursor) const;
     QString actionTextFor(int historyIndex) const;
     void updateButtonState();
     void openDocument(int historyIndex);
@@ -208,8 +208,8 @@ class ContextBrowserPlugin : public KDevelop::IPlugin, public KDevelop::IContext
     KDevelop::IndexedDeclaration m_useDeclaration;
     KDevelop::IndexedDeclaration m_lastHighlightedDeclaration;
 
-    KUrl m_mouseHoverDocument;
-    KDevelop::SimpleCursor m_mouseHoverCursor;
+    QUrl m_mouseHoverDocument;
+    KTextEditor::Cursor m_mouseHoverCursor;
     ContextBrowserViewFactory* m_viewFactory;
     QPointer<QWidget> m_currentToolTip;
     QPointer<QWidget> m_currentNavigationWidget;
@@ -227,17 +227,17 @@ class ContextBrowserPlugin : public KDevelop::IPlugin, public KDevelop::IContext
     // history browsing
     struct HistoryEntry {
         //Duchain must be locked
-        HistoryEntry(KDevelop::IndexedDUContext ctx = KDevelop::IndexedDUContext(), const KDevelop::SimpleCursor& cursorPosition = KDevelop::SimpleCursor());
+        HistoryEntry(KDevelop::IndexedDUContext ctx = KDevelop::IndexedDUContext(), const KTextEditor::Cursor& cursorPosition = KTextEditor::Cursor());
         HistoryEntry(KDevelop::DocumentCursor pos);
         //Duchain must be locked
-        void setCursorPosition(const KDevelop::SimpleCursor& cursorPosition);
+        void setCursorPosition(const KTextEditor::Cursor& cursorPosition);
 
         //Duchain does not need to be locked
         KDevelop::DocumentCursor computePosition() const;
 
         KDevelop::IndexedDUContext context;
         KDevelop::DocumentCursor absoluteCursorPosition;
-        KDevelop::SimpleCursor relativeCursorPosition; //Cursor position relative to the start line of the context
+        KTextEditor::Cursor relativeCursorPosition; //Cursor position relative to the start line of the context
         QString alternativeString;
     };
 
@@ -252,6 +252,18 @@ class ContextBrowserPlugin : public KDevelop::IPlugin, public KDevelop::IContext
     //Used to not record jumps triggered by the context-browser as history entries
     QPointer<QWidget> m_focusBackWidget;
     int m_nextHistoryIndex;
+
+    friend class ContextBrowserHintProvider;
+};
+
+class ContextBrowserHintProvider : public KTextEditor::TextHintProvider
+{
+public:
+  explicit ContextBrowserHintProvider(ContextBrowserPlugin* plugin);
+  virtual QString textHint(KTextEditor::View* view, const KTextEditor::Cursor& position) override;
+
+private:
+  ContextBrowserPlugin* m_plugin;
 };
 
 #endif // KDEVPLATFORM_PLUGIN_CONTEXTBROWSERPLUGIN_H
