@@ -12,9 +12,9 @@
 #define KDEVPLATFORM_PLUGIN_CHECKOUTDIALOG_H
 
 #include <QDialog>
+#include <QUrl>
 
 #include <KJob>
-#include <KUrl>
 
 #include "ui_checkoutdialog.h"
 
@@ -24,7 +24,7 @@ class CvsPlugin;
  * Allows the user to define from where to checkout
  * @author Robert Gruber <rgruber@users.sourceforge.net>
  */
-class CheckoutDialog : public KDialog, private Ui::CheckoutDialogBase
+class CheckoutDialog : public QDialog, private Ui::CheckoutDialogBase
 {
     Q_OBJECT
 public:
@@ -32,7 +32,7 @@ public:
     virtual ~CheckoutDialog();
 
 public slots:
-    virtual void accept();
+    virtual void accept() override;
     void jobFinished(KJob* job);
 
 private:
