@@ -8,8 +8,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef CVSDIFFJOB_H
-#define CVSDIFFJOB_H
+#ifndef KDEVPLATFORM_PLUGIN_CVSDIFFJOB_H
+#define KDEVPLATFORM_PLUGIN_CVSDIFFJOB_H
 
 #include "cvsjob.h"
 
@@ -22,13 +22,17 @@ class CvsDiffJob : public CvsJob
 {
     Q_OBJECT
 public:
-    CvsDiffJob(KDevelop::IPlugin* parent);
+    explicit CvsDiffJob(KDevelop::IPlugin* parent, KDevelop::OutputJob::OutputJobVerbosity verbosity = KDevelop::OutputJob::Verbose);
     virtual ~CvsDiffJob();
 
     // Begin:  KDevelop::VcsJob
-    virtual QVariant fetchResults();
-    virtual KDevelop::VcsJob::JobStatus status() const;
+    virtual QVariant fetchResults() override;
     // End:  KDevelop::VcsJob
+
+private:
+    // Begin: KDevelop::DVcsJob
+    virtual void slotProcessError(QProcess::ProcessError error) override;
+    // End: KDevelop::DVcsJob
 };
 
 #endif
