@@ -12,13 +12,12 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef CVSJOB_H
-#define CVSJOB_H
+#ifndef KDEVPLATFORM_PLUGIN_CVSJOB_H
+#define KDEVPLATFORM_PLUGIN_CVSJOB_H
 
 
 #include <QStringList>
 #include <KProcess>
-
 #include <vcs/dvcs/dvcsjob.h>
 
 /**
@@ -30,9 +29,11 @@ class CvsJob : public KDevelop::DVcsJob
 {
     Q_OBJECT
 public:
-    CvsJob(const QDir& workingDir, KDevelop::IPlugin* parent=0, KDevelop::OutputJob::OutputJobVerbosity verbosity = KDevelop::OutputJob::Verbose);
+    explicit CvsJob(const QDir& workingDir, KDevelop::IPlugin* parent=0, KDevelop::OutputJob::OutputJobVerbosity verbosity = KDevelop::OutputJob::Verbose);
 
-    KDE_DEPRECATED CvsJob(KDevelop::IPlugin* parent = 0, KDevelop::OutputJob::OutputJobVerbosity verbosity = KDevelop::OutputJob::Verbose);
+    explicit CvsJob(KDevelop::IPlugin* parent = 0, KDevelop::OutputJob::OutputJobVerbosity verbosity = KDevelop::OutputJob::Verbose);
+
+    virtual ~CvsJob();
 
     /**
      * @return The command that is executed when calling start()
@@ -40,7 +41,7 @@ public:
     QString cvsCommand();
     void clear();
     void setDirectory(const QString& directory);
-    KDE_DEPRECATED QString getDirectory();
+    QString getDirectory();
 
     void setRSH(const QString& rsh);
     void setServer(const QString& server);
@@ -50,7 +51,7 @@ public:
      * @note Default communication mode is KProcess::AllOutput.
      * @see Use setCommunicationMode() to override the default communication mode.
      */
-    virtual void start();
+    virtual void start() override;
 
 private:
     class CvsJobPrivate* const d;
