@@ -20,11 +20,11 @@ class CvsLogJob : public CvsJob
 {
     Q_OBJECT
 public:
-    CvsLogJob(KDevelop::IPlugin* parent, KDevelop::OutputJob::OutputJobVerbosity verbosity = KDevelop::OutputJob::Verbose);
+    explicit CvsLogJob(KDevelop::IPlugin* parent, KDevelop::OutputJob::OutputJobVerbosity verbosity = KDevelop::OutputJob::Verbose);
     virtual ~CvsLogJob();
 
     // Begin:  KDevelop::VcsJob
-    virtual QVariant fetchResults();
+    virtual QVariant fetchResults() override;
     // End:  KDevelop::VcsJob
 
 private:
