@@ -10,22 +10,20 @@
 
 #include "cvsplugin.h"
 
-#include <QtGui/QAction>
-#include <QtGui/QMenu>
+#include <QAction>
+#include <QMenu>
 #include <QtCore/QFileInfo>
 #include <QtCore/QDir>
 
 #include <KParts/PartManager>
 #include <KParts/Part>
+#include <KParts/ReadOnlyPart>
 #include <KPluginFactory>
 #include <KPluginLoader>
 #include <KActionCollection>
 #include <KMessageBox>
-#include <KUrl>
-#include <KAction>
 #include <KAboutData>
-
-#include <memory>
+#include <KLocalizedString>
 
 #include <interfaces/iproject.h>
 #include <project/projectmodel.h>
@@ -46,24 +44,26 @@
 #include "checkoutdialog.h"
 #include "importdialog.h"
 #include "importmetadatawidget.h"
+#include "debug.h"
 #include <language/interfaces/editorcontext.h>
 #include <vcs/vcspluginhelper.h>
 #include <vcs/widgets/standardvcslocationwidget.h>
 
+Q_LOGGING_CATEGORY(PLUGIN_CVS, "kdevplatform.plugins.cvs")
 K_PLUGIN_FACTORY(KDevCvsFactory, registerPlugin<CvsPlugin>();)
-K_EXPORT_PLUGIN(KDevCvsFactory(KAboutData("kdevcvs", "kdevcvs", ki18n("CVS"), "0.1", ki18n("Support for CVS version control system"), KAboutData::License_GPL)))
+// K_EXPORT_PLUGIN(KDevCvsFactory(KAboutData("kdevcvs", "kdevcvs", ki18n("CVS"), "0.1", ki18n("Support for CVS version control system"), KAboutData::License_GPL)))
 
 class KDevCvsViewFactory: public KDevelop::IToolViewFactory
 {
 public:
     KDevCvsViewFactory(CvsPlugin *plugin): m_plugin(plugin) {}
-    virtual QWidget* create(QWidget *parent = 0) {
+    virtual QWidget* create(QWidget *parent = 0) override {
         return new CvsMainView(m_plugin, parent);
     }
-    virtual Qt::DockWidgetArea defaultPosition() {
+    virtual Qt::DockWidgetArea defaultPosition() override {
         return Qt::BottomDockWidgetArea;
     }
-    virtual QString id() const {
+    virtual QString id() const override {
         return "org.kdevelop.CVSView";
     }
 
@@ -81,11 +81,11 @@ public:
 
     KDevCvsViewFactory* m_factory;
     QPointer<CvsProxy> m_proxy;
-    std::auto_ptr<KDevelop::VcsPluginHelper> m_common;
+    QScopedPointer<KDevelop::VcsPluginHelper> m_common;
 };
 
 CvsPlugin::CvsPlugin(QObject *parent, const QVariantList &)
-        : KDevelop::IPlugin(KDevCvsFactory::componentData(), parent)
+        : KDevelop::IPlugin("kdevcvs", parent)
         , d(new CvsPluginPrivate(this))
 {
     KDEV_USE_EXTENSION_INTERFACE(KDevelop::IBasicVersionControl)
@@ -115,22 +115,22 @@ CvsProxy* CvsPlugin::proxy()
 
 void CvsPlugin::setupActions()
 {
-    KAction *action;
+    QAction *action;
 
     action = actionCollection()->addAction("cvs_import");
     action->setText(i18n("Import Directory..."));
-    connect(action, SIGNAL(triggered(bool)), this, SLOT(slotImport()));
+    connect(action, &QAction::triggered, this, &CvsPlugin::slotImport);
 
     action = actionCollection()->addAction("cvs_checkout");
     action->setText(i18n("Checkout..."));
-    connect(action, SIGNAL(triggered(bool)), this, SLOT(slotCheckout()));
+    connect(action, &QAction::triggered, this, &CvsPlugin::slotCheckout);
 
     action = actionCollection()->addAction("cvs_status");
     action->setText(i18n("Status..."));
-    connect(action, SIGNAL(triggered(bool)), this, SLOT(slotStatus()));
+    connect(action, &QAction::triggered, this, &CvsPlugin::slotStatus);
 }
 
-const KUrl CvsPlugin::urlFocusedDocument() const
+const QUrl CvsPlugin::urlFocusedDocument() const
 {
     KParts::ReadOnlyPart *plugin =
         dynamic_cast<KParts::ReadOnlyPart*>(core()->partController()->activePart());
@@ -139,13 +139,13 @@ const KUrl CvsPlugin::urlFocusedDocument() const
             return plugin->url();
         }
     }
-    return KUrl();
+    return QUrl();
 }
 
 
 void CvsPlugin::slotImport()
 {
-    KUrl url = urlFocusedDocument();
+    QUrl url = urlFocusedDocument();
 
     ImportDialog dlg(this, url);
     dlg.exec();
@@ -162,11 +162,11 @@ void CvsPlugin::slotCheckout()
 
 void CvsPlugin::slotStatus()
 {
-    KUrl url = urlFocusedDocument();
-    KUrl::List urls;
+    QUrl url = urlFocusedDocument();
+    QList<QUrl> urls;
     urls << url;
 
-    KDevelop::VcsJob* j = status(url, KDevelop::IBasicVersionControl::Recursive);
+    KDevelop::VcsJob* j = status(urls, KDevelop::IBasicVersionControl::Recursive);
     CvsJob* job = dynamic_cast<CvsJob*>(j);
     if (job) {
         CvsGenericOutputView* view = new CvsGenericOutputView(job);
@@ -179,17 +179,17 @@ void CvsPlugin::slotStatus()
 KDevelop::ContextMenuExtension CvsPlugin::contextMenuExtension(KDevelop::Context* context)
 {
     d->m_common->setupFromContext(context);
-    KUrl::List const & ctxUrlList = d->m_common->contextUrlList();
+    QList<QUrl> const & ctxUrlList = d->m_common->contextUrlList();
 
     bool hasVersionControlledEntries = false;
-    foreach(const KUrl &url, ctxUrlList) {
+    foreach(const QUrl &url, ctxUrlList) {
         if (d->m_proxy->isValidDirectory(url)) {
             hasVersionControlledEntries = true;
             break;
         }
     }
 
-    kDebug() << "version controlled?" << hasVersionControlledEntries;
+    qCDebug(PLUGIN_CVS) << "version controlled?" << hasVersionControlledEntries;
 
     if (!hasVersionControlledEntries)
         return IPlugin::contextMenuExtension(context);
@@ -197,18 +197,18 @@ KDevelop::ContextMenuExtension CvsPlugin::contextMenuExtension(KDevelop::Context
     QMenu* menu = d->m_common->commonActions();
     menu->addSeparator();
 
-    KAction *action;
+    QAction *action;
     // Just add actions which are not covered by the cvscommon plugin
-    action = new KAction(i18n("Edit"), this);
-    connect(action, SIGNAL(triggered()), this, SLOT(ctxEdit()));
+    action = new QAction(i18n("Edit"), this);
+    connect(action, &QAction::triggered, this, &CvsPlugin::ctxEdit);
     menu->addAction(action);
 
-    action = new KAction(i18n("Unedit"), this);
-    connect(action, SIGNAL(triggered()), this, SLOT(ctxUnEdit()));
+    action = new QAction(i18n("Unedit"), this);
+    connect(action, &QAction::triggered, this, &CvsPlugin::ctxUnEdit);
     menu->addAction(action);
 
-    action = new KAction(i18n("Show Editors"), this);
-    connect(action, SIGNAL(triggered()), this, SLOT(ctxEditors()));
+    action = new QAction(i18n("Show Editors"), this);
+    connect(action, &QAction::triggered, this, &CvsPlugin::ctxEditors);
     menu->addAction(action);
 
     KDevelop::ContextMenuExtension menuExt;
@@ -219,47 +219,47 @@ KDevelop::ContextMenuExtension CvsPlugin::contextMenuExtension(KDevelop::Context
 
 void CvsPlugin::ctxEdit()
 {
-    KUrl::List const & urls = d->m_common->contextUrlList();
+    QList<QUrl> const & urls = d->m_common->contextUrlList();
     Q_ASSERT(!urls.empty());
 
     KDevelop::VcsJob* j = edit(urls.front());
     CvsJob* job = dynamic_cast<CvsJob*>(j);
     if (job) {
-        connect(job, SIGNAL(result(KJob*)),
-                this, SIGNAL(jobFinished(KJob*)));
+        connect(job, &CvsJob::result,
+                this, &CvsPlugin::jobFinished);
         KDevelop::ICore::self()->runController()->registerJob(job);
     }
 }
 
 void CvsPlugin::ctxUnEdit()
 {
-    KUrl::List const & urls = d->m_common->contextUrlList();
+    QList<QUrl> const & urls = d->m_common->contextUrlList();
     Q_ASSERT(!urls.empty());
 
     KDevelop::VcsJob* j = unedit(urls.front());
     CvsJob* job = dynamic_cast<CvsJob*>(j);
     if (job) {
-        connect(job, SIGNAL(result(KJob*)),
-                this, SIGNAL(jobFinished(KJob*)));
+        connect(job, &CvsJob::result,
+                this, &CvsPlugin::jobFinished);
         KDevelop::ICore::self()->runController()->registerJob(job);
     }
 }
 
 void CvsPlugin::ctxEditors()
 {
-    KUrl::List const & urls = d->m_common->contextUrlList();
+    QList<QUrl> const & urls = d->m_common->contextUrlList();
     Q_ASSERT(!urls.empty());
 
-    CvsJob* job = d->m_proxy->editors(findWorkingDir(urls.front().toLocalFile()),
+    CvsJob* job = d->m_proxy->editors(findWorkingDir(urls.front()),
                                       urls);
     if (job) {
         KDevelop::ICore::self()->runController()->registerJob(job);
-        EditorsView* view = new EditorsView(this, job);
+        EditorsView* view = new EditorsView(job);
         emit addNewTabToMainView(view, i18n("Editors"));
     }
 }
 
-QString CvsPlugin::findWorkingDir(const KUrl& location)
+QString CvsPlugin::findWorkingDir(const QUrl& location)
 {
     QFileInfo fileInfo(location.toLocalFile());
 
@@ -274,85 +274,85 @@ QString CvsPlugin::findWorkingDir(const KUrl& location)
 
 // Begin:  KDevelop::IBasicVersionControl
 
-bool CvsPlugin::isVersionControlled(const KUrl & localLocation)
+bool CvsPlugin::isVersionControlled(const QUrl & localLocation)
 {
     return d->m_proxy->isVersionControlled(localLocation);
 }
 
-KDevelop::VcsJob * CvsPlugin::repositoryLocation(const KUrl & localLocation)
+KDevelop::VcsJob * CvsPlugin::repositoryLocation(const QUrl & localLocation)
 {
     Q_UNUSED(localLocation);
     return NULL;
 }
 
-KDevelop::VcsJob * CvsPlugin::add(const KUrl::List & localLocations, KDevelop::IBasicVersionControl::RecursionMode recursion)
+KDevelop::VcsJob * CvsPlugin::add(const QList<QUrl> & localLocations, KDevelop::IBasicVersionControl::RecursionMode recursion)
 {
-    CvsJob* job = d->m_proxy->add(findWorkingDir(localLocations[0].toLocalFile()),
+    CvsJob* job = d->m_proxy->add(findWorkingDir(localLocations[0]),
                                   localLocations,
                                   (recursion == KDevelop::IBasicVersionControl::Recursive) ? true : false);
     return job;
 }
 
-KDevelop::VcsJob * CvsPlugin::remove(const KUrl::List & localLocations)
+KDevelop::VcsJob * CvsPlugin::remove(const QList<QUrl> & localLocations)
 {
-    CvsJob* job = d->m_proxy->remove(findWorkingDir(localLocations[0].toLocalFile()),
+    CvsJob* job = d->m_proxy->remove(findWorkingDir(localLocations[0]),
                                      localLocations);
     return job;
 }
 
-KDevelop::VcsJob * CvsPlugin::localRevision(const KUrl & localLocation, KDevelop::VcsRevision::RevisionType)
+KDevelop::VcsJob * CvsPlugin::localRevision(const QUrl & localLocation, KDevelop::VcsRevision::RevisionType)
 {
     Q_UNUSED(localLocation)
     return NULL;
 }
 
-KDevelop::VcsJob * CvsPlugin::status(const KUrl::List & localLocations, KDevelop::IBasicVersionControl::RecursionMode recursion)
+KDevelop::VcsJob * CvsPlugin::status(const QList<QUrl> & localLocations, KDevelop::IBasicVersionControl::RecursionMode recursion)
 {
-    CvsJob* job = d->m_proxy->status(findWorkingDir(localLocations[0].toLocalFile()),
+    CvsJob* job = d->m_proxy->status(findWorkingDir(localLocations[0]),
                                      localLocations,
                                      (recursion == KDevelop::IBasicVersionControl::Recursive) ? true : false);
     return job;
 }
 
-KDevelop::VcsJob * CvsPlugin::unedit(const KUrl & localLocation)
+KDevelop::VcsJob * CvsPlugin::unedit(const QUrl& localLocation)
 {
-    CvsJob* job = d->m_proxy->unedit(findWorkingDir(localLocation.toLocalFile()),
-                                     localLocation);
+    CvsJob* job = d->m_proxy->unedit(findWorkingDir(localLocation),
+                                     QList<QUrl>() << localLocation);
     return job;
 }
 
-KDevelop::VcsJob * CvsPlugin::edit(const KUrl & localLocation)
+KDevelop::VcsJob * CvsPlugin::edit(const QUrl& localLocation)
 {
-    CvsJob* job = d->m_proxy->edit(findWorkingDir(localLocation.toLocalFile()),
-                                   localLocation);
+    CvsJob* job = d->m_proxy->edit(findWorkingDir(localLocation),
+                                   QList<QUrl>() << localLocation);
     return job;
 }
 
-KDevelop::VcsJob * CvsPlugin::copy(const KUrl & localLocationSrc, const KUrl & localLocationDstn)
+KDevelop::VcsJob * CvsPlugin::copy(const QUrl & localLocationSrc, const QUrl & localLocationDstn)
 {
     bool ok = QFile::copy(localLocationSrc.toLocalFile(), localLocationDstn.path());
     if (!ok) {
         return NULL;
     }
 
-    KUrl::List listDstn;
+    QList<QUrl> listDstn;
     listDstn << localLocationDstn;
 
-    CvsJob* job = d->m_proxy->add(findWorkingDir(localLocationDstn.toLocalFile()),
+    CvsJob* job = d->m_proxy->add(findWorkingDir(localLocationDstn),
                                   listDstn, true);
 
     return job;
 }
 
-KDevelop::VcsJob * CvsPlugin::move(const KUrl &, const KUrl &)
+KDevelop::VcsJob * CvsPlugin::move(const QUrl &, const QUrl &)
 {
     return NULL;
 }
 
-KDevelop::VcsJob * CvsPlugin::revert(const KUrl::List & localLocations, KDevelop::IBasicVersionControl::RecursionMode recursion)
+KDevelop::VcsJob * CvsPlugin::revert(const QList<QUrl> & localLocations, KDevelop::IBasicVersionControl::RecursionMode recursion)
 {
     KDevelop::VcsRevision rev;
-    CvsJob* job = d->m_proxy->update(findWorkingDir(localLocations[0].toLocalFile()),
+    CvsJob* job = d->m_proxy->update(findWorkingDir(localLocations[0]),
                                      localLocations,
                                      rev,
                                      "-C",
@@ -361,9 +361,9 @@ KDevelop::VcsJob * CvsPlugin::revert(const KUrl::List & localLocations, KDevelop
     return job;
 }
 
-KDevelop::VcsJob * CvsPlugin::update(const KUrl::List & localLocations, const KDevelop::VcsRevision & rev, KDevelop::IBasicVersionControl::RecursionMode recursion)
+KDevelop::VcsJob * CvsPlugin::update(const QList<QUrl> & localLocations, const KDevelop::VcsRevision & rev, KDevelop::IBasicVersionControl::RecursionMode recursion)
 {
-    CvsJob* job = d->m_proxy->update(findWorkingDir(localLocations[0].toLocalFile()),
+    CvsJob* job = d->m_proxy->update(findWorkingDir(localLocations[0]),
                                      localLocations,
                                      rev,
                                      "",
@@ -372,7 +372,7 @@ KDevelop::VcsJob * CvsPlugin::update(const KUrl::List & localLocations, const KD
     return job;
 }
 
-KDevelop::VcsJob * CvsPlugin::commit(const QString & message, const KUrl::List & localLocations, KDevelop::IBasicVersionControl::RecursionMode recursion)
+KDevelop::VcsJob * CvsPlugin::commit(const QString & message, const QList<QUrl> & localLocations, KDevelop::IBasicVersionControl::RecursionMode recursion)
 {
     Q_UNUSED(recursion);
     QString msg = message;
@@ -383,19 +383,19 @@ KDevelop::VcsJob * CvsPlugin::commit(const QString & message, const KUrl::List &
         }
     }
 
-    CvsJob* job = d->m_proxy->commit(findWorkingDir(localLocations[0].toLocalFile()),
+    CvsJob* job = d->m_proxy->commit(findWorkingDir(localLocations[0]),
                                      localLocations,
                                      msg);
     return job;
 }
 
-KDevelop::VcsJob * CvsPlugin::diff(const KUrl & fileOrDirectory, const KDevelop::VcsRevision & srcRevision, const KDevelop::VcsRevision & dstRevision, KDevelop::VcsDiff::Type, KDevelop::IBasicVersionControl::RecursionMode)
+KDevelop::VcsJob * CvsPlugin::diff(const QUrl & fileOrDirectory, const KDevelop::VcsRevision & srcRevision, const KDevelop::VcsRevision & dstRevision, KDevelop::VcsDiff::Type, KDevelop::IBasicVersionControl::RecursionMode)
 {
     CvsJob* job = d->m_proxy->diff(fileOrDirectory, srcRevision, dstRevision, "-uN"/*always unified*/);
     return job;
 }
 
-KDevelop::VcsJob * CvsPlugin::log(const KUrl & localLocation, const KDevelop::VcsRevision & rev, unsigned long limit)
+KDevelop::VcsJob * CvsPlugin::log(const QUrl & localLocation, const KDevelop::VcsRevision & rev, unsigned long limit)
 {
     Q_UNUSED(limit)
 
@@ -403,26 +403,26 @@ KDevelop::VcsJob * CvsPlugin::log(const KUrl & localLocation, const KDevelop::Vc
     return job;
 }
 
-KDevelop::VcsJob * CvsPlugin::log(const KUrl & localLocation, const KDevelop::VcsRevision & rev, const KDevelop::VcsRevision & limit)
+KDevelop::VcsJob * CvsPlugin::log(const QUrl & localLocation, const KDevelop::VcsRevision & rev, const KDevelop::VcsRevision & limit)
 {
     Q_UNUSED(limit)
     return log(localLocation, rev, 0);
 }
 
-KDevelop::VcsJob * CvsPlugin::annotate(const KUrl & localLocation, const KDevelop::VcsRevision & rev)
+KDevelop::VcsJob * CvsPlugin::annotate(const QUrl & localLocation, const KDevelop::VcsRevision & rev)
 {
     CvsJob* job = d->m_proxy->annotate(localLocation, rev);
     return job;
 }
 
-KDevelop::VcsJob * CvsPlugin::resolve(const KUrl::List & localLocations, KDevelop::IBasicVersionControl::RecursionMode recursion)
+KDevelop::VcsJob * CvsPlugin::resolve(const QList<QUrl> & localLocations, KDevelop::IBasicVersionControl::RecursionMode recursion)
 {
     Q_UNUSED(localLocations);
     Q_UNUSED(recursion);
     return NULL;
 }
 
-KDevelop::VcsJob * CvsPlugin::import(const QString& commitMessage, const KUrl& sourceDirectory, const KDevelop::VcsLocation& destinationRepository)
+KDevelop::VcsJob * CvsPlugin::import(const QString& commitMessage, const QUrl& sourceDirectory, const KDevelop::VcsLocation& destinationRepository)
 {
     if (commitMessage.isEmpty()
             || !sourceDirectory.isLocalFile()
@@ -431,7 +431,7 @@ KDevelop::VcsJob * CvsPlugin::import(const QString& commitMessage, const KUrl& s
         return 0;
     }
 
-    kDebug(9500) << "CVS Import requested "
+    qCDebug(PLUGIN_CVS) << "CVS Import requested "
     << "src:" << sourceDirectory.toLocalFile()
     << "srv:" << destinationRepository.repositoryServer()
     << "module:" << destinationRepository.repositoryModule();
@@ -445,7 +445,7 @@ KDevelop::VcsJob * CvsPlugin::import(const QString& commitMessage, const KUrl& s
     return job;
 }
 
-KDevelop::VcsJob * CvsPlugin::createWorkingCopy(const KDevelop::VcsLocation & sourceRepository, const KUrl & destinationDirectory, KDevelop::IBasicVersionControl::RecursionMode recursion)
+KDevelop::VcsJob * CvsPlugin::createWorkingCopy(const KDevelop::VcsLocation & sourceRepository, const QUrl & destinationDirectory, KDevelop::IBasicVersionControl::RecursionMode recursion)
 {
     Q_UNUSED(recursion);
     if (!destinationDirectory.isLocalFile()
@@ -454,7 +454,7 @@ KDevelop::VcsJob * CvsPlugin::createWorkingCopy(const KDevelop::VcsLocation & so
         return 0;
     }
 
-    kDebug(9500) << "CVS Checkout requested "
+    qCDebug(PLUGIN_CVS) << "CVS Checkout requested "
     << "dest:" << destinationDirectory.toLocalFile()
     << "srv:" << sourceRepository.repositoryServer()
     << "module:" << sourceRepository.repositoryModule()
