@@ -21,9 +21,11 @@
 
 #include <interfaces/iplugin.h>
 #include <QtCore/QVariant>
+#include <QLoggingCategory>
+Q_DECLARE_LOGGING_CATEGORY(PLUGIN_DOCUMENTSWITCHER)
 
 class QStandardItemModel;
-namespace Sublime 
+namespace Sublime
 {
     class View;
     class MainWindow;
@@ -37,15 +39,15 @@ class QModelIndex;
 class QStringListModel;
 class QEvent;
 
-class KAction;
+class QAction;
 
 class DocumentSwitcherPlugin: public KDevelop::IPlugin {
     Q_OBJECT
 public:
-    DocumentSwitcherPlugin( QObject *parent, const QVariantList &args = QVariantList() );
+    explicit DocumentSwitcherPlugin( QObject *parent, const QVariantList &args = QVariantList() );
     ~DocumentSwitcherPlugin();
-    
-    virtual void unload();
+
+    virtual void unload() override;
 public slots:
     void itemActivated( const QModelIndex& );
     void switchToClicked(const QModelIndex& );
@@ -59,7 +61,7 @@ private slots:
     void walkForward();
     void walkBackward();
 protected:
-    bool eventFilter( QObject*, QEvent* );
+    bool eventFilter( QObject*, QEvent* ) override;
 private:
     void setViewGeometry(Sublime::MainWindow* window);
     void storeAreaViewList( Sublime::MainWindow* mainwindow, Sublime::Area* area );
@@ -71,8 +73,8 @@ private:
     QMap<QObject*, QMap<Sublime::Area*, QList<Sublime::View*> > > documentLists;
     QListView* view;
     QStandardItemModel* model;
-    KAction* forwardAction;
-    KAction* backwardAction;
+    QAction* forwardAction;
+    QAction* backwardAction;
 };
 
 #endif
