@@ -17,24 +17,24 @@
  Boston, MA 02110-1301, USA.
 */
 
-#ifndef KDEVDOCUMENTSELECTION_H
-#define KDEVDOCUMENTSELECTION_H
+#ifndef KDEVPLATFORM_PLUGIN_KDEVDOCUMENTSELECTION_H
+#define KDEVPLATFORM_PLUGIN_KDEVDOCUMENTSELECTION_H
 
-#include <QtGui/QItemSelectionModel>
+#include <QItemSelectionModel>
 
 class KDevDocumentSelection: public QItemSelectionModel
 {
     Q_OBJECT
 public:
-    KDevDocumentSelection( QAbstractItemModel* model );
+    explicit KDevDocumentSelection( QAbstractItemModel* model );
     virtual ~KDevDocumentSelection();
 
 public slots:
     virtual void select( const QModelIndex & index,
-                         QItemSelectionModel::SelectionFlags command );
+                         QItemSelectionModel::SelectionFlags command ) override;
     virtual void select( const QItemSelection & selection,
-                         QItemSelectionModel::SelectionFlags command );
+                         QItemSelectionModel::SelectionFlags command ) override;
 };
 
-#endif // KDEVDOCUMENTSELECTION_H
+#endif // KDEVPLATFORM_PLUGIN_KDEVDOCUMENTSELECTION_H
 
