@@ -22,16 +22,15 @@
 #define KDEVPLATFORM_PLUGIN_KDEVDOCUMENTVIEW_H
 
 #include <QTreeView>
+#include <QUrl>
 
 class QSortFilterProxyModel;
-class KAction;
-class KUrl;
+class QAction;
 class KDevDocumentViewPlugin;
 class KDevDocumentModel;
 class KDevDocumentViewDelegate;
 class KDevDocumentSelection;
 class KDevFileItem;
-class KMenu;
 namespace KDevelop
 {
     class IDocument;
@@ -52,7 +51,7 @@ public:
     KDevDocumentViewPlugin *plugin() const;
 
 signals:
-    void activateURL( const KUrl &url );
+    void activateURL( const QUrl &url );
 
 public slots:
     void opened( KDevelop::IDocument* document );
@@ -73,8 +72,8 @@ private slots:
     void closeUnselected();
 
 protected:
-    virtual void mousePressEvent( QMouseEvent * event );
-    virtual void contextMenuEvent( QContextMenuEvent * event );
+    virtual void mousePressEvent( QMouseEvent * event ) override;
+    virtual void contextMenuEvent( QContextMenuEvent * event ) override;
 
 private:
     template<typename F> void visitItems(F, bool selectedItems);
@@ -89,9 +88,10 @@ private:
     QSortFilterProxyModel* m_proxy;
     KDevDocumentViewDelegate* m_delegate;
     QHash< KDevelop::IDocument*, KDevFileItem* > m_doc2index;
-    QList<KUrl> m_selectedDocs; // used for ctx menu
-    QList<KUrl> m_unselectedDocs; // used for ctx menu
-    QList<KDevelop::IProject*> m_projects;
+    QList<QUrl> m_selectedDocs; // used for ctx menu
+    QList<QUrl> m_unselectedDocs; // used for ctx menu
+
+    friend class KDevDocumentViewPluginFactory; // to connect to the private slots stateChanged and documentUrlChanged
 };
 
 #endif // KDEVPLATFORM_PLUGIN_KDEVDOCUMENTVIEW_H
