@@ -20,22 +20,17 @@ Boston, MA 02110-1301, USA.
 #ifndef KDEVPLATFORM_PLUGIN_KDEVDOCUMENTVIEWDELEGATE_H
 #define KDEVPLATFORM_PLUGIN_KDEVDOCUMENTVIEWDELEGATE_H
 
-#include <QtGui/QItemDelegate>
+#include <QItemDelegate>
 class QTreeView;
 
 class KDevDocumentViewDelegate: public QItemDelegate
 {
     Q_OBJECT
 public:
-    explicit KDevDocumentViewDelegate( QTreeView *view, QObject *parent = 0 );
+    explicit KDevDocumentViewDelegate( QObject *parent = 0 );
     virtual ~KDevDocumentViewDelegate();
 
-    virtual void paint( QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index ) const;
-    virtual QSize sizeHint( const QStyleOptionViewItem &opt, const QModelIndex &index ) const;
-
-private:
-    QTreeView *m_view;
+    virtual void paint( QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index ) const override;
 };
 
 #endif // KDEVPLATFORM_PLUGIN_KDEVCLASSVIEWDELEGATE_H
-
