@@ -20,9 +20,6 @@
 #ifndef KDEVPLATFORM_PLUGIN_KDEVDOCUMENTVIEW_PART_H
 #define KDEVPLATFORM_PLUGIN_KDEVDOCUMENTVIEW_PART_H
 
-#include <QtCore/QHash>
-#include <QtCore/QPointer>
-
 #include <interfaces/iplugin.h>
 #include <interfaces/idocumentcontroller.h>
 
@@ -42,7 +39,7 @@ public:
 public:
     KDevDocumentViewPlugin( QObject *parent, const QVariantList& args );
     virtual ~KDevDocumentViewPlugin();
-    virtual void unload();
+    virtual void unload() override;
 
 private:
     KDevDocumentViewPluginFactory* factory;
