@@ -19,10 +19,6 @@
 */
 #include "nativeappconfig.h"
 
-#include <klocale.h>
-#include <kdebug.h>
-#include <kicon.h>
-
 #include <interfaces/icore.h>
 #include <interfaces/iprojectcontroller.h>
 #include <interfaces/ilaunchconfiguration.h>
@@ -35,27 +31,33 @@
 #include <project/interfaces/ibuildsystemmanager.h>
 #include <project/interfaces/iprojectbuilder.h>
 #include <project/builderjob.h>
-#include <kmessagebox.h>
 #include <interfaces/iuicontroller.h>
 #include <util/executecompositejob.h>
-#include <kparts/mainwindow.h>
+
 #include <interfaces/iplugincontroller.h>
 
 #include "executeplugin.h"
+#include "debug.h"
 #include <util/kdevstringhandler.h>
 #include <util/environmentgrouplist.h>
 #include <project/projectitemlineedit.h>
 #include "projecttargetscombobox.h"
+
+#include <QDebug>
+#include <QIcon>
 #include <QMenu>
 
-#include <KCModuleProxy>
-#include <KConfigDialog>
+#include <KConfigGroup>
+#include <KLineEdit>
+#include <KLocalizedString>
 #include <KShell>
-#include <kcmoduleinfo.h>
 
-KIcon NativeAppConfigPage::icon() const
+
+using namespace KDevelop;
+
+QIcon NativeAppConfigPage::icon() const
 {
-    return KIcon("system-run");
+    return QIcon::fromTheme("system-run");
 }
 
 static KDevelop::ProjectBaseItem* itemForPath(const QStringList& path, KDevelop::ProjectModel* model)
@@ -65,21 +67,22 @@ static KDevelop::ProjectBaseItem* itemForPath(const QStringList& path, KDevelop:
 
 //TODO: Make sure to auto-add the executable target to the dependencies when its used.
 
-void NativeAppConfigPage::loadFromConfiguration(const KConfigGroup& cfg, KDevelop::IProject* project ) 
+void NativeAppConfigPage::loadFromConfiguration(const KConfigGroup& cfg, KDevelop::IProject* project )
 {
     bool b = blockSignals( true );
     projectTarget->setBaseItem( project ? project->projectItem() : 0, true);
     projectTarget->setCurrentItemPath( cfg.readEntry( ExecutePlugin::projectTargetEntry, QStringList() ) );
 
-    KUrl exe = cfg.readEntry( ExecutePlugin::executableEntry, KUrl());
+    QUrl exe = cfg.readEntry( ExecutePlugin::executableEntry, QUrl());
     if( !exe.isEmpty() || project ){
-        executablePath->setUrl( !exe.isEmpty() ? exe : project->folder() );
+        executablePath->setUrl( !exe.isEmpty() ? exe : project->path().toUrl() );
     }else{
         KDevelop::IProjectController* pc = KDevelop::ICore::self()->projectController();
         if( pc ){
-            executablePath->setUrl( pc->projects().count() ? pc->projects().first()->folder() : KUrl() );
+            executablePath->setUrl( pc->projects().count() ? pc->projects().first()->path().toUrl() : QUrl() );
         }
     }
+    targetDependency->setSuggestion(project);
 
     //executablePath->setFilter("application/x-executable");
 
@@ -88,9 +91,9 @@ void NativeAppConfigPage::loadFromConfiguration(const KConfigGroup& cfg, KDevelo
         projectTargetRadio->setChecked( true );
     }
 
-    arguments->setClearButtonShown( true );
+    arguments->setClearButtonEnabled( true );
     arguments->setText( cfg.readEntry( ExecutePlugin::argumentsEntry, "" ) );
-    workingDirectory->setUrl( cfg.readEntry( ExecutePlugin::workingDirEntry, KUrl() ) );
+    workingDirectory->setUrl( cfg.readEntry( ExecutePlugin::workingDirEntry, QUrl() ) );
     environment->setCurrentProfile( cfg.readEntry( ExecutePlugin::environmentGroupEntry, QString() ) );
     runInTerminal->setChecked( cfg.readEntry( ExecutePlugin::useTerminalEntry, false ) );
     terminal->setEditText( cfg.readEntry( ExecutePlugin::terminalEntry, terminal->itemText(0) ) );
@@ -100,10 +103,10 @@ void NativeAppConfigPage::loadFromConfiguration(const KConfigGroup& cfg, KDevelo
         QStringList deplist = dep.toStringList();
         KDevelop::ProjectModel* model = KDevelop::ICore::self()->projectController()->projectModel();
         KDevelop::ProjectBaseItem* pitem=itemForPath(deplist, model);
-        KIcon icon;
+        QIcon icon;
         if(pitem)
-            icon=KIcon(pitem->iconName());
-        
+            icon=QIcon::fromTheme(pitem->iconName());
+
         QListWidgetItem* item = new QListWidgetItem(icon, KDevelop::joinWithEscaping( deplist, '/', '\\' ), dependencies );
         item->setData( Qt::UserRole, dep );
     }
@@ -111,53 +114,53 @@ void NativeAppConfigPage::loadFromConfiguration(const KConfigGroup& cfg, KDevelo
     blockSignals( b );
 }
 
-NativeAppConfigPage::NativeAppConfigPage( QWidget* parent ) 
+NativeAppConfigPage::NativeAppConfigPage( QWidget* parent )
     : LaunchConfigurationPage( parent )
 {
-    setupUi(this);    
+    setupUi(this);
     //Setup data info for combobox
     dependencyAction->setItemData(0, "Nothing" );
     dependencyAction->setItemData(1, "Build" );
     dependencyAction->setItemData(2, "Install" );
     dependencyAction->setItemData(3, "SudoInstall" );
 
-    addDependency->setIcon( KIcon("list-add") );
-    removeDependency->setIcon( KIcon("list-remove") );
-    moveDepUp->setIcon( KIcon("go-up") );
-    moveDepDown->setIcon( KIcon("go-down") );
-    browseProject->setIcon(KIcon("folder-document"));
-    
+    addDependency->setIcon( QIcon::fromTheme("list-add") );
+    removeDependency->setIcon( QIcon::fromTheme("list-remove") );
+    moveDepUp->setIcon( QIcon::fromTheme("go-up") );
+    moveDepDown->setIcon( QIcon::fromTheme("go-down") );
+    browseProject->setIcon(QIcon::fromTheme("folder-document"));
+
     //Set workingdirectory widget to ask for directories rather than files
     workingDirectory->setMode(KFile::Directory | KFile::ExistingOnly | KFile::LocalOnly);
 
     configureEnvironment->setSelectionWidget(environment);
 
     //connect signals to changed signal
-    connect( projectTarget, SIGNAL(currentIndexChanged(QString)), SIGNAL(changed()) );
-    connect( projectTargetRadio, SIGNAL(toggled(bool)), SIGNAL(changed()) );
-    connect( executableRadio, SIGNAL(toggled(bool)), SIGNAL(changed()) );
-    connect( executablePath->lineEdit(), SIGNAL(textEdited(QString)), SIGNAL(changed()) );
-    connect( executablePath, SIGNAL(urlSelected(KUrl)), SIGNAL(changed()) );
-    connect( arguments, SIGNAL(textEdited(QString)), SIGNAL(changed()) );
-    connect( workingDirectory, SIGNAL(urlSelected(KUrl)), SIGNAL(changed()) );
-    connect( workingDirectory->lineEdit(), SIGNAL(textEdited(QString)), SIGNAL(changed()) );
-    connect( environment, SIGNAL(currentProfileChanged(QString)), SIGNAL(changed()) );
-    connect( addDependency, SIGNAL(clicked(bool)), SLOT(addDep()) );
-    connect( addDependency, SIGNAL(clicked(bool)), SIGNAL(changed()) );
-    connect( removeDependency, SIGNAL(clicked(bool)), SIGNAL(changed()) );
-    connect( removeDependency, SIGNAL(clicked(bool)), SLOT(removeDep()) );
-    connect( moveDepDown, SIGNAL(clicked(bool)), SIGNAL(changed()) );
-    connect( moveDepUp, SIGNAL(clicked(bool)), SIGNAL(changed()) );
-    connect( moveDepDown, SIGNAL(clicked(bool)), SLOT(moveDependencyDown()) );
-    connect( moveDepUp, SIGNAL(clicked(bool)), SLOT(moveDependencyUp()) );
-    connect( dependencies->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)), SLOT(checkActions(QItemSelection,QItemSelection)) );
-    connect( dependencyAction, SIGNAL(currentIndexChanged(int)), SIGNAL(changed()) );
-    connect( runInTerminal, SIGNAL(toggled(bool)), SIGNAL(changed()) );
-    connect( terminal, SIGNAL(editTextChanged(QString)), SIGNAL(changed()) );
-    connect( terminal, SIGNAL(currentIndexChanged(int)), SIGNAL(changed()) );
-    connect( dependencyAction, SIGNAL(currentIndexChanged(int)), SLOT(activateDeps(int)) );
-    connect( targetDependency, SIGNAL(textChanged(QString)), SLOT(depEdited(QString)));
-    connect( browseProject, SIGNAL(clicked(bool)), SLOT(selectItemDialog()));
+    connect( projectTarget, static_cast<void(ProjectTargetsComboBox::*)(const QString&)>(&ProjectTargetsComboBox::currentIndexChanged), this, &NativeAppConfigPage::changed );
+    connect( projectTargetRadio, &QRadioButton::toggled, this, &NativeAppConfigPage::changed );
+    connect( executableRadio, &QRadioButton::toggled, this, &NativeAppConfigPage::changed );
+    connect( executablePath->lineEdit(), &KLineEdit::textEdited, this, &NativeAppConfigPage::changed );
+    connect( executablePath, &KUrlRequester::urlSelected, this, &NativeAppConfigPage::changed );
+    connect( arguments, &QLineEdit::textEdited, this, &NativeAppConfigPage::changed );
+    connect( workingDirectory, &KUrlRequester::urlSelected, this, &NativeAppConfigPage::changed );
+    connect( workingDirectory->lineEdit(), &KLineEdit::textEdited, this, &NativeAppConfigPage::changed );
+    connect( environment, &EnvironmentSelectionWidget::currentProfileChanged, this, &NativeAppConfigPage::changed );
+    connect( addDependency, &QPushButton::clicked, this, &NativeAppConfigPage::addDep );
+    connect( addDependency, &QPushButton::clicked, this, &NativeAppConfigPage::changed );
+    connect( removeDependency, &QPushButton::clicked, this, &NativeAppConfigPage::changed );
+    connect( removeDependency, &QPushButton::clicked, this, &NativeAppConfigPage::removeDep );
+    connect( moveDepDown, &QPushButton::clicked, this, &NativeAppConfigPage::changed );
+    connect( moveDepUp, &QPushButton::clicked, this, &NativeAppConfigPage::changed );
+    connect( moveDepDown, &QPushButton::clicked, this, &NativeAppConfigPage::moveDependencyDown );
+    connect( moveDepUp, &QPushButton::clicked, this, &NativeAppConfigPage::moveDependencyUp );
+    connect( dependencies->selectionModel(), &QItemSelectionModel::selectionChanged, this, &NativeAppConfigPage::checkActions );
+    connect( dependencyAction, static_cast<void(KComboBox::*)(int)>(&KComboBox::currentIndexChanged), this, &NativeAppConfigPage::changed );
+    connect( runInTerminal, &QCheckBox::toggled, this, &NativeAppConfigPage::changed );
+    connect( terminal, &KComboBox::editTextChanged, this, &NativeAppConfigPage::changed );
+    connect( terminal, static_cast<void(KComboBox::*)(int)>(&KComboBox::currentIndexChanged), this, &NativeAppConfigPage::changed );
+    connect( dependencyAction, static_cast<void(KComboBox::*)(int)>(&KComboBox::currentIndexChanged), this, &NativeAppConfigPage::activateDeps );
+    connect( targetDependency, &ProjectItemLineEdit::textChanged, this, &NativeAppConfigPage::depEdited);
+    connect( browseProject, &QPushButton::clicked, this, &NativeAppConfigPage::selectItemDialog);
 }
 
 
@@ -165,8 +168,8 @@ void NativeAppConfigPage::depEdited( const QString& str )
 {
     int pos;
     QString tmp = str;
-    addDependency->setEnabled( !str.isEmpty() 
-                               && ( !targetDependency->validator() 
+    addDependency->setEnabled( !str.isEmpty()
+                               && ( !targetDependency->validator()
                                || targetDependency->validator()->validate( tmp, pos ) == QValidator::Acceptable ) );
 }
 
@@ -180,17 +183,17 @@ void NativeAppConfigPage::activateDeps( int idx )
 void NativeAppConfigPage::checkActions( const QItemSelection& selected, const QItemSelection& unselected )
 {
     Q_UNUSED( unselected );
-    kDebug() << "checkActions";
+    qCDebug(PLUGIN_EXECUTE) << "checkActions";
     if( !selected.indexes().isEmpty() )
     {
-        kDebug() << "have selection";
+        qCDebug(PLUGIN_EXECUTE) << "have selection";
         Q_ASSERT( selected.indexes().count() == 1 );
         QModelIndex idx = selected.indexes().at( 0 );
-        kDebug() << "index" << idx;
+        qCDebug(PLUGIN_EXECUTE) << "index" << idx;
         moveDepUp->setEnabled( idx.row() > 0 );
         moveDepDown->setEnabled( idx.row() < dependencies->count() - 1 );
         removeDependency->setEnabled( true );
-    } else 
+    } else
     {
         removeDependency->setEnabled( false );
         moveDepUp->setEnabled( false );
@@ -214,7 +217,7 @@ void NativeAppConfigPage::moveDependencyDown()
 
 void NativeAppConfigPage::moveDependencyUp()
 {
-    
+
     QList<QListWidgetItem*> list = dependencies->selectedItems();
     if( !list.isEmpty() )
     {
@@ -229,10 +232,10 @@ void NativeAppConfigPage::moveDependencyUp()
 
 void NativeAppConfigPage::addDep()
 {
-    KIcon icon;
+    QIcon icon;
     KDevelop::ProjectBaseItem* pitem = targetDependency->currentItem();
     if(pitem)
-        icon= KIcon(pitem->iconName());
+        icon = QIcon::fromTheme(pitem->iconName());
 
     QListWidgetItem* item = new QListWidgetItem(icon, targetDependency->text(), dependencies);
     item->setData( Qt::UserRole, targetDependency->itemPath() );
@@ -258,7 +261,7 @@ void NativeAppConfigPage::removeDep()
         Q_ASSERT( list.count() == 1 );
         int row = dependencies->row( list.at(0) );
         delete dependencies->takeItem( row );
-        
+
         dependencies->selectionModel()->select( dependencies->model()->index( row - 1, 0, QModelIndex() ), QItemSelectionModel::ClearAndSelect | QItemSelectionModel::SelectCurrent );
     }
 }
@@ -283,12 +286,12 @@ void NativeAppConfigPage::saveToConfiguration( KConfigGroup cfg, KDevelop::IProj
     cfg.writeEntry( ExecutePlugin::dependencyEntry, KDevelop::qvariantToString( QVariant( deps ) ) );
 }
 
-QString NativeAppConfigPage::title() const 
+QString NativeAppConfigPage::title() const
 {
     return i18n("Configure Native Application");
 }
 
-QList< KDevelop::LaunchConfigurationPageFactory* > NativeAppLauncher::configPages() const 
+QList< KDevelop::LaunchConfigurationPageFactory* > NativeAppLauncher::configPages() const
 {
     return QList<KDevelop::LaunchConfigurationPageFactory*>();
 }
@@ -298,12 +301,12 @@ QString NativeAppLauncher::description() const
     return "Executes Native Applications";
 }
 
-QString NativeAppLauncher::id() 
+QString NativeAppLauncher::id()
 {
     return "nativeAppLauncher";
 }
 
-QString NativeAppLauncher::name() const 
+QString NativeAppLauncher::name() const
 {
     return i18n("Native Application");
 }
@@ -323,7 +326,7 @@ KJob* NativeAppLauncher::start(const QString& launchMode, KDevelop::ILaunchConfi
     {
         IExecutePlugin* iface = KDevelop::ICore::self()->pluginController()->pluginForExtension("org.kdevelop.IExecutePlugin", "kdevexecute")->extension<IExecutePlugin>();
         Q_ASSERT(iface);
-        KJob* depjob = iface->dependecyJob( cfg );
+        KJob* depjob = iface->dependencyJob( cfg );
         QList<KJob*> l;
         if( depjob )
         {
@@ -331,9 +334,9 @@ KJob* NativeAppLauncher::start(const QString& launchMode, KDevelop::ILaunchConfi
         }
         l << new NativeAppJob( KDevelop::ICore::self()->runController(), cfg );
         return new KDevelop::ExecuteCompositeJob( KDevelop::ICore::self()->runController(), l );
-        
+
     }
-    kWarning() << "Unknown launch mode " << launchMode << "for config:" << cfg->name();
+    qWarning() << "Unknown launch mode " << launchMode << "for config:" << cfg->name();
     return 0;
 }
 
@@ -351,7 +354,7 @@ NativeAppPageFactory::NativeAppPageFactory()
 {
 }
 
-NativeAppConfigType::NativeAppConfigType() 
+NativeAppConfigType::NativeAppConfigType()
 {
     factoryList.append( new NativeAppPageFactory() );
 }
@@ -368,19 +371,19 @@ QString NativeAppConfigType::name() const
 }
 
 
-QList<KDevelop::LaunchConfigurationPageFactory*> NativeAppConfigType::configPages() const 
+QList<KDevelop::LaunchConfigurationPageFactory*> NativeAppConfigType::configPages() const
 {
     return factoryList;
 }
 
-QString NativeAppConfigType::id() const 
+QString NativeAppConfigType::id() const
 {
     return ExecutePlugin::_nativeAppConfigTypeId;
 }
 
-KIcon NativeAppConfigType::icon() const
+QIcon NativeAppConfigType::icon() const
 {
-    return KIcon("application-x-executable");
+    return QIcon::fromTheme("application-x-executable");
 }
 
 bool NativeAppConfigType::canLaunch ( KDevelop::ProjectBaseItem* item ) const
@@ -391,7 +394,7 @@ bool NativeAppConfigType::canLaunch ( KDevelop::ProjectBaseItem* item ) const
     return false;
 }
 
-bool NativeAppConfigType::canLaunch ( const KUrl& file ) const
+bool NativeAppConfigType::canLaunch ( const QUrl& file ) const
 {
     return ( file.isLocalFile() && QFileInfo( file.toLocalFile() ).isExecutable() );
 }
@@ -401,14 +404,16 @@ void NativeAppConfigType::configureLaunchFromItem ( KConfigGroup cfg, KDevelop::
     cfg.writeEntry( ExecutePlugin::isExecutableEntry, false );
     KDevelop::ProjectModel* model = KDevelop::ICore::self()->projectController()->projectModel();
     cfg.writeEntry( ExecutePlugin::projectTargetEntry, model->pathFromIndex( model->indexFromItem( item ) ) );
-    cfg.writeEntry( ExecutePlugin::workingDirEntry, item->executable()->builtUrl().upUrl() );
+    cfg.writeEntry( ExecutePlugin::workingDirEntry, item->executable()->builtUrl().adjusted(QUrl::RemoveFilename) );
     cfg.sync();
 }
 
 void NativeAppConfigType::configureLaunchFromCmdLineArguments ( KConfigGroup cfg, const QStringList& args ) const
 {
     cfg.writeEntry( ExecutePlugin::isExecutableEntry, true );
-    cfg.writeEntry( ExecutePlugin::executableEntry, args.first() );
+    Q_ASSERT(QFile::exists(args.first()));
+//  TODO: we probably want to flexibilize, but at least we won't be accepting wrong values anymore
+    cfg.writeEntry( ExecutePlugin::executableEntry, QUrl::fromLocalFile(args.first()) );
     QStringList a(args);
     a.removeFirst();
     cfg.writeEntry( ExecutePlugin::argumentsEntry, KShell::joinArgs(a) );
@@ -420,7 +425,7 @@ QList<KDevelop::ProjectTargetItem*> targetsInFolder(KDevelop::ProjectFolderItem*
     QList<KDevelop::ProjectTargetItem*> ret;
     foreach(KDevelop::ProjectFolderItem* f, folder->folderList())
         ret += targetsInFolder(f);
-    
+
     ret += folder->targetList();
     return ret;
 }
@@ -438,15 +443,15 @@ bool menuLess(QMenu* a, QMenu* b)
 QMenu* NativeAppConfigType::launcherSuggestions()
 {
     QMenu* ret = new QMenu(i18n("Project Executables"));
-    
+
     KDevelop::ProjectModel* model = KDevelop::ICore::self()->projectController()->projectModel();
     QList<KDevelop::IProject*> projects = KDevelop::ICore::self()->projectController()->projects();
-    
+
     foreach(KDevelop::IProject* project, projects) {
         if(project->projectFileManager()->features() & KDevelop::IProjectFileManager::Targets) {
             QList<KDevelop::ProjectTargetItem*> targets=targetsInFolder(project->projectItem());
             QHash<KDevelop::ProjectBaseItem*, QList<QAction*> > targetsContainer;
-            QMenu* projectMenu = ret->addMenu(KIcon("project-development"), project->name());
+            QMenu* projectMenu = ret->addMenu(QIcon::fromTheme("project-development"), project->name());
             foreach(KDevelop::ProjectTargetItem* target, targets) {
                 if(target->executable()) {
                     QStringList path = model->pathFromIndex(target->index());
@@ -456,8 +461,8 @@ QMenu* NativeAppConfigType::launcherSuggestions()
                         act->setProperty("name", target->text());
                         path.removeFirst();
                         act->setText(path.join("/"));
-                        act->setIcon(KIcon("system-run"));
-                        connect(act, SIGNAL(triggered(bool)), SLOT(suggestionTriggered()));
+                        act->setIcon(QIcon::fromTheme("system-run"));
+                        connect(act, &QAction::triggered, this, &NativeAppConfigType::suggestionTriggered);
                         targetsContainer[target->parent()].append(act);
                     }
                 }
@@ -476,12 +481,13 @@ QMenu* NativeAppConfigType::launcherSuggestions()
                     QStringList path = model->pathFromIndex(folder->index());
                     path.removeFirst();
                     QMenu* submenu = new QMenu(path.join("/"));
+                    std::sort(actions.begin(), actions.end(), actionLess);
                     submenu->addActions(actions);
                     submenus += submenu;
                 }
             }
-            qSort(separateActions.begin(), separateActions.end(), actionLess);
-            qSort(submenus.begin(), submenus.end(), menuLess);
+            std::sort(separateActions.begin(), separateActions.end(), actionLess);
+            std::sort(submenus.begin(), submenus.end(), menuLess);
             foreach(QMenu* m, submenus)
                 projectMenu->addMenu(m);
             projectMenu->addActions(separateActions);
@@ -489,7 +495,7 @@ QMenu* NativeAppConfigType::launcherSuggestions()
             projectMenu->setEnabled(!projectMenu->isEmpty());
         }
     }
-    
+
     return ret;
 }
 
@@ -501,19 +507,18 @@ void NativeAppConfigType::suggestionTriggered()
     if(pitem) {
         QPair<QString,QString> launcher = qMakePair( launchers().at( 0 )->supportedModes().at(0), launchers().at( 0 )->id() );
         KDevelop::IProject* p = pitem->project();
-        
+
         KDevelop::ILaunchConfiguration* config = KDevelop::ICore::self()->runController()->createLaunchConfiguration(this, launcher, p, pitem->text());
         KConfigGroup cfg = config->config();
-        
+
         QStringList splitPath = model->pathFromIndex(pitem->index());
 //         QString path = KDevelop::joinWithEscaping(splitPath,'/','\\');
         cfg.writeEntry( ExecutePlugin::projectTargetEntry, splitPath );
         cfg.writeEntry( ExecutePlugin::dependencyEntry, KDevelop::qvariantToString( QVariantList() << splitPath ) );
         cfg.writeEntry( ExecutePlugin::dependencyActionEntry, "Build" );
         cfg.sync();
-        
+
         emit signalAddLaunchConfiguration(config);
     }
 }
 
-#include "nativeappconfig.moc"
