@@ -19,77 +19,80 @@
 
 #include "nativeappjob.h"
 
+#include <QDebug>
 #include <QFileInfo>
+#include <QMessageBox>
 
-#include <kprocess.h>
-#include <klocale.h>
-#include <kmessagebox.h>
-#include <kconfiggroup.h>
-#include <kdebug.h>
-#include <kparts/mainwindow.h>
+#include <KLocalizedString>
+#include <KProcess>
+#include <KShell>
+#include <KSharedConfig>
+#include <KCompositeJob>
 
 #include <interfaces/ilaunchconfiguration.h>
+#include <interfaces/iruncontroller.h>
 #include <outputview/outputmodel.h>
 #include <outputview/outputdelegate.h>
 #include <util/processlinemaker.h>
 #include <util/environmentgrouplist.h>
 
-#include <kshell.h>
 #include <interfaces/icore.h>
 #include <interfaces/iuicontroller.h>
 #include <interfaces/iplugincontroller.h>
 #include <project/projectmodel.h>
 
 #include "iexecuteplugin.h"
+#include "debug.h"
 
 using namespace KDevelop;
 
-NativeAppJob::NativeAppJob(QObject* parent, KDevelop::ILaunchConfiguration* cfg) 
+NativeAppJob::NativeAppJob(QObject* parent, KDevelop::ILaunchConfiguration* cfg)
     : KDevelop::OutputJob( parent ), proc(0)
+    , m_cfgname(cfg->name())
 {
     setCapabilities(Killable);
-    
+
     IExecutePlugin* iface = KDevelop::ICore::self()->pluginController()->pluginForExtension("org.kdevelop.IExecutePlugin", "kdevexecute")->extension<IExecutePlugin>();
     Q_ASSERT(iface);
-        
-    KDevelop::EnvironmentGroupList l(KGlobal::config());
+
+    KDevelop::EnvironmentGroupList l(KSharedConfig::openConfig());
     QString envgrp = iface->environmentGroup(cfg);
-    
+
     QString err;
-    KUrl executable = iface->executable( cfg, err );
-    
-    if( !err.isEmpty() ) 
+    QUrl executable = iface->executable( cfg, err );
+
+    if( !err.isEmpty() )
     {
         setError( -1 );
         setErrorText( err );
         return;
     }
-    
+
     if( envgrp.isEmpty() )
     {
-        kWarning() << "Launch Configuration:" << cfg->name() << i18n("No environment group specified, looks like a broken "
+        qWarning() << "Launch Configuration:" << cfg->name() << i18n("No environment group specified, looks like a broken "
                        "configuration, please check run configuration '%1'. "
                        "Using default environment group.", cfg->name() );
         envgrp = l.defaultGroup();
     }
-    
+
     QStringList arguments = iface->arguments( cfg, err );
-    if( !err.isEmpty() ) 
+    if( !err.isEmpty() )
     {
         setError( -2 );
         setErrorText( err );
     }
-    
+
     if( error() != 0 )
     {
-        kWarning() << "Launch Configuration:" << cfg->name() << "oops, problem" << errorText();
+        qWarning() << "Launch Configuration:" << cfg->name() << "oops, problem" << errorText();
         return;
     }
-    
+
     proc = new KProcess( this );
-    
+
     lineMaker = new KDevelop::ProcessLineMaker( proc, this );
-    
+
     setStandardToolView(KDevelop::IOutputView::RunView);
     setBehaviours(KDevelop::IOutputView::AllowUserClose | KDevelop::IOutputView::AutoScroll);
     OutputModel* m = new OutputModel;
@@ -97,25 +100,25 @@ NativeAppJob::NativeAppJob(QObject* parent, KDevelop::ILaunchConfiguration* cfg)
     setModel(m);
     setDelegate( new KDevelop::OutputDelegate );
 
-    connect( lineMaker, SIGNAL(receivedStdoutLines(QStringList)), model(), SLOT(appendLines(QStringList)) );
-    connect( proc, SIGNAL(error(QProcess::ProcessError)), SLOT(processError(QProcess::ProcessError)) );
-    connect( proc, SIGNAL(finished(int,QProcess::ExitStatus)), SLOT(processFinished(int,QProcess::ExitStatus)) );
+    connect( lineMaker, &ProcessLineMaker::receivedStdoutLines, model(), &OutputModel::appendLines );
+    connect( proc, static_cast<void(KProcess::*)(QProcess::ProcessError)>(&KProcess::error), this, &NativeAppJob::processError );
+    connect( proc, static_cast<void(KProcess::*)(int,QProcess::ExitStatus)>(&KProcess::finished), this, &NativeAppJob::processFinished );
 
     // Now setup the process parameters
-    
+
     proc->setEnvironment( l.createEnvironment( envgrp, proc->systemEnvironment()) );
-    KUrl wc = iface->workingDirectory( cfg );
+    QUrl wc = iface->workingDirectory( cfg );
     if( !wc.isValid() || wc.isEmpty() )
     {
-        wc = KUrl( QFileInfo( executable.toLocalFile() ).absolutePath() );
+        wc = QUrl::fromLocalFile( QFileInfo( executable.toLocalFile() ).absolutePath() );
     }
     proc->setWorkingDirectory( wc.toLocalFile() );
     proc->setProperty( "executable", executable );
-    
-    kDebug() << "setting app:" << executable << arguments;
-    
+
+    qCDebug(PLUGIN_EXECUTE) << "setting app:" << executable << arguments;
+
     proc->setOutputChannelMode(KProcess::MergedChannels);
-    
+
     if (iface->useTerminal(cfg)) {
         QStringList args = KShell::splitArgs(iface->terminal(cfg));
         for (QStringList::iterator it = args.begin(); it != args.end(); ++it) {
@@ -130,14 +133,34 @@ NativeAppJob::NativeAppJob(QObject* parent, KDevelop::ILaunchConfiguration* cfg)
     } else {
         proc->setProgram( executable.toLocalFile(), arguments );
     }
-    
+
     setObjectName(cfg->name());
 }
 
-
-void NativeAppJob::start() 
+NativeAppJob* findNativeJob(KJob* j)
 {
-    kDebug() << "launching?" << proc;
+    NativeAppJob* job = qobject_cast<NativeAppJob*>(j);
+    if (!job) {
+        const QList<NativeAppJob*> jobs = j->findChildren<NativeAppJob*>();
+        if (!jobs.isEmpty())
+            job = jobs.first();
+    }
+    return job;
+}
+
+void NativeAppJob::start()
+{
+    // we kill any execution of the configuration
+    foreach(KJob* j, ICore::self()->runController()->currentJobs()) {
+        NativeAppJob* job = findNativeJob(j);
+        if (job && job != this && job->m_cfgname == m_cfgname) {
+            QMessageBox::StandardButton button = QMessageBox::question(Q_NULLPTR, i18n("Job already running"), i18n("'%1' is already being executed. Should we kill the previous instance?", m_cfgname));
+            if (button != QMessageBox::NoButton)
+                j->kill();
+        }
+    }
+
+    qCDebug(PLUGIN_EXECUTE) << "launching?" << proc;
     if( proc )
     {
         startOutput();
@@ -145,7 +168,7 @@ void NativeAppJob::start()
         proc->start();
     } else
     {
-        kWarning() << "No process, something went wrong when creating the job";
+        qWarning() << "No process, something went wrong when creating the job";
         // No process means we've returned early on from the constructor, some bad error happened
         emitResult();
     }
@@ -160,14 +183,14 @@ bool NativeAppJob::doKill()
     return true;
 }
 
-void NativeAppJob::processFinished( int exitCode , QProcess::ExitStatus status ) 
+void NativeAppJob::processFinished( int exitCode , QProcess::ExitStatus status )
 {
     if (!model()) {
         outputDone();
         return;
     }
 
-    connect(model(), SIGNAL(allDone()), SLOT(outputDone()));
+    connect(model(), &OutputModel::allDone, this, &NativeAppJob::outputDone);
     lineMaker->flushBuffers();
 
     if (exitCode == 0 && status == QProcess::NormalExit) {
@@ -191,7 +214,7 @@ void NativeAppJob::outputDone()
     emitResult();
 }
 
-void NativeAppJob::processError( QProcess::ProcessError error ) 
+void NativeAppJob::processError( QProcess::ProcessError error )
 {
     if( error == QProcess::FailedToStart )
     {
@@ -202,7 +225,7 @@ void NativeAppJob::processError( QProcess::ProcessError error )
         setErrorText( errmsg );
         emitResult();
     }
-    kDebug() << "Process error";
+    qCDebug(PLUGIN_EXECUTE) << "Process error";
 }
 
 void NativeAppJob::appendLine(const QString& l)
@@ -218,4 +241,3 @@ KDevelop::OutputModel* NativeAppJob::model()
 }
 
 
-#include "nativeappjob.moc"
