@@ -22,16 +22,10 @@
 
 #include "executescriptplugin.h"
 
-#include <QApplication>
-
-#include <klocale.h>
-#include <kpluginfactory.h>
-#include <kpluginloader.h>
-#include <kdebug.h>
-#include <kjob.h>
-#include <kparts/mainwindow.h>
-#include <kmessagebox.h>
-#include <kaboutdata.h>
+#include <KConfigGroup>
+#include <KLocalizedString>
+#include <KPluginFactory>
+#include <KShell>
 
 #include <interfaces/icore.h>
 #include <interfaces/iruncontroller.h>
@@ -39,11 +33,10 @@
 #include <interfaces/iprojectcontroller.h>
 #include <interfaces/iuicontroller.h>
 #include <util/environmentgrouplist.h>
-
 #include "scriptappconfig.h"
+#include "debug.h"
 #include <project/projectmodel.h>
 #include <project/builderjob.h>
-#include <kshell.h>
 #include <util/kdevstringhandler.h>
 
 QString ExecuteScriptPlugin::_scriptAppConfigTypeId = "Script Application";
@@ -63,18 +56,16 @@ QString ExecuteScriptPlugin::outputFilteringEntry = "Output Filtering Mode";
 
 using namespace KDevelop;
 
-K_PLUGIN_FACTORY(KDevExecuteFactory, registerPlugin<ExecuteScriptPlugin>(); )
-K_EXPORT_PLUGIN(KDevExecuteFactory(KAboutData("kdevexecutescript", "kdevexecutescript", ki18n("Execute script support"), "1.0 Beta 1", ki18n("Allows running of scripts"), KAboutData::License_GPL)
-    .addAuthor(ki18n("Niko Sams"), ki18n("Author"), "niko.sams@gmail.com", "http://nikosams.blogspot.com")
-))
+Q_LOGGING_CATEGORY(PLUGIN_EXECUTESCRIPT, "kdevplatform.plugins.executescript")
+K_PLUGIN_FACTORY_WITH_JSON(KDevExecuteFactory, "kdevexecutescript.json", registerPlugin<ExecuteScriptPlugin>();)
 
 ExecuteScriptPlugin::ExecuteScriptPlugin(QObject *parent, const QVariantList&)
-    : KDevelop::IPlugin(KDevExecuteFactory::componentData(), parent)
+    : KDevelop::IPlugin("kdevexecutescript", parent)
 {
     KDEV_USE_EXTENSION_INTERFACE( IExecuteScriptPlugin )
     m_configType = new ScriptAppConfigType();
     m_configType->addLauncher( new ScriptAppLauncher( this ) );
-    kDebug() << "adding script launch config";
+    qCDebug(PLUGIN_EXECUTESCRIPT) << "adding script launch config";
     core()->runController()->addConfigurationType( m_configType );
 }
 
@@ -90,9 +81,9 @@ void ExecuteScriptPlugin::unload()
     m_configType = 0;
 }
 
-KUrl ExecuteScriptPlugin::script( KDevelop::ILaunchConfiguration* cfg, QString& err_ ) const
+QUrl ExecuteScriptPlugin::script( KDevelop::ILaunchConfiguration* cfg, QString& err_ ) const
 {
-    KUrl script;
+    QUrl script;
 
     if( !cfg )
     {
@@ -100,17 +91,17 @@ KUrl ExecuteScriptPlugin::script( KDevelop::ILaunchConfiguration* cfg, QString&
     }
     KConfigGroup grp = cfg->config();
 
-    script = grp.readEntry( ExecuteScriptPlugin::executableEntry, KUrl("") );
+    script = grp.readEntry( ExecuteScriptPlugin::executableEntry, QUrl() );
     if( !script.isLocalFile() || script.isEmpty() )
     {
         err_ = i18n("No valid executable specified");
-        kWarning() << "Launch Configuration:" << cfg->name() << "no valid script set";
+        qWarning() << "Launch Configuration:" << cfg->name() << "no valid script set";
     } else
     {
         KShell::Errors err;
         if( KShell::splitArgs( script.toLocalFile(), KShell::TildeExpand | KShell::AbortOnMeta, &err ).isEmpty() || err != KShell::NoError )
         {
-            script = KUrl();
+            script = QUrl();
             if( err == KShell::BadQuoting )
             {
                 err_ = i18n("There is a quoting error in the script "
@@ -122,7 +113,7 @@ KUrl ExecuteScriptPlugin::script( KDevelop::ILaunchConfiguration* cfg, QString&
                 "script for the launch configuration '%1', "
                 "this is not supported currently. Aborting start.", cfg->name() );
             }
-            kWarning() << "Launch Configuration:" << cfg->name() << "script has meta characters";
+            qWarning() << "Launch Configuration:" << cfg->name() << "script has meta characters";
         }
     }
     return script;
@@ -137,7 +128,7 @@ QString ExecuteScriptPlugin::remoteHost(ILaunchConfiguration* cfg, QString& err)
         if (host.isEmpty()) {
             err = i18n("No remote host set for launch configuration '%1'. "
             "Aborting start.", cfg->name() );
-            kWarning() << "Launch Configuration:" << cfg->name() << "no remote host set";
+            qWarning() << "Launch Configuration:" << cfg->name() << "no remote host set";
         }
         return host;
     }
@@ -155,7 +146,7 @@ QStringList ExecuteScriptPlugin::arguments( KDevelop::ILaunchConfiguration* cfg,
     QStringList args = KShell::splitArgs( cfg->config().readEntry( ExecuteScriptPlugin::argumentsEntry, "" ), KShell::TildeExpand | KShell::AbortOnMeta, &err );
     if( err != KShell::NoError )
     {
-        
+
         if( err == KShell::BadQuoting )
         {
             err_ = i18n("There is a quoting error in the arguments for "
@@ -167,7 +158,7 @@ QStringList ExecuteScriptPlugin::arguments( KDevelop::ILaunchConfiguration* cfg,
             "this is not supported currently. Aborting start.", cfg->name() );
         }
         args = QStringList();
-        kWarning() << "Launch Configuration:" << cfg->name() << "arguments have meta characters";
+        qWarning() << "Launch Configuration:" << cfg->name() << "arguments have meta characters";
     }
     return args;
 }
@@ -178,7 +169,7 @@ QString ExecuteScriptPlugin::environmentGroup( KDevelop::ILaunchConfiguration* c
     {
         return "";
     }
-    
+
     return cfg->config().readEntry( ExecuteScriptPlugin::environmentGroupEntry, "" );
 }
 
@@ -205,36 +196,36 @@ bool ExecuteScriptPlugin::runCurrentFile(ILaunchConfiguration* cfg) const
 QString ExecuteScriptPlugin::interpreter( KDevelop::ILaunchConfiguration* cfg, QString& err ) const
 {
     QString interpreter;
-    if( !cfg ) 
+    if( !cfg )
     {
         return interpreter;
     }
     KConfigGroup grp = cfg->config();
 
-    interpreter = grp.readEntry( ExecuteScriptPlugin::interpreterEntry, QString("") );
+    interpreter = grp.readEntry( ExecuteScriptPlugin::interpreterEntry, QString() );
 
     if( interpreter.isEmpty() )
     {
         err = i18n("No valid interpreter specified");
-        kWarning() << "Launch Configuration:" << cfg->name() << "no valid interpreter set";
+        qWarning() << "Launch Configuration:" << cfg->name() << "no valid interpreter set";
     } else
     {
         KShell::Errors err_;
         if( KShell::splitArgs( interpreter, KShell::TildeExpand | KShell::AbortOnMeta, &err_ ).isEmpty() || err_ != KShell::NoError )
         {
             interpreter.clear();
-            if( err_ == KShell::BadQuoting ) 
+            if( err_ == KShell::BadQuoting )
             {
                 err = i18n("There is a quoting error in the interpreter "
                 "for the launch configuration '%1'. "
                 "Aborting start.", cfg->name() );
-            } else 
-            {   
+            } else
+            {
                 err = i18n("A shell meta character was included in the "
                 "interpreter for the launch configuration '%1', "
                 "this is not supported currently. Aborting start.", cfg->name() );
             }
-            kWarning() << "Launch Configuration:" << cfg->name() << "interpreter has meta characters";
+            qWarning() << "Launch Configuration:" << cfg->name() << "interpreter has meta characters";
         }
     }
     return interpreter;
@@ -247,19 +238,19 @@ bool ExecuteScriptPlugin::useTerminal( KDevelop::ILaunchConfiguration* cfg ) con
     {
         return false;
     }
-    
+
     return cfg->config().readEntry( ExecuteScriptPlugin::useTerminalEntry, false );
 }
 */
 
-KUrl ExecuteScriptPlugin::workingDirectory( KDevelop::ILaunchConfiguration* cfg ) const
+QUrl ExecuteScriptPlugin::workingDirectory( KDevelop::ILaunchConfiguration* cfg ) const
 {
     if( !cfg )
     {
-        return KUrl();
+        return QUrl();
     }
-    
-    return cfg->config().readEntry( ExecuteScriptPlugin::workingDirEntry, KUrl() );
+
+    return cfg->config().readEntry( ExecuteScriptPlugin::workingDirEntry, QUrl() );
 }
 
 
