@@ -44,33 +44,31 @@
 
 #include <KPluginFactory>
 #include <KAboutData>
-#include <KAction>
 #include <KProcess>
+#include <KLocalizedString>
 
+#include <QAction>
 #include <QStandardItemModel>
 #include <QDBusConnection>
 #include <QMenu>
 
 
-K_PLUGIN_FACTORY( ExternalScriptFactory, registerPlugin<ExternalScriptPlugin>(); )
-K_EXPORT_PLUGIN( ExternalScriptFactory( KAboutData( "kdevexternalscript", "kdevexternalscript", ki18n( "External Scripts" ),
-                                        "0.1", ki18n( "Run external scripts or applications to manipulate the editor contents or do other arbitrary actions." ),
-                                        KAboutData::License_GPL ) ) )
+K_PLUGIN_FACTORY_WITH_JSON(ExternalScriptFactory, "kdevexternalscript.json", registerPlugin<ExternalScriptPlugin>();)
 
 class ExternalScriptViewFactory: public KDevelop::IToolViewFactory
 {
 public:
   ExternalScriptViewFactory( ExternalScriptPlugin *plugin ): m_plugin( plugin ) {}
 
-  virtual QWidget* create( QWidget *parent = 0 ) {
+  virtual QWidget* create( QWidget *parent = 0 ) override {
     return new ExternalScriptView( m_plugin, parent );
   }
 
-  virtual Qt::DockWidgetArea defaultPosition() {
+  virtual Qt::DockWidgetArea defaultPosition() override {
     return Qt::RightDockWidgetArea;
   }
 
-  virtual QString id() const {
+  virtual QString id() const override {
     return "org.kdevelop.ExternalScriptView";
   }
 
@@ -81,19 +79,19 @@ private:
 ExternalScriptPlugin* ExternalScriptPlugin::m_self = 0;
 
 ExternalScriptPlugin::ExternalScriptPlugin( QObject* parent, const QVariantList& /*args*/ )
-    : IPlugin( ExternalScriptFactory::componentData(), parent ),
+    : IPlugin( "kdevexternalscript", parent ),
     m_model( new QStandardItemModel( this ) ), m_factory( new ExternalScriptViewFactory( this ) )
 {
   Q_ASSERT( !m_self );
   m_self = this;
 
   QDBusConnection::sessionBus().registerObject( "/org/kdevelop/ExternalScriptPlugin", this, QDBusConnection::ExportScriptableSlots );
-  
+
   setXMLFile( "kdevexternalscript.rc" );
 
   //BEGIN load config
   KConfigGroup config = getConfig();
-  foreach( const QString group, config.groupList() ) {
+  foreach( const QString& group, config.groupList() ) {
     KConfigGroup script = config.group( group );
     if ( script.hasKey( "name" ) && script.hasKey( "command" ) ) {
       ExternalScriptItem* item = new ExternalScriptItem;
@@ -104,7 +102,7 @@ ExternalScriptPlugin::ExternalScriptPlugin( QObject* parent, const QVariantList&
       item->setErrorMode( static_cast<ExternalScriptItem::ErrorMode>( script.readEntry( "errorMode", 0u ) ) );
       item->setSaveMode( static_cast<ExternalScriptItem::SaveMode>( script.readEntry( "saveMode", 0u ) ) );
       item->setFilterMode( script.readEntry( "filterMode", 0u ));
-      item->action()->setShortcut( KShortcut( script.readEntry( "shortcuts" ) ) );
+      item->action()->setShortcut( QKeySequence( script.readEntry( "shortcuts" ) ) );
       item->setShowOutput( script.readEntry( "showOutput", true ) );
       m_model->appendRow( item );
     }
@@ -113,10 +111,10 @@ ExternalScriptPlugin::ExternalScriptPlugin( QObject* parent, const QVariantList&
 
   core()->uiController()->addToolView( i18n( "External Scripts" ), m_factory );
 
-  connect( m_model, SIGNAL(rowsRemoved(QModelIndex,int,int)),
-           this, SLOT(rowsRemoved(QModelIndex,int,int)) );
-  connect( m_model, SIGNAL(rowsInserted(QModelIndex,int,int)),
-           this, SLOT(rowsInserted(QModelIndex,int,int)) );
+  connect( m_model, &QStandardItemModel::rowsRemoved,
+           this, &ExternalScriptPlugin::rowsRemoved );
+  connect( m_model, &QStandardItemModel::rowsInserted,
+           this, &ExternalScriptPlugin::rowsInserted );
 
   const bool firstUse = config.readEntry( "firstUse", true );
   if ( firstUse ) {
@@ -213,9 +211,9 @@ KDevelop::ContextMenuExtension ExternalScriptPlugin::contextMenuExtension( KDeve
         }
       }
 
-      KAction* scriptAction = new KAction( item->text(), this );
+      QAction* scriptAction = new QAction( item->text(), this );
       scriptAction->setData( QVariant::fromValue<ExternalScriptItem*>( item ));
-      connect( scriptAction, SIGNAL( triggered() ), SLOT( executeScriptFromContextMenu() ) );
+      connect( scriptAction, &QAction::triggered, this, &ExternalScriptPlugin::executeScriptFromContextMenu );
       menu->addAction( scriptAction );
     }
 
@@ -235,7 +233,7 @@ void ExternalScriptPlugin::unload()
 
 KConfigGroup ExternalScriptPlugin::getConfig() const
 {
-  return KGlobal::config()->group("External Scripts");
+  return KSharedConfig::openConfig()->group("External Scripts");
 }
 
 QStandardItemModel* ExternalScriptPlugin::model() const
@@ -243,7 +241,7 @@ QStandardItemModel* ExternalScriptPlugin::model() const
   return m_model;
 }
 
-void ExternalScriptPlugin::execute( ExternalScriptItem* item, const KUrl& url ) const
+void ExternalScriptPlugin::execute( ExternalScriptItem* item, const QUrl& url ) const
 {
   ExternalScriptJob* job = new ExternalScriptJob( item, url, const_cast<ExternalScriptPlugin*>(this) );
 
@@ -253,7 +251,7 @@ void ExternalScriptPlugin::execute( ExternalScriptItem* item, const KUrl& url )
 void ExternalScriptPlugin::execute(ExternalScriptItem* item) const
 {
   auto document = KDevelop::ICore::self()->documentController()->activeDocument();
-  execute( item, document ? document->url() : KUrl() );
+  execute( item, document ? document->url() : QUrl() );
 }
 
 bool ExternalScriptPlugin::executeCommand ( QString command, QString workingDirectory ) const
@@ -261,7 +259,7 @@ bool ExternalScriptPlugin::executeCommand ( QString command, QString workingDire
   // We extend ExternalScriptJob so that it deletes the temporarily created item on destruction
   class ExternalScriptJobOwningItem : public ExternalScriptJob {
   public:
-    ExternalScriptJobOwningItem( ExternalScriptItem* item, const KUrl &url, ExternalScriptPlugin* parent ) : ExternalScriptJob(item, url, parent), m_item(item) {
+    ExternalScriptJobOwningItem( ExternalScriptItem* item, const QUrl &url, ExternalScriptPlugin* parent ) : ExternalScriptJob(item, url, parent), m_item(item) {
     }
     ~ExternalScriptJobOwningItem() {
       delete m_item;
@@ -273,18 +271,18 @@ bool ExternalScriptPlugin::executeCommand ( QString command, QString workingDire
   item->setCommand(command);
   item->setWorkingDirectory(workingDirectory);
   item->setPerformParameterReplacement(false);
-  debug() << "executing command " << command << " in dir " << workingDirectory << " as external script";
-  ExternalScriptJobOwningItem* job = new ExternalScriptJobOwningItem( item, KUrl(), const_cast<ExternalScriptPlugin*>(this) );
+  qCDebug(PLUGIN_EXTERNALSCRIPT) << "executing command " << command << " in dir " << workingDirectory << " as external script";
+  ExternalScriptJobOwningItem* job = new ExternalScriptJobOwningItem( item, QUrl(), const_cast<ExternalScriptPlugin*>(this) );
   // When a command is executed, for example through the terminal, we don't want the command output to be risen
   job->setVerbosity(KDevelop::OutputJob::Silent);
-  
+
   KDevelop::ICore::self()->runController()->registerJob( job );
   return true;
 }
 
 QString ExternalScriptPlugin::executeCommandSync ( QString command, QString workingDirectory ) const
 {
-  debug() << "executing command " << command << " in working-dir " << workingDirectory;
+  qCDebug(PLUGIN_EXTERNALSCRIPT) << "executing command " << command << " in working-dir " << workingDirectory;
   KProcess process;
   process.setWorkingDirectory( workingDirectory );
   process.setShellCommand( command );
@@ -295,7 +293,7 @@ QString ExternalScriptPlugin::executeCommandSync ( QString command, QString work
 
 void ExternalScriptPlugin::executeScriptFromActionData() const
 {
-  KAction* action = dynamic_cast<KAction*>( sender() );
+  QAction* action = dynamic_cast<QAction*>( sender() );
   Q_ASSERT( action );
 
   ExternalScriptItem* item = action->data().value<ExternalScriptItem*>();
@@ -306,13 +304,13 @@ void ExternalScriptPlugin::executeScriptFromActionData() const
 
 void ExternalScriptPlugin::executeScriptFromContextMenu() const
 {
-  KAction* action = dynamic_cast<KAction*>( sender() );
+  QAction* action = dynamic_cast<QAction*>( sender() );
   Q_ASSERT( action );
 
   ExternalScriptItem* item = action->data().value<ExternalScriptItem*>();
   Q_ASSERT( item );
 
-  foreach( const KUrl& url, m_urls) {
+  foreach( const QUrl& url, m_urls) {
     KDevelop::ICore::self()->documentController()->openDocument( url );
     execute( item, url );
   }
@@ -329,8 +327,8 @@ void ExternalScriptPlugin::rowsRemoved( const QModelIndex& /*parent*/, int start
 {
   KConfigGroup config = getConfig();
   for ( int i = start; i <= end; ++i ) {
-    KConfigGroup child = config.group( QString("script %1").arg(i) );
-    debug() << "removing config group:" << child.name();
+    KConfigGroup child = config.group( QStringLiteral("script %1").arg(i) );
+    qCDebug(PLUGIN_EXTERNALSCRIPT) << "removing config group:" << child.name();
     child.deleteGroup();
   }
   config.sync();
@@ -351,8 +349,8 @@ void ExternalScriptPlugin::saveItemForRow( int row )
   ExternalScriptItem* item = dynamic_cast<ExternalScriptItem*>( m_model->item( row ) );
   Q_ASSERT( item );
 
-  debug() << "save extern script:" << item << idx;
-  KConfigGroup config = getConfig().group( QString("script %1").arg( row ) );
+  qCDebug(PLUGIN_EXTERNALSCRIPT) << "save extern script:" << item << idx;
+  KConfigGroup config = getConfig().group( QStringLiteral("script %1").arg( row ) );
   config.writeEntry( "name", item->text() );
   config.writeEntry( "command", item->command() );
   config.writeEntry( "inputMode", (uint) item->inputMode() );
@@ -367,4 +365,4 @@ void ExternalScriptPlugin::saveItemForRow( int row )
 
 #include "externalscriptplugin.moc"
 
-// kate: indent-mode cstyle; space-indent on; indent-width 2; replace-tabs on; 
+// kate: indent-mode cstyle; space-indent on; indent-width 2; replace-tabs on;
