@@ -26,6 +26,7 @@
 #include <QVariantList>
 #include <KConfigGroup>
 #include <QModelIndex>
+#include <QUrl>
 
 class ExternalScriptItem;
 
@@ -38,11 +39,11 @@ class ExternalScriptPlugin : public KDevelop::IPlugin
   Q_CLASSINFO( "D-Bus Interface", "org.kdevelop.ExternalScriptPlugin" )
 
 public:
-  ExternalScriptPlugin( QObject *parent, const QVariantList &args = QVariantList() );
+  explicit ExternalScriptPlugin( QObject *parent, const QVariantList &args = QVariantList() );
 
   virtual ~ExternalScriptPlugin();
-  virtual void unload();
-  virtual KDevelop::ContextMenuExtension contextMenuExtension(KDevelop::Context* context);
+  virtual void unload() override;
+  virtual KDevelop::ContextMenuExtension contextMenuExtension(KDevelop::Context* context) override;
 
   static ExternalScriptPlugin* self();
 
@@ -52,6 +53,11 @@ public:
    */
   QStandardItemModel* model() const;
 
+  /**
+   * Executes @p script.
+   */
+  void execute(ExternalScriptItem* item, const QUrl &url) const;
+
   /**
    * Executes @p script.
    */
@@ -87,7 +93,7 @@ private:
   void saveItemForRow( int row );
 
   QStandardItemModel* m_model;
-  KUrl::List m_urls;
+  QList<QUrl> m_urls;
   static ExternalScriptPlugin* m_self;
 
   class ExternalScriptViewFactory *m_factory;
