@@ -1,6 +1,7 @@
 #include "filetemplatesplugin.h"
 #include "templateclassassistant.h"
 #include "templatepreviewtoolview.h"
+#include "debug.h"
 
 #include <language/codegen/templatesmodel.h>
 #include <language/interfaces/editorcontext.h>
@@ -12,28 +13,19 @@
 #include <project/projectmodel.h>
 #include <util/path.h>
 
-#include <KIcon>
-#include <KDebug>
+#include <KActionCollection>
+#include <KConfigGroup>
 #include <KLocalizedString>
 #include <KPluginFactory>
-#include <KAboutData>
-#include <KActionCollection>
-#include <KAction>
+
+#include <QAction>
 #include <QApplication>
 #include <QDir>
-
-#define debug() kDebug(debugArea())
+#include <QIcon>
 
 using namespace KDevelop;
 
-int debugArea()
-{
-    static int area = KDebug::registerArea("kdevfiletemplates");
-    return area;
-}
-
-K_PLUGIN_FACTORY(FileTemplatesFactory, registerPlugin<FileTemplatesPlugin>();)
-K_EXPORT_PLUGIN(FileTemplatesFactory(KAboutData("kdevfiletemplates", "kdevfiletemplates", ki18n("File Templates Configuration"), "0.1", ki18n("Manages templates for source files"), KAboutData::License_GPL)))
+K_PLUGIN_FACTORY_WITH_JSON(FileTemplatesFactory, "kdevfiletemplates.json", registerPlugin<FileTemplatesPlugin>();)
 
 class TemplatePreviewFactory : public KDevelop::IToolViewFactory
 {
@@ -45,17 +37,17 @@ public:
 
     }
 
-    virtual QWidget* create(QWidget* parent = 0)
+    virtual QWidget* create(QWidget* parent = 0) override
     {
         return new TemplatePreviewToolView(m_plugin, parent);
     }
 
-    virtual QString id() const
+    virtual QString id() const override
     {
         return "org.kdevelop.TemplateFilePreview";
     }
 
-    virtual Qt::DockWidgetArea defaultPosition()
+    virtual Qt::DockWidgetArea defaultPosition() override
     {
         return Qt::RightDockWidgetArea;
     }
@@ -65,19 +57,19 @@ private:
 };
 
 FileTemplatesPlugin::FileTemplatesPlugin(QObject* parent, const QVariantList& args)
-    : IPlugin(FileTemplatesFactory::componentData(), parent)
+    : IPlugin("kdevfiletemplates", parent)
     , m_model(0)
 {
     Q_UNUSED(args);
     KDEV_USE_EXTENSION_INTERFACE(ITemplateProvider)
 
     setXMLFile("kdevfiletemplates.rc");
-    KAction* action = actionCollection()->addAction("new_from_template");
+    QAction* action = actionCollection()->addAction("new_from_template");
     action->setText( i18n( "New From Template" ) );
-    action->setIcon( KIcon( "code-class" ) );
+    action->setIcon( QIcon::fromTheme( "code-class" ) );
     action->setWhatsThis( i18n( "Allows you to create new source code files, such as classes or unit tests, using templates." ) );
     action->setStatusTip( i18n( "Create new files from a template" ) );
-    connect (action, SIGNAL(triggered(bool)), SLOT(createFromTemplate()));
+    connect (action, &QAction::triggered, this, &FileTemplatesPlugin::createFromTemplate);
 
     m_toolView = new TemplatePreviewFactory(this);
     core()->uiController()->addToolView(i18n("Template Preview"), m_toolView);
@@ -96,7 +88,7 @@ void FileTemplatesPlugin::unload()
 ContextMenuExtension FileTemplatesPlugin::contextMenuExtension (Context* context)
 {
     ContextMenuExtension ext;
-    KUrl fileUrl;
+    QUrl fileUrl;
 
     if (context->type() == Context::ProjectItemContext)
     {
@@ -107,7 +99,7 @@ ContextMenuExtension FileTemplatesPlugin::contextMenuExtension (Context* context
             return ext;
         }
 
-        KUrl url;
+        QUrl url;
         ProjectBaseItem* item = items.first();
         if (item->folder())
         {
@@ -119,10 +111,10 @@ ContextMenuExtension FileTemplatesPlugin::contextMenuExtension (Context* context
         }
         if (url.isValid())
         {
-            KAction* action = new KAction(i18n("Create From Template"), this);
-            action->setIcon(KIcon("code-class"));
+            QAction* action = new QAction(i18n("Create From Template"), this);
+            action->setIcon(QIcon::fromTheme("code-class"));
             action->setData(url);
-            connect(action, SIGNAL(triggered(bool)), SLOT(createFromTemplate()));
+            connect(action, &QAction::triggered, this, &FileTemplatesPlugin::createFromTemplate);
             ext.addAction(ContextMenuExtension::FileGroup, action);
         }
 
@@ -139,10 +131,10 @@ ContextMenuExtension FileTemplatesPlugin::contextMenuExtension (Context* context
 
     if (fileUrl.isValid() && determineTemplateType(fileUrl) != NoTemplate)
     {
-        KAction* action = new KAction(i18n("Show Template Preview"), this);
-        action->setIcon(KIcon("document-preview"));
+        QAction* action = new QAction(i18n("Show Template Preview"), this);
+        action->setIcon(QIcon::fromTheme("document-preview"));
         action->setData(fileUrl);
-        connect(action, SIGNAL(triggered(bool)), SLOT(previewTemplate()));
+        connect(action, &QAction::triggered, this, &FileTemplatesPlugin::previewTemplate);
         ext.addAction(ContextMenuExtension::ExtensionGroup, action);
     }
 
@@ -156,7 +148,7 @@ QString FileTemplatesPlugin::name() const
 
 QIcon FileTemplatesPlugin::icon() const
 {
-    return KIcon("code-class");
+    return QIcon::fromTheme("code-class");
 }
 
 QAbstractItemModel* FileTemplatesPlugin::templatesModel()
@@ -195,16 +187,16 @@ void FileTemplatesPlugin::loadTemplate(const QString& fileName)
 
 void FileTemplatesPlugin::createFromTemplate()
 {
-    KUrl baseUrl;
+    QUrl baseUrl;
     if (QAction* action = qobject_cast<QAction*>(sender()))
     {
-        baseUrl = action->data().value<KUrl>();
+        baseUrl = action->data().value<QUrl>();
     }
     if (!baseUrl.isValid()) {
         // fall-back to currently active document's parent directory
         IDocument* doc = ICore::self()->documentController()->activeDocument();
         if (doc && doc->url().isValid()) {
-            baseUrl = doc->url().upUrl();
+            baseUrl = doc->url().adjusted(QUrl::RemoveFilename);
         }
     }
     TemplateClassAssistant* assistant = new TemplateClassAssistant(QApplication::activeWindow(), baseUrl);
@@ -212,7 +204,7 @@ void FileTemplatesPlugin::createFromTemplate()
     assistant->show();
 }
 
-FileTemplatesPlugin::TemplateType FileTemplatesPlugin::determineTemplateType(const KUrl& url)
+FileTemplatesPlugin::TemplateType FileTemplatesPlugin::determineTemplateType(const QUrl& url)
 {
     QDir dir(url.toLocalFile());
 
@@ -227,7 +219,7 @@ FileTemplatesPlugin::TemplateType FileTemplatesPlugin::determineTemplateType(con
         filters << "*.kdevtemplate" << "*.desktop";
         foreach (const QString& entry, dir.entryList(filters))
         {
-            kDebug() << "Trying entry" << entry;
+            qCDebug(PLUGIN_FILETEMPLATES) << "Trying entry" << entry;
             /*
             * This logic is not perfect, but it works for most cases.
             *
@@ -247,7 +239,7 @@ FileTemplatesPlugin::TemplateType FileTemplatesPlugin::determineTemplateType(con
             KConfig* config = new KConfig(dir.absoluteFilePath(entry), KConfig::SimpleConfig);
             KConfigGroup group = config->group("General");
 
-            kDebug() << "General group keys:" << group.keyList();
+            qCDebug(PLUGIN_FILETEMPLATES) << "General group keys:" << group.keyList();
 
             if (!group.hasKey("Name") || !group.hasKey("Category"))
             {
@@ -256,7 +248,7 @@ FileTemplatesPlugin::TemplateType FileTemplatesPlugin::determineTemplateType(con
 
             if (group.hasKey("Files"))
             {
-                kDebug() << "Group has files " << group.readEntry("Files", QStringList());
+                qCDebug(PLUGIN_FILETEMPLATES) << "Group has files " << group.readEntry("Files", QStringList());
                 foreach (const QString& outputFile, group.readEntry("Files", QStringList()))
                 {
                     if (dir.absoluteFilePath(config->group(outputFile).readEntry("File")) == url.toLocalFile())
@@ -281,7 +273,7 @@ FileTemplatesPlugin::TemplateType FileTemplatesPlugin::determineTemplateType(con
 void FileTemplatesPlugin::previewTemplate()
 {
     QAction* action = qobject_cast<QAction*>(sender());
-    if (!action || !action->data().value<KUrl>().isValid())
+    if (!action || !action->data().value<QUrl>().isValid())
     {
         return;
     }
@@ -291,5 +283,7 @@ void FileTemplatesPlugin::previewTemplate()
         return;
     }
 
-    core()->documentController()->activateDocument(core()->documentController()->openDocument(action->data().value<KUrl>()));
+    core()->documentController()->activateDocument(core()->documentController()->openDocument(action->data().value<QUrl>()));
 }
+
+#include "filetemplatesplugin.moc"
