@@ -1,11 +1,11 @@
-#ifndef FILETEMPLATESPLUGIN_H
-#define FILETEMPLATESPLUGIN_H
+#ifndef KDEVPLATFORM_PLUGIN_FILETEMPLATESPLUGIN_H
+#define KDEVPLATFORM_PLUGIN_FILETEMPLATESPLUGIN_H
 
 #include <interfaces/iplugin.h>
 #include <interfaces/itemplateprovider.h>
 #include <QVariantList>
 
-class KUrl;
+class QUrl;
 namespace KDevelop
 {
 class TemplatesModel;
@@ -28,20 +28,20 @@ public:
 
     FileTemplatesPlugin(QObject* parent, const QVariantList& args);
     virtual ~FileTemplatesPlugin();
-    virtual void unload();
+    virtual void unload() override;
 
-    virtual KDevelop::ContextMenuExtension contextMenuExtension (KDevelop::Context* context);
+    virtual KDevelop::ContextMenuExtension contextMenuExtension (KDevelop::Context* context) override;
 
-    virtual QString name() const;
-    virtual QIcon icon() const;
-    virtual QAbstractItemModel* templatesModel() const;
-    virtual QString knsConfigurationFile() const;
-    virtual QStringList supportedMimeTypes() const;
+    virtual QString name() const override;
+    virtual QIcon icon() const override;
+    virtual QAbstractItemModel* templatesModel() override;
+    virtual QString knsConfigurationFile() const override;
+    virtual QStringList supportedMimeTypes() const override;
 
-    virtual void reload();
-    virtual void loadTemplate(const QString& fileName);
+    virtual void reload() override;
+    virtual void loadTemplate(const QString& fileName) override;
 
-    TemplateType determineTemplateType(const KUrl& url);
+    TemplateType determineTemplateType(const QUrl& url);
 
 private:
     KDevelop::TemplatesModel* m_model;
@@ -52,4 +52,4 @@ public slots:
     void previewTemplate();
 };
 
-#endif // FILETEMPLATESPLUGIN_H
+#endif // KDEVPLATFORM_PLUGIN_FILETEMPLATESPLUGIN_H
