@@ -20,12 +20,9 @@
 #define KDEVPLATFORM_PLUGIN_OUTPUTPAGE_H
 
 #include <QWidget>
-#include <KUrl>
+#include <QUrl>
+#include <ktexteditor/cursor.h>
 
-
-#include <language/editor/simplecursor.h>
-
-class KUrl;
 namespace KDevelop {
 
 class TemplateRenderer;
@@ -40,7 +37,7 @@ class OutputPage : public QWidget
     Q_OBJECT
 
 public:
-    OutputPage(QWidget* parent);
+    explicit OutputPage(QWidget* parent);
     virtual ~OutputPage();
 
     /**
@@ -60,17 +57,17 @@ public:
      * @param baseUrl the directory where the files are to be generated
      * @param renderer used to render any variables in output URLs
      */
-    void loadFileTemplate(const KDevelop::SourceFileTemplate& fileTemplate, const KUrl& baseUrl,
+    void loadFileTemplate(const KDevelop::SourceFileTemplate& fileTemplate, const QUrl& baseUrl,
                           KDevelop::TemplateRenderer* renderer);
 
     /**
      * Returns the file URLs, as specified by the user.
      */
-    QHash<QString, KUrl> fileUrls() const;
+    QHash<QString, QUrl> fileUrls() const;
     /**
      * Returns the positions within files where code is to be generated.
      */
-    QHash<QString, SimpleCursor> filePositions() const;
+    QHash<QString, KTextEditor::Cursor> filePositions() const;
 
 Q_SIGNALS:
     /**
