@@ -28,6 +28,7 @@
 #include "outputpage.h"
 #include "testcasespage.h"
 #include "defaultcreateclasshelper.h"
+#include "debug.h"
 
 #include <language/codegen/templateclassgenerator.h>
 #include <language/codegen/sourcefiletemplate.h>
@@ -39,7 +40,6 @@
 
 #include <interfaces/icore.h>
 #include <interfaces/ilanguagecontroller.h>
-#include <interfaces/ilanguage.h>
 #include <interfaces/idocumentcontroller.h>
 #include <interfaces/iproject.h>
 #include <interfaces/iprojectcontroller.h>
@@ -47,12 +47,16 @@
 #include <project/interfaces/iprojectfilemanager.h>
 #include <project/interfaces/ibuildsystemmanager.h>
 
-#include <KLocalizedString>
-#include <KConfig>
-#include <QVBoxLayout>
+#include <QDialog>
+#include <QDialogButtonBox>
 #include <QLabel>
 #include <QListWidget>
 #include <QPointer>
+#include <QPushButton>
+#include <QVBoxLayout>
+
+#include <KIO/Global>
+#include <KLocalizedString>
 
 #define REMOVE_PAGE(name)       \
 if (d->name##Page)              \
@@ -71,10 +75,10 @@ using namespace KDevelop;
 class KDevelop::TemplateClassAssistantPrivate
 {
 public:
-    TemplateClassAssistantPrivate(const KUrl& baseUrl);
+    TemplateClassAssistantPrivate(const QUrl& baseUrl);
     ~TemplateClassAssistantPrivate();
 
-    void addFilesToTarget (const QHash<QString, KUrl>& fileUrls);
+    void addFilesToTarget (const QHash<QString, QUrl>& fileUrls);
 
     KPageWidgetItem* templateSelectionPage;
     KPageWidgetItem* classIdentifierPage;
@@ -95,7 +99,7 @@ public:
     TemplateOptionsPage* templateOptionsPageWidget;
     OutputPage* outputPageWidget;
 
-    KUrl baseUrl;
+    QUrl baseUrl;
     SourceFileTemplate fileTemplate;
     ICreateClassHelper* helper;
     TemplateClassGenerator* generator;
@@ -105,7 +109,7 @@ public:
     QVariantHash templateOptions;
 };
 
-TemplateClassAssistantPrivate::TemplateClassAssistantPrivate(const KUrl& baseUrl)
+TemplateClassAssistantPrivate::TemplateClassAssistantPrivate(const QUrl& baseUrl)
 : baseUrl(baseUrl)
 , helper(0)
 , generator(0)
@@ -128,10 +132,10 @@ TemplateClassAssistantPrivate::~TemplateClassAssistantPrivate()
     }
 }
 
-void TemplateClassAssistantPrivate::addFilesToTarget (const QHash< QString, KUrl >& fileUrls)
+void TemplateClassAssistantPrivate::addFilesToTarget (const QHash< QString, QUrl >& fileUrls)
 {
     // Add the generated files to a target, if one is found
-    KUrl url = baseUrl;
+    QUrl url = baseUrl;
     if (!url.isValid())
     {
         // This was probably not launched from the project manager view
@@ -139,21 +143,21 @@ void TemplateClassAssistantPrivate::addFilesToTarget (const QHash< QString, KUrl
 
         if (!fileUrls.isEmpty())
         {
-            url = fileUrls.constBegin().value().upUrl();
+            url = fileUrls.constBegin().value().adjusted(QUrl::RemoveFilename);
         }
     }
-    kDebug() << "Searching for targets with URL" << url.prettyUrl();
+    qCDebug(PLUGIN_FILETEMPLATES) << "Searching for targets with URL" << url;
     IProject* project = ICore::self()->projectController()->findProjectForUrl(url);
     if (!project || !project->buildSystemManager())
     {
-        kDebug() << "No suitable project found";
+        qCDebug(PLUGIN_FILETEMPLATES) << "No suitable project found";
         return;
     }
 
-    QList<ProjectBaseItem*> items = project->itemsForUrl(url);
+    QList<ProjectBaseItem*> items = project->itemsForPath(IndexedString(url));
     if (items.isEmpty())
     {
-        kDebug() << "No suitable project items found";
+        qCDebug(PLUGIN_FILETEMPLATES) << "No suitable project items found";
         return;
     }
 
@@ -190,27 +194,32 @@ void TemplateClassAssistantPrivate::addFilesToTarget (const QHash< QString, KUrl
 
     if (targets.size() == 1)
     {
-        kDebug() << "Only one candidate target," << targets.first()->text() << ", using it";
+        qCDebug(PLUGIN_FILETEMPLATES) << "Only one candidate target," << targets.first()->text() << ", using it";
         target = targets.first();
     }
     else if (targets.size() > 1)
     {
         // More than one candidate target, show the chooser dialog
-        QPointer<KDialog> d = new KDialog;
-        QWidget* w = new QWidget(d);
-        w->setLayout(new QVBoxLayout);
-        w->layout()->addWidget(new QLabel(i18n("Choose one target to add the file or cancel if you do not want to do so.")));
-        QListWidget* targetsWidget = new QListWidget(w);
+        QPointer<QDialog> d = new QDialog;
+
+        auto mainLayout = new QVBoxLayout(d);
+        mainLayout->addWidget(new QLabel(i18n("Choose one target to add the file or cancel if you do not want to do so.")));
+
+        QListWidget* targetsWidget = new QListWidget(d);
         targetsWidget->setSelectionMode(QAbstractItemView::SingleSelection);
         foreach(ProjectTargetItem* target, targets) {
             targetsWidget->addItem(target->text());
         }
-        w->layout()->addWidget(targetsWidget);
-
         targetsWidget->setCurrentRow(0);
-        d->setButtons( KDialog::Ok | KDialog::Cancel);
-        d->enableButtonOk(true);
-        d->setMainWidget(w);
+        mainLayout->addWidget(targetsWidget);
+
+        QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
+        QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
+        okButton->setDefault(true);
+        okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+        d->connect(buttonBox, &QDialogButtonBox::accepted, d.data(), &QDialog::accept);
+        d->connect(buttonBox, &QDialogButtonBox::rejected, d.data(), &QDialog::reject);
+        mainLayout->addWidget(buttonBox);
 
         if(d->exec() == QDialog::Accepted)
         {
@@ -220,32 +229,32 @@ void TemplateClassAssistantPrivate::addFilesToTarget (const QHash< QString, KUrl
             }
             else
             {
-                kDebug() << "Did not select anything, not adding to a target";
+                qCDebug(PLUGIN_FILETEMPLATES) << "Did not select anything, not adding to a target";
                 return;
             }
         }
         else {
-            kDebug() << "Canceled select target dialog, not adding to a target";
+            qCDebug(PLUGIN_FILETEMPLATES) << "Canceled select target dialog, not adding to a target";
             return;
         }
     }
     else
     {
         // No target, not doing anything
-        kDebug() << "No possible targets for URL" << url;
+        qCDebug(PLUGIN_FILETEMPLATES) << "No possible targets for URL" << url;
         return;
     }
 
     Q_ASSERT(target);
 
     QList<ProjectFileItem*> fileItems;
-    foreach (const KUrl& fileUrl, fileUrls)
+    foreach (const QUrl &fileUrl, fileUrls)
     {
-        foreach (ProjectBaseItem* item, project->itemsForUrl(fileUrl.upUrl()))
+        foreach (ProjectBaseItem* item, project->itemsForPath(IndexedString(KIO::upUrl(fileUrl))))
         {
             if (ProjectFolderItem* folder = item->folder())
             {
-                ///FIXME: use Path instead of KUrl in the template class assistant
+                ///FIXME: use Path instead of QUrl in the template class assistant
                 if (ProjectFileItem* file = project->projectFileManager()->addFile(Path(fileUrl), folder)) {
                     fileItems << file;
                     break;
@@ -260,7 +269,7 @@ void TemplateClassAssistantPrivate::addFilesToTarget (const QHash< QString, KUrl
 
 }
 
-TemplateClassAssistant::TemplateClassAssistant(QWidget* parent, const KUrl& baseUrl)
+TemplateClassAssistant::TemplateClassAssistant(QWidget* parent, const QUrl& baseUrl)
 : KAssistantDialog(parent)
 , d(new TemplateClassAssistantPrivate(baseUrl))
 {
@@ -285,7 +294,7 @@ void TemplateClassAssistant::setup()
 {
     if (d->baseUrl.isValid())
     {
-        setWindowTitle(i18n("Create Files from Template in <filename>%1</filename>", d->baseUrl.prettyUrl()));
+        setWindowTitle(xi18n("Create Files from Template in <filename>%1</filename>", d->baseUrl.toDisplayString()));
     }
     else
     {
@@ -293,12 +302,12 @@ void TemplateClassAssistant::setup()
     }
 
     d->templateSelectionPageWidget = new TemplateSelectionPage(this);
-    connect(this, SIGNAL(accepted()), d->templateSelectionPageWidget, SLOT(saveConfig()));
+    connect(this, &TemplateClassAssistant::accepted, d->templateSelectionPageWidget, &TemplateSelectionPage::saveConfig);
     d->templateSelectionPage = addPage(d->templateSelectionPageWidget, i18n("Language and Template"));
-    d->templateSelectionPage->setIcon(KIcon("project-development-new-template"));
+    d->templateSelectionPage->setIcon(QIcon::fromTheme("project-development-new-template"));
 
     d->dummyPage = addPage(new QWidget(this), QLatin1String("Dummy Page"));
-    showButton(KDialog::Help, false);
+//     showButton(QDialog::Help, false);
 }
 
 void TemplateClassAssistant::templateChosen(const QString& templateDescription)
@@ -313,49 +322,49 @@ void TemplateClassAssistant::templateChosen(const QString& templateDescription)
         return;
     }
 
-    kDebug() << "Selected template" << templateDescription << "of type" << d->type;
+    qCDebug(PLUGIN_FILETEMPLATES) << "Selected template" << templateDescription << "of type" << d->type;
     removePage(d->dummyPage);
 
     if (d->baseUrl.isValid())
     {
-        setWindowTitle(i18n("Create Files from Template <filename>%1</filename> in <filename>%2</filename>",
+        setWindowTitle(xi18n("Create Files from Template <filename>%1</filename> in <filename>%2</filename>",
                             d->fileTemplate.name(),
-                            d->baseUrl.prettyUrl()));
+                            d->baseUrl.toDisplayString()));
     }
     else
     {
-        setWindowTitle(i18n("Create Files from Template <filename>%1</filename>", d->fileTemplate.name()));
+        setWindowTitle(xi18n("Create Files from Template <filename>%1</filename>", d->fileTemplate.name()));
     }
 
     if (d->type == "Class")
     {
         d->classIdentifierPageWidget = new ClassIdentifierPage(this);
         d->classIdentifierPage = addPage(d->classIdentifierPageWidget, i18n("Class Basics"));
-        d->classIdentifierPage->setIcon(KIcon("classnew"));
-        connect(d->classIdentifierPageWidget, SIGNAL(isValid(bool)), SLOT(setCurrentPageValid(bool)));
+        d->classIdentifierPage->setIcon(QIcon::fromTheme("classnew"));
+        connect(d->classIdentifierPageWidget, &ClassIdentifierPage::isValid, this, &TemplateClassAssistant::setCurrentPageValid);
         setValid(d->classIdentifierPage, false);
 
         d->overridesPageWidget = new OverridesPage(this);
         d->overridesPage = addPage(d->overridesPageWidget, i18n("Override Methods"));
-        d->overridesPage->setIcon(KIcon("code-class"));
+        d->overridesPage->setIcon(QIcon::fromTheme("code-class"));
         setValid(d->overridesPage, true);
 
         d->membersPageWidget = new ClassMembersPage(this);
         d->membersPage = addPage(d->membersPageWidget, i18n("Class Members"));
-        d->membersPage->setIcon(KIcon("field"));
+        d->membersPage->setIcon(QIcon::fromTheme("field"));
         setValid(d->membersPage, true);
 
         d->helper = 0;
         QString languageName = d->fileTemplate.languageName();
-        ILanguage* language = ICore::self()->languageController()->language(languageName);
-        if (language && language->languageSupport())
+        auto language = ICore::self()->languageController()->language(languageName);
+        if (language)
         {
-            d->helper = language->languageSupport()->createClassHelper();
+            d->helper = language->createClassHelper();
         }
 
         if (!d->helper)
         {
-            kDebug() << "No class creation helper for language" << languageName;
+            qCDebug(PLUGIN_FILETEMPLATES) << "No class creation helper for language" << languageName;
             d->helper = new DefaultCreateClassHelper;
         }
 
@@ -370,7 +379,7 @@ void TemplateClassAssistant::templateChosen(const QString& templateDescription)
         {
             d->testCasesPageWidget = new TestCasesPage(this);
             d->testCasesPage = addPage(d->testCasesPageWidget, i18n("Test Cases"));
-            connect(d->testCasesPageWidget, SIGNAL(isValid(bool)), SLOT(setCurrentPageValid(bool)));
+            connect(d->testCasesPageWidget, &TestCasesPage::isValid, this, &TemplateClassAssistant::setCurrentPageValid);
             setValid(d->testCasesPage, false);
         }
 
@@ -380,19 +389,19 @@ void TemplateClassAssistant::templateChosen(const QString& templateDescription)
 
     d->licensePageWidget = new LicensePage(this);
     d->licensePage = addPage(d->licensePageWidget, i18n("License"));
-    d->licensePage->setIcon(KIcon("text-x-copying"));
+    d->licensePage->setIcon(QIcon::fromTheme("text-x-copying"));
     setValid(d->licensePage, true);
 
     d->outputPageWidget = new OutputPage(this);
     d->outputPageWidget->prepareForm(d->fileTemplate);
     d->outputPage = addPage(d->outputPageWidget, i18n("Output"));
-    d->outputPage->setIcon(KIcon("document-save"));
-    connect(d->outputPageWidget, SIGNAL(isValid(bool)), SLOT(setCurrentPageValid(bool)));
+    d->outputPage->setIcon(QIcon::fromTheme("document-save"));
+    connect(d->outputPageWidget, &OutputPage::isValid, this, &TemplateClassAssistant::setCurrentPageValid);
     setValid(d->outputPage, false);
 
     if (d->fileTemplate.hasCustomOptions())
     {
-        kDebug() << "Class generator has custom options";
+        qCDebug(PLUGIN_FILETEMPLATES) << "Class generator has custom options";
         d->templateOptionsPageWidget = new TemplateOptionsPage(this);
         d->templateOptionsPage = insertPage(d->outputPage, d->templateOptionsPageWidget,
                                             i18n("Template Options"));
@@ -403,7 +412,7 @@ void TemplateClassAssistant::templateChosen(const QString& templateDescription)
 
 void TemplateClassAssistant::next()
 {
-    kDebug() << currentPage()->name() << currentPage()->header();
+    qCDebug(PLUGIN_FILETEMPLATES) << currentPage()->name() << currentPage()->header();
     if (currentPage() == d->templateSelectionPage)
     {
         // We have chosen the template
@@ -521,7 +530,7 @@ void TemplateClassAssistant::back()
 
         if (d->baseUrl.isValid())
         {
-            setWindowTitle(i18n("Create Files from Template in <filename>%1</filename>", d->baseUrl.prettyUrl()));
+            setWindowTitle(xi18n("Create Files from Template in <filename>%1</filename>", d->baseUrl.toDisplayString()));
         }
         else
         {
@@ -534,13 +543,13 @@ void TemplateClassAssistant::back()
 void TemplateClassAssistant::accept()
 {
     // next() is not called for the last page (when the user clicks Finish), so we have to set output locations here
-    QHash<QString, KUrl> fileUrls = d->outputPageWidget->fileUrls();
-    QHash<QString, SimpleCursor> filePositions = d->outputPageWidget->filePositions();
+    QHash<QString, QUrl> fileUrls = d->outputPageWidget->fileUrls();
+    QHash<QString, KTextEditor::Cursor> filePositions = d->outputPageWidget->filePositions();
 
     DocumentChangeSet changes;
     if (d->generator)
     {
-        QHash<QString, KUrl>::const_iterator it = fileUrls.constBegin();
+        QHash<QString, QUrl>::const_iterator it = fileUrls.constBegin();
         for (; it != fileUrls.constEnd(); ++it)
         {
             d->generator->setFileUrl(it.key(), it.value());
@@ -559,7 +568,7 @@ void TemplateClassAssistant::accept()
     changes.applyAllChanges();
 
     // Open the generated files in the editor
-    foreach (const KUrl& url, fileUrls)
+    foreach (const QUrl& url, fileUrls)
     {
         ICore::self()->documentController()->openDocument(url);
     }
@@ -572,7 +581,7 @@ void TemplateClassAssistant::setCurrentPageValid(bool valid)
     setValid(currentPage(), valid);
 }
 
-KUrl TemplateClassAssistant::baseUrl() const
+QUrl TemplateClassAssistant::baseUrl() const
 {
     return d->baseUrl;
 }
