@@ -23,12 +23,11 @@
 #define KDEVPLATFORM_PLUGIN_GITJOB_H
 
 #include <vcs/dvcs/dvcsjob.h>
-#include <KUrl>
 
 class GitJob : public KDevelop::DVcsJob
 {
     public:
-        GitJob(const QDir& workingDir, KDevelop::IPlugin* parent = 0, KDevelop::OutputJob::OutputJobVerbosity verbosity = KDevelop::OutputJob::Verbose);
+        explicit GitJob(const QDir& workingDir, KDevelop::IPlugin* parent = 0, KDevelop::OutputJob::OutputJobVerbosity verbosity = KDevelop::OutputJob::Verbose);
         
 };
 
