@@ -13,25 +13,19 @@
 
 #include "grepdialog.h"
 
+#include <QDialogButtonBox>
 #include <QDir>
-#include <QLabel>
-#include <QRegExp>
-#include <QBoxLayout>
-#include <QStringList>
+#include <QFileDialog>
+#include <QLineEdit>
 #include <QMenu>
+#include <QPushButton>
+#include <QStringList>
 
-#include <kfiledialog.h>
-#include <kpushbutton.h>
-#include <kglobal.h>
-#include <kiconloader.h>
-#include <klocale.h>
-#include <kconfig.h>
-#include <kmessagebox.h>
-#include <kdebug.h>
-#include <kcombobox.h>
-#include <kurlcompletion.h>
-#include <kstandarddirs.h>
-#include <klineedit.h>
+#include <KComboBox>
+#include <KCompletion>
+#include <KConfigGroup>
+#include <KLocalizedString>
+#include <KUrlCompletion>
 
 #include <interfaces/icore.h>
 #include <interfaces/idocument.h>
@@ -41,19 +35,22 @@
 #include <interfaces/iprojectcontroller.h>
 #include <interfaces/isession.h>
 
+#include <util/path.h>
+
 #include "grepviewplugin.h"
 #include "grepjob.h"
 #include "grepoutputview.h"
 #include "grepfindthread.h"
 #include "greputil.h"
 
+
 using namespace KDevelop;
 
 namespace {
 
 QString allOpenFilesString = i18n("All Open Files");
 QString allOpenProjectsString = i18n("All Open Projects");
-    
+
 const QStringList template_desc = QStringList()
     << "verbatim"
     << "word"
@@ -108,49 +105,43 @@ const QString pathsSeparator(";");
 const int pathsMaxCount = 25;
 }
 
-const KDialog::ButtonCode GrepDialog::SearchButton  = KDialog::User1;
-
-GrepDialog::GrepDialog( GrepViewPlugin * plugin, QWidget *parent, bool setLastUsed )
-    : KDialog(parent), Ui::GrepWidget(), m_plugin( plugin )
+GrepDialog::GrepDialog( GrepViewPlugin * plugin, QWidget *parent )
+    : QDialog(parent), Ui::GrepWidget(), m_plugin( plugin )
 {
     setAttribute(Qt::WA_DeleteOnClose);
+    setWindowTitle( i18n("Find/Replace in Files") );
 
-    setButtons( SearchButton | KDialog::Cancel );
-    setButtonText( SearchButton, i18n("Search...") );
-    setButtonIcon( SearchButton, KIcon("edit-find") );
-    setCaption( i18n("Find/Replace in Files") );
-    setDefaultButton( SearchButton );
+    setupUi(this);
 
-    setupUi(mainWidget());
+    auto searchButton = buttonBox->button(QDialogButtonBox::Ok);
+    Q_ASSERT(searchButton);
+    searchButton->setText(tr("Search..."));
+    searchButton->setIcon(QIcon::fromTheme("edit-find"));
+    connect(searchButton, &QPushButton::clicked, this, &GrepDialog::startSearch);
+    connect(buttonBox, &QDialogButtonBox::rejected, this, &GrepDialog::reject);
 
     KConfigGroup cg = ICore::self()->activeSession()->config()->group( "GrepDialog" );
-    
-    // add default values when the most recent ones should not be set
-    if(!setLastUsed)
-    {
-        patternCombo->addItem( "" );
-    }
 
     patternCombo->addItems( cg.readEntry("LastSearchItems", QStringList()) );
     patternCombo->setInsertPolicy(QComboBox::InsertAtTop);
-    
+
     templateTypeCombo->addItems(template_desc);
     templateTypeCombo->setCurrentIndex( cg.readEntry("LastUsedTemplateIndex", 0) );
     templateEdit->addItems( cg.readEntry("LastUsedTemplateString", template_str) );
     templateEdit->setEditable(true);
-    templateEdit->setCompletionMode(KGlobalSettings::CompletionPopup);
+    templateEdit->setCompletionMode(KCompletion::CompletionPopup);
     KCompletion* comp = templateEdit->completionObject();
-    connect(templateEdit, SIGNAL(returnPressed(QString)), comp, SLOT(addItem(QString)));
+    connect(templateEdit, static_cast<void(KComboBox::*)(const QString&)>(&KComboBox::returnPressed), comp, static_cast<void(KCompletion::*)(const QString&)>(&KCompletion::addItem));
     for(int i=0; i<templateEdit->count(); i++)
         comp->addItem(templateEdit->itemText(i));
     replacementTemplateEdit->addItems( cg.readEntry("LastUsedReplacementTemplateString", repl_template) );
     replacementTemplateEdit->setEditable(true);
-    replacementTemplateEdit->setCompletionMode(KGlobalSettings::CompletionPopup);
+    replacementTemplateEdit->setCompletionMode(KCompletion::CompletionPopup);
     comp = replacementTemplateEdit->completionObject();
-    connect(replacementTemplateEdit, SIGNAL(returnPressed(QString)), comp, SLOT(addItem(QString)));
+    connect(replacementTemplateEdit, static_cast<void(KComboBox::*)(const QString&)>(&KComboBox::returnPressed), comp, static_cast<void(KCompletion::*)(const QString&)>(&KCompletion::addItem));
     for(int i=0; i<replacementTemplateEdit->count(); i++)
         comp->addItem(replacementTemplateEdit->itemText(i));
-    
+
     regexCheck->setChecked(cg.readEntry("regexp", false ));
 
     caseSensitiveCheck->setChecked(cg.readEntry("case_sens", true));
@@ -163,7 +154,7 @@ GrepDialog::GrepDialog( GrepViewPlugin * plugin, QWidget *parent, bool setLastUs
     searchPaths->addItems(cg.readEntry("SearchPaths", QStringList(!projects.isEmpty() ? allOpenProjectsString : QDir::homePath() ) ));
     searchPaths->setInsertPolicy(QComboBox::InsertAtTop);
 
-    syncButton->setIcon(KIcon("dirsync"));
+    syncButton->setIcon(QIcon::fromTheme("dirsync"));
     syncButton->setMenu(createSyncButtonMenu());
 
     depthSpin->setValue(cg.readEntry("depth", -1));
@@ -172,40 +163,41 @@ GrepDialog::GrepDialog( GrepViewPlugin * plugin, QWidget *parent, bool setLastUs
     filesCombo->addItems(cg.readEntry("file_patterns", filepatterns));
     excludeCombo->addItems(cg.readEntry("exclude_patterns", excludepatterns) );
 
-    connect(this, SIGNAL(buttonClicked(KDialog::ButtonCode)), this, SLOT(performAction(KDialog::ButtonCode)));
-    connect(templateTypeCombo, SIGNAL(activated(int)),
-            this, SLOT(templateTypeComboActivated(int)));
-    connect(patternCombo, SIGNAL(editTextChanged(QString)),
-            this, SLOT(patternComboEditTextChanged(QString)));
+    connect(templateTypeCombo, static_cast<void(KComboBox::*)(int)>(&KComboBox::activated),
+            this, &GrepDialog::templateTypeComboActivated);
+    connect(patternCombo, &QComboBox::editTextChanged,
+            this, &GrepDialog::patternComboEditTextChanged);
     patternComboEditTextChanged( patternCombo->currentText() );
     patternCombo->setFocus();
-    
-    connect(searchPaths, SIGNAL(activated(QString)), this, SLOT(setSearchLocations(QString)));
 
-    connect(directorySelector, SIGNAL(clicked(bool)), this, SLOT(selectDirectoryDialog()) );
+    connect(searchPaths, static_cast<void(KComboBox::*)(const QString&)>(&KComboBox::activated), this, &GrepDialog::setSearchLocations);
+
+    directorySelector->setIcon(QIcon::fromTheme("document-open"));
+    connect(directorySelector, &QPushButton::clicked, this, &GrepDialog::selectDirectoryDialog );
+    directoryChanged(directorySelector->text());
 }
 
 void GrepDialog::selectDirectoryDialog()
 {
-    QString dirName = KFileDialog::getExistingDirectory(searchPaths->lineEdit()->text(), this, tr("Select directory to search in"));
-
+    const QString dirName = QFileDialog::getExistingDirectory(this, tr("Select directory to search in"),
+                                                              searchPaths->lineEdit()->text());
     if (!dirName.isEmpty()) {
         setSearchLocations(dirName);
     }
 }
 
-void GrepDialog::addUrlToMenu(QMenu* menu, KUrl url)
+void GrepDialog::addUrlToMenu(QMenu* menu, const QUrl& url)
 {
     QAction* action = menu->addAction(m_plugin->core()->projectController()->prettyFileName(url, KDevelop::IProjectController::FormatPlain));
-    action->setData(QVariant(url.pathOrUrl()));
-    connect(action, SIGNAL(triggered(bool)), SLOT(synchronizeDirActionTriggered(bool)));
+    action->setData(QVariant(url.toString(QUrl::PreferLocalFile)));
+    connect(action, &QAction::triggered, this, &GrepDialog::synchronizeDirActionTriggered);
 }
 
 void GrepDialog::addStringToMenu(QMenu* menu, QString string)
 {
     QAction* action = menu->addAction(string);
     action->setData(QVariant(string));
-    connect(action, SIGNAL(triggered(bool)), SLOT(synchronizeDirActionTriggered(bool)));
+    connect(action, &QAction::triggered, this, &GrepDialog::synchronizeDirActionTriggered);
 }
 
 void GrepDialog::synchronizeDirActionTriggered(bool)
@@ -219,43 +211,36 @@ QMenu* GrepDialog::createSyncButtonMenu()
 {
     QMenu* ret = new QMenu;
 
-    QSet<KUrl> hadUrls;
-    
+    QSet<Path> hadUrls;
+
     IDocument *doc = m_plugin->core()->documentController()->activeDocument();
     if ( doc )
     {
-        KUrl url = doc->url();
-        url.cd("..");
-        while(m_plugin->core()->projectController()->findProjectForUrl(url))
+        Path url = Path(doc->url()).parent();
+
+        // always add the current file's parent directory
+        hadUrls.insert(url);
+        addUrlToMenu(ret, url.toUrl());
+
+        url = url.parent();
+
+        while(m_plugin->core()->projectController()->findProjectForUrl(url.toUrl()))
         {
-            url.adjustPath(KUrl::RemoveTrailingSlash);
             if(hadUrls.contains(url))
                 break;
             hadUrls.insert(url);
-            addUrlToMenu(ret, url);
-            if(!url.cd(".."))
-                break;
-        }
-
-        // if the current file's parent directory is not in the project, add it
-        url = doc->url().upUrl();
-        url.adjustPath(KUrl::RemoveTrailingSlash);
-        if(!hadUrls.contains(url))
-        {
-            hadUrls.insert(url);
-            addUrlToMenu(ret, url);
+            addUrlToMenu(ret, url.toUrl());
+            url = url.parent();
         }
     }
-    
+
     foreach(IProject* project, m_plugin->core()->projectController()->projects())
     {
-        KUrl url = project->folder();
-        url.adjustPath(KUrl::RemoveTrailingSlash);
-        if(hadUrls.contains(url))
-            continue;
-        addUrlToMenu(ret, url);
+        if (!hadUrls.contains(project->path())) {
+            addUrlToMenu(ret, project->path().toUrl());
+        }
     }
-    
+
     addStringToMenu(ret, allOpenFilesString);
     addStringToMenu(ret, allOpenProjectsString);
     return ret;
@@ -263,21 +248,21 @@ QMenu* GrepDialog::createSyncButtonMenu()
 
 void GrepDialog::directoryChanged(const QString& dir)
 {
-    KUrl currentUrl = dir;
+    QUrl currentUrl = QUrl::fromLocalFile(dir);
     if( !currentUrl.isValid() ) {
         setEnableProjectBox(false);
         return;
     }
-    
+
     bool projectAvailable = true;
-    
-    foreach(KUrl url, getDirectoryChoice())
+
+    foreach(const QUrl& url, getDirectoryChoice())
     {
-        IProject *proj = ICore::self()->projectController()->findProjectForUrl( currentUrl );
-        if( !proj || !proj->folder().isLocalFile() )
+        IProject *proj = ICore::self()->projectController()->findProjectForUrl( url );
+        if( !proj || !proj->path().toUrl().isLocalFile() )
             projectAvailable = false;
     }
-    
+
     setEnableProjectBox(projectAvailable);
 }
 
@@ -314,6 +299,7 @@ void GrepDialog::setEnableProjectBox(bool enable)
 void GrepDialog::setPattern(const QString &pattern)
 {
     patternCombo->setEditText(pattern);
+    patternComboEditTextChanged(pattern);
 }
 
 void GrepDialog::setSearchLocations(const QString &dir)
@@ -321,7 +307,7 @@ void GrepDialog::setSearchLocations(const QString &dir)
     if(!dir.isEmpty()) {
         if(QDir::isAbsolutePath(dir))
         {
-            static_cast<KUrlCompletion*>(searchPaths->completionObject())->setDir( dir );
+            static_cast<KUrlCompletion*>(searchPaths->completionObject())->setDir( QUrl::fromLocalFile(dir) );
         }
 
             if (searchPaths->contains(dir)) {
@@ -386,12 +372,12 @@ bool GrepDialog::caseSensitiveFlag() const
 
 void GrepDialog::patternComboEditTextChanged( const QString& text)
 {
-    enableButton( SearchButton,  !text.isEmpty() );
+    buttonBox->button(QDialogButtonBox::Ok)->setEnabled(!text.isEmpty());
 }
 
-QList< KUrl > GrepDialog::getDirectoryChoice() const
+QList< QUrl > GrepDialog::getDirectoryChoice() const
 {
-    QList< KUrl > ret;
+    QList< QUrl > ret;
     QString text = searchPaths->currentText();
     if(text == allOpenFilesString)
     {
@@ -400,88 +386,87 @@ QList< KUrl > GrepDialog::getDirectoryChoice() const
     }else if(text == allOpenProjectsString)
     {
         foreach(IProject* project, ICore::self()->projectController()->projects())
-            ret << project->folder();
+            ret << project->path().toUrl();
     }else{
         QStringList semicolonSeparatedFileList = text.split(pathsSeparator);
         if(!semicolonSeparatedFileList.isEmpty() && QFileInfo(semicolonSeparatedFileList[0]).exists())
         {
             // We use QFileInfo to make sure this is really a semicolon-separated file list, not a file containing
             // a semicolon in the name.
-            foreach(QString file, semicolonSeparatedFileList)
-                ret << KUrl::fromPath(file);
+            foreach(const QString& file, semicolonSeparatedFileList)
+                ret << QUrl::fromLocalFile(file);
         }else{
-            ret << KUrl(searchPaths->currentText());
+            ret << QUrl::fromUserInput(searchPaths->currentText());
         }
     }
     return ret;
 }
 
-bool GrepDialog::isPartOfChoice(KUrl url) const
+bool GrepDialog::isPartOfChoice(QUrl url) const
 {
-    foreach(KUrl choice, getDirectoryChoice())
-        if(choice.isParentOf(url) || choice.equals(url))
+    foreach(const QUrl& choice, getDirectoryChoice())
+        if(choice.isParentOf(url) || choice == url)
             return true;
     return false;
 }
 
-void GrepDialog::start()
+void GrepDialog::startSearch()
 {
-    performAction(SearchButton);
-}
-
-void GrepDialog::performAction(KDialog::ButtonCode button)
-{
-    // a click on cancel trigger this signal too
-    if( button != SearchButton ) return;
-    
     // search for unsaved documents
     QList<IDocument*> unsavedFiles;
     QStringList include = GrepFindFilesThread::parseInclude(filesString());
     QStringList exclude = GrepFindFilesThread::parseExclude(excludeString());
-    
+
     foreach(IDocument* doc, ICore::self()->documentController()->openDocuments())
     {
-        KUrl docUrl = doc->url();
-        if(doc->state() != IDocument::Clean && isPartOfChoice(docUrl) && 
+        QUrl docUrl = doc->url();
+        if(doc->state() != IDocument::Clean && isPartOfChoice(docUrl) &&
            QDir::match(include, docUrl.fileName()) && !QDir::match(exclude, docUrl.toLocalFile()))
         {
             unsavedFiles << doc;
         }
     }
-    
+
     if(!ICore::self()->documentController()->saveSomeDocuments(unsavedFiles))
     {
         close();
         return;
     }
-    
-    QList<KUrl> choice = getDirectoryChoice();
-    
+
+    QList<QUrl> choice = getDirectoryChoice();
+
     GrepJob* job = m_plugin->newGrepJob();
-    
-    QString descriptionOrUrl(searchPaths->currentText());
+
+    const QString descriptionOrUrl(searchPaths->currentText());
     QString description = descriptionOrUrl;
     // Shorten the description
-    if(descriptionOrUrl != allOpenFilesString && descriptionOrUrl != allOpenProjectsString && choice.size() > 1)
-        description = i18np("%2, and %1 more item", "%2, and %1 more items", choice.size() - 1, choice[0].pathOrUrl());
-    
+    if(descriptionOrUrl != allOpenFilesString && descriptionOrUrl != allOpenProjectsString) {
+        auto prettyFileName = [](const QUrl& url) {
+            return ICore::self()->projectController()->prettyFileName(url, KDevelop::IProjectController::FormatPlain);
+        };
+
+        if (choice.size() > 1) {
+            description = i18np("%2, and %1 more item", "%2, and %1 more items", choice.size() - 1, prettyFileName(choice[0]));
+        } else if (!choice.isEmpty()) {
+            description = prettyFileName(choice[0]);
+        }
+    }
+
     GrepOutputView *toolView = (GrepOutputView*)ICore::self()->uiController()->
                                findToolView(i18n("Find/Replace in Files"), m_plugin->toolViewFactory(), IUiController::CreateAndRaise);
     GrepOutputModel* outputModel = toolView->renewModel(patternString(), description);
-    
-    connect(job, SIGNAL(showErrorMessage(QString,int)),
-            toolView, SLOT(showErrorMessage(QString)));
+
+    connect(job, &GrepJob::showErrorMessage,
+            toolView, &GrepOutputView::showErrorMessage);
     //the GrepOutputModel gets the 'showMessage' signal to store it and forward
     //it to toolView
-    connect(job, SIGNAL(showMessage(KDevelop::IStatus*,QString,int)),
-            outputModel, SLOT(showMessageSlot(KDevelop::IStatus*,QString)));    
-    connect(outputModel, SIGNAL(showMessage(KDevelop::IStatus*,QString)),
-            toolView, SLOT(showMessage(KDevelop::IStatus*,QString)));
-    
-    
-    connect(toolView, SIGNAL(outputViewIsClosed()),
-            job, SLOT(kill()));
-    
+    connect(job, &GrepJob::showMessage,
+            outputModel, &GrepOutputModel::showMessageSlot);
+    connect(outputModel, &GrepOutputModel::showMessage,
+            toolView, &GrepOutputView::showMessage);
+
+    connect(toolView, &GrepOutputView::outputViewIsClosed, job, [=]() {job->kill();});
+
     job->setOutputModel(outputModel);
     job->setPatternString(patternString());
     job->setReplacementTemplateString(replacementTemplateString());
@@ -496,11 +481,10 @@ void GrepDialog::performAction(KDialog::ButtonCode button)
     job->setCaseSensitive( caseSensitiveFlag() );
 
     ICore::self()->runController()->registerJob(job);
-    
+
     m_plugin->rememberSearchDirectory(descriptionOrUrl);
-    
+
     close();
 }
 
-#include "grepdialog.moc"
 
