@@ -14,23 +14,22 @@
 #ifndef KDEVPLATFORM_PLUGIN_GREPDIALOG_H
 #define KDEVPLATFORM_PLUGIN_GREPDIALOG_H
 
-#include <kdialog.h>
+#include <QDialog>
+#include <QUrl>
+
 #include "ui_grepwidget.h"
 
 class KConfig;
 class KUrlRequester;
-class QPushButton;
 class GrepViewPlugin;
-class KLineEdit;
+class QLineEdit;
 
-class GrepDialog : public KDialog, private Ui::GrepWidget
+class GrepDialog : public QDialog, private Ui::GrepWidget
 {
     Q_OBJECT
 
 public:
-    static const KDialog::ButtonCode SearchButton;
-    
-    explicit GrepDialog( GrepViewPlugin * plugin, QWidget *parent=0, bool setLastUsed=false );
+    explicit GrepDialog( GrepViewPlugin * plugin, QWidget *parent=0 );
     ~GrepDialog();
 
     void setPattern(const QString &pattern);
@@ -48,20 +47,18 @@ public:
 
     int depthValue() const;
 
-    void start();
-    
 public Q_SLOTS:
+    void startSearch();
+
     ///Sets directory(ies)/files to search in. Also it can be semicolon separated list of directories/files or one of special strings: allOpenFilesString, allOpenProjectsString
     void setSearchLocations(const QString &dir);
 
 private Q_SLOTS:
-
-    void performAction(KDialog::ButtonCode button);
     void templateTypeComboActivated(int);
     void patternComboEditTextChanged( const QString& );
     void directoryChanged(const QString &dir);
     QMenu* createSyncButtonMenu();
-    void addUrlToMenu(QMenu* ret, KUrl url);
+    void addUrlToMenu(QMenu* ret, const QUrl& url);
     void addStringToMenu(QMenu* ret, QString string);
     void synchronizeDirActionTriggered(bool);
 
@@ -70,11 +67,11 @@ private Q_SLOTS:
 
 private:
     // Returns the chosen directories or files (only the top directories, not subfiles)
-    QList< KUrl > getDirectoryChoice() const;
+    QList< QUrl > getDirectoryChoice() const;
     // Returns whether the given url is a subfile/subdirectory of one of the chosen directories/files
     // This is slow, so don't call it too often
-    bool isPartOfChoice(KUrl url) const;
-    
+    bool isPartOfChoice(QUrl url) const;
+
     GrepViewPlugin * m_plugin;
 };
 
