@@ -18,15 +18,15 @@
 #include "grepoutputmodel.h"
 #include "greputil.h"
 
+#include <QFile>
 #include <QList>
 #include <QRegExp>
-#include <QTextDocument>
 #include <QTextStream>
 
-#include <klocale.h>
-#include <kencodingprober.h>
+#include <KEncodingProber>
+#include <KLocalizedString>
 
-#include <language/duchain/indexedstring.h>
+#include <serialization/indexedstring.h>
 #include <interfaces/icore.h>
 #include <interfaces/iuicontroller.h>
 #include <language/codegen/documentchangeset.h>
@@ -38,18 +38,18 @@ GrepOutputItem::List grepFile(const QString &filename, const QRegExp &re)
 {
     GrepOutputItem::List res;
     QFile file(filename);
-    
+
     if(!file.open(QIODevice::ReadOnly))
         return res;
     int lineno = 0;
-    
-    
+
+
     // detect encoding (unicode files can be feed forever, stops when confidence reachs 99%
     KEncodingProber prober;
     while(!file.atEnd() && prober.state() == KEncodingProber::Probing && prober.confidence() < 0.99) {
         prober.feed(file.read(0xFF));
     }
-        
+
     // reads file with detected encoding
     file.seek(0);
     QTextStream stream(&file);
@@ -58,25 +58,25 @@ GrepOutputItem::List grepFile(const QString &filename, const QRegExp &re)
     while( !stream.atEnd() )
     {
         QString data = stream.readLine();
-        
+
         // remove line terminators (in order to not match them)
         for(int pos = data.length()-1; pos >= 0 && (data[pos] == '\r' || data[pos] == '\n'); pos--)
         {
             data.chop(1);
         }
-        
+
         int offset = 0;
         // allow empty string matching result in an infinite loop !
         while( re.indexIn(data, offset)!=-1 && re.cap(0).length() > 0 )
         {
             int start = re.pos(0);
             int end = start + re.cap(0).length();
-            
+
             DocumentChangePointer change = DocumentChangePointer(new DocumentChange(
-                IndexedString(filename), 
-                SimpleRange(lineno, start, lineno, end),
+                IndexedString(filename),
+                KTextEditor::Range(lineno, start, lineno, end),
                 re.cap(0), QString()));
-            
+
             res << GrepOutputItem(change, data, false);
             offset = end;
         }
@@ -98,8 +98,8 @@ GrepJob::GrepJob( QObject* parent )
 {
     setCapabilities(Killable);
     KDevelop::ICore::self()->uiController()->registerStatus(this);
-    
-    connect(this, SIGNAL(result(KJob*)), this, SLOT(testFinishState(KJob*)));
+
+    connect(this, &GrepJob::result, this, &GrepJob::testFinishState);
 }
 
 QString GrepJob::statusName() const
@@ -133,8 +133,8 @@ void GrepJob::slotFindFinished()
         emitResult();
         return;
     }
-    
-    if(!m_regexpFlag) 
+
+    if(!m_regexpFlag)
     {
         m_patternString = QRegExp::escape(m_patternString);
     }
@@ -150,7 +150,7 @@ void GrepJob::slotFindFinished()
         emitResult();
         return;
     }
-    
+
     QString pattern = substitudePattern(m_templateString, m_patternString);
     m_regExp.setPattern(pattern);
     m_regExp.setPatternSyntax(QRegExp::RegExp2);
@@ -161,7 +161,7 @@ void GrepJob::slotFindFinished()
         // if pattern has already been escaped (raw text serch) a second escape will result in a different string anyway
         m_regExp.setPatternSyntax(QRegExp::Wildcard);
     }
-    
+
     m_outputModel->setRegExp(m_regExp);
     m_outputModel->setReplacementTemplate(m_replacementTemplateString);
 
@@ -169,7 +169,7 @@ void GrepJob::slotFindFinished()
     emit showMessage(this, i18np("Searching for <b>%2</b> in one file",
                                  "Searching for <b>%2</b> in %1 files",
                                  m_fileList.length(),
-                                 Qt::escape(m_regExp.pattern())));
+                                 m_regExp.pattern().toHtmlEscaped()));
 
     m_workState = WorkGrep;
     QMetaObject::invokeMethod( this, "slotWork", Qt::QueuedConnection);
@@ -188,7 +188,7 @@ void GrepJob::slotWork()
         case WorkCollectFiles:
             m_findThread = new GrepFindFilesThread(this, m_directoryChoice, m_depthValue, m_filesString, m_excludeString, m_useProjectFilesFlag);
             emit showMessage(this, i18n("Collecting files..."));
-            connect(m_findThread, SIGNAL(finished()), this, SLOT(slotFindFinished()));
+            connect(m_findThread.data(), &GrepFindFilesThread::finished, this, &GrepJob::slotFindFinished);
             m_findThread->start();
             break;
         case WorkGrep:
@@ -218,7 +218,7 @@ void GrepJob::slotWork()
                 emitResult();
             }
             break;
-        case WorkCancelled:            
+        case WorkCancelled:
             emit hideProgress(this);
             emit clearMessage(this);
             emit showErrorMessage(i18n("Search aborted"), 5000);
@@ -231,7 +231,7 @@ void GrepJob::start()
 {
     if(m_workState!=WorkIdle)
         return;
-    
+
     m_fileList.clear();
     m_workState = WorkIdle;
     m_fileIndex = 0;
@@ -240,8 +240,8 @@ void GrepJob::start()
     m_outputModel->clear();
 
     qRegisterMetaType<GrepOutputItem::List>();
-    connect(this, SIGNAL(foundMatches(QString,GrepOutputItem::List)),
-            m_outputModel, SLOT(appendOutputs(QString,GrepOutputItem::List)), Qt::QueuedConnection);
+    connect(this, &GrepJob::foundMatches,
+            m_outputModel, &GrepOutputModel::appendOutputs, Qt::QueuedConnection);
 
     QMetaObject::invokeMethod(this, "slotWork", Qt::QueuedConnection);
 }
@@ -299,7 +299,7 @@ void GrepJob::setExcludeString(const QString& excludeString)
     m_excludeString = excludeString;
 }
 
-void GrepJob::setDirectoryChoice(const QList<KUrl>& choice)
+void GrepJob::setDirectoryChoice(const QList<QUrl>& choice)
 {
     m_directoryChoice = choice;
 }
@@ -331,4 +331,3 @@ void GrepJob::setPatternString(const QString& patternString)
     setObjectName(i18n("Grep: %1", m_patternString));
 }
 
-#include "grepjob.moc"
