@@ -22,12 +22,12 @@
 #include "grepoutputdelegate.h"
 #include "grepoutputmodel.h"
 
-#include <QtGui/QPainter>
+#include <QPainter>
 #include <QtCore/QModelIndex>
-#include <QtGui/QTextDocument>
-#include <QtGui/QTextCursor>
-#include <QtGui/QAbstractTextDocumentLayout>
-#include <QtGui/QTextCharFormat>
+#include <QTextDocument>
+#include <QTextCursor>
+#include <QAbstractTextDocumentLayout>
+#include <QTextCharFormat>
 #include <QtCore/QRegExp>
 #include <KLocalizedString>
 #include <cmath>
@@ -87,7 +87,7 @@ void GrepOutputDelegate::paint( QPainter* painter, const QStyleOptionViewItem& o
     {
         // Use custom manual highlighting
 
-        const KDevelop::SimpleRange rng = item->change()->m_range;
+        const KTextEditor::Range rng = item->change()->m_range;
 
         // the line number appears grayed
         fmt.setForeground(options.palette.brush(QPalette::Disabled, cr));
@@ -95,18 +95,18 @@ void GrepOutputDelegate::paint( QPainter* painter, const QStyleOptionViewItem& o
         
         // switch to normal color
         fmt.setForeground(options.palette.brush(cg, cr));
-        cur.insertText(item->text().left(rng.start.column).remove(leftspaces), fmt);
+        cur.insertText(item->text().left(rng.start().column()).remove(leftspaces), fmt);
         
         fmt.setFontWeight(QFont::Bold);
         // Blend the highlighted background color
         // For some reason, it is extremely slow to use alpha-blending directly here
         QColor bgHighlight = blendColor(option.palette.brush(QPalette::Highlight).color(), option.palette.brush(QPalette::Base).color(), 0.3);
         fmt.setBackground(bgHighlight);
-        cur.insertText(item->text().mid(rng.start.column, rng.end.column - rng.start.column), fmt);
+        cur.insertText(item->text().mid(rng.start().column(), rng.end().column() - rng.start().column()), fmt);
         fmt.clearBackground();
         
         fmt.setFontWeight(QFont::Normal);
-        cur.insertText(item->text().right(item->text().length() - rng.end.column), fmt);
+        cur.insertText(item->text().right(item->text().length() - rng.end().column()), fmt);
     }else{
         QString text;
         if(item)
@@ -141,7 +141,7 @@ void GrepOutputDelegate::paint( QPainter* painter, const QStyleOptionViewItem& o
 QSize GrepOutputDelegate::sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const
 {
     const GrepOutputModel *model = dynamic_cast<const GrepOutputModel *>(index.model());
-    const GrepOutputItem  *item  = dynamic_cast<const GrepOutputItem *>(model->itemFromIndex(index));
+    const GrepOutputItem  *item  = model ? dynamic_cast<const GrepOutputItem *>(model->itemFromIndex(index)) : nullptr;
 
     QSize ret = QStyledItemDelegate::sizeHint(option, index);
 
@@ -150,13 +150,17 @@ QSize GrepOutputDelegate::sizeHint(const QStyleOptionViewItem& option, const QMo
     if(item && item->isText())
     {
         QFont font = option.font;
+        QFontMetrics metrics(font);
         font.setBold(true);
         QFontMetrics bMetrics(font);
 
-        //TODO: calculate width with more accuracy: here the whole text is considerated as bold
-        int width =  bMetrics.width(item->text()) +
-                     option.fontMetrics.width(i18n("Line %1: ",item->lineNumber())) +
-                     std::max(option.decorationSize.width(), 0);
+        const KTextEditor::Range rng = item->change()->m_range;
+
+        int width = metrics.width(item->text().left(rng.start().column())) +
+                    metrics.width(item->text().right(item->text().length() - rng.end().column())) +
+                    bMetrics.width(item->text().mid(rng.start().column(), rng.end().column() - rng.start().column())) +
+                    option.fontMetrics.width(i18n("Line %1: ",item->lineNumber())) +
+                    std::max(option.decorationSize.width(), 0);
         ret.setWidth(width);
     }else{
         // This is only used for titles, so not very performance critical
