@@ -45,13 +45,13 @@ public:
     /// Check children to determine current state
     void refreshState() ;
 
-    virtual QVariant data ( int role = Qt::UserRole + 1 ) const;
+    virtual QVariant data ( int role = Qt::UserRole + 1 ) const override;
 
 private:
     KDevelop::DocumentChangePointer m_change;
 };
 
-Q_DECLARE_METATYPE(GrepOutputItem::List);
+Q_DECLARE_METATYPE(GrepOutputItem::List)
 
 class GrepOutputModel : public QStandardItemModel
 {
