@@ -18,18 +18,20 @@
 #include "greputil.h"
 #include "grepjob.h"
 
-#include <QtGui/QAction>
-#include <QtGui/QStringListModel>
-#include <KMessageBox>
-#include <KColorScheme>
-#include <kdebug.h>
-#include <QMenu>
-
 #include <interfaces/icore.h>
 #include <interfaces/isession.h>
-#include <QWidgetAction>
 #include <interfaces/iprojectcontroller.h>
-#include <interfaces/iplugincontroller.h>
+#include <outputview/ioutputview.h>
+
+#include <KConfigGroup>
+#include <KMessageBox>
+#include <KColorScheme>
+#include <klocalizedstring.h>
+
+#include <QAction>
+#include <QMenu>
+#include <QStringListModel>
+#include <QWidgetAction>
 
 using namespace KDevelop;
 
@@ -68,20 +70,20 @@ GrepOutputView::GrepOutputView(QWidget* parent, GrepViewPlugin* plugin)
     Ui::GrepOutputView::setupUi(this);
 
     setWindowTitle(i18nc("@title:window", "Find/Replace Output View"));
-    setWindowIcon(SmallIcon("edit-find"));
+    setWindowIcon(QIcon::fromTheme("edit-find"));
 
-    m_prev = new QAction(KIcon("go-previous"), i18n("&Previous Item"), this);
+    m_prev = new QAction(QIcon::fromTheme("go-previous"), i18n("&Previous Item"), this);
     m_prev->setEnabled(false);
-    m_next = new QAction(KIcon("go-next"), i18n("&Next Item"), this);
+    m_next = new QAction(QIcon::fromTheme("go-next"), i18n("&Next Item"), this);
     m_next->setEnabled(false);
-    m_collapseAll = new QAction(KIcon("arrow-left-double"), i18n("C&ollapse All"), this); // TODO change icon
+    m_collapseAll = new QAction(QIcon::fromTheme("arrow-left-double"), i18n("C&ollapse All"), this); // TODO change icon
     m_collapseAll->setEnabled(false);
-    m_expandAll = new QAction(KIcon("arrow-right-double"), i18n("&Expand All"), this); // TODO change icon
+    m_expandAll = new QAction(QIcon::fromTheme("arrow-right-double"), i18n("&Expand All"), this); // TODO change icon
     m_expandAll->setEnabled(false);
     QAction *separator = new QAction(this);
     separator->setSeparator(true);
-    QAction *newSearchAction = new QAction(KIcon("edit-find"), i18n("New &Search"), this);
-    m_clearSearchHistory = new QAction(KIcon("edit-clear-list"), i18n("Clear Search History"), this);
+    QAction *newSearchAction = new QAction(QIcon::fromTheme("edit-find"), i18n("New &Search"), this);
+    m_clearSearchHistory = new QAction(QIcon::fromTheme("edit-clear-list"), i18n("Clear Search History"), this);
 
     addAction(m_prev);
     addAction(m_next);
@@ -102,33 +104,31 @@ GrepOutputView::GrepOutputView(QWidget* parent, GrepViewPlugin* plugin)
 
     modelSelector->setEditable(false);
     modelSelector->setContextMenuPolicy(Qt::CustomContextMenu);
-    connect(modelSelector, SIGNAL(customContextMenuRequested(QPoint)),
-            this, SLOT(modelSelectorContextMenu(QPoint)));
-    connect(modelSelector, SIGNAL(currentIndexChanged(int)), this, SLOT(changeModel(int)));
+    connect(modelSelector, &KComboBox::customContextMenuRequested,
+            this, &GrepOutputView::modelSelectorContextMenu);
+    connect(modelSelector, static_cast<void(KComboBox::*)(int)>(&KComboBox::currentIndexChanged), this, &GrepOutputView::changeModel);
 
     resultsTreeView->setItemDelegate(GrepOutputDelegate::self());
     resultsTreeView->setHeaderHidden(true);
     resultsTreeView->setUniformRowHeights(false);
     resultsTreeView->setHorizontalScrollBarPolicy(Qt::ScrollBarAsNeeded);
 
-    connect(m_prev, SIGNAL(triggered(bool)), this, SLOT(selectPreviousItem()));
-    connect(m_next, SIGNAL(triggered(bool)), this, SLOT(selectNextItem()));
-    connect(m_collapseAll, SIGNAL(triggered(bool)), this, SLOT(collapseAllItems()));
-    connect(m_expandAll, SIGNAL(triggered(bool)), this, SLOT(expandAllItems()));
-    connect(applyButton, SIGNAL(clicked()),  this, SLOT(onApply()));
-    connect(m_clearSearchHistory, SIGNAL(triggered(bool)), this, SLOT(clearSearchHistory()));
-    connect(resultsTreeView, SIGNAL(collapsed(QModelIndex)), this, SLOT(updateScrollArea(QModelIndex)));
-    connect(resultsTreeView, SIGNAL(expanded(QModelIndex)), this, SLOT(updateScrollArea(QModelIndex)));
+    connect(m_prev, &QAction::triggered, this, &GrepOutputView::selectPreviousItem);
+    connect(m_next, &QAction::triggered, this, &GrepOutputView::selectNextItem);
+    connect(m_collapseAll, &QAction::triggered, this, &GrepOutputView::collapseAllItems);
+    connect(m_expandAll, &QAction::triggered, this, &GrepOutputView::expandAllItems);
+    connect(applyButton, &QPushButton::clicked,  this, &GrepOutputView::onApply);
+    connect(m_clearSearchHistory, &QAction::triggered, this, &GrepOutputView::clearSearchHistory);
 
     KConfigGroup cg = ICore::self()->activeSession()->config()->group( "GrepDialog" );
     replacementCombo->addItems( cg.readEntry("LastReplacementItems", QStringList()) );
     replacementCombo->setInsertPolicy(QComboBox::InsertAtTop);
-    applyButton->setIcon(KIcon("dialog-ok-apply"));
+    applyButton->setIcon(QIcon::fromTheme("dialog-ok-apply"));
 
-    connect(replacementCombo, SIGNAL(editTextChanged(QString)), SLOT(replacementTextChanged(QString)));
-    connect(replacementCombo, SIGNAL(returnPressed()), SLOT(onApply()));
+    connect(replacementCombo, &KComboBox::editTextChanged, this, &GrepOutputView::replacementTextChanged);
+    connect(replacementCombo, static_cast<void(KComboBox::*)()>(&KComboBox::returnPressed), this, &GrepOutputView::onApply);
 
-    connect(newSearchAction, SIGNAL(triggered(bool)), this, SLOT(showDialog()));
+    connect(newSearchAction, &QAction::triggered, this, &GrepOutputView::showDialog);
 
     resultsTreeView->header()->setStretchLastSection(true);
 
@@ -152,7 +152,7 @@ GrepOutputView::~GrepOutputView()
     emit outputViewIsClosed();
 }
 
-GrepOutputModel* GrepOutputView::renewModel(QString name, QString descriptionOrUrl)
+GrepOutputModel* GrepOutputView::renewModel(const QString& name, const QString& description)
 {
     // Crear oldest model
     while(modelSelector->count() > GrepOutputView::HISTORY_SIZE) {
@@ -167,19 +167,16 @@ GrepOutputModel* GrepOutputView::renewModel(QString name, QString descriptionOrU
     applyButton->setEnabled(false);
     // text may be already present
     newModel->setReplacement(replacementCombo->currentText());
-    connect(newModel, SIGNAL(rowsRemoved(QModelIndex,int,int)),
-            this, SLOT(rowsRemoved()));
-    connect(resultsTreeView, SIGNAL(activated(QModelIndex)), newModel, SLOT(activate(QModelIndex)));
-    connect(replacementCombo, SIGNAL(editTextChanged(QString)), newModel, SLOT(setReplacement(QString)));
-    connect(newModel, SIGNAL(rowsInserted(QModelIndex,int,int)), this, SLOT(expandElements(QModelIndex)));
-    connect(newModel, SIGNAL(showErrorMessage(QString,int)), this, SLOT(showErrorMessage(QString)));
-    
-    QString prettyUrl = descriptionOrUrl;
-    if(descriptionOrUrl.startsWith('/'))
-        prettyUrl = ICore::self()->projectController()->prettyFileName(descriptionOrUrl, KDevelop::IProjectController::FormatPlain);
+    connect(newModel, &GrepOutputModel::rowsRemoved,
+            this, &GrepOutputView::rowsRemoved);
+    connect(resultsTreeView, &QTreeView::activated, newModel, &GrepOutputModel::activate);
+    connect(replacementCombo, &KComboBox::editTextChanged, newModel, &GrepOutputModel::setReplacement);
+    connect(newModel, &GrepOutputModel::rowsInserted, this, &GrepOutputView::expandElements);
+    connect(newModel, &GrepOutputModel::showErrorMessage, this, &GrepOutputView::showErrorMessage);
+    connect(m_plugin, &GrepViewPlugin::grepJobFinished, this, &GrepOutputView::updateScrollArea);
 
     // appends new model to history
-    QString displayName = i18n("Search \"%1\" in %2 (at time %3)", name, prettyUrl, QTime::currentTime().toString("hh:mm"));
+    const QString displayName = i18n("Search \"%1\" in %2 (at time %3)", name, description, QTime::currentTime().toString("hh:mm"));
     modelSelector->insertItem(0, displayName, qVariantFromValue<QObject*>(newModel));
 
     modelSelector->setCurrentIndex(0);//setCurrentItem(displayName);
@@ -198,10 +195,10 @@ GrepOutputModel* GrepOutputView::model()
 void GrepOutputView::changeModel(int index)
 {
     if (model()) {
-        disconnect(model(), SIGNAL(showMessage(KDevelop::IStatus*,QString)),
-                   this, SLOT(showMessage(KDevelop::IStatus*,QString)));
-        disconnect(model(), SIGNAL(dataChanged(QModelIndex,QModelIndex)),
-                   this, SLOT(updateApplyState(QModelIndex,QModelIndex)));
+        disconnect(model(), &GrepOutputModel::showMessage,
+                   this, &GrepOutputView::showMessage);
+        disconnect(model(), &GrepOutputModel::dataChanged,
+                   this, &GrepOutputView::updateApplyState);
     }
 
     replacementCombo->clearEditText();
@@ -213,10 +210,10 @@ void GrepOutputView::changeModel(int index)
         GrepOutputModel *resultModel = static_cast<GrepOutputModel *>(qvariant_cast<QObject*>(var));
         resultsTreeView->setModel(resultModel);
 
-        connect(model(), SIGNAL(showMessage(KDevelop::IStatus*,QString)),
-                this, SLOT(showMessage(KDevelop::IStatus*,QString)));
-        connect(model(), SIGNAL(dataChanged(QModelIndex,QModelIndex)), 
-                this, SLOT(updateApplyState(QModelIndex,QModelIndex)));
+        connect(model(), &GrepOutputModel::showMessage,
+                this, &GrepOutputView::showMessage);
+        connect(model(), &GrepOutputModel::dataChanged,
+                this, &GrepOutputView::updateApplyState);
         model()->showMessageEmit();
         applyButton->setEnabled(model()->hasResults() &&
                                 model()->getRootItem() &&
