@@ -13,6 +13,7 @@
 #define KDEVPLATFORM_PLUGIN_GREPOUTPUTVIEW_H
 
 #include <interfaces/iuicontroller.h>
+#include <interfaces/itoolviewactionlistener.h>
 
 #include "ui_grepoutputview.h"
 
@@ -30,17 +31,18 @@ class GrepOutputDelegate;
 class GrepOutputViewFactory: public KDevelop::IToolViewFactory
 {
 public:
-    GrepOutputViewFactory(GrepViewPlugin* plugin);
-    virtual QWidget* create(QWidget* parent = 0);
-    virtual Qt::DockWidgetArea defaultPosition();
-    virtual QString id() const;
+    explicit GrepOutputViewFactory(GrepViewPlugin* plugin);
+    virtual QWidget* create(QWidget* parent = 0) override;
+    virtual Qt::DockWidgetArea defaultPosition() override;
+    virtual QString id() const override;
 private:
     GrepViewPlugin* m_plugin;
 };
 
-class GrepOutputView : public QWidget, Ui::GrepOutputView
+class GrepOutputView : public QWidget, Ui::GrepOutputView, public KDevelop::IToolViewActionListener
 {
-  Q_OBJECT
+    Q_OBJECT
+    Q_INTERFACES(KDevelop::IToolViewActionListener)
 
 public:
     enum MessageType {
@@ -57,7 +59,7 @@ public:
      * Oldest models are deleted if needed.
      * @return pointer to the new model
      */
-    GrepOutputModel* renewModel(QString name, QString descriptionOrUrl);
+    GrepOutputModel* renewModel(const QString& name, const QString& description);
     
     void setMessage(const QString& msg, MessageType type = Information);
 
@@ -82,8 +84,8 @@ private:
     GrepViewPlugin *m_plugin;
     
 private slots:
-    void selectPreviousItem();
-    void selectNextItem();
+    void selectPreviousItem() override;
+    void selectNextItem() override;
     void collapseAllItems();
     void expandAllItems();
     void onApply();
