@@ -17,22 +17,19 @@
 #include "grepoutputdelegate.h"
 #include "grepjob.h"
 #include "grepoutputview.h"
+#include "debug.h"
 
-#include <QWhatsThis>
+#include <QAction>
 #include <QDBusConnection>
 #include <QKeySequence>
+#include <QMimeDatabase>
 
-#include <kpluginfactory.h>
-#include <kpluginloader.h>
-#include <kaboutdata.h>
-#include <kactioncollection.h>
-#include <klocale.h>
-#include <kmessagebox.h>
-#include <kaction.h>
-#include <ktexteditor/document.h>
-#include <ktexteditor/cursor.h>
-#include <ktexteditor/view.h>
-#include <kparts/mainwindow.h>
+#include <KActionCollection>
+#include <KLocalizedString>
+#include <KParts/MainWindow>
+#include <KTextEditor/Document>
+#include <KTextEditor/Cursor>
+#include <KTextEditor/View>
 
 #include <interfaces/icore.h>
 #include <interfaces/iplugincontroller.h>
@@ -46,8 +43,7 @@
 #include <language/interfaces/editorcontext.h>
 #include <outputview/ioutputview.h>
 
-K_PLUGIN_FACTORY(GrepViewFactory, registerPlugin<GrepViewPlugin>(); )
-K_EXPORT_PLUGIN(GrepViewFactory(KAboutData("kdevgrepview","kdevgrepview", ki18n("Find/Replace in Files"), "0.1", ki18n("Allows fast searching of multiple files using patterns or regular expressions. And allow to replace it too."), KAboutData::License_GPL)))
+Q_LOGGING_CATEGORY(PLUGIN_GREPVIEW, "kdevplatform.plugins.grepview")
 
 static QString patternFromSelection(const KDevelop::IDocument* doc)
 {
@@ -79,24 +75,24 @@ static QString patternFromSelection(const KDevelop::IDocument* doc)
 }
 
 GrepViewPlugin::GrepViewPlugin( QObject *parent, const QVariantList & )
-    : KDevelop::IPlugin( GrepViewFactory::componentData(), parent ), m_currentJob(0)
+    : KDevelop::IPlugin( "kdevgrepview", parent ), m_currentJob(0)
 {
     setXMLFile("kdevgrepview.rc");
 
     QDBusConnection::sessionBus().registerObject( "/org/kdevelop/GrepViewPlugin",
         this, QDBusConnection::ExportScriptableSlots );
 
-    KAction *action = actionCollection()->addAction("edit_grep");
+    QAction*action = actionCollection()->addAction("edit_grep");
     action->setText(i18n("Find/Replace in Fi&les..."));
-    action->setShortcut( QKeySequence("Ctrl+Alt+F") );
-    connect(action, SIGNAL(triggered(bool)), this, SLOT(showDialogFromMenu()));
+    actionCollection()->setDefaultShortcut( action, QKeySequence("Ctrl+Alt+F") );
+    connect(action, &QAction::triggered, this, &GrepViewPlugin::showDialogFromMenu);
     action->setToolTip( i18n("Search for expressions over several files") );
     action->setWhatsThis( i18n("Opens the 'Find/Replace in files' dialog. There you "
                                "can enter a regular expression which is then "
                                "searched for within all files in the directories "
                                "you specify. Matches will be displayed, you "
                                "can switch to a match directly. You can also do replacement.") );
-    action->setIcon(KIcon("edit-find"));
+    action->setIcon(QIcon::fromTheme("edit-find"));
 
     // instantiate delegate, it's supposed to be deleted via QObject inheritance
     new GrepOutputDelegate(this);
@@ -131,10 +127,10 @@ KDevelop::ContextMenuExtension GrepViewPlugin::contextMenuExtension(KDevelop::Co
         QList<KDevelop::ProjectBaseItem*> items = ctx->items();
         // verify if there is only one folder selected
         if ((items.count() == 1) && (items.first()->folder())) {
-            KAction* action = new KAction( i18n( "Find/Replace in This Folder" ), this );
-            action->setIcon(KIcon("edit-find"));
+            QAction* action = new QAction( i18n( "Find/Replace in This Folder" ), this );
+            action->setIcon(QIcon::fromTheme("edit-find"));
             m_contextMenuDirectory = items.at(0)->folder()->path().toLocalFile();
-            connect( action, SIGNAL(triggered()), this, SLOT(showDialogFromProject()));
+            connect( action, &QAction::triggered, this, &GrepViewPlugin::showDialogFromProject);
             extension.addAction( KDevelop::ContextMenuExtension::ExtensionGroup, action );
         }
     }
@@ -142,20 +138,22 @@ KDevelop::ContextMenuExtension GrepViewPlugin::contextMenuExtension(KDevelop::Co
     if ( context->type() == KDevelop::Context::EditorContext ) {
         KDevelop::EditorContext *econtext = dynamic_cast<KDevelop::EditorContext*>(context);
         if ( econtext->view()->selection() ) {
-            QAction* action = new QAction(KIcon("edit-find"), i18n("&Find/Replace in Files"), this);
-            connect(action, SIGNAL(triggered(bool)), this, SLOT(showDialogFromMenu()));
+            QAction* action = new QAction(QIcon::fromTheme("edit-find"), i18n("&Find/Replace in Files"), this);
+            connect(action, &QAction::triggered, this, &GrepViewPlugin::showDialogFromMenu);
             extension.addAction(KDevelop::ContextMenuExtension::ExtensionGroup, action);
         }
     }
 
     if(context->type() == KDevelop::Context::FileContext) {
         KDevelop::FileContext *fcontext = dynamic_cast<KDevelop::FileContext*>(context);
-        KMimeType::Ptr mimetype = KMimeType::findByUrl( fcontext->urls().first() );
-        if(mimetype->is("inode/directory")) {
-            KAction* action = new KAction( i18n( "Find/Replace in This Folder" ), this );
-            action->setIcon(KIcon("edit-find"));
+        // TODO: just stat() or QFileInfo().isDir() for local files? should be faster than mime type checking
+        QMimeType mimetype = QMimeDatabase().mimeTypeForUrl(fcontext->urls().first());
+        static const QMimeType directoryMime = QMimeDatabase().mimeTypeForName("inode/directory");
+        if (mimetype == directoryMime) {
+            QAction* action = new QAction( i18n( "Find/Replace in This Folder" ), this );
+            action->setIcon(QIcon::fromTheme("edit-find"));
             m_contextMenuDirectory = fcontext->urls().first().toLocalFile();
-            connect( action, SIGNAL(triggered()), this, SLOT(showDialogFromProject()));
+            connect( action, &QAction::triggered, this, &GrepViewPlugin::showDialogFromProject);
             extension.addAction( KDevelop::ContextMenuExtension::ExtensionGroup, action );
         }
     }
@@ -166,7 +164,7 @@ void GrepViewPlugin::showDialog(bool setLastUsed, QString pattern, bool showOpti
 {
     GrepDialog* dlg = new GrepDialog( this, core()->uiController()->activeMainWindow() );
     KDevelop::IDocument* doc = core()->documentController()->activeDocument();
-    
+
     if(!pattern.isEmpty())
     {
         dlg->setPattern(pattern);
@@ -177,19 +175,17 @@ void GrepViewPlugin::showDialog(bool setLastUsed, QString pattern, bool showOpti
         if (!pattern.isEmpty()) {
             dlg->setPattern( pattern );
         }
-
-        dlg->enableButtonOk( !pattern.isEmpty() );
     }
 
     //if directory is empty then use a default value from the config file.
     if (!m_directory.isEmpty()) {
         dlg->setSearchLocations(m_directory);
-    } 
-    
+    }
+
     if(showOptions)
         dlg->show();
     else{
-        dlg->start();
+        dlg->startSearch();
         dlg->deleteLater();
     }
 }
@@ -217,11 +213,11 @@ GrepJob* GrepViewPlugin::newGrepJob()
         m_currentJob->kill();
     }
     m_currentJob = new GrepJob();
-    connect(m_currentJob, SIGNAL(finished(KJob*)), this, SLOT(jobFinished(KJob*)));
+    connect(m_currentJob, &GrepJob::finished, this, &GrepViewPlugin::jobFinished);
     return m_currentJob;
 }
 
-GrepJob* GrepViewPlugin::grepJob() 
+GrepJob* GrepViewPlugin::grepJob()
 {
     return m_currentJob;
 }
@@ -234,5 +230,3 @@ void GrepViewPlugin::jobFinished(KJob* job)
         m_currentJob = 0;
     }
 }
-
-#include "grepviewplugin.moc"
