@@ -16,7 +16,8 @@
 
 #include <QString>
 #include <QWidget>
-#include <KUrl>
+#include <QUrl>
+
 #include <interfaces/ipatchsource.h>
 
 namespace Ui { class LocalPatchWidget; }
@@ -29,38 +30,38 @@ public:
     LocalPatchSource();
     virtual ~LocalPatchSource();
 
-    virtual QString name() const;
+    virtual QString name() const override;
 
-    virtual KUrl baseDir() const {
+    virtual QUrl baseDir() const override {
         return m_baseDir;
     }
 
-    virtual KUrl file() const {
+    virtual QUrl file() const override {
         return m_filename;
     }
 
-    virtual uint depth() const {
+    virtual uint depth() const override {
         return m_depth;
     }
 
-    virtual void update();
-    virtual QIcon icon() const;
+    virtual void update() override;
+    virtual QIcon icon() const override;
 
-    void setFilename(const KUrl& filename) { m_filename = filename; }
-    void setBaseDir(const KUrl& dir) { m_baseDir = dir; }
+    void setFilename(const QUrl& filename) { m_filename = filename; }
+    void setBaseDir(const QUrl& dir) { m_baseDir = dir; }
     void setCommand(const QString& cmd) { m_command = cmd; }
 
     QString command() const { return m_command; }
-    
-    virtual bool isAlreadyApplied() const { return m_applied; }
+
+    virtual bool isAlreadyApplied() const override { return m_applied; }
 
     void setAlreadyApplied( bool applied ) { m_applied = applied; }
 
-    virtual QWidget* customWidget() const;
+    virtual QWidget* customWidget() const override;
 
 private:
-    KUrl m_filename;
-    KUrl m_baseDir;
+    QUrl m_filename;
+    QUrl m_baseDir;
     QString m_command;
     bool m_applied;
     uint m_depth;
