@@ -13,25 +13,29 @@
 
 #include "patchreview.h"
 
-#include <QTabWidget>
-#include <QTimer>
 #include <QFileInfo>
+#include <QStandardPaths>
+#include <QTimer>
+
+#include <KActionCollection>
+#include <KLocalizedString>
+#include <KPluginFactory>
+#include <KMessageBox>
+#include <KIO/CopyJob>
 
 #include <interfaces/idocument.h>
 #include <interfaces/icore.h>
 #include <interfaces/iplugincontroller.h>
-#include <interfaces/ipatchexporter.h>
 #include <interfaces/idocumentcontroller.h>
 #include <interfaces/iuicontroller.h>
 
-#include <kparts/part.h>
-#include <kparts/factory.h>
+#include <libkomparediff2/komparemodellist.h>
+#include <libkomparediff2/kompare.h>
+#include <libkomparediff2/diffsettings.h>
 
-#include "libdiff2/komparemodellist.h"
-#include "libdiff2/kompare.h"
-
-#include <kmessagebox.h>
 #include <ktexteditor/document.h>
+#include <ktexteditor/modificationinterface.h>
+#include <ktexteditor/movingrange.h>
 #include <ktexteditor/view.h>
 
 ///Whether arbitrary exceptions that occurred while diff-parsing within the library should be caught
@@ -45,14 +49,13 @@
 #include <sublime/area.h>
 #include <sublime/document.h>
 #include <sublime/view.h>
-#include "diffsettings.h"
 #include "patchhighlighter.h"
 #include "patchreviewtoolview.h"
 #include "localpatchsource.h"
-#include <ktexteditor/modificationinterface.h>
-#include <ktexteditor/movingrange.h>
-#include <KIO/NetAccess>
-#include <KActionCollection>
+#include "debug.h"
+
+
+Q_LOGGING_CATEGORY(PLUGIN_PATCHREVIEW, "kdevplatform.plugins.patchreview")
 
 using namespace KDevelop;
 
@@ -64,9 +67,9 @@ const int maximumFilesToOpenDirectly = 15;
 
 Q_DECLARE_METATYPE( const Diff2::DiffModel* )
 
-void PatchReviewPlugin::seekHunk( bool forwards, const KUrl& fileName ) {
+void PatchReviewPlugin::seekHunk( bool forwards, const QUrl& fileName ) {
     try {
-        kDebug() << forwards << fileName << fileName.isEmpty();
+        qCDebug(PLUGIN_PATCHREVIEW) << forwards << fileName << fileName.isEmpty();
         if ( !m_modelList )
             throw "no model";
 
@@ -75,18 +78,18 @@ void PatchReviewPlugin::seekHunk( bool forwards, const KUrl& fileName ) {
             if ( !model || !model->differences() )
                 continue;
 
-            KUrl file = urlForFileModel( model );
+            QUrl file = urlForFileModel( model );
 
             if ( !fileName.isEmpty() && fileName != file )
                 continue;
-            
+
             IDocument* doc = ICore::self()->documentController()->documentForUrl( file );
-            
+
             if ( doc && m_highlighters.contains( doc->url() ) && m_highlighters[doc->url()] ) {
                 if ( doc->textDocument() ) {
                     const QList<KTextEditor::MovingRange*> ranges = m_highlighters[doc->url()]->ranges();
 
-                    KTextEditor::View * v = doc->textDocument()->activeView();
+                    KTextEditor::View * v = doc->activeTextView();
                     int bestLine = -1;
                     if ( v ) {
                         KTextEditor::Cursor c = v->cursorPosition();
@@ -113,14 +116,14 @@ void PatchReviewPlugin::seekHunk( bool forwards, const KUrl& fileName ) {
             }
         }
     } catch ( const QString & str ) {
-        kDebug() << "seekHunk():" << str;
+        qCDebug(PLUGIN_PATCHREVIEW) << "seekHunk():" << str;
     } catch ( const char * str ) {
-        kDebug() << "seekHunk():" << str;
+        qCDebug(PLUGIN_PATCHREVIEW) << "seekHunk():" << str;
     }
-    kDebug() << "no matching hunk found";
+    qCDebug(PLUGIN_PATCHREVIEW) << "no matching hunk found";
 }
 
-void PatchReviewPlugin::addHighlighting( const KUrl& highlightFile, IDocument* document ) {
+void PatchReviewPlugin::addHighlighting( const QUrl& highlightFile, IDocument* document ) {
     try {
         if ( !modelList() )
             throw "no model";
@@ -130,18 +133,18 @@ void PatchReviewPlugin::addHighlighting( const KUrl& highlightFile, IDocument* d
             if ( !model )
                 continue;
 
-            KUrl file = urlForFileModel( model );
+            QUrl file = urlForFileModel( model );
 
             if ( file != highlightFile )
                 continue;
 
-            kDebug() << "highlighting" << file.prettyUrl();
+            qCDebug(PLUGIN_PATCHREVIEW) << "highlighting" << file.toDisplayString();
 
             IDocument* doc = document;
             if( !doc )
                 doc = ICore::self()->documentController()->documentForUrl( file );
 
-            kDebug() << "highlighting file" << file << "with doc" << doc;
+            qCDebug(PLUGIN_PATCHREVIEW) << "highlighting file" << file << "with doc" << doc;
 
             if ( !doc || !doc->textDocument() )
                 continue;
@@ -151,9 +154,9 @@ void PatchReviewPlugin::addHighlighting( const KUrl& highlightFile, IDocument* d
             m_highlighters[file] = new PatchHighlighter( model, doc, this );
         }
     } catch ( const QString & str ) {
-        kDebug() << "highlightFile():" << str;
+        qCDebug(PLUGIN_PATCHREVIEW) << "highlightFile():" << str;
     } catch ( const char * str ) {
-        kDebug() << "highlightFile():" << str;
+        qCDebug(PLUGIN_PATCHREVIEW) << "highlightFile():" << str;
     }
 }
 
@@ -167,18 +170,18 @@ void PatchReviewPlugin::highlightPatch() {
             if ( !model )
                 continue;
 
-            KUrl file = urlForFileModel( model );
+            QUrl file = urlForFileModel( model );
 
             addHighlighting( file );
         }
     } catch ( const QString & str ) {
-        kDebug() << "highlightFile():" << str;
+        qCDebug(PLUGIN_PATCHREVIEW) << "highlightFile():" << str;
     } catch ( const char * str ) {
-        kDebug() << "highlightFile():" << str;
+        qCDebug(PLUGIN_PATCHREVIEW) << "highlightFile():" << str;
     }
 }
 
-void PatchReviewPlugin::removeHighlighting( const KUrl& file ) {
+void PatchReviewPlugin::removeHighlighting( const QUrl& file ) {
     if ( file.isEmpty() ) {
         ///Remove all highlighting
         qDeleteAll( m_highlighters );
@@ -193,7 +196,7 @@ void PatchReviewPlugin::removeHighlighting( const KUrl& file ) {
 }
 
 void PatchReviewPlugin::notifyPatchChanged() {
-    kDebug() << "notifying patch change: " << m_patch->file();
+    qCDebug(PLUGIN_PATCHREVIEW) << "notifying patch change: " << m_patch->file();
     m_updateKompareTimer->start( 500 );
 }
 
@@ -213,26 +216,30 @@ void PatchReviewPlugin::updateKompareModel() {
         return;
     }
 
-    kDebug() << "updating model";
+    qCDebug(PLUGIN_PATCHREVIEW) << "updating model";
+    removeHighlighting();
+    m_modelList.reset( nullptr );
+    delete m_diffSettings;
+    {
+        IDocument* patchDoc = ICore::self()->documentController()->documentForUrl( m_patch->file() );
+        if( patchDoc )
+            patchDoc->reload();
+    }
+
+    QString patchFile;
+    if( m_patch->file().isLocalFile() )
+        patchFile = m_patch->file().toLocalFile();
+    else if( m_patch->file().isValid() && !m_patch->file().isEmpty() ) {
+        patchFile = QStandardPaths::writableLocation(QStandardPaths::TempLocation);
+        bool ret = KIO::copy( m_patch->file(), QUrl::fromLocalFile(patchFile) )->exec();
+        if( !ret ) {
+            qWarning() << "Problem while downloading: " << m_patch->file() << "to" << patchFile;
+            patchFile.clear();
+        }
+    }
+
+    if (!patchFile.isEmpty()) //only try to construct the model if we have a patch to load
     try {
-        removeHighlighting();
-        m_modelList.reset( 0 );
-        delete m_diffSettings;
-
-        {
-            IDocument* patchDoc = ICore::self()->documentController()->documentForUrl( m_patch->file() );
-            if( patchDoc )
-                patchDoc->reload();
-        }
-        QString patchFile;
-        if( m_patch->file().isLocalFile() )
-            patchFile = m_patch->file().toLocalFile();
-        else if( m_patch->file().isValid() && !m_patch->file().isEmpty() ) {
-            bool ret = KIO::NetAccess::download( m_patch->file(), patchFile, ICore::self()->uiController()->activeMainWindow() );
-            if( !ret )
-                kWarning() << "Problem while downloading: " << m_patch->file();
-        }
-
         m_diffSettings = new DiffSettings( 0 );
         m_kompareInfo.reset( new Kompare::Info() );
         m_kompareInfo->localDestination = patchFile;
@@ -248,7 +255,7 @@ void PatchReviewPlugin::updateKompareModel() {
         } catch ( const QString & str ) {
             throw;
         } catch ( ... ) {
-            throw QString( "lib/libdiff2 crashed, memory may be corrupted. Please restart kdevelop." );
+            throw QStringLiteral( "lib/libdiff2 crashed, memory may be corrupted. Please restart kdevelop." );
         }
 
         emit patchChanged();
@@ -269,30 +276,29 @@ void PatchReviewPlugin::updateKompareModel() {
         KMessageBox::error( 0, str, i18n( "Kompare Model Update" ) );
     }
     removeHighlighting();
-    m_modelList.reset( 0 );
-    m_kompareInfo.reset( 0 );
+    m_modelList.reset( nullptr );
+    m_kompareInfo.reset( nullptr );
     delete m_diffSettings;
 
     emit patchChanged();
 }
 
-K_PLUGIN_FACTORY( KDevProblemReporterFactory, registerPlugin<PatchReviewPlugin>(); )
-K_EXPORT_PLUGIN( KDevProblemReporterFactory( KAboutData( "kdevpatchreview", "kdevpatchreview", ki18n( "Patch Review" ), "0.1", ki18n( "Highlights code affected by a patch" ), KAboutData::License_GPL ) ) )
+K_PLUGIN_FACTORY_WITH_JSON(KDevProblemReporterFactory, "kdevpatchreview.json", registerPlugin<PatchReviewPlugin>();)
 
 class PatchReviewToolViewFactory : public KDevelop::IToolViewFactory
 {
 public:
     PatchReviewToolViewFactory( PatchReviewPlugin *plugin ) : m_plugin( plugin ) {}
 
-    virtual QWidget* create( QWidget *parent = 0 ) {
+    virtual QWidget* create( QWidget *parent = 0 ) override {
         return m_plugin->createToolView( parent );
     }
 
-    virtual Qt::DockWidgetArea defaultPosition() {
+    virtual Qt::DockWidgetArea defaultPosition() override {
         return Qt::BottomDockWidgetArea;
     }
 
-    virtual QString id() const {
+    virtual QString id() const override {
         return "org.kdevelop.PatchReview";
     }
 
@@ -312,11 +318,11 @@ PatchReviewPlugin::~PatchReviewPlugin()
 }
 
 void PatchReviewPlugin::clearPatch( QObject* _patch ) {
-    kDebug() << "clearing patch" << _patch << "current:" << ( QObject* )m_patch;
+    qCDebug(PLUGIN_PATCHREVIEW) << "clearing patch" << _patch << "current:" << ( QObject* )m_patch;
     IPatchSource::Ptr patch( ( IPatchSource* )_patch );
 
     if( patch == m_patch ) {
-        kDebug() << "is current patch";
+        qCDebug(PLUGIN_PATCHREVIEW) << "is current patch";
         setPatch( IPatchSource::Ptr( new LocalPatchSource ) );
     }
 }
@@ -327,16 +333,15 @@ void PatchReviewPlugin::closeReview()
         removeHighlighting();
         m_modelList.reset( 0 );
 
-        emit patchChanged();
-
         if( !dynamic_cast<LocalPatchSource*>( m_patch.data() ) ) {
             // make sure "show" button still openes the file dialog to open a custom patch file
             setPatch( new LocalPatchSource );
-        }
+        } else
+            emit patchChanged();
 
         Sublime::MainWindow* w = dynamic_cast<Sublime::MainWindow*>( ICore::self()->uiController()->activeMainWindow() );
         if( w->area()->objectName() == "review" ) {
-            if( setUniqueEmptyWorkingSet() )
+            if( ICore::self()->documentController()->closeAllDocuments() )
                 ICore::self()->uiController()->switchToArea( "code", KDevelop::IUiController::ThisWindow );
         }
     }
@@ -349,7 +354,7 @@ void PatchReviewPlugin::cancelReview() {
     }
 }
 
-void PatchReviewPlugin::finishReview( QList<KUrl> selection ) {
+void PatchReviewPlugin::finishReview( QList<QUrl> selection ) {
     if( m_patch && m_patch->finishReview( selection ) ) {
         closeReview();
     }
@@ -362,106 +367,67 @@ void PatchReviewPlugin::startReview( IPatchSource* patch, IPatchReview::ReviewMo
     QMetaObject::invokeMethod( this, "updateReview", Qt::QueuedConnection );
 }
 
-void PatchReviewPlugin::switchAreaAndMakeWorkingSetUique() {
-    Sublime::MainWindow* w = dynamic_cast<Sublime::MainWindow*>( ICore::self()->uiController()->activeMainWindow() );
-    if ( w->area()->objectName() != "review" )
+void PatchReviewPlugin::switchToEmptyReviewArea()
+{
+    foreach(Sublime::Area* area, ICore::self()->uiController()->allAreas()) {
+        if (area->objectName() == "review") {
+            emit area->clearDocuments();
+        }
+    }
+
+    if ( ICore::self()->uiController()->activeArea()->objectName() != "review" )
         ICore::self()->uiController()->switchToArea( "review", KDevelop::IUiController::ThisWindow );
-
-    setUniqueEmptyWorkingSet();
 }
 
-bool PatchReviewPlugin::isWorkingSetUnique() const {
-    Sublime::MainWindow* w = dynamic_cast<Sublime::MainWindow*>( ICore::self()->uiController()->activeMainWindow() );
-    foreach( Sublime::Area* area, w->areas() )
-        if( area != w->area() && area->workingSet() == w->area()->workingSet() )
-            return false;
-    return true;
+QUrl PatchReviewPlugin::urlForFileModel( const Diff2::DiffModel* model )
+{
+    QUrl file = m_patch->baseDir();
+    file.setPath(file.toLocalFile() + '/' + model->destinationPath() + '/' + model->destinationFile());
+    return file;
 }
 
-bool PatchReviewPlugin::setUniqueEmptyWorkingSet() {
-    Sublime::MainWindow* w = dynamic_cast<Sublime::MainWindow*>( ICore::self()->uiController()->activeMainWindow() );
-
-    if( !ICore::self()->documentController()->saveAllDocumentsForWindow( ICore::self()->uiController()->activeMainWindow(), KDevelop::IDocument::Default, true ) )
-        return false;
-
-    if( !w->area()->workingSet().startsWith( "review" ) )
-        w->area()->setWorkingSet( "review" );
-
-    while( !isWorkingSetUnique() )
-        w->area()->setWorkingSet( QString( "review_%1" ).arg( rand() % 10000 ) );
-
-    // We've asked the user, so just clear silently
-    w->area()->clearViews( true );
-
-    return true;
-}
-
-void PatchReviewPlugin::updateReview() {
+void PatchReviewPlugin::updateReview()
+{
     if( !m_patch )
         return;
 
     m_updateKompareTimer->stop();
+
+    switchToEmptyReviewArea();
+
+    IDocument* futureActiveDoc = ICore::self()->documentController()->openDocument( m_patch->file() );
+
     updateKompareModel();
-
-    switchAreaAndMakeWorkingSetUique();
-
-    if( !m_modelList )
-        return;
-
-    // list of opened documents to prevent flicker
-    QMap<KUrl, IDocument*> documents;
-    foreach( IDocument* doc, ICore::self()->documentController()->openDocuments() ) {
-        documents[doc->url()] = doc;
-    }
-
-    IDocument* futureActiveDoc = 0;
-    //Open the diff itself
-    if ( !documents.contains( m_patch->file() ) ) {
-        futureActiveDoc = ICore::self()->documentController()->openDocument( m_patch->file() );
-    } else {
-        futureActiveDoc = documents.take( m_patch->file() );
-    }
-    if ( !futureActiveDoc || !futureActiveDoc->textDocument() ) {
+    if ( !m_modelList || !futureActiveDoc || !futureActiveDoc->textDocument() ) {
         // might happen if e.g. openDocument dialog was cancelled by user
         // or under the theoretic possibility of a non-text document getting opened
         return;
     }
     futureActiveDoc->textDocument()->setReadWrite( false );
     futureActiveDoc->setPrettyName( i18n( "Overview" ) );
-    
+
     IDocument* buddyDoc = futureActiveDoc;
-    
+
     KTextEditor::ModificationInterface* modif = dynamic_cast<KTextEditor::ModificationInterface*>( futureActiveDoc->textDocument() );
     modif->setModifiedOnDiskWarning( false );
 
     if( m_modelList->modelCount() < maximumFilesToOpenDirectly ) {
         //Open all relates files
         for( int a = 0; a < m_modelList->modelCount(); ++a ) {
-            KUrl absoluteUrl = urlForFileModel( m_modelList->modelAt( a ) );
+            QUrl absoluteUrl = urlForFileModel( m_modelList->modelAt( a ) );
 
-            if( QFileInfo( absoluteUrl.path() ).exists() && absoluteUrl.path() != "/dev/null" )
+            if( QFileInfo( absoluteUrl.toLocalFile() ).exists() && absoluteUrl.toLocalFile() != "/dev/null" )
             {
                 buddyDoc = ICore::self()->documentController()->openDocument( absoluteUrl, KTextEditor::Range::invalid(), IDocumentController::DoNotActivate, "", buddyDoc );
-                documents.remove( absoluteUrl );
 
                 seekHunk( true, absoluteUrl ); //Jump to the first changed position
             }else{
                 // Maybe the file was deleted
-                kDebug() << "could not open" << absoluteUrl << "because it doesn't exist";
+                qCDebug(PLUGIN_PATCHREVIEW) << "could not open" << absoluteUrl << "because it doesn't exist";
             }
         }
     }
 
-    Sublime::MainWindow* w = dynamic_cast<Sublime::MainWindow*>( ICore::self()->uiController()->activeMainWindow() );
-    // Close views for documents that were loaded from the working set, but are not in the patch
-    QList<IDocument*> documentsList = documents.values();
-    foreach( Sublime::View* view, w->area()->views() ) {
-        IDocument* doc = dynamic_cast<IDocument*>( view->document() );
-        if( doc && documentsList.contains( doc ) ) {
-            w->area()->closeView( view );
-        }
-    }
-
     Q_ASSERT( futureActiveDoc );
     ICore::self()->documentController()->activateDocument( futureActiveDoc );
 
@@ -476,7 +442,7 @@ void PatchReviewPlugin::setPatch( IPatchSource* patch ) {
     }
 
     if( m_patch ) {
-        disconnect( m_patch, SIGNAL( patchChanged() ), this, SLOT( notifyPatchChanged() ) );
+        disconnect( m_patch.data(), &IPatchSource::patchChanged, this, &PatchReviewPlugin::notifyPatchChanged );
         if ( qobject_cast<LocalPatchSource*>( m_patch ) ) {
             // make sure we don't leak this
             // TODO: what about other patch sources?
@@ -486,9 +452,9 @@ void PatchReviewPlugin::setPatch( IPatchSource* patch ) {
     m_patch = patch;
 
     if( m_patch ) {
-        kDebug() << "setting new patch" << patch->name() << "with file" << patch->file() << "basedir" << patch->baseDir();
+        qCDebug(PLUGIN_PATCHREVIEW) << "setting new patch" << patch->name() << "with file" << patch->file() << "basedir" << patch->baseDir();
 
-        connect( m_patch, SIGNAL( patchChanged() ), this, SLOT( notifyPatchChanged() ) );
+        connect( m_patch.data(), &IPatchSource::patchChanged, this, &PatchReviewPlugin::notifyPatchChanged );
     }
     QString finishText = i18n( "Finish Review" );
     if( m_patch && !m_patch->finishReviewCustomText().isEmpty() )
@@ -499,30 +465,33 @@ void PatchReviewPlugin::setPatch( IPatchSource* patch ) {
 }
 
 PatchReviewPlugin::PatchReviewPlugin( QObject *parent, const QVariantList & )
-    : KDevelop::IPlugin( KDevProblemReporterFactory::componentData(), parent ),
+    : KDevelop::IPlugin( "kdevpatchreview", parent ),
     m_patch( 0 ), m_factory( new PatchReviewToolViewFactory( this ) ) {
     KDEV_USE_EXTENSION_INTERFACE( KDevelop::IPatchReview )
     qRegisterMetaType<const Diff2::DiffModel*>( "const Diff2::DiffModel*" );
 
     setXMLFile( "kdevpatchreview.rc" );
 
-    connect( ICore::self()->documentController(), SIGNAL( documentClosed( KDevelop::IDocument* ) ), this, SLOT( documentClosed( KDevelop::IDocument* ) ) );
-    connect( ICore::self()->documentController(), SIGNAL( textDocumentCreated( KDevelop::IDocument* ) ), this, SLOT( textDocumentCreated( KDevelop::IDocument* ) ) );
-    connect( ICore::self()->documentController(), SIGNAL( documentSaved( KDevelop::IDocument* ) ), this, SLOT( documentSaved( KDevelop::IDocument* ) ) );
+    connect( ICore::self()->documentController(), &IDocumentController::documentClosed, this, &PatchReviewPlugin::documentClosed );
+    connect( ICore::self()->documentController(), &IDocumentController::textDocumentCreated, this, &PatchReviewPlugin::textDocumentCreated );
+    connect( ICore::self()->documentController(), &IDocumentController::documentSaved, this, &PatchReviewPlugin::documentSaved );
 
     m_updateKompareTimer = new QTimer( this );
     m_updateKompareTimer->setSingleShot( true );
-    connect( m_updateKompareTimer, SIGNAL( timeout() ), this, SLOT( updateKompareModel() ) );
+    connect( m_updateKompareTimer, &QTimer::timeout, this, &PatchReviewPlugin::updateKompareModel );
 
-    m_finishReview = new QAction(this);
-    m_finishReview->setIcon( KIcon( "dialog-ok" ) );
-    m_finishReview->setShortcut( Qt::CTRL|Qt::Key_Return );
+    m_finishReview = new QAction(i18n("Finish Review"), this);
+    m_finishReview->setIcon( QIcon::fromTheme( "dialog-ok" ) );
+    actionCollection()->setDefaultShortcut( m_finishReview, Qt::CTRL|Qt::Key_Return );
     actionCollection()->addAction("commit_or_finish_review", m_finishReview);
-    ICore::self()->uiController()->activeArea()->addAction(m_finishReview);
 
-    setPatch( IPatchSource::Ptr( new LocalPatchSource ) );
+    foreach(Sublime::Area* area, ICore::self()->uiController()->allAreas()) {
+        if (area->objectName() == "review")
+            area->addAction(m_finishReview);
+    }
 
     core()->uiController()->addToolView( i18n( "Patch Review" ), m_factory );
+
     areaChanged(ICore::self()->uiController()->activeArea());
 }
 
@@ -539,7 +508,9 @@ void PatchReviewPlugin::documentSaved( IDocument* doc ) {
 }
 
 void PatchReviewPlugin::textDocumentCreated( IDocument* doc ) {
-    addHighlighting( doc->url(), doc );
+    if (m_patch) {
+        addHighlighting( doc->url(), doc );
+    }
 }
 
 void PatchReviewPlugin::unload() {
@@ -552,16 +523,6 @@ QWidget* PatchReviewPlugin::createToolView( QWidget* parent ) {
     return new PatchReviewToolView( parent, this );
 }
 
-void PatchReviewPlugin::exporterSelected( QAction* action ) {
-    IPlugin* exporter = qobject_cast<IPlugin*>( action->data().value<QObject*>() );
-
-    if( exporter ) {
-        qDebug() << "exporting patch" << exporter << action->text();
-        // for git projects, m_patch will be a VCSDiffPatchSource instance
-        exporter->extension<IPatchExporter>()->exportPatch( patch() );
-    }
-}
-
 void PatchReviewPlugin::areaChanged(Sublime::Area* area)
 {
     bool reviewing = area->objectName() == "review";
@@ -573,4 +534,4 @@ void PatchReviewPlugin::areaChanged(Sublime::Area* area)
 
 #include "patchreview.moc"
 
-// kate: space-indent on; indent-width 2; tab-width 2; replace-tabs on
+// kate: space-indent on; indent-width 4; tab-width 4; replace-tabs on
