@@ -14,9 +14,9 @@
 #include "patchreviewtoolview.h"
 #include "localpatchsource.h"
 #include "patchreview.h"
-#include "standardpatchexport.h"
-#include "libdiff2/diffmodellist.h"
-#include "libdiff2/komparemodellist.h"
+#include "debug.h"
+#include <libkomparediff2/diffmodellist.h>
+#include <libkomparediff2/komparemodellist.h>
 #include <interfaces/icore.h>
 #include <interfaces/idocumentcontroller.h>
 #include <vcs/models/vcsfilechangesmodel.h>
@@ -33,9 +33,21 @@
 #include <sublime/view.h>
 #include <sublime/document.h>
 #include <sublime/mainwindow.h>
-#include <KLineEdit>
-#include <KTextEditor/Document>
+
+#include <QFileInfo>
 #include <QMenu>
+#include <QJsonObject>
+#include <QJsonArray>
+
+#include <KMessageBox>
+#include <KLocalizedString>
+#include <KTextEditor/Document>
+#include <KTextEditor/View>
+
+#ifdef WITH_PURPOSE
+#include <Purpose/AlternativesModel>
+#include <PurposeWidgets/Menu>
+#endif
 
 using namespace KDevelop;
 
@@ -43,7 +55,7 @@ class PatchFilesModel : public VcsFileChangesModel
 {
 public:
     PatchFilesModel( QObject *parent, bool allowSelection ) : VcsFileChangesModel( parent, allowSelection ) { };
-    enum ItemRoles { HunksNumberRole = VcsStatusInfoRole+1 };
+    enum ItemRoles { HunksNumberRole = LastItemRole+1 };
 
 public slots:
     void updateState( const KDevelop::VcsStatusInfo &status, unsigned hunksNum ) {
@@ -69,7 +81,7 @@ private:
     void setFileInfo( QStandardItem *item, unsigned int hunksNum ) {
         QString newText = i18ncp( "%1: number of changed hunks, %2: file name",
             "%2 (1 hunk)", "%2 (%1 hunks)", hunksNum,
-            item->data(VcsFileChangesModel::VcsStatusInfoRole).value<VcsStatusInfo>().url().pathOrUrl() );
+            item->index().data(VcsFileChangesModel::UrlRole).toUrl().toDisplayString(QUrl::PreferLocalFile) );
         item->setText( newText );
     }
 };
@@ -77,18 +89,34 @@ private:
 PatchReviewToolView::PatchReviewToolView( QWidget* parent, PatchReviewPlugin* plugin )
     : QWidget( parent ),
     m_resetCheckedUrls( true ),
-    m_plugin( plugin ) {
-    connect( plugin, SIGNAL( patchChanged() ), SLOT( patchChanged() ) );
-    connect( plugin, SIGNAL( startingNewReview() ), SLOT( startingNewReview() ) );
-    connect( ICore::self()->documentController(), SIGNAL( documentActivated( KDevelop::IDocument* ) ), this, SLOT( documentActivated( KDevelop::IDocument* ) ) );
+    m_plugin( plugin )
+{
+    connect( m_plugin->finishReviewAction(), &QAction::triggered, this, &PatchReviewToolView::finishReview );
+
+    connect( plugin, &PatchReviewPlugin::patchChanged, this, &PatchReviewToolView::patchChanged );
+    connect( plugin, &PatchReviewPlugin::startingNewReview, this, &PatchReviewToolView::startingNewReview );
+    connect( ICore::self()->documentController(), &IDocumentController::documentActivated, this, &PatchReviewToolView::documentActivated );
 
     Sublime::MainWindow* w = dynamic_cast<Sublime::MainWindow*>( ICore::self()->uiController()->activeMainWindow() );
-    connect(w, SIGNAL(areaChanged(Sublime::Area*)), m_plugin, SLOT(areaChanged(Sublime::Area*)));
+    connect(w, &Sublime::MainWindow::areaChanged, m_plugin, &PatchReviewPlugin::areaChanged);
 
     showEditDialog();
     patchChanged();
 }
 
+void PatchReviewToolView::resizeEvent(QResizeEvent* ev)
+{
+    bool vertical = (width() < height());
+    m_editPatch.buttonsLayout->setDirection(vertical ? QBoxLayout::TopToBottom : QBoxLayout::LeftToRight);
+    m_editPatch.contentLayout->setDirection(vertical ? QBoxLayout::TopToBottom : QBoxLayout::LeftToRight);
+    m_editPatch.buttonsSpacer->changeSize(vertical ? 0 : 40, 0, QSizePolicy::Fixed, QSizePolicy::Fixed);
+    QWidget::resizeEvent(ev);
+    if(m_customWidget) {
+        m_editPatch.contentLayout->removeWidget( m_customWidget );
+        m_editPatch.contentLayout->insertWidget(0, m_customWidget );
+    }
+}
+
 void PatchReviewToolView::startingNewReview()
 {
     m_resetCheckedUrls = true;
@@ -97,9 +125,21 @@ void PatchReviewToolView::startingNewReview()
 void PatchReviewToolView::patchChanged() {
     fillEditFromPatch();
     kompareModelChanged();
+
+#ifdef WITH_PURPOSE
+    IPatchSource::Ptr p = m_plugin->patch();
+    if (p) {
+        m_exportMenu->model()->setInputData(QJsonObject {
+            { QStringLiteral("urls"), QJsonArray { p->file().toString() } },
+            { QStringLiteral("mimeType"), { QStringLiteral("text/x-patch") } },
+            { QStringLiteral("localBaseDir"), { p->baseDir().toString() } }
+        });
+    }
+#endif
 }
 
-PatchReviewToolView::~PatchReviewToolView() {
+PatchReviewToolView::~PatchReviewToolView()
+{
 }
 
 LocalPatchSource* PatchReviewToolView::GetLocalPatchSource() {
@@ -110,64 +150,32 @@ LocalPatchSource* PatchReviewToolView::GetLocalPatchSource() {
     return dynamic_cast<LocalPatchSource*>( ips.data() );
 }
 
-void PatchReviewToolView::updatePatchFromEdit() {
-    LocalPatchSource* lpatch = GetLocalPatchSource();
-    if( !lpatch )
-        return;
-
-    lpatch->setCommand(m_editPatch.command->text());
-    lpatch->setFilename(m_editPatch.filename->url());
-    lpatch->setBaseDir(m_editPatch.baseDir->url());
-    lpatch->setAlreadyApplied( m_editPatch.applied->checkState() == Qt::Checked );
-
-    m_plugin->notifyPatchChanged();
-}
-
 void PatchReviewToolView::fillEditFromPatch() {
     IPatchSource::Ptr ipatch = m_plugin->patch();
     if ( !ipatch )
         return;
 
-    disconnect( m_editPatch.patchSelection, SIGNAL( currentIndexChanged( int ) ), this, SLOT( patchSelectionChanged( int ) ) );
-
-    m_editPatch.patchSelection->clear();
-    foreach( IPatchSource::Ptr patch, m_plugin->knownPatches() )
-    {
-        if( !patch )
-            continue;
-        m_editPatch.patchSelection->addItem( patch->icon(), patch->name() );
-        if( patch == ipatch )
-            m_editPatch.patchSelection->setCurrentIndex( m_editPatch.patchSelection->count()-1 );
-    }
-
-    connect( m_editPatch.patchSelection, SIGNAL( currentIndexChanged( int ) ), this, SLOT( patchSelectionChanged( int ) ) );
-
     m_editPatch.cancelReview->setVisible( ipatch->canCancel() );
 
-    QString finishText = i18n( "Finish Review" );
-    if( !ipatch->finishReviewCustomText().isEmpty() )
-        finishText = ipatch->finishReviewCustomText();
-    kDebug() << "finish-text: " << finishText;
-    m_editPatch.finishReview->setText( finishText );
     m_fileModel->setIsCheckbable( m_plugin->patch()->canSelectFiles() );
 
     if( m_customWidget ) {
-        kDebug() << "removing custom widget";
+        qCDebug(PLUGIN_PATCHREVIEW) << "removing custom widget";
         m_customWidget->hide();
-        m_editPatch.customWidgetsLayout->removeWidget( m_customWidget );
+        m_editPatch.contentLayout->removeWidget( m_customWidget );
     }
 
     m_customWidget = ipatch->customWidget();
     if( m_customWidget ) {
-        m_editPatch.customWidgetsLayout->insertWidget( 0, m_customWidget );
+        m_editPatch.contentLayout->insertWidget( 0, m_customWidget );
         m_customWidget->show();
-        kDebug() << "got custom widget";
+        qCDebug(PLUGIN_PATCHREVIEW) << "got custom widget";
     }
 
     bool showTests = false;
     IProject* project = 0;
-    QMap<KUrl, VcsStatusInfo::State> files = ipatch->additionalSelectableFiles();
-    QMap<KUrl, VcsStatusInfo::State>::const_iterator it = files.constBegin();
+    QMap<QUrl, VcsStatusInfo::State> files = ipatch->additionalSelectableFiles();
+    QMap<QUrl, VcsStatusInfo::State>::const_iterator it = files.constBegin();
 
     for (; it != files.constEnd(); ++it) {
         project = ICore::self()->projectController()->findProjectForUrl(it.key());
@@ -179,28 +187,6 @@ void PatchReviewToolView::fillEditFromPatch() {
 
     m_editPatch.testsButton->setVisible(showTests);
     m_editPatch.testProgressBar->hide();
-
-    LocalPatchSource* lpatch = dynamic_cast<LocalPatchSource*>( ipatch.data() );
-    m_editPatch.localPatchOptions->setVisible( lpatch );
-    if( !lpatch )
-        return;
-
-    m_editPatch.command->setText( lpatch->command());
-    m_editPatch.filename->setUrl( lpatch->file() );
-    m_editPatch.baseDir->setUrl( lpatch->baseDir() );
-    m_editPatch.applied->setCheckState( lpatch->isAlreadyApplied() ? Qt::Checked : Qt::Unchecked );
-
-    if ( lpatch->command().isEmpty() )
-        m_editPatch.tabWidget->setCurrentIndex( m_editPatch.tabWidget->indexOf( m_editPatch.fileTab ) );
-    else
-        m_editPatch.tabWidget->setCurrentIndex( m_editPatch.tabWidget->indexOf( m_editPatch.commandTab ) );
-}
-
-void PatchReviewToolView::patchSelectionChanged( int selection ) {
-    m_fileModel->removeRows( 0, m_fileModel->rowCount() );
-    if( selection >= 0 && selection < m_plugin->knownPatches().size() ) {
-        m_plugin->setPatch( m_plugin->knownPatches()[selection] );
-    }
 }
 
 void PatchReviewToolView::slotAppliedChanged( int newState ) {
@@ -219,81 +205,62 @@ void PatchReviewToolView::showEditDialog() {
     m_editPatch.filesList->header()->hide();
     m_editPatch.filesList->setRootIsDecorated( false );
     m_editPatch.filesList->setContextMenuPolicy(Qt::CustomContextMenu);
-    connect(m_editPatch.filesList, SIGNAL(customContextMenuRequested(QPoint)), SLOT(customContextMenuRequested(QPoint)));
-    connect(m_fileModel, SIGNAL(itemChanged(QStandardItem*)), SLOT(fileItemChanged(QStandardItem*)));
+    connect(m_editPatch.filesList, &QTreeView::customContextMenuRequested, this, &PatchReviewToolView::customContextMenuRequested);
+    connect(m_fileModel, &PatchFilesModel::itemChanged, this, &PatchReviewToolView::fileItemChanged);
+    m_editPatch.previousFile->setIcon( QIcon::fromTheme( "arrow-left" ) );
+    m_editPatch.previousHunk->setIcon( QIcon::fromTheme( "arrow-up" ) );
+    m_editPatch.nextHunk->setIcon( QIcon::fromTheme( "arrow-down" ) );
+    m_editPatch.nextFile->setIcon( QIcon::fromTheme( "arrow-right" ) );
+    m_editPatch.cancelReview->setIcon( QIcon::fromTheme( "dialog-cancel" ) );
+    m_editPatch.updateButton->setIcon( QIcon::fromTheme( "view-refresh" ) );
+    m_editPatch.testsButton->setIcon( QIcon::fromTheme( "preflight-verifier" ) );
+    m_editPatch.finishReview->setDefaultAction(m_plugin->finishReviewAction());
 
-    m_editPatch.previousFile->setIcon( KIcon( "arrow-left" ) );
-    m_editPatch.previousHunk->setIcon( KIcon( "arrow-up" ) );
-    m_editPatch.nextHunk->setIcon( KIcon( "arrow-down" ) );
-    m_editPatch.nextFile->setIcon( KIcon( "arrow-right" ) );
-    m_editPatch.cancelReview->setIcon( KIcon( "dialog-cancel" ) );
-    m_editPatch.finishReview->setIcon( KIcon( "dialog-ok" ) );
-    m_editPatch.updateButton->setIcon( KIcon( "view-refresh" ) );
-    m_editPatch.testsButton->setIcon( KIcon( "preflight-verifier" ) );
+#ifdef WITH_PURPOSE
+    m_exportMenu = new Purpose::Menu(this);
+    connect(m_exportMenu, &Purpose::Menu::finished, this, [](const QJsonObject &output, int error, const QString &message) {
+        if (error==0) {
+            KMessageBox::information(0, i18n("<qt>You can find the new request at:<br /><a href='%1'>%1</a> </qt>", output["url"].toString()),
+                                    QString(), QString(), KMessageBox::AllowLink);
+        } else {
+            QMessageBox::warning(nullptr, i18n("Error exporting"), i18n("Couldn't export the patch.\n%1", message));
+        }
+    });
+    m_exportMenu->model()->setPluginType("Export");
+    m_editPatch.exportReview->setMenu( m_exportMenu );
+#else
+    m_editPatch.exportReview->setEnabled(false);
+#endif
 
-    QMenu* exportMenu = new QMenu( m_editPatch.exportReview );
-    StandardPatchExport* stdactions = new StandardPatchExport( m_plugin, this );
-    stdactions->addActions( exportMenu );
-    connect( exportMenu, SIGNAL( triggered( QAction* ) ), m_plugin, SLOT( exporterSelected( QAction* ) ) );
+    connect( m_editPatch.previousHunk, &QToolButton::clicked, this, &PatchReviewToolView::prevHunk );
+    connect( m_editPatch.nextHunk, &QToolButton::clicked, this, &PatchReviewToolView::nextHunk );
+    connect( m_editPatch.previousFile, &QToolButton::clicked, this, &PatchReviewToolView::prevFile );
+    connect( m_editPatch.nextFile, &QToolButton::clicked, this, &PatchReviewToolView::nextFile );
+    connect( m_editPatch.filesList, &QTreeView::activated , this, &PatchReviewToolView::fileDoubleClicked );
 
-    IPluginController* pluginManager = ICore::self()->pluginController();
-    foreach( IPlugin* p, pluginManager->allPluginsForExtension( "org.kdevelop.IPatchExporter" ) )
-    {
-        KPluginInfo info = pluginManager->pluginInfo( p );
-        QAction* action = exportMenu->addAction( KIcon( info.icon() ), info.name() );
-        action->setData( qVariantFromValue<QObject*>( p ) );
-    }
-
-    m_editPatch.exportReview->setMenu( exportMenu );
-
-    connect( m_editPatch.previousHunk, SIGNAL( clicked( bool ) ), this, SLOT( prevHunk() ) );
-    connect( m_editPatch.nextHunk, SIGNAL( clicked( bool ) ), this, SLOT( nextHunk() ) );
-    connect( m_editPatch.previousFile, SIGNAL( clicked( bool ) ), this, SLOT( prevFile() ) );
-    connect( m_editPatch.nextFile, SIGNAL( clicked( bool ) ), this, SLOT( nextFile() ) );
-    connect( m_editPatch.filesList, SIGNAL( activated ( QModelIndex ) ), this, SLOT( fileDoubleClicked( QModelIndex ) ) );
-
-    connect( m_editPatch.cancelReview, SIGNAL( clicked( bool ) ), m_plugin, SLOT( cancelReview() ) );
-    connect( m_editPatch.finishReview, SIGNAL( clicked( bool ) ), this, SLOT( finishReview() ) );
+    connect( m_editPatch.cancelReview, &QPushButton::clicked, m_plugin, &PatchReviewPlugin::cancelReview );
     //connect( m_editPatch.cancelButton, SIGNAL(pressed()), this, SLOT(slotEditCancel()) );
 
     //connect( this, SIGNAL(finished(int)), this, SLOT(slotEditDialogFinished(int)) );
 
-    connect( m_editPatch.applied, SIGNAL( stateChanged( int ) ), SLOT( updatePatchFromEdit() ) );
-    connect( m_editPatch.filename, SIGNAL( textChanged( QString ) ), SLOT( updatePatchFromEdit() ) );
+    connect( m_editPatch.updateButton, &QPushButton::clicked, m_plugin, &PatchReviewPlugin::forceUpdate );
 
-    m_editPatch.baseDir->setMode( KFile::Directory );
+    connect( m_editPatch.testsButton, &QPushButton::clicked, this, &PatchReviewToolView::runTests );
 
-    connect( m_editPatch.command, SIGNAL( textChanged( QString ) ), this, SLOT( updatePatchFromEdit() ) );
-//   connect( m_editPatch.commandToFile, SIGNAL(clicked(bool)), this, SLOT(slotToFile()) );
-
-    connect( m_editPatch.filename->lineEdit(), SIGNAL( returnPressed() ), this, SLOT( updatePatchFromEdit() ) );
-    connect( m_editPatch.filename->lineEdit(), SIGNAL( editingFinished() ), this, SLOT( updatePatchFromEdit() ) );
-    connect( m_editPatch.filename, SIGNAL( urlSelected( KUrl ) ), this, SLOT( updatePatchFromEdit() ) );
-    connect( m_editPatch.command, SIGNAL( textChanged( QString ) ), this, SLOT( updatePatchFromEdit() ) );
-//     connect( m_editPatch.commandToFile, SIGNAL(clicked(bool)), m_plugin, SLOT(commandToFile()) );
-
-    connect( m_editPatch.patchSelection, SIGNAL( currentIndexChanged( int ) ), this, SLOT( patchSelectionChanged( int ) ) );
-
-    connect( m_editPatch.updateButton, SIGNAL( clicked( bool ) ), m_plugin, SLOT( forceUpdate() ) );
-
-    connect( m_editPatch.showButton, SIGNAL( clicked( bool ) ), m_plugin, SLOT( updateReview()) );
-
-    connect( m_editPatch.testsButton, SIGNAL( clicked( bool ) ), this, SLOT( runTests() ) );
-    
-    m_selectAllAction = new QAction(KIcon("edit-select-all"), i18n("Select All"), this );
-    connect( m_selectAllAction, SIGNAL(triggered(bool)), SLOT(selectAll()) );
+    m_selectAllAction = new QAction(QIcon::fromTheme("edit-select-all"), i18n("Select All"), this );
+    connect( m_selectAllAction, &QAction::triggered, this, &PatchReviewToolView::selectAll );
     m_deselectAllAction = new QAction( i18n("Deselect All"), this );
-    connect( m_deselectAllAction, SIGNAL(triggered(bool)), SLOT(deselectAll()) );
+    connect( m_deselectAllAction, &QAction::triggered, this, &PatchReviewToolView::deselectAll );
 }
 
 void PatchReviewToolView::customContextMenuRequested(const QPoint& )
 {
-    KUrl::List urls;
+    QList<QUrl> urls;
     QModelIndexList selectionIdxs = m_editPatch.filesList->selectionModel()->selectedIndexes();
     foreach(const QModelIndex& idx, selectionIdxs) {
-        urls += idx.sibling(idx.row(), 0).data(KDevelop::VcsFileChangesModel::VcsStatusInfoRole).value<VcsStatusInfo>().url();
+        urls += idx.data(KDevelop::VcsFileChangesModel::UrlRole).toUrl();
     }
-    
+
     QPointer<QMenu> menu = new QMenu(m_editPatch.filesList);
     QList<ContextMenuExtension> extensions;
     if(!urls.isEmpty()) {
@@ -313,7 +280,7 @@ void PatchReviewToolView::customContextMenuRequested(const QPoint& )
     if ( !menu->isEmpty() ) {
         menu->exec(QCursor::pos());
     }
-    
+
     delete menu;
 }
 
@@ -335,19 +302,19 @@ void PatchReviewToolView::seekFile(bool forwards)
 {
     if(!m_plugin->patch())
         return;
-    QList<KUrl> checkedUrls = m_fileModel->checkedUrls();
-    QList<KUrl> allUrls = m_fileModel->urls();
+    QList<QUrl> checkedUrls = m_fileModel->checkedUrls();
+    QList<QUrl> allUrls = m_fileModel->urls();
     IDocument* current = ICore::self()->documentController()->activeDocument();
     if(!current || checkedUrls.empty())
         return;
-    kDebug() << "seeking direction" << forwards;
+    qCDebug(PLUGIN_PATCHREVIEW) << "seeking direction" << forwards;
     int currentIndex = allUrls.indexOf(current->url());
-    KUrl newUrl;
+    QUrl newUrl;
     if((forwards && current->url() == checkedUrls.back()) ||
             (!forwards && current->url() == checkedUrls[0]))
     {
         newUrl = m_plugin->patch()->file();
-        kDebug() << "jumping to patch";
+        qCDebug(PLUGIN_PATCHREVIEW) << "jumping to patch";
     }
     else if(current->url() == m_plugin->patch()->file() || currentIndex == -1)
     {
@@ -355,11 +322,11 @@ void PatchReviewToolView::seekFile(bool forwards)
             newUrl = checkedUrls[0];
         else
             newUrl = checkedUrls.back();
-        kDebug() << "jumping from patch";
+        qCDebug(PLUGIN_PATCHREVIEW) << "jumping from patch";
     }
     else
     {
-        QSet<KUrl> checkedUrlsSet( checkedUrls.toSet() );
+        QSet<QUrl> checkedUrlsSet( checkedUrls.toSet() );
         for(int offset = 1; offset < allUrls.size(); ++offset)
         {
             int pos;
@@ -382,13 +349,13 @@ void PatchReviewToolView::seekFile(bool forwards)
     {
         activate( newUrl, forwards ? current : 0 );
     }else{
-        kDebug() << "found no valid target url";
+        qCDebug(PLUGIN_PATCHREVIEW) << "found no valid target url";
     }
 }
 
-void PatchReviewToolView::activate( const KUrl& url, IDocument* buddy ) const
+void PatchReviewToolView::activate( const QUrl& url, IDocument* buddy ) const
 {
-    kDebug() << "activating url" << url;
+    qCDebug(PLUGIN_PATCHREVIEW) << "activating url" << url;
     // If the document is already open in this area, just re-activate it
     if(KDevelop::IDocument* doc = ICore::self()->documentController()->documentForUrl(url)) {
         foreach(Sublime::View* view, ICore::self()->uiController()->activeArea()->views())
@@ -400,33 +367,40 @@ void PatchReviewToolView::activate( const KUrl& url, IDocument* buddy ) const
             }
         }
     }
-    
+
     // If the document is not open yet, open it in the correct order
     IDocument* newDoc = ICore::self()->documentController()->openDocument(url, KTextEditor::Range(), IDocumentController::DefaultMode, "", buddy);
-    if(newDoc && newDoc->textDocument() && newDoc->textDocument()->activeView() && newDoc->textDocument()->activeView()->cursorPosition().line() == 0)
+    KTextEditor::View* view = 0;
+    if(newDoc)
+        view= newDoc->activeTextView();
+
+    if(view && view->cursorPosition().line() == 0)
         m_plugin->seekHunk( true, url );
 }
 
 void PatchReviewToolView::fileItemChanged( QStandardItem* item )
 {
-    KUrl url = m_fileModel->statusInfo(item).url();
-    if(!m_fileModel->checkedUrls().contains(url))
+    QUrl url = m_fileModel->statusInfo(item->index()).url();
+    if (url.isEmpty())
+        return;
+
+    KDevelop::IDocument* doc = ICore::self()->documentController()->documentForUrl(url);
+    if(m_fileModel->isCheckable() && item->checkState() != Qt::Checked)
     {
         // Eventually close the document
-        if(KDevelop::IDocument* doc = ICore::self()->documentController()->documentForUrl(url)) {
-            if(doc->state() == IDocument::Clean)
+        if(doc && doc->state() == IDocument::Clean)
+        {
+            foreach(Sublime::View* view, ICore::self()->uiController()->activeArea()->views())
             {
-                foreach(Sublime::View* view, ICore::self()->uiController()->activeArea()->views())
+                if(view->document() == dynamic_cast<Sublime::Document*>(doc))
                 {
-                    if(view->document() == dynamic_cast<Sublime::Document*>(doc))
-                    {
-                        kDebug() << "closing view of" << url << "because the item was unchecked";
-                        ICore::self()->uiController()->activeArea()->closeView(view);
-                        return;
-                    }
+                    ICore::self()->uiController()->activeArea()->closeView(view);
+                    return;
                 }
             }
         }
+    } else if (!doc) {
+        ICore::self()->documentController()->openDocument(url, KTextEditor::Range::invalid(), IDocumentController::DoNotActivate);
     }
 }
 
@@ -451,37 +425,28 @@ void PatchReviewToolView::selectAll()
 }
 
 void PatchReviewToolView::finishReview() {
-    QList<KUrl> selectedUrls = m_fileModel->checkedUrls();
-    kDebug() << "finishing review with" << selectedUrls;
+    QList<QUrl> selectedUrls = m_fileModel->checkedUrls();
+    qCDebug(PLUGIN_PATCHREVIEW) << "finishing review with" << selectedUrls;
     m_plugin->finishReview( selectedUrls );
 }
 
 void PatchReviewToolView::fileDoubleClicked( const QModelIndex& idx ) {
     QModelIndex i = idx.sibling(idx.row(), 0);
-    KUrl file = m_fileModel->statusInfo( i ).url();
+    QUrl file = m_fileModel->statusInfo( i ).url();
 
     activate( file );
 }
 
-KUrl PatchReviewPlugin::urlForFileModel( const Diff2::DiffModel* model ) {
-    KUrl file = m_patch->baseDir();
-
-    file.addPath( model->destinationPath() );
-    file.addPath( model->destinationFile() );
-
-    return file;
-}
-
 void PatchReviewToolView::kompareModelChanged() {
-    
-    QList<KUrl> oldCheckedUrls = m_fileModel->checkedUrls();
-    
+
+    QList<QUrl> oldCheckedUrls = m_fileModel->checkedUrls();
+
     m_fileModel->clear();
-    
+
     if ( !m_plugin->modelList() )
         return;
 
-    QMap<KUrl, KDevelop::VcsStatusInfo::State> additionalUrls = m_plugin->patch()->additionalSelectableFiles();
+    QMap<QUrl, KDevelop::VcsStatusInfo::State> additionalUrls = m_plugin->patch()->additionalSelectableFiles();
 
     const Diff2::DiffModelList* models = m_plugin->modelList()->models();
     if( models )
@@ -493,7 +458,7 @@ void PatchReviewToolView::kompareModelChanged() {
             if ( diffs )
                 cnt = diffs->count();
 
-            KUrl file = m_plugin->urlForFileModel( *it );
+            QUrl file = m_plugin->urlForFileModel( *it );
             if( !QFileInfo( file.toLocalFile() ).isReadable() )
                 continue;
 
@@ -505,20 +470,20 @@ void PatchReviewToolView::kompareModelChanged() {
         }
     }
 
-    for( QMap<KUrl, KDevelop::VcsStatusInfo::State>::const_iterator it = additionalUrls.constBegin(); it != additionalUrls.constEnd(); it++ ) {
+    for( QMap<QUrl, KDevelop::VcsStatusInfo::State>::const_iterator it = additionalUrls.constBegin(); it != additionalUrls.constEnd(); it++ ) {
         VcsStatusInfo status;
         status.setUrl( it.key() );
         status.setState( it.value() );
         m_fileModel->updateState( status );
     }
-    
+
     if(!m_resetCheckedUrls)
         m_fileModel->setCheckedUrls(oldCheckedUrls);
     else
         m_resetCheckedUrls = false;
 
     m_editPatch.filesList->resizeColumnToContents( 0 );
-    
+
     // Eventually select the active document
     documentActivated( ICore::self()->documentController()->activeDocument() );
 }
@@ -530,9 +495,9 @@ void PatchReviewToolView::documentActivated( IDocument* doc ) {
     if ( !m_plugin->modelList() )
         return;
 
-    QStandardItem *fileItem = m_fileModel->fileItemForUrl( doc->url() );
-    if ( fileItem ) {
-        m_editPatch.filesList->setCurrentIndex( fileItem->index() );
+    QModelIndex idx = m_fileModel->indexForUrl( doc->url() );
+    if ( idx.isValid() ) {
+        m_editPatch.filesList->setCurrentIndex( idx );
     } else {
         m_editPatch.filesList->setCurrentIndex( QModelIndex() );
     }
@@ -546,8 +511,8 @@ void PatchReviewToolView::runTests()
     }
 
     IProject* project = 0;
-    QMap<KUrl, VcsStatusInfo::State> files = ipatch->additionalSelectableFiles();
-    QMap<KUrl, VcsStatusInfo::State>::const_iterator it = files.constBegin();
+    QMap<QUrl, VcsStatusInfo::State> files = ipatch->additionalSelectableFiles();
+    QMap<QUrl, VcsStatusInfo::State>::const_iterator it = files.constBegin();
 
     for (; it != files.constEnd(); ++it) {
         project = ICore::self()->projectController()->findProjectForUrl(it.key());
@@ -565,8 +530,8 @@ void PatchReviewToolView::runTests()
     m_editPatch.testProgressBar->show();
 
     ProjectTestJob* job = new ProjectTestJob(project, this);
-    connect (job, SIGNAL(finished(KJob*)), SLOT(testJobResult(KJob*)));
-    connect (job, SIGNAL(percent(KJob*,ulong)), SLOT(testJobPercent(KJob*,ulong)));
+    connect(job, &ProjectTestJob::finished, this, &PatchReviewToolView::testJobResult);
+    connect(job, SIGNAL(percent(KJob*,ulong)), this, SLOT(testJobPercent(KJob*,ulong)));
     ICore::self()->runController()->registerJob(job);
 }
 
