@@ -28,9 +28,8 @@
 #include <ktexteditor/view.h>
 #include <ktexteditor/movinginterface.h>
 
-#include <language/duchain/indexedstring.h>
+#include <serialization/indexedstring.h>
 #include <language/duchain/navigation/abstractnavigationwidget.h>
-#include <language/duchain/navigation/problemnavigationcontext.h>
 #include <language/util/navigationtooltip.h>
 #include <interfaces/icore.h>
 #include <interfaces/ilanguagecontroller.h>
@@ -41,25 +40,28 @@
 
 #include <kcolorscheme.h>
 
+#include <shell/problem.h>
+#include "problemnavigationcontext.h"
+
 using namespace KTextEditor;
 using namespace KDevelop;
 
-namespace {
+namespace
+{
 
-QColor colorForSeverity(ProblemData::Severity severity)
+QColor colorForSeverity(IProblem::Severity severity)
 {
     KColorScheme scheme(QPalette::Active);
     switch (severity) {
-    case ProblemData::Error:
+    case IProblem::Error:
         return scheme.foreground(KColorScheme::NegativeText).color();
-    case ProblemData::Warning:
+    case IProblem::Warning:
         return scheme.foreground(KColorScheme::NeutralText).color();
-    case ProblemData::Hint:
+    case IProblem::Hint:
     default:
         return scheme.foreground(KColorScheme::PositiveText).color();
     }
 }
-
 }
 
 ProblemHighlighter::ProblemHighlighter(KTextEditor::Document* document)
@@ -67,75 +69,82 @@ ProblemHighlighter::ProblemHighlighter(KTextEditor::Document* document)
 {
     Q_ASSERT(m_document);
 
-    foreach(KTextEditor::View* view, m_document->views())
+    foreach (KTextEditor::View* view, m_document->views())
         viewCreated(document, view);
 
-    connect(m_document, SIGNAL(viewCreated(KTextEditor::Document*,KTextEditor::View*)), this, SLOT(viewCreated(KTextEditor::Document*,KTextEditor::View*)));
-    connect(ICore::self()->languageController()->completionSettings(), SIGNAL(settingsChanged(ICompletionSettings*)), this, SLOT(settingsChanged()));
-    connect(m_document, SIGNAL(aboutToInvalidateMovingInterfaceContent(KTextEditor::Document*)),
-            this, SLOT(aboutToInvalidateMovingInterfaceContent()));
-    connect(m_document, SIGNAL(aboutToRemoveText(KTextEditor::Range)),
-            this, SLOT(aboutToRemoveText(KTextEditor::Range)));
-    connect(m_document, SIGNAL(reloaded(KTextEditor::Document*)),
-            this, SLOT(documentReloaded()));
+    connect(m_document.data(), &Document::viewCreated, this, &ProblemHighlighter::viewCreated);
+    connect(ICore::self()->languageController()->completionSettings(), &ICompletionSettings::settingsChanged, this,
+            &ProblemHighlighter::settingsChanged);
+    connect(m_document.data(), &Document::reloaded, this, &ProblemHighlighter::documentReloaded);
+    if (qobject_cast<MovingInterface*>(m_document)) {
+        // can't use new signal/slot syntax here, MovingInterface is not a QObject
+        connect(m_document, SIGNAL(aboutToInvalidateMovingInterfaceContent(KTextEditor::Document*)), this,
+                SLOT(aboutToInvalidateMovingInterfaceContent()));
+    }
+    // TODO: this depends on m_document being a KateDocument, should we rely on internals here?
+    connect(m_document, SIGNAL(aboutToRemoveText(KTextEditor::Range)), this,
+            SLOT(aboutToRemoveText(KTextEditor::Range)));
 }
 
 void ProblemHighlighter::settingsChanged()
 {
-    //Re-highlight
+    // Re-highlight
     setProblems(m_problems);
 }
 
-void ProblemHighlighter::viewCreated(Document* , View* view)
+void ProblemHighlighter::viewCreated(Document*, View* view)
 {
     KTextEditor::TextHintInterface* iface = dynamic_cast<KTextEditor::TextHintInterface*>(view);
-    if( !iface )
+    if (!iface)
         return;
 
-    connect(view, SIGNAL(needTextHint(KTextEditor::Cursor,QString&)), this, SLOT(textHintRequested(KTextEditor::Cursor,QString&)));
+    iface->registerTextHintProvider(new ProblemTextHintProvider(this));
 }
 
-void ProblemHighlighter::textHintRequested(const KTextEditor::Cursor& pos, QString& )
+ProblemTextHintProvider::ProblemTextHintProvider(ProblemHighlighter* highlighter)
+    : m_highlighter(highlighter)
 {
-    KTextEditor::View* view = qobject_cast<KTextEditor::View*>(sender());
-    Q_ASSERT(view);
+}
 
-    KTextEditor::MovingInterface* moving = dynamic_cast<KTextEditor::MovingInterface*>(m_document.data());
-    if(moving) {
+QString ProblemTextHintProvider::textHint(View* view, const Cursor& pos)
+{
+    KTextEditor::MovingInterface* moving = dynamic_cast<KTextEditor::MovingInterface*>(view->document());
+    if (moving) {
         ///@todo Sort the ranges when writing them, and do binary search instead of linear
-        foreach(MovingRange* range, m_topHLRanges) {
-            if(m_problemsForRanges.contains(range) && range->contains(pos))
-            {
-                //There is a problem which's range contains the cursor
-                ProblemPointer problem = m_problemsForRanges[range];
-                if (problem->source() == ProblemData::ToDo) {
+        foreach (MovingRange* range, m_highlighter->m_topHLRanges) {
+            if (m_highlighter->m_problemsForRanges.contains(range) && range->contains(pos)) {
+                // There is a problem which's range contains the cursor
+                IProblem::Ptr problem = m_highlighter->m_problemsForRanges[range];
+                if (problem->source() == IProblem::ToDo) {
                     continue;
                 }
 
                 KDevelop::AbstractNavigationWidget* widget = new KDevelop::AbstractNavigationWidget;
                 widget->setContext(NavigationContextPointer(new ProblemNavigationContext(problem)));
 
-                KDevelop::NavigationToolTip* tooltip = new KDevelop::NavigationToolTip(view, QCursor::pos() + QPoint(20, 40), widget);
+                KDevelop::NavigationToolTip* tooltip
+                    = new KDevelop::NavigationToolTip(view, QCursor::pos() + QPoint(20, 40), widget);
 
-                tooltip->resize( widget->sizeHint() + QSize(10, 10) );
+                tooltip->resize(widget->sizeHint() + QSize(10, 10));
                 ActiveToolTip::showToolTip(tooltip, 99, "problem-tooltip");
-                return;
+                return QString();
             }
         }
     }
+    return QString();
 }
 
 ProblemHighlighter::~ProblemHighlighter()
 {
-    if(m_topHLRanges.isEmpty() || !m_document)
+    if (m_topHLRanges.isEmpty() || !m_document)
         return;
 
     qDeleteAll(m_topHLRanges);
 }
 
-void ProblemHighlighter::setProblems(const QList<KDevelop::ProblemPointer>& problems)
+void ProblemHighlighter::setProblems(const QVector<IProblem::Ptr>& problems)
 {
-    if(!m_document)
+    if (!m_document)
         return;
 
     KTextEditor::MovingInterface* iface = dynamic_cast<KTextEditor::MovingInterface*>(m_document.data());
@@ -148,9 +157,9 @@ void ProblemHighlighter::setProblems(const QList<KDevelop::ProblemPointer>& prob
     m_topHLRanges.clear();
     m_problemsForRanges.clear();
 
-    IndexedString url( m_document->url() );
+    IndexedString url(m_document->url());
 
-    ///TODO: create a better MarkInterface that makes it possible to add the marks to the scrollbar
+    /// TODO: create a better MarkInterface that makes it possible to add the marks to the scrollbar
     ///      but having no background.
     ///      also make it nicer together with other plugins, this would currently fail with
     ///      this method...
@@ -159,7 +168,7 @@ void ProblemHighlighter::setProblems(const QList<KDevelop::ProblemPointer>& prob
     KTextEditor::MarkInterface* markIface = dynamic_cast<KTextEditor::MarkInterface*>(m_document.data());
     if (markIface && hadProblems) {
         // clear previously added marks
-        foreach(KTextEditor::Mark* mark, markIface->marks().values()) {
+        foreach (KTextEditor::Mark* mark, markIface->marks().values()) {
             if (mark->type == errorMarkType || mark->type == warningMarkType) {
                 markIface->removeMark(mark->line, mark->type);
             }
@@ -170,30 +179,31 @@ void ProblemHighlighter::setProblems(const QList<KDevelop::ProblemPointer>& prob
 
     TopDUContext* top = DUChainUtils::standardContextForUrl(m_document->url());
 
-    foreach (const KDevelop::ProblemPointer& problem, problems) {
+    foreach (const IProblem::Ptr problem, problems) {
         if (problem->finalLocation().document != url || !problem->finalLocation().isValid())
             continue;
 
-        SimpleRange range;
-        if(top)
+        KTextEditor::Range range;
+        if (top)
             range = top->transformFromLocalRevision(RangeInRevision::castFromSimpleRange(problem->finalLocation()));
         else
             range = problem->finalLocation();
 
-        if(range.end.line >= m_document->lines())
-            range.end = SimpleCursor(m_document->endOfLine(m_document->lines()-1));
+        if (range.end().line() >= m_document->lines())
+            range.end() = KTextEditor::Cursor(m_document->endOfLine(m_document->lines() - 1));
 
-        if(range.isEmpty())
-            range.end.column += 1;
+        if (range.isEmpty()) {
+            range.setEnd(range.end() + KTextEditor::Cursor(0, 1));
+        }
 
-        KTextEditor::MovingRange* problemRange = iface->newMovingRange(range.textRange());
+        KTextEditor::MovingRange* problemRange = iface->newMovingRange(range);
 
         m_problemsForRanges.insert(problemRange, problem);
         m_topHLRanges.append(problemRange);
 
-        if(problem->source() != ProblemData::ToDo && (problem->severity() != ProblemData::Hint
-            || ICore::self()->languageController()->completionSettings()->highlightSemanticProblems()))
-        {
+        if (problem->source() != IProblem::ToDo
+            && (problem->severity() != IProblem::Hint
+                || ICore::self()->languageController()->completionSettings()->highlightSemanticProblems())) {
             KTextEditor::Attribute::Ptr attribute(new KTextEditor::Attribute());
             attribute->setUnderlineStyle(QTextCharFormat::WaveUnderline);
             attribute->setUnderlineColor(colorForSeverity(problem->severity()));
@@ -202,14 +212,14 @@ void ProblemHighlighter::setProblems(const QList<KDevelop::ProblemPointer>& prob
 
         if (markIface && ICore::self()->languageController()->completionSettings()->highlightProblematicLines()) {
             uint mark;
-            if (problem->severity() == ProblemData::Error) {
+            if (problem->severity() == IProblem::Error) {
                 mark = errorMarkType;
-            } else if (problem->severity() == ProblemData::Warning) {
+            } else if (problem->severity() == IProblem::Warning) {
                 mark = warningMarkType;
             } else {
                 continue;
             }
-            markIface->addMark(problem->finalLocation().start.line, mark);
+            markIface->addMark(problem->finalLocation().start().line(), mark);
         }
     }
 }
@@ -221,14 +231,14 @@ void ProblemHighlighter::aboutToInvalidateMovingInterfaceContent()
     m_problemsForRanges.clear();
 }
 
-void ProblemHighlighter::aboutToRemoveText( const KTextEditor::Range& range )
+void ProblemHighlighter::aboutToRemoveText(const KTextEditor::Range& range)
 {
     if (range.onSingleLine()) { // no need to optimize this
         return;
     }
 
-    QList< MovingRange* >::iterator it = m_topHLRanges.begin();
-    while(it != m_topHLRanges.end()) {
+    QList<MovingRange*>::iterator it = m_topHLRanges.begin();
+    while (it != m_topHLRanges.end()) {
         if (range.contains((*it)->toRange())) {
             m_problemsForRanges.remove(*it);
             delete (*it);
@@ -243,5 +253,3 @@ void ProblemHighlighter::documentReloaded()
 {
     setProblems(m_problems);
 }
-
-#include "problemhighlighter.moc"
