@@ -23,23 +23,23 @@
 #ifndef KDEVPLATFORM_PLUGIN_PROBLEM_HIGHLIGHT_H
 #define KDEVPLATFORM_PLUGIN_PROBLEM_HIGHLIGHT_H
 
-
 #include <language/duchain/problem.h>
 #include <qpointer.h>
 #include <ktexteditor/movingrange.h>
+#include <KTextEditor/TextHintInterface>
+#include <interfaces/iproblem.h>
 
 class ProblemHighlighter : public QObject
 {
     Q_OBJECT
 public:
-    ProblemHighlighter(KTextEditor::Document* document);
+    explicit ProblemHighlighter(KTextEditor::Document* document);
     virtual ~ProblemHighlighter();
 
-    void setProblems(const QList<KDevelop::ProblemPointer>& problems);
+    void setProblems(const QVector<KDevelop::IProblem::Ptr>& problems);
 
 private slots:
-    void viewCreated(KTextEditor::Document*,KTextEditor::View*);
-    void textHintRequested(const KTextEditor::Cursor&, QString&);
+    void viewCreated(KTextEditor::Document*, KTextEditor::View*);
     void aboutToInvalidateMovingInterfaceContent();
     void aboutToRemoveText(const KTextEditor::Range& range);
     void documentReloaded();
@@ -47,11 +47,24 @@ private slots:
 private:
     QPointer<KTextEditor::Document> m_document;
     QList<KTextEditor::MovingRange*> m_topHLRanges;
-    QList<KDevelop::ProblemPointer> m_problems;
-    QMap<KTextEditor::MovingRange*, KDevelop::ProblemPointer> m_problemsForRanges;
+    QVector<KDevelop::IProblem::Ptr> m_problems;
+    QMap<KTextEditor::MovingRange*, KDevelop::IProblem::Ptr> m_problemsForRanges;
+
+    friend class ProblemTextHintProvider;
 
 public slots:
     void settingsChanged();
 };
 
+class ProblemTextHintProvider : public KTextEditor::TextHintProvider
+{
+public:
+    explicit ProblemTextHintProvider(ProblemHighlighter* highlighter);
+
+    virtual QString textHint(KTextEditor::View* view, const KTextEditor::Cursor& position) override;
+
+private:
+    ProblemHighlighter* m_highlighter;
+};
+
 #endif // KDEVPLATFORM_PLUGIN_PROBLEM_HIGHLIGHT_H
