@@ -27,39 +27,49 @@
 #include <interfaces/iplugin.h>
 #include <QtCore/QVariant>
 
-#include <language/duchain/indexedstring.h>
+#include <serialization/indexedstring.h>
 #include <language/duchain/topducontext.h>
 
-namespace KTextEditor { class Document; }
-namespace KDevelop { class IDocument; class ParseJob; }
+#include <QLoggingCategory>
+Q_DECLARE_LOGGING_CATEGORY(PLUGIN_PROBLEMREPORTER)
+
+namespace KTextEditor
+{
+class Document;
+}
+namespace KDevelop
+{
+class IDocument;
+class ParseJob;
+}
 
 class ProblemHighlighter;
-class ProblemModel;
+class ProblemReporterModel;
 
 class ProblemReporterPlugin : public KDevelop::IPlugin
 {
     Q_OBJECT
 
-  public:
-    ProblemReporterPlugin(QObject *parent, const QVariantList & = QVariantList() );
+public:
+    explicit ProblemReporterPlugin(QObject* parent, const QVariantList& = QVariantList());
     virtual ~ProblemReporterPlugin();
 
-    virtual KDevelop::ContextMenuExtension contextMenuExtension(KDevelop::Context* context);
-    
+    virtual KDevelop::ContextMenuExtension contextMenuExtension(KDevelop::Context* context) override;
+
     // KDevelop::Plugin methods
-    virtual void unload();
+    virtual void unload() override;
 
-    ProblemModel* getModel() const;
+    ProblemReporterModel* model() const;
 
-  private Q_SLOTS:
-    void updateReady(const KDevelop::IndexedString &url,
+private Q_SLOTS:
+    void updateReady(const KDevelop::IndexedString& url,
                      const KDevelop::ReferencedTopDUContext& = KDevelop::ReferencedTopDUContext());
     void textDocumentCreated(KDevelop::IDocument* document);
     void parseJobFinished(KDevelop::ParseJob* parseJob);
 
-  private:
+private:
     class ProblemReporterFactory* m_factory;
-    class ProblemModel* m_model;
+    ProblemReporterModel* m_model;
 
     QHash<KDevelop::IndexedString, ProblemHighlighter*> m_highlighters;
 public slots:
