@@ -21,15 +21,12 @@
 
 #include "projectmanagerview.h"
 
-#include <QtGui/QHeaderView>
-#include <QtGui/QKeyEvent>
+#include <QHeaderView>
+#include <QKeyEvent>
+#include <QUrl>
 
-#include <kiconloader.h>
-#include <kdebug.h>
-#include <kurl.h>
-#include <klocale.h>
-#include <kactioncollection.h>
-#include <KLineEdit>
+#include <KActionCollection>
+#include <KLocalizedString>
 
 #include <interfaces/iselectioncontroller.h>
 #include <interfaces/context.h>
@@ -41,20 +38,24 @@
 #include <interfaces/iproject.h>
 #include <project/projectproxymodel.h>
 #include <project/projectmodel.h>
+#include <serialization/indexedstring.h>
+#include <util/path.h>
 
 #include "../openwith/iopenwith.h"
 
 #include <sublime/mainwindow.h>
+#include <sublime/area.h>
 
-#include "tests/modeltest.h"
 #include "projectmanagerviewplugin.h"
 #include "vcsoverlayproxymodel.h"
 #include "ui_projectmanagerview.h"
+#include "debug.h"
+
 
 using namespace KDevelop;
 
 ProjectManagerViewItemContext::ProjectManagerViewItemContext(const QList< ProjectBaseItem* >& items, ProjectManagerView* view)
-    : ProjectItemContext(items), m_view(view)
+    : ProjectItemContextImpl(items), m_view(view)
 {
 }
 
@@ -64,8 +65,9 @@ ProjectManagerView *ProjectManagerViewItemContext::view() const
 }
 
 
-static const char* sessionConfigGroup = "ProjectManagerView";
-static const char* splitterStateConfigKey = "splitterState";
+static const char sessionConfigGroup[] = "ProjectManagerView";
+static const char splitterStateConfigKey[] = "splitterState";
+static const char targetsVisibleConfigKey[] = "targetsVisible";
 static const int projectTreeViewStrechFactor = 75; // %
 static const int projectBuildSetStrechFactor = 25; // %
 
@@ -76,7 +78,7 @@ ProjectManagerView::ProjectManagerView( ProjectManagerViewPlugin* plugin, QWidge
 
     m_ui->projectTreeView->installEventFilter(this);
 
-    setWindowIcon( SmallIcon( "project-development" ) );
+    setWindowIcon( QIcon::fromTheme( "project-development" ) );
 
     KConfigGroup pmviewConfig(ICore::self()->activeSession()->config(), sessionConfigGroup);
     if (pmviewConfig.hasKey(splitterStateConfigKey)) {
@@ -92,35 +94,43 @@ ProjectManagerView::ProjectManagerView( ProjectManagerViewPlugin* plugin, QWidge
     m_syncAction->setShortcutContext(Qt::WidgetWithChildrenShortcut);
     m_syncAction->setText(i18n("Locate Current Document"));
     m_syncAction->setToolTip(i18n("Locates the current document in the project tree and selects it."));
-    m_syncAction->setIcon(KIcon("dirsync"));
+    m_syncAction->setIcon(QIcon::fromTheme("dirsync"));
     m_syncAction->setShortcut(Qt::ControlModifier + Qt::Key_Less);
-    connect(m_syncAction, SIGNAL(triggered(bool)), this, SLOT(locateCurrentDocument()));
+    connect(m_syncAction, &QAction::triggered, this, &ProjectManagerView::locateCurrentDocument);
     addAction(m_syncAction);
     updateSyncAction();
 
+    m_toggleTargetsAction = new QAction(i18n("Show Targets"), this);
+    m_toggleTargetsAction->setCheckable(true);
+    m_toggleTargetsAction->setChecked(pmviewConfig.readEntry<bool>(targetsVisibleConfigKey, true));
+    m_toggleTargetsAction->setIcon(QIcon::fromTheme("system-run"));
+    connect(m_toggleTargetsAction, &QAction::triggered, this, &ProjectManagerView::toggleHideTargets);
+    addAction(m_toggleTargetsAction);
+
     addAction(plugin->actionCollection()->action("project_build"));
     addAction(plugin->actionCollection()->action("project_install"));
     addAction(plugin->actionCollection()->action("project_clean"));
 
-    connect(m_ui->projectTreeView, SIGNAL(activateUrl(KUrl)), this, SLOT(openUrl(KUrl)));
+    connect(m_ui->projectTreeView, &ProjectTreeView::activate, this, &ProjectManagerView::open);
 
     m_ui->buildSetView->setProjectView( this );
 
     m_modelFilter = new ProjectProxyModel( this );
+    m_modelFilter->showTargets(m_toggleTargetsAction->isChecked());
     m_modelFilter->setSourceModel(ICore::self()->projectController()->projectModel());
     m_overlayProxy = new VcsOverlayProxyModel( this );
     m_overlayProxy->setSourceModel(m_modelFilter);
 
     m_ui->projectTreeView->setModel( m_overlayProxy );
 
-    connect( m_ui->projectTreeView->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
-             this, SLOT(selectionChanged()) );
-    connect( KDevelop::ICore::self()->documentController(), SIGNAL(documentClosed(KDevelop::IDocument*)),
-             SLOT(updateSyncAction()));
-    connect( KDevelop::ICore::self()->documentController(), SIGNAL(documentActivated(KDevelop::IDocument*)),
-             SLOT(updateSyncAction()));
-    connect( qobject_cast<Sublime::MainWindow*>(KDevelop::ICore::self()->uiController()->activeMainWindow()), SIGNAL(areaChanged(Sublime::Area*)),
-             SLOT(updateSyncAction()));
+    connect( m_ui->projectTreeView->selectionModel(), &QItemSelectionModel::selectionChanged,
+             this, &ProjectManagerView::selectionChanged );
+    connect( KDevelop::ICore::self()->documentController(), &IDocumentController::documentClosed,
+             this, &ProjectManagerView::updateSyncAction);
+    connect( KDevelop::ICore::self()->documentController(), &IDocumentController::documentActivated,
+             this, &ProjectManagerView::updateSyncAction);
+    connect( qobject_cast<Sublime::MainWindow*>(KDevelop::ICore::self()->uiController()->activeMainWindow()), &Sublime::MainWindow::areaChanged,
+             this, &ProjectManagerView::updateSyncAction);
     selectionChanged();
 
     //Update the "sync" button after the initialization has completed, to see whether there already is some open documents
@@ -128,7 +138,7 @@ ProjectManagerView::ProjectManagerView( ProjectManagerViewPlugin* plugin, QWidge
 
     // Need to set this to get horizontal scrollbar. Also needs to be done after
     // the setModel call
-    m_ui->projectTreeView->header()->setResizeMode( QHeaderView::ResizeToContents );
+    m_ui->projectTreeView->header()->setSectionResizeMode( QHeaderView::ResizeToContents );
 }
 
 bool ProjectManagerView::eventFilter(QObject* obj, QEvent* event)
@@ -136,10 +146,10 @@ bool ProjectManagerView::eventFilter(QObject* obj, QEvent* event)
     if (obj == m_ui->projectTreeView) {
         if (event->type() == QEvent::KeyRelease) {
             QKeyEvent* keyEvent = static_cast<QKeyEvent*>(event);
-            if (keyEvent->key() == Qt::Key_Delete) {
+            if (keyEvent->key() == Qt::Key_Delete && keyEvent->modifiers() == Qt::NoModifier) {
                 m_plugin->removeItems(selectedItems());
                 return true;
-            } else if (keyEvent->key() == Qt::Key_F2) {
+            } else if (keyEvent->key() == Qt::Key_F2 && keyEvent->modifiers() == Qt::NoModifier) {
                 m_plugin->renameItems(selectedItems());
                 return true;
             } else if (keyEvent->key() == Qt::Key_C && keyEvent->modifiers() == Qt::ControlModifier) {
@@ -189,7 +199,7 @@ QList<KDevelop::ProjectBaseItem*> ProjectManagerView::selectedItems() const
         if( item )
             items << item;
         else
-            kDebug(9511) << "adding an unknown item";
+            qCDebug(PLUGIN_PROJECTMANAGERVIEW) << "adding an unknown item";
     }
     return items;
 }
@@ -210,6 +220,13 @@ void ProjectManagerView::expandItem(ProjectBaseItem* item)
     m_ui->projectTreeView->expand( indexToView(item->index()));
 }
 
+void ProjectManagerView::toggleHideTargets(bool visible)
+{
+    KConfigGroup pmviewConfig(ICore::self()->activeSession()->config(), sessionConfigGroup);
+    pmviewConfig.writeEntry<bool>(targetsVisibleConfigKey, visible);
+    m_modelFilter->showTargets(visible);
+}
+
 void ProjectManagerView::locateCurrentDocument()
 {
     ICore::self()->uiController()->raiseToolView(this);
@@ -226,7 +243,7 @@ void ProjectManagerView::locateCurrentDocument()
 
     QModelIndex bestMatch;
     foreach (IProject* proj, ICore::self()->projectController()->projects()) {
-        foreach (KDevelop::ProjectFileItem* item, proj->filesForUrl(doc->url())) {
+        foreach (KDevelop::ProjectFileItem* item, proj->filesForPath(IndexedString(doc->url()))) {
             QModelIndex index = indexToView(item->index());
             if (index.isValid()) {
                 if (!bestMatch.isValid()) {
@@ -249,9 +266,9 @@ void ProjectManagerView::locateCurrentDocument()
     }
 }
 
-void ProjectManagerView::openUrl( const KUrl& url )
+void ProjectManagerView::open( const Path& path )
 {
-    IOpenWith::openFiles(KUrl::List() << url);
+    IOpenWith::openFiles(QList<QUrl>() << path.toUrl());
 }
 
 QModelIndex ProjectManagerView::indexFromView(const QModelIndex& index) const
@@ -264,4 +281,3 @@ QModelIndex ProjectManagerView::indexToView(const QModelIndex& index) const
     return m_overlayProxy->mapFromSource( m_modelFilter->mapFromSource(index) );
 }
 
-#include "projectmanagerview.moc"
