@@ -19,19 +19,19 @@
 */
 #include "projectmanagerviewplugin.h"
 
-#include <QtCore/QList>
-#include <QMimeData>
-#include <QtGui/QInputDialog>
-#include <QtGui/QApplication>
+#include <QApplication>
+#include <QAction>
 #include <QClipboard>
+#include <QInputDialog>
+#include <QList>
+#include <QMimeData>
+#include <QUrl>
 
-#include <kaction.h>
-#include <kactioncollection.h>
-#include <kaboutdata.h>
-#include <klocale.h>
-#include <kmessagebox.h>
-#include <kparts/mainwindow.h>
-#include <kparts/componentfactory.h>
+#include <KActionCollection>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KParts/MainWindow>
+#include <KPluginFactory>
 
 #include <project/projectmodel.h>
 #include <project/projectbuildsetmodel.h>
@@ -43,6 +43,7 @@
 #include <interfaces/iruncontroller.h>
 #include <interfaces/idocumentcontroller.h>
 #include <project/interfaces/iprojectbuilder.h>
+#include <util/jobstatus.h>
 #include <util/path.h>
 #include <interfaces/iprojectcontroller.h>
 #include <interfaces/context.h>
@@ -50,26 +51,27 @@
 #include <interfaces/iselectioncontroller.h>
 
 #include "projectmanagerview.h"
+#include "debug.h"
 
 using namespace KDevelop;
 
-K_PLUGIN_FACTORY(ProjectManagerFactory, registerPlugin<ProjectManagerViewPlugin>(); )
-K_EXPORT_PLUGIN(ProjectManagerFactory(KAboutData("kdevprojectmanagerview","kdevprojectmanagerview", ki18n("Project Management View"), "0.1", ki18n("Toolview to do all the project management stuff"), KAboutData::License_GPL)))
+Q_LOGGING_CATEGORY(PLUGIN_PROJECTMANAGERVIEW, "kdevplatform.plugins.projectmanagerview")
+K_PLUGIN_FACTORY_WITH_JSON(ProjectManagerFactory, "kdevprojectmanagerview.json", registerPlugin<ProjectManagerViewPlugin>();)
 
 class KDevProjectManagerViewFactory: public KDevelop::IToolViewFactory
 {
     public:
         KDevProjectManagerViewFactory( ProjectManagerViewPlugin *plugin ): mplugin( plugin )
         {}
-        virtual QWidget* create( QWidget *parent = 0 )
+        virtual QWidget* create( QWidget *parent = 0 ) override
         {
             return new ProjectManagerView( mplugin, parent );
         }
-        virtual Qt::DockWidgetArea defaultPosition()
+        virtual Qt::DockWidgetArea defaultPosition() override
         {
             return Qt::LeftDockWidgetArea;
         }
-        virtual QString id() const
+        virtual QString id() const override
         {
             return "org.kdevelop.ProjectsView";
         }
@@ -84,12 +86,12 @@ public:
     {}
     KDevProjectManagerViewFactory *factory;
     QList<QPersistentModelIndex> ctxProjectItemList;
-    KAction* m_buildAll;
-    KAction* m_build;
-    KAction* m_install;
-    KAction* m_clean;
-    KAction* m_configure;
-    KAction* m_prune;
+    QAction* m_buildAll;
+    QAction* m_build;
+    QAction* m_install;
+    QAction* m_clean;
+    QAction* m_configure;
+    QAction* m_prune;
 };
 
 static QList<ProjectBaseItem*> itemsFromIndexes(const QList<QPersistentModelIndex>& indexes)
@@ -103,44 +105,44 @@ static QList<ProjectBaseItem*> itemsFromIndexes(const QList<QPersistentModelInde
 }
 
 ProjectManagerViewPlugin::ProjectManagerViewPlugin( QObject *parent, const QVariantList& )
-        : IPlugin( ProjectManagerFactory::componentData(), parent ), d(new ProjectManagerViewPluginPrivate)
+        : IPlugin( "kdevprojectmanagerview", parent ), d(new ProjectManagerViewPluginPrivate)
 {
-    d->m_buildAll = new KAction( i18n("Build all Projects"), this );
-    d->m_buildAll->setIcon(KIcon("run-build"));
-    connect( d->m_buildAll, SIGNAL(triggered()), this, SLOT(buildAllProjects()) );
+    d->m_buildAll = new QAction( i18n("Build all Projects"), this );
+    d->m_buildAll->setIcon(QIcon::fromTheme("run-build"));
+    connect( d->m_buildAll, &QAction::triggered, this, &ProjectManagerViewPlugin::buildAllProjects );
     actionCollection()->addAction( "project_buildall", d->m_buildAll );
 
-    d->m_build = new KAction( i18n("Build Selection"), this );
+    d->m_build = new QAction( i18n("Build Selection"), this );
     d->m_build->setIconText( i18n("Build") );
-    d->m_build->setShortcut( Qt::Key_F8 );
-    d->m_build->setIcon(KIcon("run-build"));
+    actionCollection()->setDefaultShortcut( d->m_build, Qt::Key_F8 );
+    d->m_build->setIcon(QIcon::fromTheme("run-build"));
     d->m_build->setEnabled( false );
-    connect( d->m_build, SIGNAL(triggered()), this, SLOT(buildProjectItems()) );
+    connect( d->m_build, &QAction::triggered, this, &ProjectManagerViewPlugin::buildProjectItems );
     actionCollection()->addAction( "project_build", d->m_build );
-    d->m_install = new KAction( i18n("Install Selection"), this );
+    d->m_install = new QAction( i18n("Install Selection"), this );
     d->m_install->setIconText( i18n("Install") );
-    d->m_install->setIcon(KIcon("run-build-install"));
-    d->m_install->setShortcut( Qt::SHIFT + Qt::Key_F8 );
+    d->m_install->setIcon(QIcon::fromTheme("run-build-install"));
+    actionCollection()->setDefaultShortcut( d->m_install, Qt::SHIFT + Qt::Key_F8 );
     d->m_install->setEnabled( false );
-    connect( d->m_install, SIGNAL(triggered()), this, SLOT(installProjectItems()) );
+    connect( d->m_install, &QAction::triggered, this, &ProjectManagerViewPlugin::installProjectItems );
     actionCollection()->addAction( "project_install", d->m_install );
-    d->m_clean = new KAction( i18n("Clean Selection"), this );
+    d->m_clean = new QAction( i18n("Clean Selection"), this );
     d->m_clean->setIconText( i18n("Clean") );
-    d->m_clean->setIcon(KIcon("run-build-clean"));
+    d->m_clean->setIcon(QIcon::fromTheme("run-build-clean"));
     d->m_clean->setEnabled( false );
-    connect( d->m_clean, SIGNAL(triggered()), this, SLOT(cleanProjectItems()) );
+    connect( d->m_clean, &QAction::triggered, this, &ProjectManagerViewPlugin::cleanProjectItems );
     actionCollection()->addAction( "project_clean", d->m_clean );
-    d->m_configure = new KAction( i18n("Configure Selection"), this );
+    d->m_configure = new QAction( i18n("Configure Selection"), this );
     d->m_configure->setIconText( i18n("Configure") );
-    d->m_configure->setIcon(KIcon("run-build-configure"));
+    d->m_configure->setIcon(QIcon::fromTheme("run-build-configure"));
     d->m_configure->setEnabled( false );
-    connect( d->m_configure, SIGNAL(triggered()), this, SLOT(configureProjectItems()) );
+    connect( d->m_configure, &QAction::triggered, this, &ProjectManagerViewPlugin::configureProjectItems );
     actionCollection()->addAction( "project_configure", d->m_configure );
-    d->m_prune = new KAction( i18n("Prune Selection"), this );
+    d->m_prune = new QAction( i18n("Prune Selection"), this );
     d->m_prune->setIconText( i18n("Prune") );
-    d->m_prune->setIcon(KIcon("run-build-prune"));
+    d->m_prune->setIcon(QIcon::fromTheme("run-build-prune"));
     d->m_prune->setEnabled( false );
-    connect( d->m_prune, SIGNAL(triggered()), this, SLOT(pruneProjectItems()) );
+    connect( d->m_prune, &QAction::triggered, this, &ProjectManagerViewPlugin::pruneProjectItems );
     actionCollection()->addAction( "project_prune", d->m_prune );
     // only add the action so that its known in the actionCollection
     // and so that it's shortcut etc. pp. is restored
@@ -149,14 +151,14 @@ ProjectManagerViewPlugin::ProjectManagerViewPlugin( QObject *parent, const QVari
     setXMLFile( "kdevprojectmanagerview.rc" );
     d->factory = new KDevProjectManagerViewFactory( this );
     core()->uiController()->addToolView( i18n("Projects"), d->factory );
-    connect( core()->selectionController(), SIGNAL(selectionChanged(KDevelop::Context*)),
-             SLOT(updateActionState(KDevelop::Context*)));
-    connect( ICore::self()->projectController()->buildSetModel(), SIGNAL(rowsInserted(QModelIndex,int,int)),
-             SLOT(updateFromBuildSetChange()));
-    connect( ICore::self()->projectController()->buildSetModel(), SIGNAL(rowsRemoved(QModelIndex,int,int)),
-             SLOT(updateFromBuildSetChange()));
-    connect( ICore::self()->projectController()->buildSetModel(), SIGNAL(modelReset()),
-             SLOT(updateFromBuildSetChange()));
+    connect(core()->selectionController(), &ISelectionController::selectionChanged,
+             this, &ProjectManagerViewPlugin::updateActionState);
+    connect(ICore::self()->projectController()->buildSetModel(), &KDevelop::ProjectBuildSetModel::rowsInserted,
+             this, &ProjectManagerViewPlugin::updateFromBuildSetChange);
+    connect(ICore::self()->projectController()->buildSetModel(), &KDevelop::ProjectBuildSetModel::rowsRemoved,
+             this, &ProjectManagerViewPlugin::updateFromBuildSetChange);
+    connect(ICore::self()->projectController()->buildSetModel(), &KDevelop::ProjectBuildSetModel::modelReset,
+             this, &ProjectManagerViewPlugin::updateFromBuildSetChange);
 }
 
 void ProjectManagerViewPlugin::updateFromBuildSetChange()
@@ -185,7 +187,7 @@ ProjectManagerViewPlugin::~ProjectManagerViewPlugin()
 
 void ProjectManagerViewPlugin::unload()
 {
-    kDebug() << "unloading manager view";
+    qCDebug(PLUGIN_PROJECTMANAGERVIEW) << "unloading manager view";
     core()->uiController()->removeToolView(d->factory);
 }
 
@@ -218,7 +220,7 @@ ContextMenuExtension ProjectManagerViewPlugin::contextMenuExtension( KDevelop::C
     //needsCreateFolder if there is one item and it's a folder
     needsCreateFolder &= (items.count() == 1) && (items.first()->folder());
     needsPaste = needsCreateFolder;
-    
+
     foreach( ProjectBaseItem* item, items ) {
         d->ctxProjectItemList << item->index();
         //needsBuildItems if items are limited to targets and buildfolders
@@ -238,73 +240,73 @@ ContextMenuExtension ProjectManagerViewPlugin::contextMenuExtension( KDevelop::C
     }
 
     if ( needsCreateFile ) {
-        KAction* action = new KAction( i18n( "Create File" ), this );
-        action->setIcon(KIcon("document-new"));
-        connect( action, SIGNAL(triggered()), this, SLOT(createFileFromContextMenu()) );
+        QAction* action = new QAction( i18n( "Create File" ), this );
+        action->setIcon(QIcon::fromTheme("document-new"));
+        connect( action, &QAction::triggered, this, &ProjectManagerViewPlugin::createFileFromContextMenu );
         menuExt.addAction( ContextMenuExtension::FileGroup, action );
     }
     if ( needsCreateFolder ) {
-        KAction* action = new KAction( i18n( "Create Folder" ), this );
-        action->setIcon(KIcon("folder-new"));
-        connect( action, SIGNAL(triggered()), this, SLOT(createFolderFromContextMenu()) );
+        QAction* action = new QAction( i18n( "Create Folder" ), this );
+        action->setIcon(QIcon::fromTheme("folder-new"));
+        connect( action, &QAction::triggered, this, &ProjectManagerViewPlugin::createFolderFromContextMenu );
         menuExt.addAction( ContextMenuExtension::FileGroup, action );
     }
 
     if ( needsBuildItems ) {
-        KAction* action = new KAction( i18nc( "@action", "Build" ), this );
-        action->setIcon(KIcon("run-build"));
-        connect( action, SIGNAL(triggered()), this, SLOT(buildItemsFromContextMenu()) );
+        QAction* action = new QAction( i18nc( "@action", "Build" ), this );
+        action->setIcon(QIcon::fromTheme("run-build"));
+        connect( action, &QAction::triggered, this, &ProjectManagerViewPlugin::buildItemsFromContextMenu );
         menuExt.addAction( ContextMenuExtension::BuildGroup, action );
-        action = new KAction( i18nc( "@action", "Install" ), this );
-        action->setIcon(KIcon("run-install"));
-        connect( action, SIGNAL(triggered()), this, SLOT(installItemsFromContextMenu()) );
+        action = new QAction( i18nc( "@action", "Install" ), this );
+        action->setIcon(QIcon::fromTheme("run-install"));
+        connect( action, &QAction::triggered, this, &ProjectManagerViewPlugin::installItemsFromContextMenu );
         menuExt.addAction( ContextMenuExtension::BuildGroup, action );
-        action = new KAction( i18nc( "@action", "Clean" ), this );
-        action->setIcon(KIcon("run-clean"));
-        connect( action, SIGNAL(triggered()), this, SLOT(cleanItemsFromContextMenu()) );
+        action = new QAction( i18nc( "@action", "Clean" ), this );
+        action->setIcon(QIcon::fromTheme("run-clean"));
+        connect( action, &QAction::triggered, this, &ProjectManagerViewPlugin::cleanItemsFromContextMenu );
         menuExt.addAction( ContextMenuExtension::BuildGroup, action );
-        action = new KAction( i18n( "Add to Build Set" ), this );
-        action->setIcon(KIcon("list-add"));
-        connect( action, SIGNAL(triggered()), this, SLOT(addItemsFromContextMenuToBuildset()) );
+        action = new QAction( i18n( "Add to Build Set" ), this );
+        action->setIcon(QIcon::fromTheme("list-add"));
+        connect( action, &QAction::triggered, this, &ProjectManagerViewPlugin::addItemsFromContextMenuToBuildset );
         menuExt.addAction( ContextMenuExtension::BuildGroup, action );
     }
 
     if ( needsCloseProjects ) {
-        KAction* close = new KAction( i18np( "Close Project", "Close Projects", items.count() ), this );
-        close->setIcon(KIcon("project-development-close"));
-        connect( close, SIGNAL(triggered()), this, SLOT(closeProjects()) );
+        QAction* close = new QAction( i18np( "Close Project", "Close Projects", items.count() ), this );
+        close->setIcon(QIcon::fromTheme("project-development-close"));
+        connect( close, &QAction::triggered, this, &ProjectManagerViewPlugin::closeProjects );
         menuExt.addAction( ContextMenuExtension::ProjectGroup, close );
     }
     if ( needsFolderItems ) {
-        KAction* action = new KAction( i18n( "Reload" ), this );
-        action->setIcon(KIcon("view-refresh"));
-        connect( action, SIGNAL(triggered()), this, SLOT(reloadFromContextMenu()) );
+        QAction* action = new QAction( i18n( "Reload" ), this );
+        action->setIcon(QIcon::fromTheme("view-refresh"));
+        connect( action, &QAction::triggered, this, &ProjectManagerViewPlugin::reloadFromContextMenu );
         menuExt.addAction( ContextMenuExtension::FileGroup, action );
     }
     if ( needsRemoveAndRename ) {
-        KAction* remove = new KAction( i18n( "Remove" ), this );
-        remove->setIcon(KIcon("user-trash"));
-        connect( remove, SIGNAL(triggered()), this, SLOT(removeFromContextMenu()) );
+        QAction* remove = new QAction( i18n( "Remove" ), this );
+        remove->setIcon(QIcon::fromTheme("user-trash"));
+        connect( remove, &QAction::triggered, this, &ProjectManagerViewPlugin::removeFromContextMenu );
         menuExt.addAction( ContextMenuExtension::FileGroup, remove );
-        KAction* rename = new KAction( i18n( "Rename" ), this );
-        rename->setIcon(KIcon("edit-rename"));
-        connect( rename, SIGNAL(triggered()), this, SLOT(renameItemFromContextMenu()) );
+        QAction* rename = new QAction( i18n( "Rename" ), this );
+        rename->setIcon(QIcon::fromTheme("edit-rename"));
+        connect( rename, &QAction::triggered, this, &ProjectManagerViewPlugin::renameItemFromContextMenu );
         menuExt.addAction( ContextMenuExtension::FileGroup, rename );
     }
     if ( needsRemoveTargetFiles ) {
-        KAction* remove = new KAction( i18n( "Remove From Target" ), this );
-        remove->setIcon(KIcon("user-trash"));
-        connect( remove, SIGNAL(triggered()), this, SLOT(removeTargetFilesFromContextMenu()) );
+        QAction* remove = new QAction( i18n( "Remove From Target" ), this );
+        remove->setIcon(QIcon::fromTheme("user-trash"));
+        connect( remove, &QAction::triggered, this, &ProjectManagerViewPlugin::removeTargetFilesFromContextMenu );
         menuExt.addAction( ContextMenuExtension::FileGroup, remove );
     }
 
     {
-        KAction* copy = KStandardAction::copy(this, SLOT(copyFromContextMenu()), this);
+        QAction* copy = KStandardAction::copy(this, SLOT(copyFromContextMenu()), this);
         copy->setShortcutContext(Qt::WidgetShortcut);
         menuExt.addAction( ContextMenuExtension::FileGroup, copy );
     }
     if (needsPaste) {
-        KAction* paste = KStandardAction::paste(this, SLOT(pasteFromContextMenu()), this);
+        QAction* paste = KStandardAction::paste(this, SLOT(pasteFromContextMenu()), this);
         paste->setShortcutContext(Qt::WidgetShortcut);
         menuExt.addAction( ContextMenuExtension::FileGroup, paste );
     }
@@ -393,6 +395,7 @@ void ProjectManagerViewPlugin::runBuilderJob( BuilderJob::BuildType type, QList<
     BuilderJob* builder = new BuilderJob;
     builder->addItems( type, items );
     builder->updateJobName();
+    ICore::self()->uiController()->registerStatus(new JobStatus(builder));
     ICore::self()->runController()->registerJob( builder );
 }
 
@@ -436,7 +439,7 @@ void ProjectManagerViewPlugin::runTargetsFromContextMenu( )
         KDevelop::ProjectExecutableTargetItem* t=item->executable();
         if(t)
         {
-            kDebug() << "Running target: " << t->text() << t->builtUrl();
+            qCDebug(PLUGIN_PROJECTMANAGERVIEW) << "Running target: " << t->text() << t->builtUrl();
         }
     }
 }
@@ -507,7 +510,7 @@ void ProjectManagerViewPlugin::removeItems(const QList< ProjectBaseItem* >& item
 
     //copy the list of selected items and sort it to guarantee parents will come before children
     QList<KDevelop::ProjectBaseItem*> sortedItems = items;
-    qSort(sortedItems.begin(), sortedItems.end(), ProjectBaseItem::pathLessThan);
+    std::sort(sortedItems.begin(), sortedItems.end(), ProjectBaseItem::pathLessThan);
 
     Path lastFolder;
     QMap< IProjectFileManager*, QList<KDevelop::ProjectBaseItem*> > filteredItems;
@@ -655,16 +658,16 @@ void ProjectManagerViewPlugin::createFileFromContextMenu( )
 void ProjectManagerViewPlugin::copyFromContextMenu()
 {
     KDevelop::ProjectItemContext* ctx = dynamic_cast<KDevelop::ProjectItemContext*>(ICore::self()->selectionController()->currentSelection());
-    KUrl::List urls;
+    QList<QUrl> urls;
     foreach (ProjectBaseItem* item, ctx->items()) {
         if (item->folder() || item->file()) {
             urls << item->path().toUrl();
         }
     }
-    kDebug() << urls;
+    qCDebug(PLUGIN_PROJECTMANAGERVIEW) << urls;
     if (!urls.isEmpty()) {
-        QMimeData *data = new QMimeData;
-        urls.populateMimeData(data);
+        QMimeData* data = new QMimeData;
+        data->setUrls(urls);
         qApp->clipboard()->setMimeData(data);
     }
 }
@@ -680,7 +683,7 @@ void ProjectManagerViewPlugin::pasteFromContextMenu()
         return; //do nothing if the target is not a directory
 
     const QMimeData* data = qApp->clipboard()->mimeData();
-    kDebug() << data->urls();
+    qCDebug(PLUGIN_PROJECTMANAGERVIEW) << data->urls();
     const Path::List paths = toPathList(data->urls());
     bool success = destItem->project()->projectFileManager()->copyFilesAndFolders(paths, destItem->folder());
 
