@@ -22,20 +22,16 @@
 #include "projecttreeview.h"
 
 
-#include <QtGui/QHeaderView>
-#include <QtCore/QDebug>
-#include <QtGui/QMouseEvent>
-#include <QApplication>
+#include <QAction>
 #include <QAbstractProxyModel>
-#include <QItemDelegate>
+#include <QApplication>
+#include <QHeaderView>
+#include <QMenu>
+#include <QMouseEvent>
+#include <QPainter>
 
-#include <kxmlguiwindow.h>
-#include <kglobalsettings.h>
-#include <kaction.h>
-#include <kmenu.h>
-#include <kdebug.h>
-#include <kurl.h>
-#include <klocale.h>
+#include <KConfigGroup>
+#include <KLocalizedString>
 
 #include <project/projectmodel.h>
 #include <language/duchain/duchainutils.h>
@@ -53,53 +49,22 @@
 #include "projectmanagerviewplugin.h"
 #include "projectmodelsaver.h"
 #include "projectmodelitemdelegate.h"
+#include "debug.h"
 #include <language/duchain/duchainlock.h>
 #include <language/duchain/duchain.h>
 #include <language/util/navigationtooltip.h>
 #include <project/projectutils.h>
+#include <widgetcolorizer.h>
 
 using namespace KDevelop;
 
-static const char* settingsConfigGroup = "ProjectTreeView";
+namespace {
+const char settingsConfigGroup[] = "ProjectTreeView";
 
-ProjectTreeView::ProjectTreeView( QWidget *parent )
-        : QTreeView( parent ), m_ctxProject( 0 )
+QList<ProjectFileItem*> fileItemsWithin(const QList<ProjectBaseItem*>& items)
 {
-    header()->hide();
-
-    setEditTriggers( QAbstractItemView::EditKeyPressed );
-
-    setContextMenuPolicy( Qt::CustomContextMenu );
-    setSelectionMode( QAbstractItemView::ExtendedSelection );
-
-    setIndentation(10);
-
-    setDragEnabled(true);
-    setDragDropMode(QAbstractItemView::InternalMove);
-    setAutoScroll(true);
-    setAutoExpandDelay(300);
-    setItemDelegate(new ProjectModelItemDelegate(this));
-
-    connect( this, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(popupContextMenu(QPoint)) );
-    connect( this, SIGNAL(activated(QModelIndex)), this, SLOT(slotActivated(QModelIndex)) );
-
-    connect( ICore::self(), SIGNAL(aboutToShutdown()),
-             this, SLOT(aboutToShutdown()));
-    connect( ICore::self()->projectController(), SIGNAL(projectOpened(KDevelop::IProject*)),
-             this, SLOT(restoreState(KDevelop::IProject*)) );
-    connect( ICore::self()->projectController(), SIGNAL(projectClosing(KDevelop::IProject*)),
-             this, SLOT(saveState()) );
-
-    restoreState();
-}
-
-ProjectTreeView::~ProjectTreeView()
-{
-}
-
-QList<ProjectFileItem*> fileItemsWithin(const QList<ProjectBaseItem*> items)
-{
-   QList<ProjectFileItem*> fileItems;
+    QList<ProjectFileItem*> fileItems;
+    fileItems.reserve(items.size());
     foreach(ProjectBaseItem* item, items)
     {
         if (ProjectFileItem *file = item->file())
@@ -112,7 +77,7 @@ QList<ProjectFileItem*> fileItemsWithin(const QList<ProjectBaseItem*> items)
 
 QList<ProjectBaseItem*> topLevelItemsWithin(QList<ProjectBaseItem*> items)
 {
-    qSort(items.begin(), items.end(), ProjectBaseItem::pathLessThan);
+    std::sort(items.begin(), items.end(), ProjectBaseItem::pathLessThan);
     Path lastFolder;
     for (int i = items.size() - 1; i >= 0; --i)
     {
@@ -138,6 +103,50 @@ void filterDroppedItems(QList<T*> &items, ProjectBaseItem* dest)
     }
 }
 
+//TODO test whether this could be replaced by projectbuildsetwidget.cpp::showContextMenu_appendActions
+void popupContextMenu_appendActions(QMenu& menu, const QList<QAction*>& actions)
+{
+    menu.addActions(actions);
+    menu.addSeparator();
+}
+
+}
+
+ProjectTreeView::ProjectTreeView( QWidget *parent )
+        : QTreeView( parent ), m_ctxProject( 0 )
+{
+    header()->hide();
+
+    setEditTriggers( QAbstractItemView::EditKeyPressed );
+
+    setContextMenuPolicy( Qt::CustomContextMenu );
+    setSelectionMode( QAbstractItemView::ExtendedSelection );
+
+    setIndentation(10);
+
+    setDragEnabled(true);
+    setDragDropMode(QAbstractItemView::InternalMove);
+    setAutoScroll(true);
+    setAutoExpandDelay(300);
+    setItemDelegate(new ProjectModelItemDelegate(this));
+
+    connect( this, &ProjectTreeView::customContextMenuRequested, this, &ProjectTreeView::popupContextMenu );
+    connect( this, &ProjectTreeView::activated, this, &ProjectTreeView::slotActivated );
+
+    connect( ICore::self(), &ICore::aboutToShutdown,
+             this, &ProjectTreeView::aboutToShutdown);
+    connect( ICore::self()->projectController(), &IProjectController::projectOpened,
+             this, &ProjectTreeView::restoreState );
+    connect( ICore::self()->projectController(), &IProjectController::projectClosing,
+             this, &ProjectTreeView::saveState );
+
+    restoreState();
+}
+
+ProjectTreeView::~ProjectTreeView()
+{
+}
+
 ProjectBaseItem* ProjectTreeView::itemAtPos(QPoint pos)
 {
     return indexAt(pos).data(ProjectModel::ProjectItemRole).value<ProjectBaseItem*>();
@@ -154,24 +163,24 @@ void ProjectTreeView::dropEvent(QDropEvent* event)
     {
         if (ProjectFolderItem *folder = destItem->folder())
         {
-            KMenu dropMenu(this);
+            QMenu dropMenu(this);
 
             QString seq = QKeySequence( Qt::ShiftModifier ).toString();
             seq.chop(1); // chop superfluous '+'
             QAction* move = new QAction(i18n( "&Move Here" ) + '\t' + seq, &dropMenu);
-            move->setIcon(KIcon("go-jump"));
+            move->setIcon(QIcon::fromTheme("go-jump"));
             dropMenu.addAction(move);
 
             seq = QKeySequence( Qt::ControlModifier ).toString();
             seq.chop(1);
             QAction* copy = new QAction(i18n( "&Copy Here" ) + '\t' + seq, &dropMenu);
-            copy->setIcon(KIcon("edit-copy"));
+            copy->setIcon(QIcon::fromTheme("edit-copy"));
             dropMenu.addAction(copy);
 
             dropMenu.addSeparator();
 
             QAction* cancel = new QAction(i18n( "C&ancel" ) + '\t' + QKeySequence( Qt::Key_Escape ).toString(), &dropMenu);
-            cancel->setIcon(KIcon("process-stop"));
+            cancel->setIcon(QIcon::fromTheme("process-stop"));
             dropMenu.addAction(cancel);
 
             QAction *executedAction = 0;
@@ -219,18 +228,18 @@ void ProjectTreeView::dropEvent(QDropEvent* event)
         }
         else if (destItem->target() && destItem->project()->buildSystemManager())
         {
-            KMenu dropMenu(this);
+            QMenu dropMenu(this);
 
             QString seq = QKeySequence( Qt::ControlModifier ).toString();
             seq.chop(1);
             QAction* addToTarget = new QAction(i18n( "&Add to Target" ) + '\t' + seq, &dropMenu);
-            addToTarget->setIcon(KIcon("edit-link"));
+            addToTarget->setIcon(QIcon::fromTheme("edit-link"));
             dropMenu.addAction(addToTarget);
 
             dropMenu.addSeparator();
 
             QAction* cancel = new QAction(i18n( "C&ancel" ) + '\t' + QKeySequence( Qt::Key_Escape ).toString(), &dropMenu);
-            cancel->setIcon(KIcon("process-stop"));
+            cancel->setIcon(QIcon::fromTheme("process-stop"));
             dropMenu.addAction(cancel);
 
             QAction *executedAction = 0;
@@ -284,12 +293,6 @@ void ProjectTreeView::slotActivated( const QModelIndex &index )
         emit activate( item->file()->path() );
     }
 }
-//TODO test whether this could be replaced by projectbuildsetwidget.cpp::showContextMenu_appendActions
-void popupContextMenu_appendActions(QMenu& menu, const QList<QAction*>& actions)
-{
-    menu.addActions(actions);
-    menu.addSeparator();
-}
 
 void ProjectTreeView::popupContextMenu( const QPoint &pos )
 {
@@ -313,9 +316,9 @@ void ProjectTreeView::popupContextMenu( const QPoint &pos )
         m_ctxProject = 0;
     }
 
-    KMenu menu( this );
+    QMenu menu( this );
 
-    KDevelop::ProjectItemContext context(itemlist);
+    KDevelop::ProjectItemContextImpl context(itemlist);
     QList<ContextMenuExtension> extensions = ICore::self()->pluginController()->queryPluginsForContextMenuExtensions( &context );
 
     QList<QAction*> buildActions;
@@ -342,13 +345,13 @@ void ProjectTreeView::popupContextMenu( const QPoint &pos )
 
     if ( !itemlist.isEmpty() && itemlist.size() == 1 && itemlist[0]->folder() && !itemlist[0]->folder()->parent() )
     {
-        KAction* projectConfig = new KAction(i18n("Open Configuration..."), this);
-        projectConfig->setIcon(KIcon("configure"));
-        connect( projectConfig, SIGNAL(triggered()), this, SLOT(openProjectConfig()) );
+        QAction* projectConfig = new QAction(i18n("Open Configuration..."), this);
+        projectConfig->setIcon(QIcon::fromTheme("configure"));
+        connect( projectConfig, &QAction::triggered, this, &ProjectTreeView::openProjectConfig );
         projectActions << projectConfig;
     }
     popupContextMenu_appendActions(menu, projectActions);
-    
+
     if(!itemlist.isEmpty())
         KDevelop::populateParentItemsMenu(itemlist.front(), &menu);
 
@@ -389,8 +392,8 @@ void ProjectTreeView::restoreState(IProject* project)
 void ProjectTreeView::aboutToShutdown()
 {
     // save all projects, not just the last one that is closed
-    disconnect( ICore::self()->projectController(), SIGNAL(projectClosing(KDevelop::IProject*)),
-                this, SLOT(saveState()) );
+    disconnect( ICore::self()->projectController(), &IProjectController::projectClosing,
+                this, &ProjectTreeView::saveState );
     saveState();
 }
 
@@ -400,22 +403,22 @@ bool ProjectTreeView::event(QEvent* event)
     {
         QPoint p = mapFromGlobal(QCursor::pos());
         QModelIndex idxView = indexAt(p);
-        
+
         ProjectBaseItem* it = idxView.data(ProjectModel::ProjectItemRole).value<ProjectBaseItem*>();
         QModelIndex idx;
         if(it)
             idx = it->index();
-        
+
         if((m_idx!=idx || !m_tooltip) && it && it->file())
         {
             m_idx=idx;
             ProjectFileItem* file=it->file();
             KDevelop::DUChainReadLocker lock(KDevelop::DUChain::lock());
             TopDUContext* top= DUChainUtils::standardContextForUrl(file->path().toUrl());
-            
+
             if(m_tooltip)
                 m_tooltip->close();
-            
+
             if(top)
             {
                 QWidget* navigationWidget = top->createNavigationWidget();
@@ -423,18 +426,17 @@ bool ProjectTreeView::event(QEvent* event)
                 {
                     m_tooltip = new KDevelop::NavigationToolTip(this, mapToGlobal(p) + QPoint(40, 0), navigationWidget);
                     m_tooltip->resize( navigationWidget->sizeHint() + QSize(10, 10) );
-                    kDebug() << "tooltip size" << m_tooltip->size();
+                    qCDebug(PLUGIN_PROJECTMANAGERVIEW) << "tooltip size" << m_tooltip->size();
                     ActiveToolTip::showToolTip(m_tooltip);
                     return true;
                 }
             }
         }
     }
-    
+
     return QAbstractItemView::event(event);
 }
 
-
 void ProjectTreeView::keyPressEvent(QKeyEvent* event)
 {
     if (event->key() == Qt::Key_Return && currentIndex().isValid() && state()!=QAbstractItemView::EditingState)
@@ -446,6 +448,14 @@ void ProjectTreeView::keyPressEvent(QKeyEvent* event)
         QTreeView::keyPressEvent(event);
 }
 
+void ProjectTreeView::drawBranches(QPainter* painter, const QRect& rect, const QModelIndex& index) const
+{
+    const bool colorizeByProject = KSharedConfig::openConfig()->group("UiSettings").readEntry("ColorizeByProject", false);
+    if (colorizeByProject) {
+        const auto projectPath = index.data(ProjectModel::ProjectRole).value<IProject *>()->path();
+        const QColor color = WidgetColorizer::colorForId(qHash(projectPath), palette());
+        WidgetColorizer::drawBranches(this, painter, rect, index, color);
+    }
 
-#include "projecttreeview.moc"
-
+    QTreeView::drawBranches(painter, rect, index);
+}
