@@ -21,11 +21,10 @@
 #ifndef KDEVPLATFORM_PLUGIN_PROJECTTREEVIEW_H
 #define KDEVPLATFORM_PLUGIN_PROJECTTREEVIEW_H
 
-#include <QtGui/QTreeView>
+#include <QTreeView>
 #include <QtCore/QPointer>
 
 class QAbstractProxyModel;
-class KUrl;
 class QAction;
 class QItemSelectionModel;
 class QMouseEvent;
@@ -47,12 +46,12 @@ class ProjectTreeView: public QTreeView
 {
         Q_OBJECT
     public:
-        ProjectTreeView( QWidget *parent = 0 );
+        explicit ProjectTreeView( QWidget *parent = 0 );
         virtual ~ProjectTreeView();
 
         static QModelIndex mapFromSource(const QAbstractProxyModel* proxy, const QModelIndex& sourceIdx);
 
-        virtual bool event(QEvent* event);
+        virtual bool event(QEvent* event) override;
 
     Q_SIGNALS:
         void activate( const KDevelop::Path &url );
@@ -66,8 +65,9 @@ class ProjectTreeView: public QTreeView
         void aboutToShutdown();
 
     protected:
-        virtual void keyPressEvent(QKeyEvent *event);
-        virtual void dropEvent(QDropEvent* event);
+        virtual void keyPressEvent(QKeyEvent *event) override;
+        virtual void dropEvent(QDropEvent* event) override;
+        virtual void drawBranches(QPainter* painter, const QRect& rect, const QModelIndex& index) const override;
 
     private:
         QModelIndex mapFromItem(const KDevelop::ProjectBaseItem* item);
