@@ -18,6 +18,7 @@
 */
 
 #include "vcsoverlayproxymodel.h"
+#include <projectchangesmodel.h>
 #include <interfaces/icore.h>
 #include <interfaces/iprojectcontroller.h>
 #include <interfaces/iproject.h>
@@ -25,12 +26,12 @@
 #include <interfaces/iplugin.h>
 #include <vcs/interfaces/ibranchingversioncontrol.h>
 #include <vcs/vcsjob.h>
+#include <vcs/models/vcsfilechangesmodel.h>
 #include <project/projectmodel.h>
 #include <util/path.h>
 
-#include <KLocale>
+#include <KLocalizedString>
 
-#include <QDebug>
 
 using namespace KDevelop;
 
@@ -39,23 +40,30 @@ Q_DECLARE_METATYPE(SafeProjectPointer)
 
 VcsOverlayProxyModel::VcsOverlayProxyModel(QObject* parent): QIdentityProxyModel(parent)
 {
-    connect(ICore::self()->projectController(), SIGNAL(projectOpened(KDevelop::IProject*)),
-                                              SLOT(addProject(KDevelop::IProject*)));
-    connect(ICore::self()->projectController(), SIGNAL(projectClosing(KDevelop::IProject*)),
-                                              SLOT(removeProject(KDevelop::IProject*)));
+    connect(ICore::self()->projectController(), &IProjectController::projectOpened,
+                                              this, &VcsOverlayProxyModel::addProject);
+    connect(ICore::self()->projectController(), &IProjectController::projectClosing,
+                                              this, &VcsOverlayProxyModel::removeProject);
 
-    foreach (auto project, ICore::self()->projectController()->projects()) {
+    foreach (const auto& project, ICore::self()->projectController()->projects()) {
         addProject(project);
     }
 }
 
 QVariant VcsOverlayProxyModel::data(const QModelIndex& proxyIndex, int role) const
 {
-    if(role == BranchNameRole && !proxyIndex.parent().isValid()) {
-        IProject* p = qobject_cast<IProject*>(proxyIndex.data(ProjectModel::ProjectRole).value<QObject*>());
-        return m_branchName.value(p);
+    if(role == VcsStatusRole) {
+        if (!proxyIndex.parent().isValid()) {
+            IProject* p = qobject_cast<IProject*>(proxyIndex.data(ProjectModel::ProjectRole).value<QObject*>());
+            return m_branchName.value(p);
+        } else {
+            ProjectChangesModel* model = ICore::self()->projectController()->changesModel();
+            const QUrl url = proxyIndex.data(ProjectModel::UrlRole).toUrl();
+            const QModelIndex idx = model->indexForUrl(url);
+            return idx.sibling(idx.row(), 1).data(Qt::DisplayRole);
+        }
     } else
-        return QAbstractProxyModel::data(proxyIndex, role);;
+        return QAbstractProxyModel::data(proxyIndex, role);
 }
 
 void VcsOverlayProxyModel::addProject(IProject* p)
@@ -63,31 +71,29 @@ void VcsOverlayProxyModel::addProject(IProject* p)
     IPlugin* plugin = p->versionControlPlugin();
     if(!plugin)
         return;
-    
+
+    // TODO: Show revision in case we're in "detached" state
     IBranchingVersionControl* branchingExtension = plugin->extension<KDevelop::IBranchingVersionControl>();
     if(branchingExtension) {
-        const KUrl url = p->path().toUrl();
+        const QUrl url = p->path().toUrl();
         branchingExtension->registerRepositoryForCurrentBranchChanges(url);
-        connect(plugin, SIGNAL(repositoryBranchChanged(KUrl)), SLOT(repositoryBranchChanged(KUrl)));
+        //can't use new signal/slot syntax here, IBranchingVersionControl is not a QObject
+        connect(plugin, SIGNAL(repositoryBranchChanged(QUrl)), SLOT(repositoryBranchChanged(QUrl)));
         repositoryBranchChanged(url);
     }
 }
 
-void VcsOverlayProxyModel::repositoryBranchChanged(const KUrl& url)
+void VcsOverlayProxyModel::repositoryBranchChanged(const QUrl& url)
 {
     QList<IProject*> allProjects = ICore::self()->projectController()->projects();
     foreach(IProject* project, allProjects) {
-        if( url.isParentOf(project->folder())) {
+        if( url.isParentOf(project->path().toUrl()) || url.matches(project->path().toUrl(), QUrl::StripTrailingSlash)) {
             IPlugin* v = project->versionControlPlugin();
             Q_ASSERT(v);
-            if (!v) {
-                continue;
-            }
-
             IBranchingVersionControl* branching = v->extension<IBranchingVersionControl>();
             Q_ASSERT(branching);
             VcsJob* job = branching->currentBranch(url);
-            connect(job, SIGNAL(resultsReady(KDevelop::VcsJob*)), SLOT(branchNameReady(KDevelop::VcsJob*)));
+            connect(job, &VcsJob::resultsReady, this, &VcsOverlayProxyModel::branchNameReady);
             job->setProperty("project", QVariant::fromValue<SafeProjectPointer>(project));
             ICore::self()->runController()->registerJob(job);
         }
@@ -96,12 +102,15 @@ void VcsOverlayProxyModel::repositoryBranchChanged(const KUrl& url)
 
 void VcsOverlayProxyModel::branchNameReady(KDevelop::VcsJob* job)
 {
+    static const QString noBranchStr = i18nc("Version control: Currently not on a branch", "(no branch)");
+
     if(job->status()==VcsJob::JobSucceeded) {
         SafeProjectPointer p = job->property("project").value<SafeProjectPointer>();
         QModelIndex index = indexFromProject(p);
         if(index.isValid()) {
             IProject* project = p.data();
-            m_branchName[project] = job->fetchResults().toString();
+            const auto branchName =  job->fetchResults().toString();
+            m_branchName[project] = branchName.isEmpty() ? noBranchStr : branchName;
             emit dataChanged(index, index);
         }
     }
