@@ -18,11 +18,12 @@
 
 #include "projectfilequickopen.h"
 
+#include <QApplication>
 #include <QIcon>
 #include <QTextBrowser>
-#include <QApplication>
 
-#include <KLocale>
+#include <KIconLoader>
+#include <KLocalizedString>
 
 #include <interfaces/iprojectcontroller.h>
 #include <interfaces/idocumentcontroller.h>
@@ -32,10 +33,11 @@
 #include <language/duchain/topducontext.h>
 #include <language/duchain/duchain.h>
 #include <language/duchain/duchainlock.h>
-#include <language/duchain/indexedstring.h>
+#include <serialization/indexedstring.h>
 #include <language/duchain/parsingenvironment.h>
 
 #include <project/projectmodel.h>
+#include <project/projectutils.h>
 
 #include "../openwith/iopenwith.h"
 
@@ -49,7 +51,7 @@ QSet<IndexedString> openFiles()
     const QList<IDocument*>& docs = ICore::self()->documentController()->openDocuments();
     openFiles.reserve(docs.size());
     foreach( IDocument* doc, docs ) {
-        openFiles << IndexedString(doc->url().pathOrUrl());
+        openFiles << IndexedString(doc->url());
     }
     return openFiles;
 }
@@ -57,13 +59,13 @@ QSet<IndexedString> openFiles()
 QString iconNameForUrl(const IndexedString& url)
 {
     if (url.isEmpty()) {
-        return QString("tab-duplicate");
+        return QStringLiteral("tab-duplicate");
     }
     ProjectBaseItem* item = ICore::self()->projectController()->projectModel()->itemForPath(url);
     if (item) {
         return item->iconName();
     }
-    return QString("unknown");
+    return QStringLiteral("unknown");
 }
 
 }
@@ -85,8 +87,8 @@ QString ProjectFileData::htmlDescription() const
 
 bool ProjectFileData::execute( QString& filterText )
 {
-    const KUrl url = m_file.path.toUrl();
-    IOpenWith::openFiles(KUrl::List() << url);
+    const QUrl url = m_file.path.toUrl();
+    IOpenWith::openFiles(QList<QUrl>() << url);
     QString path;
     uint lineNumber;
     if (extractLineNumber(filterText, path, lineNumber)) {
@@ -127,7 +129,7 @@ QList<QVariant> ProjectFileData::highlighting() const
 
 QWidget* ProjectFileData::expandingWidget() const
 {
-    const KUrl url = m_file.path.toUrl();
+    const QUrl url = m_file.path.toUrl();
     DUChainReadLocker lock;
 
     ///Find a du-chain for the document
@@ -204,11 +206,7 @@ void BaseFileDataProvider::setFilterText( const QString& text )
         // assume we want to filter relative to active document's url
         IDocument* doc = ICore::self()->documentController()->activeDocument();
         if (doc) {
-            KUrl url = doc->url().upUrl();
-            url.addPath( path);
-            url.cleanPath();
-            url.adjustPath(KUrl::RemoveTrailingSlash);
-            path = url.pathOrUrl();
+            path = Path(Path(doc->url()).parent(), path).pathOrUrl();
         }
     }
     setFilter( path.split('/', QString::SkipEmptyParts) );
@@ -231,15 +229,19 @@ QuickOpenDataPointer BaseFileDataProvider::data(uint row) const
 
 ProjectFileDataProvider::ProjectFileDataProvider()
 {
-    connect(ICore::self()->projectController(), SIGNAL(projectClosing(KDevelop::IProject*)),
-            this, SLOT(projectClosing(KDevelop::IProject*)));
-    connect(ICore::self()->projectController(), SIGNAL(projectOpened(KDevelop::IProject*)),
-            this, SLOT(projectOpened(KDevelop::IProject*)));
+    auto projectController = ICore::self()->projectController();
+    connect(projectController, &IProjectController::projectClosing,
+            this, &ProjectFileDataProvider::projectClosing);
+    connect(projectController, &IProjectController::projectOpened,
+            this, &ProjectFileDataProvider::projectOpened);
+    foreach (const auto& project, projectController->projects()) {
+        projectOpened(project);
+    }
 }
 
 void ProjectFileDataProvider::projectClosing( IProject* project )
 {
-    foreach(ProjectFileItem* file, project->files()) {
+    foreach(ProjectFileItem* file, KDevelop::allFiles(project->projectItem())) {
         fileRemovedFromSet(file);
     }
 }
@@ -248,7 +250,7 @@ void ProjectFileDataProvider::projectOpened( IProject* project )
 {
     const int processAfter = 1000;
     int processed = 0;
-    foreach(ProjectFileItem* file, project->files()) {
+    foreach(ProjectFileItem* file, KDevelop::allFiles(project->projectItem())) {
         fileAddedToSet(file);
         if (++processed == processAfter) {
             // prevent UI-lockup when a huge project was imported
@@ -257,10 +259,10 @@ void ProjectFileDataProvider::projectOpened( IProject* project )
         }
     }
 
-    connect(project, SIGNAL(fileAddedToSet(KDevelop::ProjectFileItem*)),
-            this, SLOT(fileAddedToSet(KDevelop::ProjectFileItem*)));
-    connect(project, SIGNAL(fileRemovedFromSet(KDevelop::ProjectFileItem*)),
-            this, SLOT(fileRemovedFromSet(KDevelop::ProjectFileItem*)));
+    connect(project, &IProject::fileAddedToSet,
+            this, &ProjectFileDataProvider::fileAddedToSet);
+    connect(project, &IProject::fileRemovedFromSet,
+            this, &ProjectFileDataProvider::fileRemovedFromSet);
 }
 
 void ProjectFileDataProvider::fileAddedToSet( ProjectFileItem* file )
@@ -270,7 +272,7 @@ void ProjectFileDataProvider::fileAddedToSet( ProjectFileItem* file )
     f.path = file->path();
     f.indexedPath = file->indexedPath();
     f.outsideOfProject = !f.projectPath.isParentOf(f.path);
-    QList<ProjectFile>::iterator it = qLowerBound(m_projectFiles.begin(), m_projectFiles.end(), f);
+    auto it = std::lower_bound(m_projectFiles.begin(), m_projectFiles.end(), f);
     if (it == m_projectFiles.end() || it->path != f.path) {
         m_projectFiles.insert(it, f);
     }
@@ -284,16 +286,16 @@ void ProjectFileDataProvider::fileRemovedFromSet( ProjectFileItem* file )
     // fast-path for non-generated files
     // NOTE: figuring out whether something is generated is expensive... and since
     // generated files are rare we apply this two-step algorithm here
-    QList<ProjectFile>::iterator it = qBinaryFind(m_projectFiles.begin(), m_projectFiles.end(), item);
-    if (it != m_projectFiles.end()) {
+    auto it = std::lower_bound(m_projectFiles.begin(), m_projectFiles.end(), item);
+    if (it != m_projectFiles.end() && !(item < *it)) {
         m_projectFiles.erase(it);
         return;
     }
 
     // last try: maybe it was generated
     item.outsideOfProject = true;
-    it = qBinaryFind(m_projectFiles.begin(), m_projectFiles.end(), item);
-    if (it != m_projectFiles.end()) {
+    it = std::lower_bound(m_projectFiles.begin(), m_projectFiles.end(), item);
+    if (it != m_projectFiles.end() && !(item < *it)) {
         m_projectFiles.erase(it);
         return;
     }
@@ -348,7 +350,7 @@ void OpenFilesDataProvider::reset()
         currentFiles << f;
     }
 
-    qSort(currentFiles);
+    std::sort(currentFiles.begin(), currentFiles.end());
 
     setItems(currentFiles);
 }
@@ -358,4 +360,3 @@ QSet<IndexedString> OpenFilesDataProvider::files() const
     return openFiles();
 }
 
-#include "projectfilequickopen.moc"
