@@ -72,11 +72,11 @@ QStringList items(const ProjectFileDataProvider& provider);
 
 class TestFilter : public KDevelop::Filter<DUChainItem> {
 public:
-    virtual QString itemText(const DUChainItem &data) const {
+    virtual QString itemText(const DUChainItem &data) const override {
         return data.m_text;
     };
 };
 
-Q_DECLARE_METATYPE(QList<DUChainItem>);
+Q_DECLARE_METATYPE(QList<DUChainItem>)
 
 #endif // KDEVPLATFORM_PLUGIN_QUICKOPENTESTBASE_H
