@@ -22,35 +22,33 @@
 #include "outputwidget.h"
 
 #include "standardoutputview.h"
-#include <QtCore/QTimer>
-#include <QtCore/QRegExp>
-#include <QtGui/QAbstractItemDelegate>
-#include <QtGui/QItemSelectionModel>
-#include <QtGui/QTreeView>
-#include <QtGui/QToolButton>
-#include <QtGui/QScrollBar>
-#include <QtGui/QVBoxLayout>
-#include <QtGui/QStackedWidget>
-#include <QtGui/QApplication>
-#include <QtGui/QClipboard>
-#include <QtGui/QWidgetAction>
-#include <QtGui/QSortFilterProxyModel>
-#include <kmenu.h>
-#include <kaction.h>
-#include <kdebug.h>
-#include <ktoggleaction.h>
-#include <klocale.h>
-#include <kicon.h>
-#include <ktabwidget.h>
-#include <kstandardaction.h>
-#include <klineedit.h>
-#include <kactioncollection.h>
+
+#include <QAction>
+#include <QApplication>
+#include <QClipboard>
+#include <QIcon>
+#include <QLineEdit>
+#include <QRegExp>
+#include <QSortFilterProxyModel>
+#include <QStackedWidget>
+#include <QTabWidget>
+#include <QToolButton>
+#include <QTreeView>
+#include <QVBoxLayout>
+#include <QWidgetAction>
+
+#include <KActionCollection>
+#include <KLocalizedString>
+#include <KStandardAction>
+#include <KToggleAction>
 
 #include <outputview/ioutputviewmodel.h>
 #include <util/focusedtreeview.h>
 
 #include "toolviewdata.h"
+#include "debug.h"
 
+Q_LOGGING_CATEGORY(PLUGIN_STANDARDOUTPUTVIEW, "kdevplatform.plugins.standardoutputview")
 Q_DECLARE_METATYPE(QTreeView*)
 
 OutputWidget::OutputWidget(QWidget* parent, const ToolViewData* tvdata)
@@ -73,17 +71,16 @@ OutputWidget::OutputWidget(QWidget* parent, const ToolViewData* tvdata)
     layout->setMargin(0);
     if( data->type & KDevelop::IOutputView::MultipleView )
     {
-        tabwidget = new KTabWidget(this);
+        tabwidget = new QTabWidget(this);
         layout->addWidget( tabwidget );
         m_closeButton = new QToolButton( this );
-        connect( m_closeButton, SIGNAL(clicked()), SLOT(closeActiveView()) );
-        m_closeButton->setIcon( KIcon("tab-close") );
+        connect( m_closeButton, &QToolButton::clicked, this, &OutputWidget::closeActiveView );
+        m_closeButton->setIcon( QIcon::fromTheme("tab-close") );
         m_closeButton->setToolTip( i18n( "Close the currently active output view") );
-        m_closeButton->setAutoRaise(true);
 
         m_closeOthersAction = new QAction( this );
-        connect(m_closeOthersAction, SIGNAL(triggered(bool)), SLOT(closeOtherViews()));
-        m_closeOthersAction->setIcon(KIcon("tab-close-other"));
+        connect(m_closeOthersAction, &QAction::triggered, this, &OutputWidget::closeOtherViews);
+        m_closeOthersAction->setIcon(QIcon::fromTheme("tab-close-other"));
         m_closeOthersAction->setToolTip( i18n( "Close all other output views" ) );
         m_closeOthersAction->setText( m_closeOthersAction->toolTip() );
         addAction(m_closeOthersAction);
@@ -94,20 +91,20 @@ OutputWidget::OutputWidget(QWidget* parent, const ToolViewData* tvdata)
         stackwidget = new QStackedWidget( this );
         layout->addWidget( stackwidget );
 
-        previousAction = new KAction( KIcon( "go-previous" ), i18n("Previous"), this );
-        connect(previousAction, SIGNAL(triggered()), this, SLOT(previousOutput()));
+        previousAction = new QAction( QIcon::fromTheme( "arrow-left" ), i18n("Previous Output"), this );
+        connect(previousAction, &QAction::triggered, this, &OutputWidget::previousOutput);
         addAction(previousAction);
-        nextAction = new KAction( KIcon( "go-next" ), i18n("Next"), this );
-        connect(nextAction, SIGNAL(triggered()), this, SLOT(nextOutput()));
+        nextAction = new QAction( QIcon::fromTheme( "arrow-right" ), i18n("Next Output"), this );
+        connect(nextAction, &QAction::triggered, this, &OutputWidget::nextOutput);
         addAction(nextAction);
     }
 
-    addAction(dynamic_cast<KAction*>(data->plugin->actionCollection()->action("prev_error")));
-    addAction(dynamic_cast<KAction*>(data->plugin->actionCollection()->action("next_error")));
+    addAction(dynamic_cast<QAction*>(data->plugin->actionCollection()->action("prev_error")));
+    addAction(dynamic_cast<QAction*>(data->plugin->actionCollection()->action("next_error")));
 
-    activateOnSelect = new KToggleAction( KIcon(), i18n("Select activated Item"), this );
+    activateOnSelect = new KToggleAction( QIcon(), i18n("Select activated Item"), this );
     activateOnSelect->setChecked( true );
-    focusOnSelect = new KToggleAction( KIcon(), i18n("Focus when selecting Item"), this );
+    focusOnSelect = new KToggleAction( QIcon(), i18n("Focus when selecting Item"), this );
     focusOnSelect->setChecked( false );
     if( data->option & KDevelop::IOutputView::ShowItemsButton )
     {
@@ -117,52 +114,63 @@ OutputWidget::OutputWidget(QWidget* parent, const ToolViewData* tvdata)
 
     QAction *separator = new QAction(this);
     separator->setSeparator(true);
+    addAction(separator);
 
-    KAction *selectAllAction = KStandardAction::selectAll(this, SLOT(selectAll()), this);
-    selectAllAction->setShortcut(KShortcut()); //FIXME: why does CTRL-A conflict with Katepart (while CTRL-Cbelow doesn't) ?
+    QAction* action;
+
+    action = new QAction(QIcon::fromTheme("go-previous"), i18n("Previous Item"), this);
+    connect(action, &QAction::triggered, this, &OutputWidget::selectPreviousItem);
+    addAction(action);
+
+    action = new QAction(QIcon::fromTheme("go-next"), i18n("Next Item"), this);
+    connect(action, &QAction::triggered, this, &OutputWidget::selectNextItem);
+    addAction(action);
+
+    QAction* selectAllAction = KStandardAction::selectAll(this, SLOT(selectAll()), this);
+    selectAllAction->setShortcut(QKeySequence()); //FIXME: why does CTRL-A conflict with Katepart (while CTRL-Cbelow doesn't) ?
     selectAllAction->setShortcutContext(Qt::WidgetWithChildrenShortcut);
     addAction(selectAllAction);
 
-    KAction *copyAction = KStandardAction::copy(this, SLOT(copySelection()), this);
+    QAction* copyAction = KStandardAction::copy(this, SLOT(copySelection()), this);
     copyAction->setShortcutContext(Qt::WidgetWithChildrenShortcut);
     addAction(copyAction);
 
     if( data->option & KDevelop::IOutputView::AddFilterAction )
     {
+        QAction *separator = new QAction(this);
+        separator->setSeparator(true);
         addAction(separator);
-        filterInput = new KLineEdit();
+
+        filterInput = new QLineEdit();
         filterInput->setMaximumWidth(150);
         filterInput->setMinimumWidth(100);
-        filterInput->setClickMessage(i18n("Search..."));
-        filterInput->setClearButtonShown(true);
+        filterInput->setPlaceholderText(i18n("Search..."));
+        filterInput->setClearButtonEnabled(true);
         filterInput->setToolTip(i18n("Enter a wild card string to filter the output view"));
         filterAction = new QWidgetAction(this);
         filterAction->setDefaultWidget(filterInput);
         addAction(filterAction);
 
-        connect(filterInput, SIGNAL(textEdited(QString)),
-                this, SLOT(outputFilter(QString)) );
+        connect(filterInput, &QLineEdit::textEdited,
+                this, &OutputWidget::outputFilter );
         if( data->type & KDevelop::IOutputView::MultipleView )
         {
-            connect(tabwidget, SIGNAL(currentChanged(int)),
-                    this, SLOT(updateFilter(int)));
+            connect(tabwidget, &QTabWidget::currentChanged,
+                    this, &OutputWidget::updateFilter);
         } else if ( data->type == KDevelop::IOutputView::HistoryView )
         {
-            connect(stackwidget, SIGNAL(currentChanged(int)),
-                    this, SLOT(updateFilter(int)));
+            connect(stackwidget, &QStackedWidget::currentChanged,
+                    this, &OutputWidget::updateFilter);
         }
     }
 
     addActions(data->actionList);
 
-    connect( data, SIGNAL(outputAdded(int)),
-             this, SLOT(addOutput(int)) );
+    connect( data, &ToolViewData::outputAdded,
+             this, &OutputWidget::addOutput );
 
-    connect( this, SIGNAL(outputRemoved(int,int)),
-             data->plugin, SIGNAL(outputRemoved(int,int)) );
-
-    connect( data->plugin, SIGNAL(selectNextItem()), this, SLOT(selectNextItem()) );
-    connect( data->plugin, SIGNAL(selectPrevItem()), this, SLOT(selectPrevItem()) );
+    connect( this, &OutputWidget::outputRemoved,
+             data->plugin, &StandardOutputView::outputRemoved );
 
     foreach( int id, data->outputdata.keys() )
     {
@@ -176,9 +184,9 @@ void OutputWidget::addOutput( int id )
 {
     QTreeView* listview = createListView(id);
     setCurrentWidget( listview );
-    connect( data->outputdata.value(id), SIGNAL(modelChanged(int)), this, SLOT(changeModel(int)));
-    connect( data->outputdata.value(id), SIGNAL(delegateChanged(int)), this, SLOT(changeDelegate(int)));
-    
+    connect( data->outputdata.value(id), &OutputData::modelChanged, this, &OutputWidget::changeModel);
+    connect( data->outputdata.value(id), &OutputData::delegateChanged, this, &OutputWidget::changeDelegate);
+
     enableActions();
 }
 
@@ -208,17 +216,6 @@ void OutputWidget::changeModel( int id )
     {
         OutputData* od = data->outputdata.value(id);
         views.value( id )->setModel(od->model);
-
-        if (!od->model)
-            return;
-
-        disconnect( od->model,SIGNAL(rowsInserted(QModelIndex,int,int)), this,
-                    SLOT(rowsInserted(QModelIndex,int,int)) );
-        if( od->behaviour & KDevelop::IOutputView::AutoScroll )
-        {
-            connect( od->model,SIGNAL(rowsInserted(QModelIndex,int,int)),
-                     SLOT(rowsInserted(QModelIndex,int,int)) );
-        }
     }
     else
     {
@@ -265,11 +262,7 @@ void OutputWidget::removeOutput( int id )
                 filters.remove( 0 );
             }
         }
-        disconnect( data->outputdata.value( id )->model,SIGNAL(rowsInserted(QModelIndex,int,int)),
-                    this, SLOT(rowsInserted(QModelIndex,int,int)) );
-
         views.remove( id );
-        m_scrollDelay.remove( view );
         emit outputRemoved( data->toolViewId, id );
     }
     enableActions();
@@ -397,7 +390,7 @@ void OutputWidget::selectNextItem()
     selectItem(Next);
 }
 
-void OutputWidget::selectPrevItem()
+void OutputWidget::selectPreviousItem()
 {
     selectItem(Previous);
 }
@@ -423,7 +416,7 @@ void OutputWidget::selectItem(Direction direction)
         ? iface->previousHighlightIndex( index )
         : iface->nextHighlightIndex( index );
 
-    kDebug() << "old:" << index << "- new:" << newIndex;
+    qCDebug(PLUGIN_STANDARDOUTPUTVIEW) << "old:" << index << "- new:" << newIndex;
     activateIndex(newIndex, view, iface);
 }
 
@@ -436,35 +429,36 @@ void OutputWidget::activate(const QModelIndex& index)
     activateIndex(index, view, iface);
 }
 
-static QTreeView* createFocusedTreeView( QWidget* parent )
-{
-    QTreeView* listview = new KDevelop::FocusedTreeView(parent);
-    listview->setEditTriggers( QAbstractItemView::NoEditTriggers );
-    listview->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOn); //Always enable the scrollbar, so it doesn't flash around
-    listview->setHeaderHidden(true);
-    listview->setUniformRowHeights(true);
-    listview->setRootIsDecorated(false);
-    listview->setSelectionMode( QAbstractItemView::ContiguousSelection );
-
-    return listview;
-}
-
 QTreeView* OutputWidget::createListView(int id)
 {
+    auto createHelper = [&]() -> QTreeView* {
+        KDevelop::FocusedTreeView* listview = new KDevelop::FocusedTreeView(this);
+        listview->setEditTriggers( QAbstractItemView::NoEditTriggers );
+        listview->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOn); //Always enable the scrollbar, so it doesn't flash around
+        listview->setHeaderHidden(true);
+        listview->setUniformRowHeights(true);
+        listview->setRootIsDecorated(false);
+        listview->setSelectionMode( QAbstractItemView::ContiguousSelection );
+
+        if (data->outputdata.value(id)->behaviour & KDevelop::IOutputView::AutoScroll) {
+            listview->setAutoScrollAtEnd(true);
+        }
+
+        connect(listview, &QTreeView::activated, this, &OutputWidget::activate);
+        connect(listview, &QTreeView::clicked, this, &OutputWidget::activate);
+
+        return listview;
+    };
+
     QTreeView* listview = 0;
-    bool newView = true;
     if( !views.contains(id) )
     {
+        bool newView = true;
+
         if( data->type & KDevelop::IOutputView::MultipleView || data->type & KDevelop::IOutputView::HistoryView )
         {
-            kDebug() << "creating listview";
-            listview = createFocusedTreeView(this);
-
-            views[id] = listview;
-            connect( listview, SIGNAL(activated(QModelIndex)),
-                     this, SLOT(activate(QModelIndex)));
-            connect( listview, SIGNAL(clicked(QModelIndex)),
-                     this, SLOT(activate(QModelIndex)));
+            qCDebug(PLUGIN_STANDARDOUTPUTVIEW) << "creating listview";
+            listview = createHelper();
 
             if( data->type & KDevelop::IOutputView::MultipleView )
             {
@@ -478,32 +472,22 @@ QTreeView* OutputWidget::createListView(int id)
         {
             if( views.isEmpty() )
             {
-                listview = createFocusedTreeView(this);
+                listview = createHelper();
 
                 layout()->addWidget( listview );
-                connect( listview, SIGNAL(activated(QModelIndex)),
-                         this, SLOT(activate(QModelIndex)));
-                connect( listview, SIGNAL(clicked(QModelIndex)),
-                         this, SLOT(activate(QModelIndex)));
             } else
             {
                 listview = views.begin().value();
                 newView = false;
             }
-            views[id] = listview;
-        }
-
-        if (newView) {
-            auto timer = new QTimer(listview);
-            timer->setSingleShot(true);
-            timer->setInterval(300);
-            timer->setProperty("view", QVariant::fromValue(listview));
-            m_scrollDelay[listview] = {timer, -1, -1};
-            connect(timer, SIGNAL(timeout()), SLOT(delayedScroll()));
         }
+        views[id] = listview;
 
         changeModel( id );
         changeDelegate( id );
+
+        if (newView)
+            listview->scrollToBottom();
     } else
     {
         listview = views.value(id);
@@ -565,55 +549,6 @@ void OutputWidget::enableActions()
     }
 }
 
-void OutputWidget::rowsInserted(const QModelIndex& parent, int from, int to) {
-    if (parent.isValid()) {
-        return;
-    }
-
-    auto model = qobject_cast<QAbstractItemModel*>(sender());
-    Q_ASSERT(model);
-
-    foreach (QTreeView* view, views) {
-        if (view->model() == model) {
-            auto& data = m_scrollDelay[view];
-            if (data.from == -1) {
-                data.from = from;
-            }
-            data.to = to;
-            if (!data.timer->isActive()) {
-                data.timer->start();
-            }
-        }
-    }
-}
-
-void OutputWidget::delayedScroll()
-{
-    auto timer = qobject_cast<QTimer*>(sender());
-    Q_ASSERT(timer);
-    auto view = timer->property("view").value<QTreeView*>();
-    Q_ASSERT(view);
-    delayedScroll(view);
-}
-
-void OutputWidget::delayedScroll(QTreeView* view)
-{
-    Q_ASSERT(m_scrollDelay.contains(view));
-    auto& data = m_scrollDelay[view];
-
-    QModelIndex pre = view->model()->index(data.from - 1, 0);
-    bool scroll = !pre.isValid();
-    if (!scroll && data.to == view->model()->rowCount() - 1) {
-        auto rect = view->visualRect(pre);
-        scroll = rect.isValid() && view->viewport()->rect().intersects(rect);
-    }
-    if (scroll) {
-        view->scrollToBottom();
-    }
-
-    data.from = -1;
-}
-
 void OutputWidget::scrollToIndex( const QModelIndex& idx )
 {
     QWidget* w = currentWidget();
@@ -666,7 +601,7 @@ int OutputWidget::currentOutputIndex()
     return index;
 }
 
-void OutputWidget::outputFilter(const QString filter)
+void OutputWidget::outputFilter(const QString& filter)
 {
     QWidget* widget = currentWidget();
     if( !widget )
@@ -707,4 +642,3 @@ void OutputWidget::setTitle(int outputId, const QString& title)
     }
 }
 
-#include "outputwidget.moc"
