@@ -22,19 +22,14 @@
 #include "standardoutputview.h"
 #include "outputwidget.h"
 #include "toolviewdata.h"
+#include "debug.h"
 
-#include <QtCore/QList>
-#include <QtCore/QAbstractItemModel>
-#include <QtGui/QAction>
-#include <QtGui/QAbstractItemDelegate>
+#include <QAbstractItemDelegate>
+#include <QAbstractItemModel>
+#include <QAction>
+#include <QList>
 
-#include <kpluginfactory.h>
-#include <kpluginloader.h>
-#include <kaboutdata.h>
-#include <klocale.h>
-#include <kdebug.h>
-#include <kactioncollection.h>
-#include <kaction.h>
+#include <KLocalizedString>
 
 #include <interfaces/icore.h>
 #include <interfaces/iuicontroller.h>
@@ -44,27 +39,22 @@
 #include <sublime/controller.h>
 #include <sublime/document.h>
 
-
-K_PLUGIN_FACTORY(StandardOutputViewFactory, registerPlugin<StandardOutputView>(); )
-K_EXPORT_PLUGIN(StandardOutputViewFactory(KAboutData("kdevstandardoutputview","kdevstandardoutputview",ki18n("Output View"), "0.1", ki18n("Provides toolviews for presenting the output of running apps"), KAboutData::License_GPL)))
-
-
 class OutputViewFactory : public KDevelop::IToolViewFactory{
 public:
     OutputViewFactory(const ToolViewData* data): m_data(data) {}
-    virtual QWidget* create(QWidget *parent = 0)
+    virtual QWidget* create(QWidget *parent = 0) override
     {
         return new OutputWidget( parent, m_data );
     }
-    virtual Qt::DockWidgetArea defaultPosition()
+    virtual Qt::DockWidgetArea defaultPosition() override
     {
         return Qt::BottomDockWidgetArea;
     }
-    virtual void viewCreated( Sublime::View* view )
+    virtual void viewCreated( Sublime::View* view ) override
     {
         m_data->views << view;
     }
-    virtual QString id() const
+    virtual QString id() const override
     {
         //NOTE: id must be unique, see e.g. https://bugs.kde.org/show_bug.cgi?id=287093
         return "org.kdevelop.OutputView." + QString::number(m_data->toolViewId);
@@ -74,26 +64,14 @@ private:
 };
 
 StandardOutputView::StandardOutputView(QObject *parent, const QVariantList &)
-    : KDevelop::IPlugin(StandardOutputViewFactory::componentData(), parent)
+    : KDevelop::IPlugin("kdevstandardoutputview", parent)
 {
     KDEV_USE_EXTENSION_INTERFACE( KDevelop::IOutputView )
 
     setXMLFile("kdevstandardoutputview.rc");
-    // setup actions
-    KAction *action;
 
-    action = actionCollection()->addAction("next_error");
-    action->setText(i18n("Jump to Next Outputmark"));
-    action->setShortcut( QKeySequence(Qt::Key_F4) );
-    connect(action, SIGNAL(triggered(bool)), this, SIGNAL(selectNextItem()));
-
-    action = actionCollection()->addAction("prev_error");
-    action->setText(i18n("Jump to Previous Outputmark"));
-    action->setShortcut( QKeySequence(Qt::SHIFT | Qt::Key_F4) );
-    connect(action, SIGNAL(triggered(bool)), this, SIGNAL(selectPrevItem()));
-
-    connect(KDevelop::ICore::self()->uiController()->controller(), SIGNAL(aboutToRemoveView(Sublime::View*)),
-            this, SLOT(removeSublimeView(Sublime::View*)));
+    connect(KDevelop::ICore::self()->uiController()->controller(), &Sublime::Controller::aboutToRemoveView,
+            this, &StandardOutputView::removeSublimeView);
 
 }
 
@@ -131,27 +109,27 @@ int StandardOutputView::standardToolView( KDevelop::IOutputView::StandardToolVie
     {
         case KDevelop::IOutputView::BuildView:
         {
-            ret = registerToolView( i18nc("@title:window", "Build"), KDevelop::IOutputView::HistoryView, KIcon("run-build"), KDevelop::IOutputView::AddFilterAction );
+            ret = registerToolView( i18nc("@title:window", "Build"), KDevelop::IOutputView::HistoryView, QIcon::fromTheme("run-build"), KDevelop::IOutputView::AddFilterAction );
             break;
         }
         case KDevelop::IOutputView::RunView:
         {
-            ret = registerToolView( i18nc("@title:window", "Run"), KDevelop::IOutputView::MultipleView, KIcon("system-run"), KDevelop::IOutputView::AddFilterAction );
+            ret = registerToolView( i18nc("@title:window", "Run"), KDevelop::IOutputView::MultipleView, QIcon::fromTheme("system-run"), KDevelop::IOutputView::AddFilterAction );
             break;
         }
         case KDevelop::IOutputView::DebugView:
         {
-            ret = registerToolView( i18nc("@title:window", "Debug"), KDevelop::IOutputView::MultipleView, KIcon("debugger"), KDevelop::IOutputView::AddFilterAction );
+            ret = registerToolView( i18nc("@title:window", "Debug"), KDevelop::IOutputView::MultipleView, QIcon::fromTheme("debug-step-into"), KDevelop::IOutputView::AddFilterAction );
             break;
         }
         case KDevelop::IOutputView::TestView:
         {
-            ret = registerToolView( i18nc("@title:window", "Test"), KDevelop::IOutputView::HistoryView, KIcon("system-run"));
+            ret = registerToolView( i18nc("@title:window", "Test"), KDevelop::IOutputView::HistoryView, QIcon::fromTheme("system-run"));
             break;
         }
         case KDevelop::IOutputView::VcsView:
         {
-            ret = registerToolView( i18nc("@title:window", "Version Control"), KDevelop::IOutputView::HistoryView, KIcon("system-run"));
+            ret = registerToolView( i18nc("@title:window", "Version Control"), KDevelop::IOutputView::HistoryView, QIcon::fromTheme("system-run"));
             break;
         }
     }
@@ -163,7 +141,7 @@ int StandardOutputView::standardToolView( KDevelop::IOutputView::StandardToolVie
 
 int StandardOutputView::registerToolView( const QString& title,
                                           KDevelop::IOutputView::ViewType type,
-                                          const KIcon& icon, Options option,
+                                          const QIcon& icon, Options option,
                                           const QList<QAction*>& actionList )
 {
     // try to reuse existing toolview
@@ -176,7 +154,7 @@ int StandardOutputView::registerToolView( const QString& title,
 
     // register new tool view
     const int newid = ids.isEmpty() ? 0 : (ids.last() + 1);
-    kDebug() << "Registering view" << title << "with type:" << type << "id:" << newid;
+    qCDebug(PLUGIN_STANDARDOUTPUTVIEW) << "Registering view" << title << "with type:" << type << "id:" << newid;
     ToolViewData* tvdata = new ToolViewData( this );
     tvdata->toolViewId = newid;
     tvdata->type = type;
@@ -240,7 +218,7 @@ void StandardOutputView::setModel( int outputId, QAbstractItemModel* model )
         }
     }
     if( tvid == -1 )
-        kDebug() << "Trying to set model on unknown view-id:" << outputId;
+        qCDebug(PLUGIN_STANDARDOUTPUTVIEW) << "Trying to set model on unknown view-id:" << outputId;
     else
     {
         toolviews.value( tvid )->outputdata.value( outputId )->setModel( model );
@@ -259,7 +237,7 @@ void StandardOutputView::setDelegate( int outputId, QAbstractItemDelegate* deleg
         }
     }
     if( tvid == -1 )
-        kDebug() << "Trying to set model on unknown view-id:" << outputId;
+        qCDebug(PLUGIN_STANDARDOUTPUTVIEW) << "Trying to set model on unknown view-id:" << outputId;
     else
     {
         toolviews.value( tvid )->outputdata.value( outputId )->setDelegate( delegate );
@@ -331,4 +309,7 @@ void StandardOutputView::removeOutput( int outputId )
     }
 }
 
-#include "standardoutputview.moc"
+void StandardOutputView::setTitle(int outputId, const QString& title)
+{
+    outputWidgetForId(outputId)->setTitle(outputId, title);
+}
