@@ -12,26 +12,20 @@
 #include "kdevsvnplugin.h"
 
 #include <QAction>
-#include <QVariant>
-#include <QTextStream>
+#include <QDialog>
 #include <QMenu>
+#include <QVBoxLayout>
+#include <QVariant>
 
-#include <kparts/part.h>
-#include <kparts/partmanager.h>
-#include <kparts/mainwindow.h>
-#include <kaboutdata.h>
-#include <ktexteditor/document.h>
-#include <ktexteditor/markinterface.h>
-#include <kpluginfactory.h>
-#include <kpluginloader.h>
-#include <klocale.h>
-#include <kurlrequester.h>
-#include <kaction.h>
-#include <kurlrequesterdialog.h>
-#include <kfile.h>
-#include <ktemporaryfile.h>
-#include <kmessagebox.h>
-#include <kfiledialog.h>
+#include <KFile>
+#include <KIO/Global>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KPluginFactory>
+#include <KTextEditor/Document>
+#include <KTextEditor/MarkInterface>
+#include <KUrlRequester>
+#include <KUrlRequesterDialog>
 
 #include <interfaces/iuicontroller.h>
 #include <interfaces/idocumentcontroller.h>
@@ -46,7 +40,6 @@
 #include <vcs/vcsevent.h>
 #include <vcs/vcsstatusinfo.h>
 #include <vcs/vcsannotation.h>
-#include <vcs/widgets/vcsannotationwidget.h>
 #include <vcs/widgets/vcseventwidget.h>
 #include <vcs/widgets/vcsdiffwidget.h>
 #include <vcs/widgets/vcscommitdialog.h>
@@ -74,14 +67,17 @@
 #include <vcs/vcspluginhelper.h>
 #include <vcs/widgets/standardvcslocationwidget.h>
 #include "svnlocationwidget.h"
+#include "debug.h"
 
-K_PLUGIN_FACTORY(KDevSvnFactory, registerPlugin<KDevSvnPlugin>();)
-K_EXPORT_PLUGIN(KDevSvnFactory(KAboutData("kdevsubversion", "kdevsubversion", ki18n("Subversion"), "0.1", ki18n("Support for Subversion version control systems"), KAboutData::License_GPL)))
+Q_LOGGING_CATEGORY(PLUGIN_SVN, "kdevplatform.plugins.svn")
+K_PLUGIN_FACTORY_WITH_JSON(KDevSvnFactory, "kdevsubversion.json", registerPlugin<KDevSvnPlugin>();)
 
 KDevSvnPlugin::KDevSvnPlugin(QObject *parent, const QVariantList &)
-        : KDevelop::IPlugin(KDevSvnFactory::componentData(), parent)
-        , m_common(new KDevelop::VcsPluginHelper(this, this)),
-        copy_action( 0 ), move_action( 0 )
+        : KDevelop::IPlugin("kdevsubversion", parent)
+        , m_common(new KDevelop::VcsPluginHelper(this, this))
+        , copy_action( 0 )
+        , move_action( 0 )
+        , m_jobQueue(new ThreadWeaver::Queue(this))
 {
     KDEV_USE_EXTENSION_INTERFACE(KDevelop::IBasicVersionControl)
     KDEV_USE_EXTENSION_INTERFACE(KDevelop::ICentralizedVersionControl)
@@ -99,7 +95,7 @@ KDevSvnPlugin::~KDevSvnPlugin()
 {
 }
 
-bool KDevSvnPlugin::isVersionControlled(const KUrl& localLocation)
+bool KDevSvnPlugin::isVersionControlled(const QUrl &localLocation)
 {
     ///TODO: also check this in the other functions?
     if (!localLocation.isValid()) {
@@ -114,17 +110,17 @@ bool KDevSvnPlugin::isVersionControlled(const KUrl& localLocation)
         QVariant result = job->fetchResults();
 
         if (result.isValid()) {
-            SvnInfoHolder h = qVariantValue<SvnInfoHolder>(result);
+            SvnInfoHolder h = result.value<SvnInfoHolder>();
             return !h.name.isEmpty();
         }
     } else {
-        kDebug(9510) << "Couldn't execute job";
+        qCDebug(PLUGIN_SVN) << "Couldn't execute job";
     }
 
     return false;
 }
 
-KDevelop::VcsJob* KDevSvnPlugin::repositoryLocation(const KUrl& localLocation)
+KDevelop::VcsJob* KDevSvnPlugin::repositoryLocation(const QUrl &localLocation)
 {
     SvnInfoJob* job = new SvnInfoJob(this);
 
@@ -133,7 +129,7 @@ KDevelop::VcsJob* KDevSvnPlugin::repositoryLocation(const KUrl& localLocation)
     return job;
 }
 
-KDevelop::VcsJob* KDevSvnPlugin::status(const KUrl::List& localLocations,
+KDevelop::VcsJob* KDevSvnPlugin::status(const QList<QUrl>& localLocations,
                                         KDevelop::IBasicVersionControl::RecursionMode mode)
 {
     SvnStatusJob* job = new SvnStatusJob(this);
@@ -142,7 +138,7 @@ KDevelop::VcsJob* KDevSvnPlugin::status(const KUrl::List& localLocations,
     return job;
 }
 
-KDevelop::VcsJob* KDevSvnPlugin::add(const KUrl::List& localLocations,
+KDevelop::VcsJob* KDevSvnPlugin::add(const QList<QUrl>& localLocations,
                                      KDevelop::IBasicVersionControl::RecursionMode recursion)
 {
     SvnAddJob* job = new SvnAddJob(this);
@@ -151,24 +147,24 @@ KDevelop::VcsJob* KDevSvnPlugin::add(const KUrl::List& localLocations,
     return job;
 }
 
-KDevelop::VcsJob* KDevSvnPlugin::remove(const KUrl::List& localLocations)
+KDevelop::VcsJob* KDevSvnPlugin::remove(const QList<QUrl>& localLocations)
 {
     SvnRemoveJob* job = new SvnRemoveJob(this);
     job->setLocations(localLocations);
     return job;
 }
 
-KDevelop::VcsJob* KDevSvnPlugin::edit(const KUrl& /*localLocation*/)
+KDevelop::VcsJob* KDevSvnPlugin::edit(const QUrl& /*localLocation*/)
 {
     return 0;
 }
 
-KDevelop::VcsJob* KDevSvnPlugin::unedit(const KUrl& /*localLocation*/)
+KDevelop::VcsJob* KDevSvnPlugin::unedit(const QUrl& /*localLocation*/)
 {
     return 0;
 }
 
-KDevelop::VcsJob* KDevSvnPlugin::localRevision(const KUrl& localLocation, KDevelop::VcsRevision::RevisionType type)
+KDevelop::VcsJob* KDevSvnPlugin::localRevision(const QUrl &localLocation, KDevelop::VcsRevision::RevisionType type)
 {
     SvnInfoJob* job = new SvnInfoJob(this);
 
@@ -178,7 +174,7 @@ KDevelop::VcsJob* KDevSvnPlugin::localRevision(const KUrl& localLocation, KDevel
     return job;
 }
 
-KDevelop::VcsJob* KDevSvnPlugin::copy(const KUrl& localLocationSrc, const KUrl& localLocationDstn)
+KDevelop::VcsJob* KDevSvnPlugin::copy(const QUrl &localLocationSrc, const QUrl& localLocationDstn)
 {
     SvnCopyJob* job = new SvnCopyJob(this);
     job->setSourceLocation(localLocationSrc);
@@ -186,7 +182,7 @@ KDevelop::VcsJob* KDevSvnPlugin::copy(const KUrl& localLocationSrc, const KUrl&
     return job;
 }
 
-KDevelop::VcsJob* KDevSvnPlugin::move(const KUrl& localLocationSrc, const KUrl& localLocationDst)
+KDevelop::VcsJob* KDevSvnPlugin::move(const QUrl &localLocationSrc, const QUrl& localLocationDst)
 {
     SvnMoveJob* job = new SvnMoveJob(this);
     job->setSourceLocation(localLocationSrc);
@@ -194,7 +190,7 @@ KDevelop::VcsJob* KDevSvnPlugin::move(const KUrl& localLocationSrc, const KUrl&
     return job;
 }
 
-KDevelop::VcsJob* KDevSvnPlugin::revert(const KUrl::List& localLocations,
+KDevelop::VcsJob* KDevSvnPlugin::revert(const QList<QUrl>& localLocations,
                                         KDevelop::IBasicVersionControl::RecursionMode recursion)
 {
     SvnRevertJob* job = new SvnRevertJob(this);
@@ -203,7 +199,7 @@ KDevelop::VcsJob* KDevSvnPlugin::revert(const KUrl::List& localLocations,
     return job;
 }
 
-KDevelop::VcsJob* KDevSvnPlugin::update(const KUrl::List& localLocations,
+KDevelop::VcsJob* KDevSvnPlugin::update(const QList<QUrl>& localLocations,
                                         const KDevelop::VcsRevision& rev,
                                         KDevelop::IBasicVersionControl::RecursionMode recursion)
 {
@@ -214,18 +210,18 @@ KDevelop::VcsJob* KDevSvnPlugin::update(const KUrl::List& localLocations,
     return job;
 }
 
-KDevelop::VcsJob* KDevSvnPlugin::commit(const QString& message, const KUrl::List& localLocations,
+KDevelop::VcsJob* KDevSvnPlugin::commit(const QString& message, const QList<QUrl>& localLocations,
                                         KDevelop::IBasicVersionControl::RecursionMode recursion)
 {
     SvnCommitJob* job = new SvnCommitJob(this);
-    kDebug(9510) << "Committing locations:" << localLocations << endl;
+    qCDebug(PLUGIN_SVN) << "Committing locations:" << localLocations << endl;
     job->setUrls(localLocations);
     job->setCommitMessage(message) ;
     job->setRecursive((recursion == KDevelop::IBasicVersionControl::Recursive));
     return job;
 }
 
-KDevelop::VcsJob* KDevSvnPlugin::diff(const KUrl& fileOrDirectory,
+KDevelop::VcsJob* KDevSvnPlugin::diff(const QUrl &fileOrDirectory,
                                       const KDevelop::VcsRevision& srcRevision,
                                       const KDevelop::VcsRevision& dstRevision,
                                       KDevelop::VcsDiff::Type diffType,
@@ -252,7 +248,7 @@ KDevelop::VcsJob* KDevSvnPlugin::diff2(const KDevelop::VcsLocation& src,
     return job;
 }
 
-KDevelop::VcsJob* KDevSvnPlugin::log(const KUrl& localLocation, const KDevelop::VcsRevision& rev, unsigned long limit)
+KDevelop::VcsJob* KDevSvnPlugin::log(const QUrl &localLocation, const KDevelop::VcsRevision& rev, unsigned long limit)
 {
     SvnLogJob* job = new SvnLogJob(this);
     job->setLocation(localLocation);
@@ -261,7 +257,7 @@ KDevelop::VcsJob* KDevSvnPlugin::log(const KUrl& localLocation, const KDevelop::
     return job;
 }
 
-KDevelop::VcsJob* KDevSvnPlugin::log(const KUrl& localLocation,
+KDevelop::VcsJob* KDevSvnPlugin::log(const QUrl &localLocation,
                                      const KDevelop::VcsRevision& startRev,
                                      const KDevelop::VcsRevision& endRev)
 {
@@ -272,7 +268,7 @@ KDevelop::VcsJob* KDevSvnPlugin::log(const KUrl& localLocation,
     return job;
 }
 
-KDevelop::VcsJob* KDevSvnPlugin::annotate(const KUrl& localLocation,
+KDevelop::VcsJob* KDevSvnPlugin::annotate(const QUrl &localLocation,
         const KDevelop::VcsRevision& rev)
 {
     SvnBlameJob* job = new SvnBlameJob(this);
@@ -285,7 +281,7 @@ KDevelop::VcsJob* KDevSvnPlugin::merge(const KDevelop::VcsLocation& localOrRepoL
                                        const KDevelop::VcsLocation& localOrRepoLocationDst,
                                        const KDevelop::VcsRevision& srcRevision,
                                        const KDevelop::VcsRevision& dstRevision,
-                                       const KUrl& localLocation)
+                                       const QUrl &localLocation)
 {
     // TODO implement merge
     Q_UNUSED(localOrRepoLocationSrc)
@@ -296,13 +292,13 @@ KDevelop::VcsJob* KDevSvnPlugin::merge(const KDevelop::VcsLocation& localOrRepoL
     return 0;
 }
 
-KDevelop::VcsJob* KDevSvnPlugin::resolve(const KUrl::List& /*localLocations*/,
+KDevelop::VcsJob* KDevSvnPlugin::resolve(const QList<QUrl>& /*localLocations*/,
         KDevelop::IBasicVersionControl::RecursionMode /*recursion*/)
 {
     return 0;
 }
 
-KDevelop::VcsJob* KDevSvnPlugin::import(const QString & commitMessage, const KUrl & sourceDirectory, const KDevelop::VcsLocation & destinationRepository)
+KDevelop::VcsJob* KDevSvnPlugin::import(const QString & commitMessage, const QUrl &sourceDirectory, const KDevelop::VcsLocation & destinationRepository)
 {
     SvnImportJob* job = new SvnImportJob(this);
     job->setMapping(sourceDirectory, destinationRepository);
@@ -310,7 +306,7 @@ KDevelop::VcsJob* KDevSvnPlugin::import(const QString & commitMessage, const KUr
     return job;
 }
 
-KDevelop::VcsJob* KDevSvnPlugin::createWorkingCopy(const KDevelop::VcsLocation & sourceRepository, const KUrl & destinationDirectory, KDevelop::IBasicVersionControl::RecursionMode recursion)
+KDevelop::VcsJob* KDevSvnPlugin::createWorkingCopy(const KDevelop::VcsLocation & sourceRepository, const QUrl &destinationDirectory, KDevelop::IBasicVersionControl::RecursionMode recursion)
 {
     SvnCheckoutJob* job = new SvnCheckoutJob(this);
     job->setMapping(sourceRepository, destinationDirectory, recursion);
@@ -322,17 +318,17 @@ KDevelop::ContextMenuExtension KDevSvnPlugin::contextMenuExtension(KDevelop::Con
 {
     m_common->setupFromContext(context);
 
-    const KUrl::List & ctxUrlList  = m_common->contextUrlList();
+    const QList<QUrl> & ctxUrlList  = m_common->contextUrlList();
 
     bool hasVersionControlledEntries = false;
-    foreach(const KUrl &url, ctxUrlList) {
-        if (isVersionControlled(url) || isVersionControlled(url.upUrl())) {
+    foreach(const QUrl &url, ctxUrlList) {
+        if (isVersionControlled(url) || isVersionControlled(KIO::upUrl(url))) {
             hasVersionControlledEntries = true;
             break;
         }
     }
 
-    kDebug() << "version controlled?" << hasVersionControlledEntries;
+    qCDebug(PLUGIN_SVN) << "version controlled?" << hasVersionControlledEntries;
 
     if (!hasVersionControlledEntries)
         return IPlugin::contextMenuExtension(context);
@@ -340,17 +336,17 @@ KDevelop::ContextMenuExtension KDevSvnPlugin::contextMenuExtension(KDevelop::Con
 
     QMenu* svnmenu= m_common->commonActions();
     svnmenu->addSeparator();
-    
+
     if( !copy_action )
     {
-        copy_action = new KAction(i18n("Copy..."), this);
+        copy_action = new QAction(i18n("Copy..."), this);
         connect(copy_action, SIGNAL(triggered()), this, SLOT(ctxCopy()));
     }
     svnmenu->addAction(copy_action);
 
     if( !move_action )
     {
-        move_action = new KAction(i18n("Move..."), this);
+        move_action = new QAction(i18n("Move..."), this);
         connect(move_action, SIGNAL(triggered()), this, SLOT(ctxMove()));
     }
     svnmenu->addAction(move_action);
@@ -363,7 +359,7 @@ KDevelop::ContextMenuExtension KDevSvnPlugin::contextMenuExtension(KDevelop::Con
 
 void KDevSvnPlugin::ctxInfo()
 {
-    KUrl::List const & ctxUrlList = m_common->contextUrlList();
+    QList<QUrl> const & ctxUrlList = m_common->contextUrlList();
     if (ctxUrlList.count() != 1) {
         KMessageBox::error(0, i18n("Please select only one item for this operation"));
         return;
@@ -372,7 +368,7 @@ void KDevSvnPlugin::ctxInfo()
 
 void KDevSvnPlugin::ctxStatus()
 {
-    KUrl::List const & ctxUrlList = m_common->contextUrlList();
+    QList<QUrl> const & ctxUrlList = m_common->contextUrlList();
     if (ctxUrlList.count() > 1) {
         KMessageBox::error(0, i18n("Please select only one item for this operation"));
         return;
@@ -381,20 +377,20 @@ void KDevSvnPlugin::ctxStatus()
 
 void KDevSvnPlugin::ctxCopy()
 {
-    KUrl::List const & ctxUrlList = m_common->contextUrlList();
+    QList<QUrl> const & ctxUrlList = m_common->contextUrlList();
     if (ctxUrlList.count() > 1) {
         KMessageBox::error(0, i18n("Please select only one item for this operation"));
         return;
     }
 
-    KUrl source = ctxUrlList.first();
+    QUrl source = ctxUrlList.first();
 
     if (source.isLocalFile()) {
-        QString dir = source.toLocalFile();
+        QUrl dir = source;
         bool isFile = QFileInfo(source.toLocalFile()).isFile();
 
         if (isFile) {
-            dir = source.directory();
+            dir = dir.adjusted(QUrl::RemoveFilename|QUrl::StripTrailingSlash);
         }
 
         KUrlRequesterDialog dlg(dir, i18n("Destination file/directory"), 0);
@@ -417,25 +413,24 @@ void KDevSvnPlugin::ctxCopy()
 
 void KDevSvnPlugin::ctxMove()
 {
-    KUrl::List const & ctxUrlList = m_common->contextUrlList();
+    QList<QUrl> const & ctxUrlList = m_common->contextUrlList();
     if (ctxUrlList.count() != 1) {
         KMessageBox::error(0, i18n("Please select only one item for this operation"));
         return;
     }
 
-    KUrl source = ctxUrlList.first();
+    QUrl source = ctxUrlList.first();
 
     if (source.isLocalFile()) {
-        QString dir = source.toLocalFile();
+        QUrl dir = source;
         bool isFile = QFileInfo(source.toLocalFile()).isFile();
 
         if (isFile) {
-            dir = source.directory();
+            dir = source.adjusted(QUrl::RemoveFilename|QUrl::StripTrailingSlash);
         }
 
         KUrlRequesterDialog dlg(dir, i18n("Destination file/directory"), 0);
 
-        dlg.fileDialog()->setOperationMode( KFileDialog::Saving );
         if (isFile) {
             dlg.urlRequester()->setMode(KFile::File | KFile::Directory | KFile::LocalOnly);
         } else {
@@ -453,7 +448,7 @@ void KDevSvnPlugin::ctxMove()
 
 void KDevSvnPlugin::ctxCat()
 {
-    KUrl::List const & ctxUrlList = m_common->contextUrlList();
+    QList<QUrl> const & ctxUrlList = m_common->contextUrlList();
     if (ctxUrlList.count() != 1) {
         KMessageBox::error(0, i18n("Please select only one item for this operation"));
         return;
@@ -472,19 +467,25 @@ KDevelop::VcsImportMetadataWidget* KDevSvnPlugin::createImportMetadataWidget(QWi
 
 void KDevSvnPlugin::ctxImport()
 {
-    KUrl::List const & ctxUrlList = m_common->contextUrlList();
+    QList<QUrl> const & ctxUrlList = m_common->contextUrlList();
     if (ctxUrlList.count() != 1) {
         KMessageBox::error(0, i18n("Please select only one item for this operation"));
         return;
     }
 
-    KDialog dlg;
+    QDialog dlg;
 
-    dlg.setCaption(i18n("Import into Subversion repository"));
+    dlg.setWindowTitle(i18n("Import into Subversion repository"));
     SvnImportMetadataWidget* widget = new SvnImportMetadataWidget(&dlg);
     widget->setSourceLocation(KDevelop::VcsLocation(ctxUrlList.first()));
     widget->setSourceLocationEditable(false);
-    dlg.setMainWidget(widget);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
+    auto layout = new QVBoxLayout();
+    dlg.setLayout(layout);
+    layout->addWidget(widget);
+    layout->addWidget(buttonBox);
+    connect(buttonBox, &QDialogButtonBox::accepted, &dlg, &QDialog::accept);
+    connect(buttonBox, &QDialogButtonBox::rejected, &dlg, &QDialog::reject);
 
     if (dlg.exec() == QDialog::Accepted) {
         KDevelop::ICore::self()->runController()->registerJob(import(widget->message(), widget->source(), widget->destination()));
@@ -493,20 +494,25 @@ void KDevSvnPlugin::ctxImport()
 
 void KDevSvnPlugin::ctxCheckout()
 {
-    KUrl::List const & ctxUrlList = m_common->contextUrlList();
+    QList<QUrl> const & ctxUrlList = m_common->contextUrlList();
     if (ctxUrlList.count() != 1) {
         KMessageBox::error(0, i18n("Please select only one item for this operation"));
         return;
     }
 
-    KDialog dlg;
+    QDialog dlg;
 
-    dlg.setCaption(i18n("Checkout from Subversion repository"));
+    dlg.setWindowTitle(i18n("Checkout from Subversion repository"));
     SvnCheckoutMetadataWidget* widget = new SvnCheckoutMetadataWidget(&dlg);
-    KUrl tmp = ctxUrlList.first();
-    tmp.cd("..");
+    QUrl tmp = KIO::upUrl(ctxUrlList.first());
     widget->setDestinationLocation(tmp);
-    dlg.setMainWidget(widget);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
+    auto layout = new QVBoxLayout();
+    dlg.setLayout(layout);
+    layout->addWidget(widget);
+    layout->addWidget(buttonBox);
+    connect(buttonBox, &QDialogButtonBox::accepted, &dlg, &QDialog::accept);
+    connect(buttonBox, &QDialogButtonBox::rejected, &dlg, &QDialog::reject);
 
     if (dlg.exec() == QDialog::Accepted) {
         KDevelop::ICore::self()->runController()->registerJob(createWorkingCopy(widget->source(), widget->destination(), widget->recursionMode()));
@@ -518,4 +524,9 @@ KDevelop::VcsLocationWidget* KDevSvnPlugin::vcsLocation(QWidget* parent) const
     return new SvnLocationWidget(parent);
 }
 
+ThreadWeaver::Queue* KDevSvnPlugin::jobQueue() const
+{
+    return m_jobQueue;
+}
+
 #include "kdevsvnplugin.moc"
