@@ -23,11 +23,11 @@ class SvnCheckoutMetadataWidget : public QWidget
 {
     Q_OBJECT
 public:
-    SvnCheckoutMetadataWidget( QWidget *parent );
+    explicit SvnCheckoutMetadataWidget( QWidget *parent );
     virtual ~SvnCheckoutMetadataWidget();
-    void setDestinationLocation( const KUrl& );
+    void setDestinationLocation( const QUrl& );
     virtual KDevelop::VcsLocation source() const;
-    virtual KUrl destination() const;
+    virtual QUrl destination() const;
     virtual KDevelop::IBasicVersionControl::RecursionMode recursionMode() const;
 
 private:
