@@ -27,9 +27,7 @@
 #include <QStringList>
 #include <QFileInfo>
 
-#include <kdebug.h>
-#include <klocale.h>
-#include <ThreadWeaver.h>
+#include <KLocalizedString>
 
 #include <vcs/vcsrevision.h>
 
@@ -46,14 +44,14 @@
 ///           takes those headers, and moves them into the correct place to create a valid working diff.
 ///           Find the source of this problem.
 QString repairDiff(QString diff) {
-    kDebug() << "diff before repair:" << diff;
+    qCDebug(PLUGIN_SVN) << "diff before repair:" << diff;
     QStringList lines = diff.split('\n');
     QMap<QString, QString> headers;
     for(int a = 0; a < lines.size()-1; ++a) {
         if(lines[a].startsWith("Index: ") && lines[a+1].startsWith("=====")) {
             QString fileName = lines[a].mid(strlen("Index: ")).trimmed();
             headers[fileName] = lines[a];
-            kDebug() << "found header for" << fileName;
+            qCDebug(PLUGIN_SVN) << "found header for" << fileName;
             lines[a] = QString();
             if(lines[a+1].startsWith("======")) {
                 headers[fileName] += '\n' + lines[a+1];
@@ -61,24 +59,24 @@ QString repairDiff(QString diff) {
             }
         }
     }
-    
+
     QRegExp spaceRegExp("\\s");
-    
+
     for(int a = 0; a < lines.size()-1; ++a) {
         if(lines[a].startsWith("--- ")) {
             QString tail = lines[a].mid(strlen("--- "));
             if(tail.indexOf(spaceRegExp) != -1) {
                 QString file = tail.left(tail.indexOf(spaceRegExp));
-                kDebug() << "checking for" << file;
+                qCDebug(PLUGIN_SVN) << "checking for" << file;
                 if(headers.contains(file)) {
-                    kDebug() << "adding header for" << file << ":" << headers[file];
+                    qCDebug(PLUGIN_SVN) << "adding header for" << file << ":" << headers[file];
                     lines[a] = headers[file] + '\n' + lines[a];
                 }
             }
         }
     }
     QString ret = lines.join("\n");
-    kDebug() << "repaired diff:" << ret;
+    qCDebug(PLUGIN_SVN) << "repaired diff:" << ret;
     return ret;
 }
 
@@ -93,7 +91,7 @@ SvnInternalDiffJob::SvnInternalDiffJob( SvnJobBase* parent )
                                     KDevelop::VcsRevision::Special );
 }
 
-void SvnInternalDiffJob::run()
+void SvnInternalDiffJob::run(ThreadWeaver::JobPointer /*self*/, ThreadWeaver::Thread* /*thread*/)
 {
     initBeforeRun();
 
@@ -107,14 +105,7 @@ void SvnInternalDiffJob::run()
             QByteArray srcba;
             if( source().type() == KDevelop::VcsLocation::LocalLocation )
             {
-                KUrl url = source().localUrl();
-                if( url.isLocalFile() )
-                {
-                    srcba = url.toLocalFile( KUrl::RemoveTrailingSlash ).toUtf8();
-                }else
-                {
-                    srcba = url.url( KUrl::RemoveTrailingSlash ).toUtf8();
-                }
+                srcba = source().localUrl().toString( QUrl::PreferLocalFile | QUrl::StripTrailingSlash ).toUtf8();
             }else
             {
                 srcba = source().repositoryServer().toUtf8();
@@ -122,14 +113,7 @@ void SvnInternalDiffJob::run()
             QByteArray dstba;
             if( destination().type() == KDevelop::VcsLocation::LocalLocation )
             {
-                KUrl url = destination().localUrl();
-                if( url.isLocalFile() )
-                {
-                    dstba = url.toLocalFile( KUrl::RemoveTrailingSlash ).toUtf8();
-                }else
-                {
-                    dstba = url.url().toUtf8();
-                }
+                dstba = destination().localUrl().toString( QUrl::PreferLocalFile | QUrl::StripTrailingSlash ).toUtf8();
             }else
             {
                 dstba = destination().repositoryServer().toUtf8();
@@ -149,14 +133,7 @@ void SvnInternalDiffJob::run()
             QByteArray srcba;
             if( source().type() == KDevelop::VcsLocation::LocalLocation )
             {
-                KUrl url = source().localUrl();
-                if( url.isLocalFile() )
-                {
-                    srcba = url.toLocalFile( KUrl::RemoveTrailingSlash ).toUtf8();
-                }else
-                {
-                    srcba = url.url().toUtf8();
-                }
+                srcba = source().localUrl().toString( QUrl::PreferLocalFile | QUrl::StripTrailingSlash ).toUtf8();
             }else
             {
                 srcba = source().repositoryServer().toUtf8();
@@ -170,7 +147,6 @@ void SvnInternalDiffJob::run()
             {
                 throw svn::ClientException( "Not enough information for a diff");
             }
-            //@TODO: Make sure there's no diff-cmd set via the users configuration file, can be done only via C api
             diff = cli.diff( svn::Path( srcba.data() ), pegRev, srcRev,
                              dstRev, recursive(), ignoreAncestry(),
                              noDiffOnDelete(), ignoreContentType() );
@@ -180,7 +156,7 @@ void SvnInternalDiffJob::run()
 
     }catch( svn::ClientException ce )
     {
-        kDebug(9510) << "Exception while doing a diff: "
+        qCDebug(PLUGIN_SVN) << "Exception while doing a diff: "
                 << m_source.localUrl() << m_source.repositoryServer() << m_srcRevision.prettyValue()
                 << m_destination.localUrl() << m_destination.repositoryServer() << m_dstRevision.prettyValue()
                 << QString::fromUtf8( ce.message() );
@@ -192,101 +168,102 @@ void SvnInternalDiffJob::run()
 
 void SvnInternalDiffJob::setSource( const KDevelop::VcsLocation& src )
 {
-    QMutexLocker l( m_mutex );
+    QMutexLocker l( &m_mutex );
     m_source = src;
 }
 void SvnInternalDiffJob::setDestination( const KDevelop::VcsLocation& dst )
 {
-    QMutexLocker l( m_mutex );
+    QMutexLocker l( &m_mutex );
     m_destination = dst;
 }
 void SvnInternalDiffJob::setSrcRevision( const KDevelop::VcsRevision& srcRev )
 {
-    QMutexLocker l( m_mutex );
+    QMutexLocker l( &m_mutex );
     m_srcRevision = srcRev;
 }
 void SvnInternalDiffJob::setDstRevision( const KDevelop::VcsRevision& dstRev )
 {
-    QMutexLocker l( m_mutex );
+    QMutexLocker l( &m_mutex );
     m_dstRevision = dstRev;
 }
 void SvnInternalDiffJob::setPegRevision( const KDevelop::VcsRevision& pegRev )
 {
-    QMutexLocker l( m_mutex );
+    QMutexLocker l( &m_mutex );
     m_pegRevision = pegRev;
 }
 void SvnInternalDiffJob::setRecursive( bool recursive )
 {
-    QMutexLocker l( m_mutex );
+    QMutexLocker l( &m_mutex );
     m_recursive = recursive;
 }
 void SvnInternalDiffJob::setIgnoreAncestry( bool ignoreAncestry )
 {
-    QMutexLocker l( m_mutex );
+    QMutexLocker l( &m_mutex );
     m_ignoreAncestry = ignoreAncestry;
 }
 void SvnInternalDiffJob::setIgnoreContentType( bool ignoreContentType )
 {
-    QMutexLocker l( m_mutex );
+    QMutexLocker l( &m_mutex );
     m_ignoreContentType = ignoreContentType;
 }
 void SvnInternalDiffJob::setNoDiffOnDelete( bool noDiffOnDelete )
 {
-    QMutexLocker l( m_mutex );
+    QMutexLocker l( &m_mutex );
     m_noDiffOnDelete = noDiffOnDelete;
 }
 
 bool SvnInternalDiffJob::recursive() const
 {
-    QMutexLocker l( m_mutex );
+    QMutexLocker l( &m_mutex );
     return m_recursive;
 }
 bool SvnInternalDiffJob::ignoreAncestry() const
 {
-    QMutexLocker l( m_mutex );
+    QMutexLocker l( &m_mutex );
     return m_ignoreAncestry;
 }
 bool SvnInternalDiffJob::ignoreContentType() const
 {
-    QMutexLocker l( m_mutex );
+    QMutexLocker l( &m_mutex );
     return m_ignoreContentType;
 }
 bool SvnInternalDiffJob::noDiffOnDelete() const
 {
-    QMutexLocker l( m_mutex );
+    QMutexLocker l( &m_mutex );
     return m_noDiffOnDelete;
 }
 KDevelop::VcsLocation SvnInternalDiffJob::source() const
 {
-    QMutexLocker l( m_mutex );
+    QMutexLocker l( &m_mutex );
     return m_source;
 }
 KDevelop::VcsLocation SvnInternalDiffJob::destination() const
 {
-    QMutexLocker l( m_mutex );
+    QMutexLocker l( &m_mutex );
     return m_destination;
 }
 KDevelop::VcsRevision SvnInternalDiffJob::srcRevision() const
 {
-    QMutexLocker l( m_mutex );
+    QMutexLocker l( &m_mutex );
     return m_srcRevision;
 }
 KDevelop::VcsRevision SvnInternalDiffJob::dstRevision() const
 {
-    QMutexLocker l( m_mutex );
+    QMutexLocker l( &m_mutex );
     return m_dstRevision;
 }
 KDevelop::VcsRevision SvnInternalDiffJob::pegRevision() const
 {
-    QMutexLocker l( m_mutex );
+    QMutexLocker l( &m_mutex );
     return m_pegRevision;
 }
 
 SvnDiffJob::SvnDiffJob( KDevSvnPlugin* parent )
-    : SvnJobBase( parent, KDevelop::OutputJob::Silent )
+    : SvnJobBaseImpl( parent, KDevelop::OutputJob::Silent )
 {
     setType( KDevelop::VcsJob::Add );
-    m_job = new SvnInternalDiffJob( this );
+    connect( m_job, &SvnInternalDiffJob::gotDiff,
+                this, &SvnDiffJob::setDiff, Qt::QueuedConnection );
 
     setObjectName(i18n("Subversion Diff"));
 }
@@ -298,30 +275,19 @@ QVariant SvnDiffJob::fetchResults()
 
 void SvnDiffJob::start()
 {
-
-    disconnect( m_job, SIGNAL(done(ThreadWeaver::Job*)), this, SLOT(internalJobDone(ThreadWeaver::Job*)) );
     if( !m_job->source().isValid()
          || ( !m_job->destination().isValid() &&
                 ( m_job->srcRevision().revisionType() == KDevelop::VcsRevision::Invalid
                  || m_job->dstRevision().revisionType() == KDevelop::VcsRevision::Invalid ) )
       )
     {
-        internalJobFailed( m_job );
+        internalJobFailed();
         setErrorText( i18n( "Not enough information given to execute diff" ) );
-    }else
-    {
-        connect( m_job, SIGNAL(gotDiff(QString)),
-                 this, SLOT(setDiff(QString)),
-                 Qt::QueuedConnection );
-        ThreadWeaver::Weaver::instance()->enqueue( m_job );
+    } else {
+        startInternalJob();
     }
 }
 
-SvnInternalJobBase* SvnDiffJob::internalJob() const
-{
-    return m_job;
-}
-
 void SvnDiffJob::setSource( const KDevelop::VcsLocation& source )
 {
     if( status() == KDevelop::VcsJob::JobNotStarted )
@@ -372,7 +338,7 @@ void SvnDiffJob::setNoDiffOnDelete( bool noDiffOnDelete )
 void SvnDiffJob::setDiff( const QString& diff )
 {
     m_diff = KDevelop::VcsDiff();
-    m_diff.setBaseDiff(KUrl("/"));
+    m_diff.setBaseDiff(QUrl::fromLocalFile("/"));
     m_diff.setType( KDevelop::VcsDiff::DiffUnified );
 
     m_diff.setContentType( KDevelop::VcsDiff::Text );
@@ -390,7 +356,7 @@ void SvnDiffJob::setDiff( const QString& diff )
     }
 
     if (paths.isEmpty()) {
-        internalJobDone( m_job );
+        internalJobDone();
         emit resultsReady( this );
         return;
     }
@@ -403,10 +369,10 @@ void SvnDiffJob::setDiff( const QString& diff )
             KDevelop::VcsLocation l = m_job->source();
             if( l.type() == KDevelop::VcsLocation::LocalLocation )
             {
-                l.setLocalUrl( KUrl( s ) );
+                l.setLocalUrl( QUrl::fromLocalFile( s ) );
             }else
             {
-                QString repoLocation = KUrl( l.repositoryServer() ).toLocalFile( KUrl::RemoveTrailingSlash );
+                QString repoLocation = QUrl( l.repositoryServer() ).toString( QUrl::PreferLocalFile | QUrl::StripTrailingSlash );
                 QFileInfo fi( repoLocation );
                 if( s == fi.fileName() )
                 {
@@ -442,7 +408,7 @@ void SvnDiffJob::addLeftText( KDevelop::VcsJob* job )
     }
     if( m_catJobMap.isEmpty() )
     {
-        internalJobDone( m_job );
+        internalJobDone();
         emit resultsReady( this );
     }
 }
@@ -464,7 +430,7 @@ void SvnDiffJob::removeJob( KJob* job )
 
     if( m_catJobMap.isEmpty() )
     {
-        internalJobDone( m_job );
+        internalJobDone();
         emit resultsReady( this );
     }
 }
@@ -473,8 +439,3 @@ void SvnDiffJob::setDiffType( KDevelop::VcsDiff::Type type )
 {
     m_diffType = type;
 }
-
-#include "svndiffjob.moc"
-#include "svndiffjob_p.moc"
-
-
