@@ -27,9 +27,7 @@
 
 #include <iostream>
 
-#include <ThreadWeaver.h>
-#include <klocale.h>
-#include <kdebug.h>
+#include <KLocalizedString>
 
 extern "C" {
 #include <svn_auth.h>
@@ -43,17 +41,16 @@ extern "C" {
 #include "kdevsvncpp/revision.hpp"
 
 SvnInternalJobBase::SvnInternalJobBase( SvnJobBase* parent )
-    : ThreadWeaver::Job( parent ), m_ctxt( new svn::Context() ),
-      m_guiSemaphore( 0 ), m_mutex( new QMutex() ), m_killMutex( new QMutex() ),
-      m_success( true ), sendFirstDelta( false ), killed( false )
+    : QObject(parent)
+    , m_ctxt( new svn::Context() )
+    , m_guiSemaphore( 0 )
+    , m_mutex()
+    , m_killMutex()
+    , m_success( true )
+    , sendFirstDelta( false )
+    , killed( false )
 {
     m_ctxt->setListener(this);
-    connect( this, SIGNAL(failed(ThreadWeaver::Job*)),
-             parent, SLOT(internalJobFailed(ThreadWeaver::Job*)), Qt::QueuedConnection );
-    connect( this, SIGNAL(done(ThreadWeaver::Job*)),
-             parent, SLOT(internalJobDone(ThreadWeaver::Job*)), Qt::QueuedConnection );
-    connect( this, SIGNAL(started(ThreadWeaver::Job*)),
-             parent, SLOT(internalJobStarted(ThreadWeaver::Job*)), Qt::QueuedConnection );
 }
 
 SvnInternalJobBase::~SvnInternalJobBase()
@@ -63,6 +60,21 @@ SvnInternalJobBase::~SvnInternalJobBase()
     m_ctxt = 0;
 }
 
+void SvnInternalJobBase::defaultBegin(const ThreadWeaver::JobPointer& self, ThreadWeaver::Thread *thread)
+{
+    emit started();
+    ThreadWeaver::Job::defaultBegin(self, thread);
+}
+
+void SvnInternalJobBase::defaultEnd(const ThreadWeaver::JobPointer& self, ThreadWeaver::Thread *thread)
+{
+    ThreadWeaver::Job::defaultEnd(self, thread);
+    if (!self->success()) {
+        emit failed();
+    }
+    emit done();
+}
+
 bool SvnInternalJobBase::contextGetLogin( const std::string& realm,
                         std::string& username, std::string& password,
                         bool& maySave )
@@ -70,7 +82,7 @@ bool SvnInternalJobBase::contextGetLogin( const std::string& realm,
 
     emit needLogin( QString::fromUtf8( realm.c_str() )  );
     m_guiSemaphore.acquire( 1 );
-    QMutexLocker l(m_mutex);
+    QMutexLocker l(&m_mutex);
     if( m_login_username.isEmpty() || m_login_password.isEmpty() )
         return false;
     username = std::string( m_login_username.toUtf8() );
@@ -130,7 +142,7 @@ void SvnInternalJobBase::contextNotify( const char* path, svn_wc_notify_action_t
                         || contentState == svn_wc_notify_state_unknown)
                         && (propState == svn_wc_notify_state_unchanged
                         || propState == svn_wc_notify_state_unknown)))
-                    notifyString += QString( " " ) + QString::fromUtf8( path );
+                    notifyString += QStringLiteral( " " ) + QString::fromUtf8( path );
 
             }
             break;
@@ -191,7 +203,7 @@ void SvnInternalJobBase::contextNotify( const char* path, svn_wc_notify_action_t
 
 bool SvnInternalJobBase::contextCancel()
 {
-    QMutexLocker lock( m_killMutex );
+    QMutexLocker lock( &m_killMutex );
     return killed;
 }
 
@@ -199,7 +211,7 @@ bool SvnInternalJobBase::contextGetLogMessage( std::string& msg )
 {
     emit needCommitMessage();
     m_guiSemaphore.acquire( 1 );
-    QMutexLocker l( m_mutex );
+    QMutexLocker l( &m_mutex );
     QByteArray ba = m_commitMessage.toUtf8();
     msg = std::string( ba.data() );
     return true;
@@ -266,7 +278,7 @@ svn::ContextListener::SslServerTrustAnswer SvnInternalJobBase::contextSslServerT
                                      QString::fromUtf8( issue.c_str() ),
                                      QString::fromUtf8( realm.c_str() ) );
     m_guiSemaphore.acquire(1);
-    QMutexLocker l(m_mutex);
+    QMutexLocker l(&m_mutex);
     return m_trustAnswer;
 }
 
@@ -356,22 +368,21 @@ svn::Revision SvnInternalJobBase::createSvnCppRevisionFromVcsRevision( const KDe
 
 void SvnInternalJobBase::setErrorMessage( const QString& msg )
 {
-    QMutexLocker lock( m_mutex );
+    QMutexLocker lock( &m_mutex );
     m_errorMessage = msg;
 }
 
 QString SvnInternalJobBase::errorMessage() const
 {
-    QMutexLocker lock( m_mutex );
+    QMutexLocker lock( &m_mutex );
     return m_errorMessage;
 }
 
 void SvnInternalJobBase::kill()
 {
-    QMutexLocker lock( m_killMutex );
+    QMutexLocker lock( &m_killMutex );
     killed = true;
 }
 
 
 
-#include "svninternaljobbase.moc"
