@@ -27,16 +27,16 @@ class SvnInternalRevertJob : public SvnInternalJobBase
 {
     Q_OBJECT
 public:
-    SvnInternalRevertJob( SvnJobBase* parent = 0 );
-    void setLocations( const KUrl::List& );
+    explicit SvnInternalRevertJob( SvnJobBase* parent = 0 );
+    void setLocations( const QList<QUrl>& );
     void setRecursive( bool );
 
     bool recursive() const;
-    KUrl::List locations() const;
+    QList<QUrl> locations() const;
 protected:
-    void run();
+    void run(ThreadWeaver::JobPointer self, ThreadWeaver::Thread* thread) override;
 private:
-    KUrl::List m_locations;
+    QList<QUrl> m_locations;
     bool m_recursive;
 };
 
