@@ -11,14 +11,14 @@
 #ifndef KDEVPLATFORM_PLUGIN_SVN_SSLDIALOG_H
 #define KDEVPLATFORM_PLUGIN_SVN_SSLDIALOG_H
 
-#include <kdialog.h>
+#include <QDialog>
+#include <QDialogButtonBox>
 
-
-class SvnSSLTrustDialog: public KDialog
+class SvnSSLTrustDialog: public QDialog
 {
     Q_OBJECT
 public:
-    SvnSSLTrustDialog( QWidget *parent = 0 );
+    explicit SvnSSLTrustDialog( QWidget *parent = 0 );
     virtual ~SvnSSLTrustDialog();
 
     void setCertInfos( const QString& hostname, const QString& fingerPrint,
@@ -27,10 +27,10 @@ public:
                        const QStringList& failures );
     bool useTemporarily();
 private slots:
-    void temporarilyClicked();
-    void permanentlyClicked();
+    void buttonClicked(QAbstractButton *button);
 private:
     class SvnSSLTrustDialogPrivate *d;
+    QDialogButtonBox *buttonBox;
 };
 
 #endif
