@@ -20,35 +20,19 @@
 #ifndef KDEVPLATFORM_PLUGIN_TESTVIEW_H
 #define KDEVPLATFORM_PLUGIN_TESTVIEW_H
 
-#include <QtGui/QTreeView>
+#include <QTreeView>
+#include <QAction>
 #include <interfaces/itestcontroller.h>
-#include <KAction>
 
 class QSortFilterProxyModel;
 class QStandardItem;
 class TestViewPlugin;
 class QStandardItemModel;
-class KIcon;
 
 namespace KDevelop {
 class ITestSuite;
 }
 
-
-class TestViewFilterAction : public KAction {
-    Q_OBJECT
-
-public:
-    explicit TestViewFilterAction( const QString &initialFilter, QObject* parent );
-
-signals:
-    void filterChanged(const QString& filter);
-
-protected:
-    virtual QWidget* createWidget( QWidget* parent );
-    QString m_intialFilter;
-};
-
 class TestView : public QWidget
 {
     Q_OBJECT
@@ -71,13 +55,15 @@ public slots:
     QList<QAction*> contextMenuActions();
 
 private:
+    void changeFilter(const QString &newFilter);
+
     TestViewPlugin* m_plugin;
     QStandardItemModel* m_model;
     QTreeView* m_tree;
     QSortFilterProxyModel* m_filter;
     QList<QAction*> m_contextMenuActions;
 
-    KIcon iconForTestResult(KDevelop::TestResult::TestCaseResult result);
+    QIcon iconForTestResult(KDevelop::TestResult::TestCaseResult result);
     QStandardItem* itemForSuite(KDevelop::ITestSuite* suite);
     QStandardItem* itemForProject(KDevelop::IProject* project);
 };
