@@ -35,11 +35,11 @@
 #include <KPluginFactory>
 #include <KAboutData>
 #include <KLocalizedString>
-#include <KAction>
 #include <KActionCollection>
 
-K_PLUGIN_FACTORY(TestViewFactory, registerPlugin<TestViewPlugin>(); )
-K_EXPORT_PLUGIN(TestViewFactory(KAboutData("kdevtestview","kdevtestview", ki18n("Unit Test View"), "0.1", ki18n("Lets you see and run unit tests"), KAboutData::License_GPL)))
+#include <QAction>
+
+K_PLUGIN_FACTORY_WITH_JSON(TestViewFactory, "kdevtestview.json", registerPlugin<TestViewPlugin>();)
 
 using namespace KDevelop;
 
@@ -48,19 +48,19 @@ class TestToolViewFactory: public KDevelop::IToolViewFactory
     public:
         TestToolViewFactory( TestViewPlugin *plugin ): mplugin( plugin )
         {}
-        virtual QWidget* create( QWidget *parent = 0 )
+        virtual QWidget* create( QWidget *parent = 0 ) override
         {
             return new TestView( mplugin, parent );
         }
-        virtual Qt::DockWidgetArea defaultPosition()
+        virtual Qt::DockWidgetArea defaultPosition() override
         {
             return Qt::LeftDockWidgetArea;
         }
-        virtual QString id() const
+        virtual QString id() const override
         {
             return "org.kdevelop.TestView";
         }
-        virtual QList< QAction* > contextMenuActions(QWidget* viewWidget) const
+        virtual QList< QAction* > contextMenuActions(QWidget* viewWidget) const override
         {
             return qobject_cast<TestView*>(viewWidget)->contextMenuActions();
         }
@@ -68,16 +68,17 @@ class TestToolViewFactory: public KDevelop::IToolViewFactory
         TestViewPlugin *mplugin;
 };
 
-TestViewPlugin::TestViewPlugin(QObject* parent, const QVariantList& args): IPlugin(TestViewFactory::componentData(), parent)
+TestViewPlugin::TestViewPlugin(QObject* parent, const QVariantList& args)
+    : IPlugin("kdevtestview", parent)
 {
     Q_UNUSED(args)
 
-    KAction* runAll = new KAction( KIcon("system-run"), i18n("Run All Tests"), this );
-    connect(runAll, SIGNAL(triggered(bool)), SLOT(runAllTests()));
+    QAction* runAll = new QAction( QIcon::fromTheme("system-run"), i18n("Run All Tests"), this );
+    connect(runAll, &QAction::triggered, this, &TestViewPlugin::runAllTests);
     actionCollection()->addAction("run_all_tests", runAll);
     
-    KAction* stopTest = new KAction( KIcon("process-stop"), i18n("Stop Running Tests"), this );
-    connect(stopTest, SIGNAL(triggered(bool)), SLOT(stopRunningTests()));
+    QAction* stopTest = new QAction( QIcon::fromTheme("process-stop"), i18n("Stop Running Tests"), this );
+    connect(stopTest, &QAction::triggered, this, &TestViewPlugin::stopRunningTests);
     actionCollection()->addAction("stop_running_tests", stopTest);
 
     setXMLFile("kdevtestview.rc");
@@ -85,8 +86,8 @@ TestViewPlugin::TestViewPlugin(QObject* parent, const QVariantList& args): IPlug
     m_viewFactory = new TestToolViewFactory(this);
     core()->uiController()->addToolView(i18n("Unit Tests"), m_viewFactory);
     
-    connect(core()->runController(),SIGNAL(jobRegistered(KJob*)), this, SLOT(jobStateChanged()));
-    connect(core()->runController(),SIGNAL(jobUnregistered(KJob*)), this, SLOT(jobStateChanged()));
+    connect(core()->runController(),&IRunController::jobRegistered, this, &TestViewPlugin::jobStateChanged);
+    connect(core()->runController(),&IRunController::jobUnregistered, this, &TestViewPlugin::jobStateChanged);
     
     jobStateChanged();
 }
@@ -103,7 +104,6 @@ void TestViewPlugin::unload()
 
 void TestViewPlugin::runAllTests()
 {
-    QString jobName = "Run %1 tests in %2";
     ITestController* tc = core()->testController();
     foreach (IProject* project, core()->projectController()->projects())
     {
@@ -152,3 +152,4 @@ void TestViewPlugin::jobStateChanged()
     actionCollection()->action("stop_running_tests")->setEnabled(found);
 }
 
+#include "testviewplugin.moc"
