@@ -29,16 +29,18 @@ class TestViewPlugin : public KDevelop::IPlugin
 {
     Q_OBJECT
 public:
-    TestViewPlugin(QObject* parent, const QVariantList& args = QVariantList());
+    explicit TestViewPlugin(QObject* parent, const QVariantList& args = QVariantList());
     virtual ~TestViewPlugin();
 
-    virtual void unload();
+    virtual void unload() override;
 
 private:
     TestToolViewFactory* m_viewFactory;
 
-public slots:
+private slots:
     void runAllTests();
+    void stopRunningTests();
+    void jobStateChanged();
 };
 
 #endif // KDEVPLATFORM_PLUGIN_TESTVIEWPLUGIN_H
