@@ -28,19 +28,17 @@
 #include <QApplication>
 
 #include <KConfigGroup>
-#include <KDebug>
 #include <KMessageBox>
 #include <KLocalizedString>
 #include <KDirWatch>
-#include <KIO/NetAccess>
 
 #include <interfaces/iproject.h>
 #include <interfaces/icore.h>
-#include <interfaces/iruncontroller.h>
 #include <interfaces/iprojectcontroller.h>
-#include <language/duchain/indexedstring.h>
+#include <serialization/indexedstring.h>
 
 #include "projectfiltermanager.h"
+#include "debug.h"
 
 #define ifDebug(x)
 
@@ -111,7 +109,7 @@ void AbstractFileManagerPlugin::Private::projectClosing(IProject* project)
         // make sure the import job does not live longer than the project
         // see also addLotsOfFiles test
         foreach( FileManagerListJob* job, m_projectJobs[project] ) {
-            kDebug(9517) << "killing project job:" << job;
+            qCDebug(FILEMANAGER) << "killing project job:" << job;
             job->abort();
         }
         m_projectJobs.remove(project);
@@ -125,15 +123,14 @@ KIO::Job* AbstractFileManagerPlugin::Private::eventuallyReadFolder( ProjectFolde
 {
     FileManagerListJob* listJob = new FileManagerListJob( item, forceRecursion );
     m_projectJobs[ item->project() ] << listJob;
-    kDebug(9517) << "adding job" << listJob << item << item->path() << "for project" << item->project();
+    qCDebug(FILEMANAGER) << "adding job" << listJob << item << item->path() << "for project" << item->project();
 
-    ICore::self()->runController()->registerJob( listJob );
+    q->connect( listJob, &FileManagerListJob::finished,
+                q, [&] (KJob* job) { jobFinished(job); } );
 
-    q->connect( listJob, SIGNAL(finished(KJob*)),
-                q, SLOT(jobFinished(KJob*)) );
-
-    q->connect( listJob, SIGNAL(entries(FileManagerListJob*,ProjectFolderItem*,KIO::UDSEntryList,bool)),
-                q, SLOT(addJobItems(FileManagerListJob*,ProjectFolderItem*,KIO::UDSEntryList,bool)) );
+    q->connect( listJob, &FileManagerListJob::entries,
+                q, [&] (FileManagerListJob* job, ProjectFolderItem* baseItem, const KIO::UDSEntryList& entries, bool forceRecursion) {
+                    addJobItems(job, baseItem, entries, forceRecursion); } );
 
     return listJob;
 }
@@ -141,9 +138,18 @@ KIO::Job* AbstractFileManagerPlugin::Private::eventuallyReadFolder( ProjectFolde
 void AbstractFileManagerPlugin::Private::jobFinished(KJob* job)
 {
     FileManagerListJob* gmlJob = qobject_cast<FileManagerListJob*>(job);
-    Q_ASSERT(gmlJob);
-    ifDebug(kDebug(9517) << job << gmlJob << gmlJob->item();)
-    m_projectJobs[ gmlJob->item()->project() ].removeOne( gmlJob );
+    if (gmlJob) {
+        ifDebug(qCDebug(FILEMANAGER) << job << gmlJob << gmlJob->item();)
+        m_projectJobs[ gmlJob->item()->project() ].removeOne( gmlJob );
+    } else {
+        // job emitted its finished signal from its destructor
+        // ensure we don't keep a dangling point in our list
+        for (auto& jobs : m_projectJobs) {
+            if (jobs.removeOne(reinterpret_cast<FileManagerListJob*>(job))) {
+                break;
+            }
+        }
+    }
 }
 
 void AbstractFileManagerPlugin::Private::addJobItems(FileManagerListJob* job,
@@ -155,7 +161,7 @@ void AbstractFileManagerPlugin::Private::addJobItems(FileManagerListJob* job,
         return;
     }
 
-    kDebug(9517) << "reading entries of" << baseItem->path();
+    qCDebug(FILEMANAGER) << "reading entries of" << baseItem->path();
 
     // build lists of valid files and folders with paths relative to the project folder
     Path::List files;
@@ -189,8 +195,8 @@ void AbstractFileManagerPlugin::Private::addJobItems(FileManagerListJob* job,
         }
     }
 
-    ifDebug(kDebug(9517) << "valid folders:" << folders;)
-    ifDebug(kDebug(9517) << "valid files:" << files;)
+    ifDebug(qCDebug(FILEMANAGER) << "valid folders:" << folders;)
+    ifDebug(qCDebug(FILEMANAGER) << "valid files:" << files;)
 
     // remove obsolete rows
     for ( int j = 0; j < baseItem->rowCount(); ++j ) {
@@ -215,7 +221,7 @@ void AbstractFileManagerPlugin::Private::addJobItems(FileManagerListJob* job,
             int index = files.indexOf( f->path() );
             if ( index == -1 ) {
                 // file got removed or is now invalid
-                ifDebug(kDebug(9517) << "removing file:" << f << f->path();)
+                ifDebug(qCDebug(FILEMANAGER) << "removing file:" << f << f->path();)
                 baseItem->removeRow( j );
                 --j;
             } else {
@@ -244,11 +250,11 @@ void AbstractFileManagerPlugin::Private::addJobItems(FileManagerListJob* job,
 
 void AbstractFileManagerPlugin::Private::created(const QString &path_)
 {
-    kDebug(9517) << "created:" << path_;
+    qCDebug(FILEMANAGER) << "created:" << path_;
     QFileInfo info(path_);
 
     ///FIXME: share memory with parent
-    const Path path(KUrl::fromPath(path_));
+    const Path path(path_);
     const IndexedString indexedPath(path.pathOrUrl());
     const IndexedString indexedParent(path.parent().pathOrUrl());
 
@@ -266,7 +272,7 @@ void AbstractFileManagerPlugin::Private::created(const QString &path_)
             foreach ( ProjectFolderItem* folder, p->foldersForPath(indexedPath) ) {
                 // exists already in this project, happens e.g. when we restart the dirwatcher
                 // or if we delete and remove folders consecutively https://bugs.kde.org/show_bug.cgi?id=260741
-                kDebug(9517) << "force reload of" << path << folder;
+                qCDebug(FILEMANAGER) << "force reload of" << path << folder;
                 eventuallyReadFolder( folder, true );
                 found = true;
             }
@@ -306,7 +312,7 @@ void AbstractFileManagerPlugin::Private::deleted(const QString &path_)
             return;
         }
     }
-    kDebug(9517) << "deleted:" << path_;
+    qCDebug(FILEMANAGER) << "deleted:" << path_;
 
     const Path path(path_);
     const IndexedString indexed(path.pathOrUrl());
@@ -330,7 +336,7 @@ void AbstractFileManagerPlugin::Private::deleted(const QString &path_)
         }
         foreach ( ProjectFileItem* item, p->filesForPath(indexed) ) {
             emit q->fileRemoved(item);
-            ifDebug(kDebug(9517) << "removing file" << item;)
+            ifDebug(qCDebug(FILEMANAGER) << "removing file" << item;)
             item->parent()->removeRow(item->row());
         }
     }
@@ -409,10 +415,10 @@ bool isChildItem(ProjectBaseItem* parent, ProjectBaseItem* child)
 
 void AbstractFileManagerPlugin::Private::removeFolder(ProjectFolderItem* folder)
 {
-    ifDebug(kDebug(9517) << "removing folder:" << folder << folder->path();)
+    ifDebug(qCDebug(FILEMANAGER) << "removing folder:" << folder << folder->path();)
     foreach(FileManagerListJob* job, m_projectJobs[folder->project()]) {
         if (isChildItem(folder, job->item())) {
-            kDebug(9517) << "killing list job for removed folder" << job << folder->path();
+            qCDebug(FILEMANAGER) << "killing list job for removed folder" << job << folder->path();
             job->abort();
             Q_ASSERT(!m_projectJobs.value(folder->project()).contains(job));
         } else {
@@ -426,17 +432,17 @@ void AbstractFileManagerPlugin::Private::removeFolder(ProjectFolderItem* folder)
 
 //BEGIN Plugin
 
-AbstractFileManagerPlugin::AbstractFileManagerPlugin( const KComponentData& instance,
+AbstractFileManagerPlugin::AbstractFileManagerPlugin( const QString& componentName,
                                                       QObject *parent,
                                                       const QVariantList & /*args*/ )
     : IProjectFileManager(),
-      IPlugin( instance, parent ),
+      IPlugin( componentName, parent ),
       d(new Private(this))
 {
     KDEV_USE_EXTENSION_INTERFACE( IProjectFileManager )
 
-    connect(core()->projectController(), SIGNAL(projectClosing(KDevelop::IProject*)),
-            this, SLOT(projectClosing(KDevelop::IProject*)));
+    connect(core()->projectController(), &IProjectController::projectClosing,
+            this, [&] (IProject* project) { d->projectClosing(project); });
 }
 
 AbstractFileManagerPlugin::~AbstractFileManagerPlugin()
@@ -452,7 +458,7 @@ IProjectFileManager::Features AbstractFileManagerPlugin::features() const
 QList<ProjectFolderItem*> AbstractFileManagerPlugin::parse( ProjectFolderItem *item )
 {
     // we are async, can't return anything here
-    kDebug(9517) << "note: parse will always return an empty list";
+    qCDebug(FILEMANAGER) << "note: parse will always return an empty list";
     Q_UNUSED(item);
     return QList<ProjectFolderItem*>();
 }
@@ -461,16 +467,16 @@ ProjectFolderItem *AbstractFileManagerPlugin::import( IProject *project )
 {
     ProjectFolderItem *projectRoot = createFolderItem( project, project->path(), 0 );
     emit folderAdded( projectRoot );
-    kDebug(9517) << "imported new project" << project->name() << "at" << projectRoot->path();
+    qCDebug(FILEMANAGER) << "imported new project" << project->name() << "at" << projectRoot->path();
 
     ///TODO: check if this works for remote files when something gets changed through another KDE app
     if ( project->path().isLocalFile() ) {
         d->m_watchers[project] = new KDirWatch( project );
 
-        connect(d->m_watchers[project], SIGNAL(created(QString)),
-                this, SLOT(created(QString)));
-        connect(d->m_watchers[project], SIGNAL(deleted(QString)),
-                this, SLOT(deleted(QString)));
+        connect(d->m_watchers[project], &KDirWatch::created,
+                this, [&] (const QString& path_) { d->created(path_); });
+        connect(d->m_watchers[project], &KDirWatch::deleted,
+                this, [&] (const QString& path_) { d->deleted(path_); });
 
         d->m_watchers[project]->addDir(project->path().toLocalFile(), KDirWatch::WatchSubDirs | KDirWatch:: WatchFiles );
     }
@@ -487,7 +493,7 @@ KJob* AbstractFileManagerPlugin::createImportJob(ProjectFolderItem* item)
 
 bool AbstractFileManagerPlugin::reload( ProjectFolderItem* item )
 {
-    kDebug(9517) << "reloading item" << item->path();
+    qCDebug(FILEMANAGER) << "reloading item" << item->path();
     d->eventuallyReadFolder( item->folder(), true );
     return true;
 }
@@ -495,7 +501,7 @@ bool AbstractFileManagerPlugin::reload( ProjectFolderItem* item )
 ProjectFolderItem* AbstractFileManagerPlugin::addFolder( const Path& folder,
         ProjectFolderItem * parent )
 {
-    kDebug(9517) << "adding folder" << folder << "to" << parent->path();
+    qCDebug(FILEMANAGER) << "adding folder" << folder << "to" << parent->path();
     ProjectFolderItem* created = 0;
     d->stopWatcher(parent);
     if ( createFolder(folder.toUrl()) ) {
@@ -512,7 +518,7 @@ ProjectFolderItem* AbstractFileManagerPlugin::addFolder( const Path& folder,
 ProjectFileItem* AbstractFileManagerPlugin::addFile( const Path& file,
         ProjectFolderItem * parent )
 {
-    kDebug(9517) << "adding file" << file << "to" << parent->path();
+    qCDebug(FILEMANAGER) << "adding file" << file << "to" << parent->path();
     ProjectFileItem* created = 0;
     d->stopWatcher(parent);
     if ( createFile(file.toUrl()) ) {
@@ -527,13 +533,13 @@ ProjectFileItem* AbstractFileManagerPlugin::addFile( const Path& file,
 
 bool AbstractFileManagerPlugin::renameFolder(ProjectFolderItem* folder, const Path& newPath)
 {
-    kDebug(9517) << "trying to rename a folder:" << folder->path() << newPath;
+    qCDebug(FILEMANAGER) << "trying to rename a folder:" << folder->path() << newPath;
     return d->rename(folder, newPath);
 }
 
 bool AbstractFileManagerPlugin::renameFile(ProjectFileItem* file, const Path& newPath)
 {
-    kDebug(9517) << "trying to rename a file:" << file->path() << newPath;
+    qCDebug(FILEMANAGER) << "trying to rename a file:" << file->path() << newPath;
     return d->rename(file, newPath);
 }
 
@@ -591,7 +597,7 @@ bool AbstractFileManagerPlugin::moveFilesAndFolders(const QList< ProjectBaseItem
             // reload first level synchronously, deeper levels will run async
             // this is required for code that expects the new item to exist after
             // this method finished
-            KIO::NetAccess::synchronousRun(readJob, 0);
+            readJob->exec();
         }
 
         d->continueWatcher(oldParent);
@@ -615,7 +621,7 @@ bool AbstractFileManagerPlugin::copyFilesAndFolders(const Path::List& items, Pro
             // reload first level synchronously, deeper levels will run async
             // this is required for code that expects the new item to exist after
             // this method finished
-            KIO::NetAccess::synchronousRun(readJob, 0);
+            readJob->exec();
         }
 
         d->continueWatcher(newParent);
@@ -650,4 +656,4 @@ KDirWatch* AbstractFileManagerPlugin::projectWatcher( IProject* project ) const
 
 //END Plugin
 
-#include "abstractfilemanagerplugin.moc"
+#include "moc_abstractfilemanagerplugin.cpp"
