@@ -46,6 +46,7 @@ public:
     void removeSubDir(ProjectFolderItem* item);
 
     void abort();
+    virtual void start() override;
 
 signals:
     void entries(FileManagerListJob* job, ProjectFolderItem* baseItem,
@@ -54,7 +55,7 @@ signals:
 
 private slots:
     void slotEntries(KIO::Job* job, const KIO::UDSEntryList& entriesIn );
-    void slotResult(KJob* job);
+    void slotResult(KJob* job) override;
     void startNextJob();
 
 private:
