@@ -18,18 +18,23 @@
 */
 
 #include "helper.h"
-
-#include <KTemporaryFile>
-#include <KIO/NetAccess>
-#include <kio/job.h>
-#include <kio/copyjob.h>
-#include <KMessageBox>
-#include <KLocalizedString>
-#include <KTextEditor/Document>
-#include <kparts/mainwindow.h>
+#include "path.h"
 
 #include <QApplication>
+#include <QDir>
 #include <QFileInfo>
+
+#include <KIO/CopyJob>
+#include <KIO/DeleteJob>
+#include <KIO/StatJob>
+#include <KIO/StoredTransferJob>
+#include <KIO/MkdirJob>
+#include <KJobWidgets>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KParts/MainWindow>
+#include <KTextEditor/Document>
+
 #include <interfaces/iproject.h>
 #include <vcs/interfaces/ibasicversioncontrol.h>
 #include <interfaces/iplugin.h>
@@ -38,12 +43,16 @@
 #include <interfaces/iuicontroller.h>
 #include <interfaces/idocumentcontroller.h>
 
-bool KDevelop::removeUrl(const KDevelop::IProject* project, const KUrl& url, const bool isFolder)
+using namespace KDevelop;
+
+bool KDevelop::removeUrl(const KDevelop::IProject* project, const QUrl& url, const bool isFolder)
 {
     QWidget* window(ICore::self()->uiController()->activeMainWindow()->window());
 
-    if ( !KIO::NetAccess::exists(url, KIO::NetAccess::DestinationSide, window) ) {
-        kWarning() << "tried to remove non-existing url:" << url << project << isFolder;
+    auto job = KIO::stat(url, KIO::StatJob::DestinationSide, 0);
+    KJobWidgets::setWindow(job, window);
+    if (!job->exec()) {
+        qWarning() << "tried to remove non-existing url:" << url << project << isFolder;
         return true;
     }
 
@@ -53,7 +62,7 @@ bool KDevelop::removeUrl(const KDevelop::IProject* project, const KUrl& url, con
 
         // We have a vcs and the file/folder is controller, need to make the rename through vcs
         if(vcs->isVersionControlled(url)) {
-            VcsJob* job=vcs->remove(KUrl::List() << url);
+            VcsJob* job=vcs->remove(QList<QUrl>() << url);
             if(job) {
                 return job->exec();
             }
@@ -61,49 +70,66 @@ bool KDevelop::removeUrl(const KDevelop::IProject* project, const KUrl& url, con
     }
 
     //if we didn't find a VCS, we remove using KIO (if the file still exists, the vcs plugin might have simply deleted the url without returning a job
-    if ( !KIO::NetAccess::del( url, window ) && url.isLocalFile() && (QFileInfo(url.toLocalFile())).exists() ) {
+    auto deleteJob = KIO::del(url);
+    KJobWidgets::setWindow(deleteJob, window);
+    if (!deleteJob->exec() && url.isLocalFile() && (QFileInfo(url.toLocalFile())).exists()) {
         KMessageBox::error( window,
-            isFolder ? i18n( "Cannot remove folder <i>%1</i>.", url.pathOrUrl() )
-                        : i18n( "Cannot remove file <i>%1</i>.", url.pathOrUrl() ) );
+            isFolder ? i18n( "Cannot remove folder <i>%1</i>.", url.toDisplayString(QUrl::PreferLocalFile) )
+                        : i18n( "Cannot remove file <i>%1</i>.", url.toDisplayString(QUrl::PreferLocalFile) ) );
         return false;
     }
     return true;
 }
 
-bool KDevelop::createFile(const KUrl& file)
+bool KDevelop::removePath(const KDevelop::IProject* project, const KDevelop::Path& path, const bool isFolder)
 {
-    if (KIO::NetAccess::exists( file, KIO::NetAccess::DestinationSide, QApplication::activeWindow() )) {
+    return removeUrl(project, path.toUrl(), isFolder);
+}
+
+bool KDevelop::createFile(const QUrl& file)
+{
+    auto statJob = KIO::stat(file, KIO::StatJob::DestinationSide, 0);
+    KJobWidgets::setWindow(statJob, QApplication::activeWindow());
+    if (statJob->exec()) {
         KMessageBox::error( QApplication::activeWindow(),
-                            i18n( "The file <i>%1</i> already exists.", file.pathOrUrl() ) );
+                            i18n( "The file <i>%1</i> already exists.", file.toDisplayString(QUrl::PreferLocalFile) ) );
         return false;
     }
 
     {
-        KTemporaryFile temp;
-        if ( !temp.open() || temp.write("\n") == -1 ) {
+        auto uploadJob = KIO::storedPut(QByteArray("\n"), file, -1);
+        KJobWidgets::setWindow(uploadJob, QApplication::activeWindow());
+        if (!uploadJob->exec()) {
             KMessageBox::error( QApplication::activeWindow(),
-                                i18n( "Cannot create temporary file to create <i>%1</i>.", file.pathOrUrl() ) );
-            return false;
-        }
-        if ( !KIO::NetAccess::upload( temp.fileName(), file, QApplication::activeWindow() ) ) {
-            KMessageBox::error( QApplication::activeWindow(),
-                                i18n( "Cannot create file <i>%1</i>.", file.pathOrUrl() ) );
+                                i18n( "Cannot create file <i>%1</i>.", file.toDisplayString(QUrl::PreferLocalFile) ) );
             return false;
         }
     }
     return true;
 }
 
-bool KDevelop::createFolder(const KUrl& folder)
+bool KDevelop::createFile(const KDevelop::Path& file)
 {
-    if ( !KIO::NetAccess::mkdir( folder, QApplication::activeWindow() ) ) {
-        KMessageBox::error( QApplication::activeWindow(), i18n( "Cannot create folder <i>%1</i>.", folder.pathOrUrl() ) );
+    return createFile(file.toUrl());
+}
+
+bool KDevelop::createFolder(const QUrl& folder)
+{
+    auto mkdirJob = KIO::mkdir(folder);
+    KJobWidgets::setWindow(mkdirJob, QApplication::activeWindow());
+    if (!mkdirJob->exec()) {
+        KMessageBox::error( QApplication::activeWindow(), i18n( "Cannot create folder <i>%1</i>.", folder.toDisplayString(QUrl::PreferLocalFile) ) );
         return false;
     }
     return true;
 }
 
-bool KDevelop::renameUrl(const KDevelop::IProject* project, const KUrl& oldname, const KUrl& newname)
+bool KDevelop::createFolder(const KDevelop::Path& folder)
+{
+    return createFolder(folder.toUrl());
+}
+
+bool KDevelop::renameUrl(const KDevelop::IProject* project, const QUrl& oldname, const QUrl& newname)
 {
     bool wasVcsMoved = false;
     IPlugin* vcsplugin = project->versionControlPlugin();
@@ -136,13 +162,18 @@ bool KDevelop::renameUrl(const KDevelop::IProject* project, const KUrl& oldname,
     } else if (!wasVcsMoved) {
         // fallback for non-textdocuments (also folders e.g.)
         KIO::CopyJob* job = KIO::move(oldname, newname);
-        return KIO::NetAccess::synchronousRun(job, 0);
+        return job->exec();
     } else {
         return true;
     }
 }
 
-bool KDevelop::copyUrl(const KDevelop::IProject* project, const KUrl& source, const KUrl& target)
+bool KDevelop::renamePath(const KDevelop::IProject* project, const KDevelop::Path& oldName, const KDevelop::Path& newName)
+{
+    return renameUrl(project, oldName.toUrl(), newName.toUrl());
+}
+
+bool KDevelop::copyUrl(const KDevelop::IProject* project, const QUrl& source, const QUrl& target)
 {
     IPlugin* vcsplugin=project->versionControlPlugin();
     if(vcsplugin) {
@@ -156,7 +187,30 @@ bool KDevelop::copyUrl(const KDevelop::IProject* project, const KUrl& source, co
             }
         }
     }
+
     // Fallback for the case of no vcs, or not-vcs-managed file/folder
-    KIO::CopyJob* job=KIO::copy(source, target);
-    return KIO::NetAccess::synchronousRun(job, 0);
+    auto job = KIO::copy(source, target);
+    return job->exec();
+}
+
+bool KDevelop::copyPath(const KDevelop::IProject* project, const KDevelop::Path& source, const KDevelop::Path& target)
+{
+    return copyUrl(project, source.toUrl(), target.toUrl());
+}
+
+Path KDevelop::proposedBuildFolder(const Path& sourceFolder)
+{
+    Path proposedBuildFolder;
+    if (sourceFolder.path().contains("/src/")) {
+        const QString srcBuildPath = sourceFolder.path().replace("/src/", "/build/");
+        Q_ASSERT(!srcBuildPath.isEmpty());
+        if (QDir(srcBuildPath).exists()) {
+            proposedBuildFolder = Path(srcBuildPath);
+        }
+    }
+    if (!proposedBuildFolder.isValid()) {
+        proposedBuildFolder = Path( sourceFolder, "build" );
+    }
+
+    return proposedBuildFolder;
 }
