@@ -24,7 +24,7 @@
 
 #include "iprojectfilemanager.h"
 
-#include "../projectexport.h"
+#include <project/projectexport.h>
 
 namespace KDevelop
 {
@@ -111,6 +111,11 @@ public:
      */
     virtual bool removeFilesFromTargets(const QList<KDevelop::ProjectFileItem*> &files) = 0;
 
+    /**
+     * Returns if the build system has information specific to @p item
+     */
+    virtual bool hasIncludesOrDefines(ProjectBaseItem* item) const = 0;
+
     /**
      * Get the toplevel build directory for the project
      */
