@@ -20,8 +20,10 @@
 #ifndef KDEVPLATFORM_IPROJECTBUILDER_H
 #define KDEVPLATFORM_IPROJECTBUILDER_H
 
-#include "../projectexport.h"
+#include <project/projectexport.h>
+
 #include <QtCore/QObject>
+#include <QtCore/QUrl>
 
 class KJob;
 
@@ -44,47 +46,49 @@ public:
     virtual ~IProjectBuilder();
 
     /**
-     * Installs the given project item, exact behaviour depends
-     * on the implementation
+     * Installs the given project @p item, exact behaviour depends
+     * on the implementation.
+     *
+     * @param specificPrefix defines where the project will be installed.
      */
-    virtual KJob* install(ProjectBaseItem* item) = 0;
+    virtual KJob* install(ProjectBaseItem* item, const QUrl &specificPrefix = {}) = 0;
 
     /**
-     * Builds the given project item, exact behaviour depends
+     * Builds the given project @p item, exact behaviour depends
      * on the implementation
      */
-    virtual KJob* build(ProjectBaseItem *dom) = 0;
+    virtual KJob* build(ProjectBaseItem *item) = 0;
 
     /**
-     * Cleans the given project item, exact behaviour depends
+     * Cleans the given project @p item, exact behaviour depends
      * on the implementation. The cleaning should only include
      * output files, like C/C++ object files, binaries, files
      * that the builder needs shouldn't be removed.
      */
-    virtual KJob* clean(ProjectBaseItem *dom) = 0;
+    virtual KJob* clean(ProjectBaseItem *item) = 0;
 
     /**
-     * Configures the given project, exact behaviour depends
+     * Configures the given @p project, exact behaviour depends
      * on the implementation. After calling this a build() call should
      * succeed (given the code doesn't have errors).
      *
      * This function is optional, the default implementation does nothing.
      */
-    virtual KJob* configure(IProject*);
+    virtual KJob* configure(IProject* project);
 
     /**
-     * Prunes the given project, exact behaviour depends
+     * Prunes the given @p project, exact behaviour depends
      * on the implementation. Additionally to what clean() does this may
      * also remove files used for the builder (or a "subbuilder"), for example
      * generated Makefiles in QMake/CMake/Automake projects
      *
      * This function is optional, the default implementation does nothing.
      */
-    virtual KJob* prune(IProject*);
+    virtual KJob* prune(IProject* project);
 
     /**
-     * Provide access to the builders related to this one.
-     * The list returned by this method is used to select the appropriate KCMs for a project.
+     * Provide access to the builders related to the @p project.
+     * The list returned by this method is used to select the appropriate config pages for a project.
      * This method may safely return an empty list, as does the default implementation.
      */
     virtual QList<IProjectBuilder*> additionalBuilderPlugins( IProject* project ) const;
