@@ -20,22 +20,23 @@
 #ifndef KDEVPLATFORM_PROJECTITEMLINEEDIT_H
 #define KDEVPLATFORM_PROJECTITEMLINEEDIT_H
 
-#include <KLineEdit>
+#include <QLineEdit>
 #include "projectexport.h"
 
 namespace KDevelop { 
 class ProjectModel; 
 class ProjectBaseItem;
+class IProject;
 }
 
 class ProjectItemValidator;
 class ProjectItemCompleter;
 
-class KDEVPLATFORMPROJECT_EXPORT ProjectItemLineEdit : public KLineEdit
+class KDEVPLATFORMPROJECT_EXPORT ProjectItemLineEdit : public QLineEdit
 {
     Q_OBJECT
 public:
-    ProjectItemLineEdit(QWidget* parent=0);
+    explicit ProjectItemLineEdit(QWidget* parent=0);
     
     /**
      * Sets this lineedit to show the given @p path, eventually removing
@@ -65,6 +66,8 @@ public:
     
     KDevelop::ProjectBaseItem* currentItem() const;
     
+    void setSuggestion(KDevelop::IProject* project);
+
 public slots:
     bool selectItemDialog();
     
@@ -75,6 +78,7 @@ private:
     KDevelop::ProjectBaseItem* m_base;
     ProjectItemCompleter* m_completer;
     ProjectItemValidator* m_validator;
+    KDevelop::IProject* m_suggestion;
 };
 
 #endif
