@@ -21,26 +21,19 @@
 
 #include "projectmodel.h"
 
-#include <kmimetype.h>
+#include <QDebug>
+#include <QIcon>
+#include <QMimeDatabase>
+#include <QMimeType>
 
-#include <QApplication>
-#include <QPalette>
-#include <QBrush>
-#include <QColor>
-#include <QFileInfo>
-#include <kdebug.h>
+#include <KIO/StatJob>
+#include <KLocalizedString>
 
 #include <interfaces/iproject.h>
 #include <interfaces/iprojectcontroller.h>
 #include <interfaces/icore.h>
 #include "interfaces/iprojectfilemanager.h"
-#include <language/duchain/indexedstring.h>
-#include <KLocalizedString>
-#include <KMessageBox>
-#include <kio/udsentry.h>
-#include <kio/netaccess.h>
-#include <QMetaClassInfo>
-#include <QThread>
+#include <serialization/indexedstring.h>
 
 #include "path.h"
 
@@ -148,8 +141,8 @@ public:
         Path newPath = item->path();
         newPath.setLastPathSegment(newName);
 
-        KIO::UDSEntry entry;
-        if( KIO::NetAccess::stat(newPath.toUrl(), entry, 0) ) {
+        auto job = KIO::stat(newPath.toUrl(), KIO::StatJob::SourceSide, 0);
+        if (job->exec()) {
             // file/folder exists already
             return ProjectBaseItem::ExistingItemSameName;
         }
@@ -216,9 +209,9 @@ ProjectBaseItem* ProjectBaseItem::takeRow(int row)
 {
     Q_D(ProjectBaseItem);
     Q_ASSERT(row >= 0 && row < d->children.size());
-    
+
     if( model() ) {
-        QMetaObject::invokeMethod( model(), "rowsAboutToBeRemoved", Qt::DirectConnection, Q_ARG(QModelIndex, index()), Q_ARG(int, row), Q_ARG(int, row) );
+        model()->beginRemoveRows(index(), row, row);
     }
     ProjectBaseItem* olditem = d->children.takeAt( row );
     olditem->d_func()->parent = 0;
@@ -229,9 +222,9 @@ ProjectBaseItem* ProjectBaseItem::takeRow(int row)
         child(i)->d_func()->row--;
         Q_ASSERT(child(i)->d_func()->row==i);
     }
-    
+
     if( model() ) {
-        QMetaObject::invokeMethod( model(), "rowsRemoved", Qt::DirectConnection, Q_ARG(QModelIndex, index()), Q_ARG(int, row), Q_ARG(int, row) );
+        model()->endRemoveRows();
     }
     return olditem;
 }
@@ -251,7 +244,7 @@ void ProjectBaseItem::removeRows(int row, int count)
     Q_ASSERT(row >= 0 && row + count <= d->children.size());
 
     if( model() ) {
-        QMetaObject::invokeMethod( model(), "rowsAboutToBeRemoved", Qt::DirectConnection, Q_ARG(QModelIndex, index()), Q_ARG(int, row), Q_ARG(int, row + count - 1) );
+        model()->beginRemoveRows(index(), row, row + count - 1);
     }
 
     //NOTE: we unset parent, row and model manually to speed up the deletion
@@ -279,7 +272,7 @@ void ProjectBaseItem::removeRows(int row, int count)
     }
 
     if( model() ) {
-        QMetaObject::invokeMethod( model(), "rowsRemoved", Qt::DirectConnection, Q_ARG(QModelIndex, index()), Q_ARG(int, row), Q_ARG(int, row + count - 1) );
+        model()->endRemoveRows();
     }
 }
 
@@ -369,7 +362,7 @@ void ProjectBaseItem::setText( const QString& text )
     d->text = text;
     if( d->model ) {
         QModelIndex idx = index();
-        QMetaObject::invokeMethod( d->model, "dataChanged", Qt::DirectConnection, Q_ARG(QModelIndex, idx), Q_ARG(QModelIndex, idx) );
+        emit d->model->dataChanged(idx, idx);
     }
 }
 
@@ -433,7 +426,7 @@ void ProjectBaseItem::appendRow( ProjectBaseItem* item )
     }
     if( item->parent() ) {
         // Proper way is to first removeRow() on the original parent, then appendRow on this one
-        kWarning() << "Ignoring double insertion of item" << item;
+        qWarning() << "Ignoring double insertion of item" << item;
         return;
     }
     // this is too slow... O(n) and thankfully not a problem anyways
@@ -441,27 +434,17 @@ void ProjectBaseItem::appendRow( ProjectBaseItem* item )
     int startrow,endrow;
     if( model() ) {
         startrow = endrow = d->children.count();
-        QMetaObject::invokeMethod( model(), "rowsAboutToBeInserted", Qt::DirectConnection, Q_ARG(QModelIndex, index()), Q_ARG(int, startrow), Q_ARG(int, endrow) );
+        model()->beginInsertRows(index(), startrow, endrow);
     }
     d->children.append( item );
     item->setRow( d->children.count() - 1 );
     item->d_func()->parent = this;
     item->setModel( model() );
     if( model() ) {
-        QMetaObject::invokeMethod( model(), "rowsInserted", Qt::DirectConnection, Q_ARG( QModelIndex, index() ), Q_ARG( int, startrow ), Q_ARG( int, endrow ) );
+        model()->endInsertRows();
     }
 }
 
-KUrl ProjectBaseItem::url( ) const
-{
-    Q_D(const ProjectBaseItem);
-    KUrl url = d->m_path.toUrl();
-    if (folder()) {
-        url.adjustPath(KUrl::AddTrailingSlash);
-    }
-    return url;
-}
-
 Path ProjectBaseItem::path() const
 {
     Q_D(const ProjectBaseItem);
@@ -557,7 +540,7 @@ QList<ProjectTargetItem*> ProjectBaseItem::targetList() const
     for ( int i = 0; i < rowCount(); ++i )
     {
         ProjectBaseItem* item = child( i );
-        
+
         if ( item->type() == Target || item->type() == LibraryTarget || item->type() == ExecutableTarget )
         {
             ProjectTargetItem *kdevitem = dynamic_cast<ProjectTargetItem*>( item );
@@ -587,11 +570,6 @@ QList<ProjectFileItem*> ProjectBaseItem::fileList() const
     return lst;
 }
 
-void ProjectModel::resetModel()
-{
-    reset();
-}
-
 void ProjectModel::clear()
 {
     d->rootItem->removeRows(0, d->rootItem->rowCount());
@@ -784,13 +762,13 @@ public:
             }
         }
 
-        KMimeType::Ptr mime = KMimeType::findByUrl( KUrl::fromPath(path.lastPathSegment()), 0, false, true );
+        QMimeType mime = QMimeDatabase().mimeTypeForFile(path.lastPathSegment(), QMimeDatabase::MatchExtension); // no I/O
         QMutexLocker lock(&mutex);
-        QHash< QString, QString >::const_iterator it = mimeToIcon.constFind( mime->name() );
+        QHash< QString, QString >::const_iterator it = mimeToIcon.constFind(mime.name());
         QString iconName;
         if ( it == mimeToIcon.constEnd() ) {
-            iconName = mime->iconName();
-            mimeToIcon.insert(mime->name(), iconName);
+            iconName = mime.iconName();
+            mimeToIcon.insert(mime.name(), iconName);
         } else {
             iconName = *it;
         }
@@ -804,7 +782,7 @@ public:
     QHash<QString, QString> fileExtensionToIcon;
 };
 
-K_GLOBAL_STATIC(IconNameCache, s_cache);
+Q_GLOBAL_STATIC(IconNameCache, s_cache);
 
 QString ProjectFileItem::iconName() const
 {
@@ -993,31 +971,30 @@ ProjectBaseItem* ProjectModel::itemFromIndex( const QModelIndex& index ) const
     return 0;
 }
 
-QSet<int> supportedRoles() {
-    QSet<int> ret;
-    ret << Qt::DisplayRole;
-    ret << Qt::ToolTipRole;
-    ret << Qt::DecorationRole;
-    ret << KDevelop::ProjectModel::ProjectItemRole;
-    ret << KDevelop::ProjectModel::ProjectRole;
-    return ret;
-}
-
 QVariant ProjectModel::data( const QModelIndex& index, int role ) const
 {
-    static QSet<int> allowedRoles = supportedRoles();
+    static const QSet<int> allowedRoles = {
+        Qt::DisplayRole,
+        Qt::ToolTipRole,
+        Qt::DecorationRole,
+        ProjectItemRole,
+        ProjectRole,
+        UrlRole
+    };
     if( allowedRoles.contains(role) && index.isValid() ) {
         ProjectBaseItem* item = itemFromIndex( index );
         if( item ) {
             switch(role) {
                 case Qt::DecorationRole:
-                    return KIcon(item->iconName());
+                    return QIcon::fromTheme(item->iconName());
                 case Qt::ToolTipRole:
                     return item->path().pathOrUrl();
                 case Qt::DisplayRole:
                     return item->text();
                 case ProjectItemRole:
                     return QVariant::fromValue<ProjectBaseItem*>(item);
+                case UrlRole:
+                    return item->path().toUrl();
                 case ProjectRole:
                     return QVariant::fromValue<QObject*>(item->project());
             }
@@ -1210,4 +1187,3 @@ ProjectVisitor::~ProjectVisitor()
 
 
 }
-#include "projectmodel.moc"
