@@ -23,9 +23,10 @@
 #define KDEVPLATFORM_PROJECTMODEL_H
 
 #include <QtCore/QAbstractItemModel>
+#include <QUrl>
+
 #include "projectexport.h"
-#include <KDE/KUrl>
-#include <KDE/KSharedConfig>
+#include <KSharedConfig>
 
 template<typename T1,typename T2> struct QPair;
 template<typename T> class QList;
@@ -174,17 +175,17 @@ class KDEVPLATFORMPROJECT_EXPORT ProjectBaseItem
          * Adds a new child item to this item.
          */
         void appendRow( ProjectBaseItem* item );
-        
+
         /**
          * Removes and deletes the item at the given @p row if there is one.
          */
         void removeRow( int row );
-        
+
         /**
          * Removes and deletes the @p count items after the given @p row if there is one.
          */
         void removeRows( int row, int count );
-        
+
         /**
          * Returns and removes the item at the given @p row if there is one.
          */
@@ -193,12 +194,9 @@ class KDEVPLATFORMPROJECT_EXPORT ProjectBaseItem
         /** @returns RTTI info, allows to know the type of item */
         virtual int type() const;
 
-        /** @returns a string to pass to KIcon as icon-name suitable to represent this item. */
+        /** @returns a string to pass to QIcon::fromTheme() as icon-name suitable to represent this item. */
         virtual QString iconName() const;
 
-        /** Get the path of this item (if any) converted to a url */
-        KDE_DEPRECATED KUrl url() const;
-
         /**
          * Set the path of this item.
          *
@@ -224,16 +222,16 @@ class KDEVPLATFORMPROJECT_EXPORT ProjectBaseItem
          * @returns status information whether the renaming succeeded.
          */
         virtual RenameStatus rename( const QString& newname );
-        
+
         bool isProjectRoot() const;
-        
+
          /**
          * Default flags: Qt::ItemIsEnabled | Qt::ItemIsSelectable
-         * 
+         *
          * @returns the flags supported by the item
          */
         virtual Qt::ItemFlags flags();
-        
+
         /**
          * Sets what flags should be returned by ::flags() method.
          */
@@ -280,12 +278,12 @@ public:
 
     virtual ~ProjectFolderItem();
 
-    virtual void setPath(const Path& );
+    virtual void setPath(const Path& ) override;
 
-    virtual ProjectFolderItem *folder() const;
+    virtual ProjectFolderItem *folder() const override;
 
     ///Reimplemented from QStandardItem
-    virtual int type() const;
+    virtual int type() const override;
 
     /**
      * Get the folder name, equal to path().fileName() or text().
@@ -294,9 +292,9 @@ public:
 
     /** @returns Returns whether this folder directly contains the specified file or folder. */
     bool hasFileOrFolder(const QString& name) const;
-    
-    virtual QString iconName() const;
-    virtual RenameStatus rename(const QString& newname);
+
+    virtual QString iconName() const override;
+    virtual RenameStatus rename(const QString& newname) override;
 
 private:
     void propagateRename( const Path& newBase ) const;
@@ -322,8 +320,8 @@ public:
     ProjectBuildFolderItem( const QString &name, ProjectBaseItem *parent );
 
     ///Reimplemented from QStandardItem
-    virtual int type() const;
-    virtual QString iconName() const;
+    virtual int type() const override;
+    virtual QString iconName() const override;
 };
 
 /**
@@ -337,11 +335,11 @@ public:
     ProjectTargetItem( IProject*, const QString &name, ProjectBaseItem *parent = 0 );
 
     ///Reimplemented from QStandardItem
-    virtual int type() const;
+    virtual int type() const override;
 
-    virtual ProjectTargetItem *target() const;
-    virtual QString iconName() const;
-    virtual void setPath(const Path& path );
+    virtual ProjectTargetItem *target() const override;
+    virtual QString iconName() const override;
+    virtual void setPath(const Path& path ) override;
 };
 
 /**
@@ -354,10 +352,10 @@ class KDEVPLATFORMPROJECT_EXPORT ProjectExecutableTargetItem: public ProjectTarg
     public:
         ProjectExecutableTargetItem( IProject*, const QString &name, ProjectBaseItem *parent = 0 );
 
-        virtual ProjectExecutableTargetItem *executable() const;
-        virtual int type() const;
-        virtual KUrl builtUrl() const=0;
-        virtual KUrl installedUrl() const=0;
+        virtual ProjectExecutableTargetItem *executable() const override;
+        virtual int type() const override;
+        virtual QUrl builtUrl() const=0;
+        virtual QUrl installedUrl() const=0;
 };
 
 
@@ -371,7 +369,7 @@ class KDEVPLATFORMPROJECT_EXPORT ProjectLibraryTargetItem: public ProjectTargetI
     public:
         ProjectLibraryTargetItem(IProject* project, const QString &name, ProjectBaseItem *parent = 0 );
 
-        virtual int type() const;
+        virtual int type() const override;
 };
 
 /**
@@ -395,18 +393,18 @@ public:
     ~ProjectFileItem();
 
     ///Reimplemented from QStandardItem
-    virtual int type() const;
+    virtual int type() const override;
 
-    virtual ProjectFileItem *file() const;
+    virtual ProjectFileItem *file() const override;
 
     /**
      * @returns the file name, equal to path().fileName() or text()
      */
     QString fileName() const;
 
-    virtual void setPath( const Path& );
-    virtual QString iconName() const;
-    virtual RenameStatus rename(const QString& newname);
+    virtual void setPath( const Path& ) override;
+    virtual QString iconName() const override;
+    virtual RenameStatus rename(const QString& newname) override;
 
     /**
      * @return the items indexed path, which is often required for performant
@@ -427,14 +425,13 @@ public:
     enum Roles {
           ProjectRole = Qt::UserRole+1
         , ProjectItemRole
+        , UrlRole
         , LastRole
     };
 
-    ProjectModel( QObject *parent = 0 );
+    explicit ProjectModel( QObject *parent = 0 );
     virtual ~ProjectModel();
 
-    void resetModel();
-
     void clear();
 
     void appendRow( ProjectBaseItem* item );
@@ -450,18 +447,18 @@ public:
     QModelIndex indexFromItem( const ProjectBaseItem* item ) const;
     ProjectBaseItem* itemFromIndex( const QModelIndex& ) const;
 
-    virtual int columnCount( const QModelIndex& parent = QModelIndex() ) const;
-    virtual QVariant data( const QModelIndex& index, int role = Qt::DisplayRole ) const;
-    virtual QModelIndex parent( const QModelIndex& child ) const;
-    virtual int rowCount( const QModelIndex& parent = QModelIndex() ) const;
-    virtual QModelIndex index(int row, int column, const QModelIndex& parent = QModelIndex()) const;
+    virtual int columnCount( const QModelIndex& parent = QModelIndex() ) const override;
+    virtual QVariant data( const QModelIndex& index, int role = Qt::DisplayRole ) const override;
+    virtual QModelIndex parent( const QModelIndex& child ) const override;
+    virtual int rowCount( const QModelIndex& parent = QModelIndex() ) const override;
+    virtual QModelIndex index(int row, int column, const QModelIndex& parent = QModelIndex()) const override;
 
-    virtual bool setData(const QModelIndex& index, const QVariant& value, int role = Qt::EditRole);
-    virtual bool insertColumns(int column, int count, const QModelIndex& parent = QModelIndex());
-    virtual bool insertRows(int row, int count, const QModelIndex& parent = QModelIndex());
-    
-    virtual Qt::ItemFlags flags(const QModelIndex& index) const;
-    virtual Qt::DropActions supportedDropActions() const;
+    virtual bool setData(const QModelIndex& index, const QVariant& value, int role = Qt::EditRole) override;
+    virtual bool insertColumns(int column, int count, const QModelIndex& parent = QModelIndex()) override;
+    virtual bool insertRows(int row, int count, const QModelIndex& parent = QModelIndex()) override;
+
+    virtual Qt::ItemFlags flags(const QModelIndex& index) const override;
+    virtual Qt::DropActions supportedDropActions() const override;
 
     /**
      * @return all items for the given indexed path.
