@@ -20,17 +20,43 @@
 
 #ifndef KDEVPLATFORM_PROJECTUTILS_H
 #define KDEVPLATFORM_PROJECTUTILS_H
+
 #include "projectexport.h"
 
+#include <context.h>
+
+#include <QList>
+
 class QMenu;
 
 namespace KDevelop {
+
 class ProjectBaseItem;
+class ProjectFileItem;
+
+// TODO: Move to own header? Rename to ProjectItemContext and remove original from context.h?
+class KDEVPLATFORMPROJECT_EXPORT ProjectItemContextImpl : public ProjectItemContext
+{
+public:
+    explicit ProjectItemContextImpl(const QList<ProjectBaseItem*>& items);
+
+    virtual QList<QUrl> urls() const override;
+
+private:
+    Q_DISABLE_COPY(ProjectItemContextImpl)
+};
+
 /**
  * Adds menu entries for all parent folders of the given item, each containing all the project
  * items for the folder, at the end of the given menu.
  * */
 KDEVPLATFORMPROJECT_EXPORT void populateParentItemsMenu( ProjectBaseItem* item, QMenu* menu );
+
+/**
+ * Returns all the files that have @p projectItem as ancestor
+ */
+KDEVPLATFORMPROJECT_EXPORT QList<ProjectFileItem*> allFiles(ProjectBaseItem* projectItem);
+
 }
 
 #endif // KDEVPLATFORM_PROJECTUTILS_H
