@@ -20,13 +20,10 @@
 #include "core.h"
 #include "core_p.h"
 
-#include <QtGui/QApplication>
+#include <QApplication>
 #include <QtCore/QTimer>
 
-#include <kdebug.h>
-#include <kglobal.h>
-#include <klocale.h>
-#include <ksplashscreen.h>
+#include <KLocalizedString>
 
 #include <language/duchain/duchain.h>
 
@@ -45,9 +42,10 @@
 #include "progresswidget/progressmanager.h"
 #include "selectioncontroller.h"
 #include "debugcontroller.h"
-#include "kdevplatformversion.h"
+#include "kdevplatform_version.h"
 #include "workingsetcontroller.h"
 #include "testcontroller.h"
+#include "debug.h"
 
 #include <KMessageBox>
 
@@ -56,13 +54,14 @@
 
 #include <csignal>
 
-volatile std::sig_atomic_t handlingSignal = 0;
-
+namespace {
 void shutdownGracefully(int sig)
 {
+    static volatile std::sig_atomic_t handlingSignal = 0;
+
     if ( !handlingSignal ) {
         handlingSignal = 1;
-        qDebug() << "signal " << sig << " received, shutting down gracefully";
+        qCDebug(SHELL) << "signal " << sig << " received, shutting down gracefully";
         QCoreApplication* app = QCoreApplication::instance();
         if (QApplication* guiApp = qobject_cast<QApplication*>(app)) {
             guiApp->closeAllWindows();
@@ -88,45 +87,51 @@ void installSignalHandler()
     std::signal(SIGTERM, shutdownGracefully);
 #endif
 }
+}
 
 namespace KDevelop {
 
 Core *Core::m_self = 0;
-KAboutData aboutData()
+
+KAboutData createAboutData()
 {
-    KAboutData aboutData( "kdevplatform", "kdevplatform", 
-                          ki18n("KDevelop Platform"), KDEVPLATFORM_VERSION_STR, 
-                          ki18n("Development Platform for IDE-like Applications"), 
-                          KAboutData::License_LGPL_V2, ki18n( "Copyright 2004-2013, The KDevelop developers" ),
-                          KLocalizedString(), "http://www.kdevelop.org" );
-    aboutData.addAuthor( ki18n("Andreas Pakulat"), ki18n( "Architecture, VCS Support, Project Management Support, QMake Projectmanager" ), "apaku@gmx.de" );
-    aboutData.addAuthor( ki18n("Alexander Dymo"), ki18n( "Architecture, Sublime UI, Ruby support" ), "adymo@kdevelop.org" );
-    aboutData.addAuthor( ki18n("David Nolden"), ki18n( "Definition-Use Chain, C++ Support" ), "david.nolden.kdevelop@art-master.de" );
-    aboutData.addAuthor( ki18n("Aleix Pol Gonzalez"), ki18n( "Co-Maintainer, CMake Support, Run Support, Kross Support" ), "aleixpol@kde.org" );
-    aboutData.addAuthor( ki18n("Vladimir Prus"), ki18n( "GDB integration" ), "ghost@cs.msu.su" );
-    aboutData.addAuthor( ki18n("Hamish Rodda"), ki18n( "Text editor integration, definition-use chain" ), "rodda@kde.org" );
-    
-    aboutData.addCredit( ki18n("Matt Rogers"), KLocalizedString(), "mattr@kde.org");
-    aboutData.addCredit( ki18n("Cédric Pasteur"), ki18n("astyle and indent support"), "cedric.pasteur@free.fr" );
-    aboutData.addCredit( ki18n("Evgeniy Ivanov"), ki18n("Distributed VCS, Git, Mercurial"), "powerfox@kde.ru" );
+    KAboutData aboutData( "kdevplatform",
+                          i18n("KDevelop Platform"), KDEVPLATFORM_VERSION_STRING,
+                          i18n("Development Platform for IDE-like Applications"),
+                          KAboutLicense::LGPL_V2, i18n( "Copyright 2004-2014, The KDevelop developers" ),
+                          QString(), "http://www.kdevelop.org" );
+
+    aboutData.addAuthor( i18n("Andreas Pakulat"), i18n( "Architecture, VCS Support, Project Management Support, QMake Projectmanager" ), "apaku@gmx.de" );
+    aboutData.addAuthor( i18n("Alexander Dymo"), i18n( "Architecture, Sublime UI, Ruby support" ), "adymo@kdevelop.org" );
+    aboutData.addAuthor( i18n("David Nolden"), i18n( "Definition-Use Chain, C++ Support" ), "david.nolden.kdevelop@art-master.de" );
+    aboutData.addAuthor( i18n("Aleix Pol Gonzalez"), i18n( "Co-Maintainer, CMake Support, Run Support, Kross Support" ), "aleixpol@kde.org" );
+    aboutData.addAuthor( i18n("Vladimir Prus"), i18n( "GDB integration" ), "ghost@cs.msu.su" );
+    aboutData.addAuthor( i18n("Hamish Rodda"), i18n( "Text editor integration, definition-use chain" ), "rodda@kde.org" );
+
+    aboutData.addCredit( i18n("Matt Rogers"), QString(), "mattr@kde.org");
+    aboutData.addCredit( i18n("Cédric Pasteur"), i18n("astyle and indent support"), "cedric.pasteur@free.fr" );
+    aboutData.addCredit( i18n("Evgeniy Ivanov"), i18n("Distributed VCS, Git, Mercurial"), "powerfox@kde.ru" );
     //Veritas is outside in playground currently.
-    //aboutData.addCredit( ki18n("Manuel Breugelmanns"), ki18n( "Veritas, QTest integraton"), "mbr.nxi@gmail.com" );
-    aboutData.addCredit( ki18n("Robert Gruber") , ki18n( "SnippetPart, debugger and usability patches" ), "rgruber@users.sourceforge.net" );
-    aboutData.addCredit( ki18n("Dukju Ahn"), ki18n( "Subversion plugin, Custom Make Manager, Overall improvements" ), "dukjuahn@gmail.com" );
-    aboutData.addAuthor( ki18n("Niko Sams"), ki18n( "GDB integration, Webdevelopment Plugins" ), "niko.sams@gmail.com" );
-    aboutData.addAuthor( ki18n("Milian Wolff"), ki18n( "Co-Maintainer, Generic manager, Webdevelopment Plugins, Snippets, Performance" ), "mail@milianw.de" );
+    //aboutData.addCredit( i18n("Manuel Breugelmanns"), i18n( "Veritas, QTest integraton"), "mbr.nxi@gmail.com" );
+    aboutData.addCredit( i18n("Robert Gruber") , i18n( "SnippetPart, debugger and usability patches" ), "rgruber@users.sourceforge.net" );
+    aboutData.addCredit( i18n("Dukju Ahn"), i18n( "Subversion plugin, Custom Make Manager, Overall improvements" ), "dukjuahn@gmail.com" );
+    aboutData.addAuthor( i18n("Niko Sams"), i18n( "GDB integration, Webdevelopment Plugins" ), "niko.sams@gmail.com" );
+    aboutData.addAuthor( i18n("Milian Wolff"), i18n( "Co-Maintainer, Generic manager, Webdevelopment Plugins, Snippets, Performance" ), "mail@milianw.de" );
 
     return aboutData;
 }
 
 CorePrivate::CorePrivate(Core *core):
-    m_componentData( aboutData() ), m_core(core), m_cleanedUp(false), m_shuttingDown(false)
+    m_aboutData( createAboutData() ), m_core(core), m_cleanedUp(false), m_shuttingDown(false)
 {
 }
 
 bool CorePrivate::initialize(Core::Setup mode, QString session )
 {
     m_mode=mode;
+
+    qCDebug(SHELL) << "Creating controllers";
+
     emit m_core->startupProgress(0);
     if( !sessionController )
     {
@@ -136,13 +141,13 @@ bool CorePrivate::initialize(Core::Setup mode, QString session )
     {
         workingSetController = new WorkingSetController();
     }
-    kDebug() << "Creating ui controller";
+    qCDebug(SHELL) << "Creating ui controller";
     if( !uiController )
     {
         uiController = new UiController(m_core);
     }
     emit m_core->startupProgress(10);
-    kDebug() << "Creating plugin controller";
+    qCDebug(SHELL) << "Creating plugin controller";
 
     if( !pluginController )
     {
@@ -183,7 +188,7 @@ bool CorePrivate::initialize(Core::Setup mode, QString session )
     }
     emit m_core->startupProgress(30);
 
-    if ( !progressController) 
+    if ( !progressController)
     {
         progressController = ProgressManager::instance();
     }
@@ -211,7 +216,9 @@ bool CorePrivate::initialize(Core::Setup mode, QString session )
     }
     emit m_core->startupProgress(47);
 
-    kDebug() << "initializing ui controller";
+    qCDebug(SHELL) << "Done creating controllers";
+
+    qCDebug(SHELL) << "Initializing controllers";
 
     sessionController.data()->initialize( session );
     if( !sessionController.data()->activeSessionLock() ) {
@@ -224,8 +231,13 @@ bool CorePrivate::initialize(Core::Setup mode, QString session )
     // the controller construct
     DUChain::initialize();
 
-    if(!(mode & Core::NoUi)) uiController.data()->initialize();
+    if (!(mode & Core::NoUi)) {
+        uiController.data()->initialize();
+    }
     languageController.data()->initialize();
+    if (partController) {
+        partController.data()->initialize();
+    }
     projectController.data()->initialize();
     documentController.data()->initialize();
 
@@ -240,20 +252,23 @@ bool CorePrivate::initialize(Core::Setup mode, QString session )
         tool views to a list of available tool view, and then grab
         those tool views when loading an area.  */
 
-    kDebug() << "loading session plugins";
+    qCDebug(SHELL) << "Initializing plugin controller (loading session plugins)";
     pluginController.data()->initialize();
     emit m_core->startupProgress(78);
 
+    qCDebug(SHELL) << "Initializing working set controller";
     if(!(mode & Core::NoUi))
     {
         workingSetController.data()->initialize();
         /* Need to do this after everything else is loaded.  It's too
             hard to restore position of views, and toolbars, and whatever
             that are not created yet.  */
-        uiController.data()->loadAllAreas(KGlobal::config());
+        uiController.data()->loadAllAreas(KSharedConfig::openConfig());
         uiController.data()->defaultMainWindow()->show();
     }
     emit m_core->startupProgress(90);
+
+    qCDebug(SHELL) << "Initializing remaining controllers";
     runController.data()->initialize();
     sourceFormatterController.data()->initialize();
     selectionController.data()->initialize();
@@ -266,6 +281,8 @@ bool CorePrivate::initialize(Core::Setup mode, QString session )
 
     installSignalHandler();
 
+    qCDebug(SHELL) << "Done initializing controllers";
+
     if (partController) {
         // check features of kate and report to user if it does not fit
         KTextEditor::Document* doc = partController.data()->createTextPart();
@@ -319,23 +336,24 @@ CorePrivate::~CorePrivate()
     testController.clear();
 }
 
-bool Core::initialize(KSplashScreen* splash, Setup mode, const QString& session )
+bool Core::initialize(QObject* splash, Setup mode, const QString& session )
 {
     if (m_self)
         return true;
 
     m_self = new Core();
     if (splash) {
+        // can't use new signal/slot syntax here, we don't know the class that splash has at runtime
         connect(m_self, SIGNAL(startupProgress(int)), splash, SLOT(progress(int)));
     }
     bool ret = m_self->d->initialize(mode, session);
     if( splash ) {
         QTimer::singleShot( 200, splash, SLOT(deleteLater()) );
     }
-    
+
     if(ret)
         emit m_self->initializationCompleted();
-    
+
     return ret;
 }
 
@@ -349,18 +367,19 @@ Core::Core(QObject *parent)
 {
     d = new CorePrivate(this);
 
-    connect(QCoreApplication::instance(), SIGNAL(aboutToQuit()), this, SLOT(shutdown()));
+    connect(QCoreApplication::instance(), &QCoreApplication::aboutToQuit, this, &Core::shutdown);
 }
 
 Core::Core(CorePrivate* dd, QObject* parent)
 : ICore(parent), d(dd)
 {
-    connect(QCoreApplication::instance(), SIGNAL(aboutToQuit()), this, SLOT(shutdown()));
+    connect(QCoreApplication::instance(), &QCoreApplication::aboutToQuit, this, &Core::shutdown);
 }
 
 Core::~Core()
 {
-    kDebug() ;
+    qCDebug(SHELL);
+
     //Cleanup already called before mass destruction of GUI
     delete d;
     m_self = 0;
@@ -373,10 +392,14 @@ Core::Setup Core::setupFlags() const
 
 void Core::shutdown()
 {
+    qCDebug(SHELL);
+
     if (!d->m_shuttingDown) {
         cleanup();
         deleteLater();
     }
+
+    qCDebug(SHELL) << "Shutdown done";
 }
 
 bool Core::shuttingDown() const
@@ -386,6 +409,8 @@ bool Core::shuttingDown() const
 
 void Core::cleanup()
 {
+    qCDebug(SHELL);
+
     d->m_shuttingDown = true;
     emit aboutToShutdown();
 
@@ -402,7 +427,9 @@ void Core::cleanup()
         // Closes all documents (discards, as already saved if the user wished earlier)
         d->documentController.data()->cleanup();
         d->runController.data()->cleanup();
-
+        if (d->partController) {
+            d->partController->cleanup();
+        }
         d->projectController.data()->cleanup();
         d->sourceFormatterController.data()->cleanup();
         d->pluginController.data()->cleanup();
@@ -420,9 +447,9 @@ void Core::cleanup()
     emit shutdownCompleted();
 }
 
-KComponentData Core::componentData() const
+KAboutData Core::aboutData() const
 {
-    return d->m_componentData;
+    return d->m_aboutData;
 }
 
 IUiController *Core::uiController()
@@ -568,9 +595,8 @@ WorkingSetController* Core::workingSetControllerInternal()
 
 QString Core::version()
 {
-    return KDEVPLATFORM_VERSION_STR;
+    return KDEVPLATFORM_VERSION_STRING;
 }
 
 }
 
-#include "core.moc"
