@@ -24,16 +24,13 @@
 
 #include "debugcontroller.h"
 
-#include <QtCore/QMetaEnum>
+#include <QAction>
 
-#include <KDE/KLocale>
-#include <KDE/KDebug>
-#include <KDE/KActionCollection>
-#include <KDE/KAction>
-#include <KDE/KParts/Part>
-#include <KDE/KParts/PartManager>
-#include <KDE/KTextEditor/Document>
-#include <KDE/KTextEditor/MarkInterface>
+#include <KActionCollection>
+#include <KLocalizedString>
+#include <KTextEditor/Document>
+#include <KTextEditor/MarkInterface>
+#include <KXMLGUIFactory>
 
 #include "../interfaces/idocument.h"
 #include "../interfaces/icore.h"
@@ -45,14 +42,14 @@
 #include "../sublime/view.h"
 #include "../sublime/mainwindow.h"
 #include "../sublime/area.h"
-#include "core.h"
-#include "uicontroller.h"
 #include "../debugger/breakpoint/breakpointmodel.h"
 #include "../debugger/breakpoint/breakpointwidget.h"
 #include "../debugger/variable/variablewidget.h"
 #include "../debugger/framestack/framestackmodel.h"
 #include "../debugger/framestack/framestackwidget.h"
-#include <KXMLGUIFactory>
+#include "core.h"
+#include "debug.h"
+#include "uicontroller.h"
 
 
 namespace KDevelop {
@@ -64,22 +61,22 @@ public:
   DebuggerToolFactory(DebugController* controller, const QString &id, Qt::DockWidgetArea defaultArea)
   : m_controller(controller), m_id(id), m_defaultArea(defaultArea) {}
 
-  virtual QWidget* create(QWidget *parent = 0)
+  virtual QWidget* create(QWidget *parent = 0) override
   {
     return new T(m_controller, parent);
   }
 
-  virtual QString id() const
+  virtual QString id() const override
   {
     return m_id;
   }
 
-  virtual Qt::DockWidgetArea defaultPosition()
+  virtual Qt::DockWidgetArea defaultPosition() override
   {
     return m_defaultArea;
   }
 
-  virtual void viewCreated(Sublime::View* view)
+  virtual void viewCreated(Sublime::View* view) override
   {
       if (view->widget()->metaObject()->indexOfSignal("requestRaise()") != -1)
           QObject::connect(view->widget(), SIGNAL(requestRaise()), view, SLOT(requestRaise()));
@@ -87,7 +84,7 @@ public:
 
   /* At present, some debugger widgets (e.g. breakpoint) contain actions so that shortcuts
      work, but they don't need any toolbar.  So, suppress toolbar action.  */
-  virtual QList<QAction*> toolBarActions( QWidget* viewWidget ) const
+  virtual QList<QAction*> toolBarActions( QWidget* viewWidget ) const override
   {
       Q_UNUSED(viewWidget);
       return QList<QAction*>();
@@ -111,12 +108,13 @@ DebugController::DebugController(QObject *parent)
       m_variableCollection(new VariableCollection(this)),
       m_uiInitialized(false)
 {
-    setComponentData(KComponentData("kdevdebugger"));
+    setComponentName("kdevdebugger", "kdevdebugger");
     setXMLFile("kdevdebuggershellui.rc");
 }
 
 void DebugController::initialize()
 {
+    m_breakpointModel->load();
 }
 
 void DebugController::initializeUi()
@@ -148,9 +146,9 @@ void DebugController::initializeUi()
     foreach(KParts::Part* p, KDevelop::ICore::self()->partController()->parts())
         partAdded(p);
     connect(KDevelop::ICore::self()->partController(),
-            SIGNAL(partAdded(KParts::Part*)),
+            &IPartController::partAdded,
             this,
-            SLOT(partAdded(KParts::Part*)));
+            &DebugController::partAdded);
 
 
     ICore::self()->uiController()->activeMainWindow()->guiFactory()->addClient(this);
@@ -184,7 +182,7 @@ void DebugController::partAdded(KParts::Part* part)
         KTextEditor::MarkInterface *iface = dynamic_cast<KTextEditor::MarkInterface*>(doc);
         if( !iface )
             return;
-        
+
         iface->setMarkPixmap(KTextEditor::MarkInterface::Execution, *executionPointPixmap());
     }
 }
@@ -198,104 +196,99 @@ void DebugController::setupActions()
 {
     KActionCollection* ac = actionCollection();
 
-    KAction* action = m_continueDebugger = new KAction(KIcon("media-playback-start"), i18n("&Continue"), this);
-    action->setToolTip( i18n("Continues the application execution") );
-    action->setWhatsThis( i18n("<b>Continue application execution</b><p>"
-        "Continues the execution of your application in the "
-        "debugger. This only takes effect when the application "
-        "has been halted by the debugger (i.e. a breakpoint has "
-        "been activated or the interrupt was pressed).</p>") );
+    QAction* action = m_continueDebugger = new QAction(QIcon::fromTheme("media-playback-start"), i18n("&Continue"), this);
+    action->setToolTip( i18n("Continue application execution") );
+    action->setWhatsThis( i18n("Continues the execution of your application in the "
+                               "debugger. This only takes effect when the application "
+                               "has been halted by the debugger (i.e. a breakpoint has "
+                               "been activated or the interrupt was pressed).") );
     ac->addAction("debug_continue", action);
-    connect(action, SIGNAL(triggered(bool)), this, SLOT(run()));
+    connect(action, &QAction::triggered, this, &DebugController::run);
 
     #if 0
-    m_restartDebugger = action = new KAction(KIcon("media-seek-backward"), i18n("&Restart"), this);
+    m_restartDebugger = action = new QAction(QIcon::fromTheme("media-seek-backward"), i18n("&Restart"), this);
     action->setToolTip( i18n("Restart program") );
-    action->setWhatsThis( i18n("<b>Restarts application</b><p>"
-                               "Restarts applications from the beginning.</p>"
-                              ) );
+    action->setWhatsThis( i18n("Restarts applications from the beginning.") );
     action->setEnabled(false);
     connect(action, SIGNAL(triggered(bool)), this, SLOT(restartDebugger()));
     ac->addAction("debug_restart", action);
     #endif
 
-    m_interruptDebugger = action = new KAction(KIcon("media-playback-pause"), i18n("Interrupt"), this);
+    m_interruptDebugger = action = new QAction(QIcon::fromTheme("media-playback-pause"), i18n("Interrupt"), this);
     action->setToolTip( i18n("Interrupt application") );
-    action->setWhatsThis(i18n("<b>Interrupt application</b><p>Interrupts the debugged process or current debugger command.</p>"));
-    connect(action, SIGNAL(triggered(bool)), this, SLOT(interruptDebugger()));
+    action->setWhatsThis(i18n("Interrupts the debugged process or current debugger command."));
+    connect(action, &QAction::triggered, this, &DebugController::interruptDebugger);
     ac->addAction("debug_pause", action);
 
-    m_runToCursor = action = new KAction(KIcon("debug-run-cursor"), i18n("Run to &Cursor"), this);
+    m_runToCursor = action = new QAction(QIcon::fromTheme("debug-run-cursor"), i18n("Run to &Cursor"), this);
     action->setToolTip( i18n("Run to cursor") );
-    action->setWhatsThis(i18n("<b>Run to cursor</b><p>Continues execution until the cursor position is reached.</p>"));
-    connect(action, SIGNAL(triggered(bool)), this, SLOT(runToCursor()));
+    action->setWhatsThis(i18n("Continues execution until the cursor position is reached."));
+    connect(action, &QAction::triggered, this, &DebugController::runToCursor);
     ac->addAction("debug_runtocursor", action);
 
 
-    m_jumpToCursor = action = new KAction(KIcon("debug-execute-to-cursor"), i18n("Set E&xecution Position to Cursor"), this);
+    m_jumpToCursor = action = new QAction(QIcon::fromTheme("debug-execute-to-cursor"), i18n("Set E&xecution Position to Cursor"), this);
     action->setToolTip( i18n("Jump to cursor") );
-    action->setWhatsThis(i18n("<b>Set Execution Position </b><p>Set the execution pointer to the current cursor position.</p>"));
-    connect(action, SIGNAL(triggered(bool)), this, SLOT(jumpToCursor()));
+    action->setWhatsThis(i18n("Continue execution from the current cursor position."));
+    connect(action, &QAction::triggered, this, &DebugController::jumpToCursor);
     ac->addAction("debug_jumptocursor", action);
 
-    m_stepOver = action = new KAction(KIcon("debug-step-over"), i18n("Step &Over"), this);
-    action->setShortcut(Qt::Key_F10);
+    m_stepOver = action = new QAction(QIcon::fromTheme("debug-step-over"), i18n("Step &Over"), this);
+    ac->setDefaultShortcut( action, Qt::Key_F10);
     action->setToolTip( i18n("Step over the next line") );
-    action->setWhatsThis( i18n("<b>Step over</b><p>"
-                               "Executes one line of source in the current source file. "
+    action->setWhatsThis( i18n("Executes one line of source in the current source file. "
                                "If the source line is a call to a function the whole "
                                "function is executed and the app will stop at the line "
-                               "following the function call.</p>") );
-    connect(action, SIGNAL(triggered(bool)), this, SLOT(stepOver()));
+                               "following the function call.") );
+    connect(action, &QAction::triggered, this, &DebugController::stepOver);
     ac->addAction("debug_stepover", action);
 
 
-    m_stepOverInstruction = action = new KAction(KIcon("debug-step-instruction"), i18n("Step over Ins&truction"), this);
+    m_stepOverInstruction = action = new QAction(QIcon::fromTheme("debug-step-instruction"), i18n("Step over Ins&truction"), this);
     action->setToolTip( i18n("Step over instruction") );
-    action->setWhatsThis(i18n("<b>Step over instruction</b><p>Steps over the next assembly instruction.</p>"));
-    connect(action, SIGNAL(triggered(bool)), this, SLOT(stepOverInstruction()));
+    action->setWhatsThis(i18n("Steps over the next assembly instruction."));
+    connect(action, &QAction::triggered, this, &DebugController::stepOverInstruction);
     ac->addAction("debug_stepoverinst", action);
 
 
-    m_stepInto = action = new KAction(KIcon("debug-step-into"), i18n("Step &Into"), this);
-    action->setShortcut(Qt::Key_F11);
+    m_stepInto = action = new QAction(QIcon::fromTheme("debug-step-into"), i18n("Step &Into"), this);
+    ac->setDefaultShortcut( action, Qt::Key_F11);
     action->setToolTip( i18n("Step into the next statement") );
-    action->setWhatsThis( i18n("<b>Step into</b><p>"
-                               "Executes exactly one line of source. If the source line "
+    action->setWhatsThis( i18n("Executes exactly one line of source. If the source line "
                                "is a call to a function then execution will stop after "
-                               "the function has been entered.</p>") );
-    connect(action, SIGNAL(triggered(bool)), this, SLOT(stepInto()));
+                               "the function has been entered.") );
+    connect(action, &QAction::triggered, this, &DebugController::stepInto);
     ac->addAction("debug_stepinto", action);
 
 
-    m_stepIntoInstruction = action = new KAction(KIcon("debug-step-into-instruction"), i18n("Step into I&nstruction"), this);
+    m_stepIntoInstruction = action = new QAction(QIcon::fromTheme("debug-step-into-instruction"), i18n("Step into I&nstruction"), this);
     action->setToolTip( i18n("Step into instruction") );
-    action->setWhatsThis(i18n("<b>Step into instruction</b><p>Steps into the next assembly instruction.</p>"));
-    connect(action, SIGNAL(triggered(bool)), this, SLOT(stepIntoInstruction()));
+    action->setWhatsThis(i18n("Steps into the next assembly instruction."));
+    connect(action, &QAction::triggered, this, &DebugController::stepIntoInstruction);
     ac->addAction("debug_stepintoinst", action);
 
-    m_stepOut = action = new KAction(KIcon("debug-step-out"), i18n("Step O&ut"), this);
-    action->setShortcut(Qt::Key_F12);
-    action->setToolTip( i18n("Steps out of the current function") );
-    action->setWhatsThis( i18n("<b>Step out</b><p>"
-                               "Executes the application until the currently executing "
+    m_stepOut = action = new QAction(QIcon::fromTheme("debug-step-out"), i18n("Step O&ut"), this);
+    ac->setDefaultShortcut( action, Qt::Key_F12);
+    action->setToolTip( i18n("Step out of the current function") );
+    action->setWhatsThis( i18n("Executes the application until the currently executing "
                                "function is completed. The debugger will then display "
                                "the line after the original call to that function. If "
                                "program execution is in the outermost frame (i.e. in "
-                               "main()) then this operation has no effect.</p>") );
-    connect(action, SIGNAL(triggered(bool)), this, SLOT(stepOut()));
+                               "main()) then this operation has no effect.") );
+    connect(action, &QAction::triggered, this, &DebugController::stepOut);
     ac->addAction("debug_stepout", action);
 
-    m_toggleBreakpoint = action = new KAction(KIcon("script-error"), i18n("Toggle Breakpoint"), this);
+    m_toggleBreakpoint = action = new QAction(QIcon::fromTheme("script-error"), i18n("Toggle Breakpoint"), this);
+    ac->setDefaultShortcut( action, i18n("Ctrl+Alt+B") );
     action->setToolTip(i18n("Toggle breakpoint"));
-    action->setWhatsThis(i18n("<b>Toggle breakpoint</b><p>Toggles the breakpoint at the current line in editor.</p>"));
-    connect(action, SIGNAL(triggered(bool)), this, SLOT(toggleBreakpoint()));
+    action->setWhatsThis(i18n("Toggles the breakpoint at the current line in editor."));
+    connect(action, &QAction::triggered, this, &DebugController::toggleBreakpoint);
     ac->addAction("debug_toggle_breakpoint", action);
 }
 
 void DebugController::addSession(IDebugSession* session)
 {
-    kDebug() << session;
+    qCDebug(SHELL) << session;
     Q_ASSERT(session->variableController());
     Q_ASSERT(session->breakpointController());
     Q_ASSERT(session->frameStackModel());
@@ -305,16 +298,16 @@ void DebugController::addSession(IDebugSession* session)
         m_currentSession.data()->stopDebugger();
     }
     m_currentSession = session;
-        
-    connect(session, SIGNAL(stateChanged(KDevelop::IDebugSession::DebuggerState)), SLOT(debuggerStateChanged(KDevelop::IDebugSession::DebuggerState)));
-    connect(session, SIGNAL(showStepInSource(KUrl,int,QString)), SLOT(showStepInSource(KUrl,int)));
-    connect(session, SIGNAL(clearExecutionPoint()), SLOT(clearExecutionPoint()));
-    connect(session, SIGNAL(raiseFramestackViews()), SIGNAL(raiseFramestackViews()));
-    
+
+    connect(session, &IDebugSession::stateChanged, this, &DebugController::debuggerStateChanged);
+    connect(session, &IDebugSession::showStepInSource, this, &DebugController::showStepInSource);
+    connect(session, &IDebugSession::clearExecutionPoint, this, &DebugController::clearExecutionPoint);
+    connect(session, &IDebugSession::raiseFramestackViews, this, &DebugController::raiseFramestackViews);
+
     updateDebuggerState(session->state(), session);
-        
+
     emit currentSessionChanged(session);
-    
+
     if((Core::self()->setupFlags() & Core::NoUi)) return;
 
 
@@ -323,12 +316,13 @@ void DebugController::addSession(IDebugSession* session)
         QString workingSet = mainWindow->area()->workingSet();
         ICore::self()->uiController()->switchToArea("debug", IUiController::ThisWindow);
         mainWindow->area()->setWorkingSet(workingSet);
+        connect(mainWindow, &Sublime::MainWindow::areaChanged, this, &DebugController::areaChanged);
     }
 }
 
 void DebugController::clearExecutionPoint()
 {
-    kDebug();
+    qCDebug(SHELL);
     foreach (KDevelop::IDocument* document, KDevelop::ICore::self()->documentController()->openDocuments()) {
         KTextEditor::MarkInterface *iface = dynamic_cast<KTextEditor::MarkInterface*>(document->textDocument());
         if (!iface)
@@ -344,18 +338,18 @@ void DebugController::clearExecutionPoint()
     }
 }
 
-void DebugController::showStepInSource(const KUrl &url, int lineNum)
+void DebugController::showStepInSource(const QUrl &url, int lineNum)
 {
     if((Core::self()->setupFlags() & Core::NoUi)) return;
 
     clearExecutionPoint();
-    kDebug() << url << lineNum;
+    qCDebug(SHELL) << url << lineNum;
 
     Q_ASSERT(dynamic_cast<IDebugSession*>(sender()));
-    QPair<KUrl,int> openUrl = static_cast<IDebugSession*>(sender())->convertToLocalUrl(qMakePair<KUrl,int>( url, lineNum ));
+    QPair<QUrl,int> openUrl = static_cast<IDebugSession*>(sender())->convertToLocalUrl(qMakePair<QUrl,int>( url, lineNum ));
     KDevelop::IDocument* document = KDevelop::ICore::self()
         ->documentController()
-        ->openDocument(openUrl.first, KTextEditor::Cursor(openUrl.second, 0));
+        ->openDocument(openUrl.first, KTextEditor::Cursor(openUrl.second, 0), IDocumentController::DoNotFocus);
 
     if( !document )
         return;
@@ -374,7 +368,7 @@ void DebugController::debuggerStateChanged(KDevelop::IDebugSession::DebuggerStat
 {
     Q_ASSERT(dynamic_cast<IDebugSession*>(sender()));
     IDebugSession* session = static_cast<IDebugSession*>(sender());
-    kDebug() << session << state << "current" << m_currentSession.data();
+    qCDebug(SHELL) << session << state << "current" << m_currentSession.data();
     if (session == m_currentSession.data()) {
         updateDebuggerState(state, session);
     }
@@ -402,32 +396,29 @@ void DebugController::updateDebuggerState(IDebugSession::DebuggerState state, ID
     Q_UNUSED(session);
     if((Core::self()->setupFlags() & Core::NoUi)) return;
 
-    kDebug() << state;
+    qCDebug(SHELL) << state;
     switch (state) {
         case IDebugSession::StoppedState:
         case IDebugSession::NotStartedState:
         case IDebugSession::StoppingState:
-            kDebug() << "new state: stopped";
+            qCDebug(SHELL) << "new state: stopped";
             stateChanged("stopped");
-            clearExecutionPoint();
-            //m_restartDebugger->setEnabled(session->restartAvaliable());
+            //m_restartDebugger->setEnabled(session->restartAvailable());
             break;
         case IDebugSession::StartingState:
         case IDebugSession::PausedState:
-            kDebug() << "new state: paused";
+            qCDebug(SHELL) << "new state: paused";
             stateChanged("paused");
-            //m_restartDebugger->setEnabled(session->restartAvaliable());
+            //m_restartDebugger->setEnabled(session->restartAvailable());
             break;
         case IDebugSession::ActiveState:
-            kDebug() << "new state: active";
+            qCDebug(SHELL) << "new state: active";
             stateChanged("active");
             //m_restartDebugger->setEnabled(false);
-            clearExecutionPoint();
             break;
         case IDebugSession::EndedState:
-            kDebug() << "new state: ended";
+            qCDebug(SHELL) << "new state: ended";
             stateChanged("ended");
-            clearExecutionPoint();
             //m_restartDebugger->setEnabled(false);
             break;
     }
@@ -518,6 +509,13 @@ void DebugController::stepOut() {
     }
 }
 
+void DebugController::areaChanged(Sublime::Area* newArea)
+{
+    if (newArea->objectName()!="debug") {
+        stopDebugger();
+    }
+}
+
 void DebugController::toggleBreakpoint()
 {
     if (KDevelop::IDocument* document = KDevelop::ICore::self()->documentController()->activeDocument()) {
@@ -529,7 +527,7 @@ void DebugController::toggleBreakpoint()
 
 const QPixmap* DebugController::executionPointPixmap()
 {
-  static QPixmap pixmap=KIcon("go-next").pixmap(QSize(22,22), QIcon::Normal, QIcon::Off);
+  static QPixmap pixmap=QIcon::fromTheme("go-next").pixmap(QSize(22,22), QIcon::Normal, QIcon::Off);
   return &pixmap;
 }
 
