@@ -1,7 +1,7 @@
 /*
    Copyright 2009 Aleix Pol Gonzalez <aleixpol@kde.org>
    Copyright 2010 Benjamin Port <port.benjamin@gmail.com>
-   
+
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License version 2 as published by the Free Software Foundation.
@@ -18,6 +18,8 @@
 */
 
 #include "documentationcontroller.h"
+#include "debug.h"
+
 #include <interfaces/iplugin.h>
 #include <interfaces/idocumentationprovider.h>
 #include <interfaces/idocumentationproviderprovider.h>
@@ -25,11 +27,13 @@
 #include <interfaces/iplugincontroller.h>
 #include <interfaces/iuicontroller.h>
 #include <shell/core.h>
-#include <sublime/view.h>
 
-#include <ktexteditor/document.h>
-#include <ktexteditor/view.h>
-#include <KDebug>
+#include <QAction>
+
+#include <KActionCollection>
+#include <KParts/MainWindow>
+#include <KTextEditor/Document>
+#include <KTextEditor/View>
 
 #include <interfaces/contextmenuextension.h>
 #include <interfaces/idocumentcontroller.h>
@@ -38,35 +42,73 @@
 #include <language/duchain/duchain.h>
 #include <language/duchain/duchainlock.h>
 #include <language/duchain/duchainutils.h>
+#include <language/duchain/types/identifiedtype.h>
+#include <language/duchain/types/typeutils.h>
 #include <documentation/documentationview.h>
-#include <KParts/MainWindow>
-#include <KActionCollection>
 
 using namespace KDevelop;
 
+namespace {
+
+/**
+ * Return a "more useful" declaration that documentation providers can look-up
+ *
+ * @code
+ *   QPoint point;
+ *            ^-- cursor here
+ * @endcode
+ *
+ * In this case, this method returns a Declaration pointer to the *type*
+ * instead of a pointer to the instance, which is more useful when looking for help
+ *
+ * @return A more appropriate Declaration pointer or the given parameter @p decl
+ */
+Declaration* usefulDeclaration(Declaration* decl)
+{
+    if (!decl)
+        return nullptr;
+
+    // First: Attempt to find the declaration of a definition
+    decl = DUChainUtils::declarationForDefinition(decl);
+
+    // Convenience feature: Retrieve the type declaration of instances,
+    // it makes no sense to pass the declaration pointer of instances of types
+    if (decl->kind() == Declaration::Instance) {
+        AbstractType::Ptr type = TypeUtils::targetTypeKeepAliases(decl->abstractType(), decl->topContext());
+        IdentifiedType* idType = dynamic_cast<IdentifiedType*>(type.data());
+        Declaration* idDecl = idType ? idType->declaration(decl->topContext()) : 0;
+        if (idDecl) {
+            decl = idDecl;
+        }
+    }
+    return decl;
+}
+
+}
+
 class DocumentationViewFactory: public KDevelop::IToolViewFactory
 {
     public:
         DocumentationViewFactory()
             : mProvidersModel(0)
         {}
-        
-        virtual QWidget* create( QWidget *parent = 0 )
+
+        virtual QWidget* create( QWidget *parent = 0 ) override
         {
             return new DocumentationView( parent, providers() );
         }
-        
-        virtual Qt::DockWidgetArea defaultPosition() { return Qt::RightDockWidgetArea; }
-        virtual QString id() const { return "org.kdevelop.DocumentationView"; }
-        
+
+        virtual Qt::DockWidgetArea defaultPosition() override { return Qt::RightDockWidgetArea; }
+        virtual QString id() const override { return "org.kdevelop.DocumentationView"; }
+
     private:
         ProvidersModel* providers() {
             if(!mProvidersModel)
                 mProvidersModel = new ProvidersModel;
-            
+
             return mProvidersModel;
         }
-        
+
         ProvidersModel* mProvidersModel;
 };
 
@@ -75,8 +117,8 @@ DocumentationController::DocumentationController(Core* core)
 {
     m_showDocumentation = core->uiController()->activeMainWindow()->actionCollection()->addAction("showDocumentation");
     m_showDocumentation->setText(i18n("Show Documentation"));
-    m_showDocumentation->setIcon(KIcon("documentation"));
-    connect(m_showDocumentation, SIGNAL(triggered(bool)), SLOT(doShowDocumentation()));
+    m_showDocumentation->setIcon(QIcon::fromTheme("documentation"));
+    connect(m_showDocumentation, &QAction::triggered, this, &DocumentationController::doShowDocumentation);
 }
 
 void DocumentationController::initialize()
@@ -89,69 +131,54 @@ void DocumentationController::initialize()
 
 void KDevelop::DocumentationController::doShowDocumentation()
 {
-    IDocument* doc = ICore::self()->documentController()->activeDocument();
-    if(!doc)
-      return;
-    
-    KTextEditor::Document* textDoc = doc->textDocument();
-    if(!textDoc)
-      return;
-    
-    KTextEditor::View* view = textDoc->activeView();
+    KTextEditor::View* view = ICore::self()->documentController()->activeTextDocumentView();
     if(!view)
       return;
-    
+
     KDevelop::DUChainReadLocker lock( DUChain::lock() );
-    
-    Declaration *dec = DUChainUtils::declarationForDefinition( DUChainUtils::itemUnderCursor( doc->url(), SimpleCursor(view->cursorPosition()) ) );
-    
-    if(dec) {
-        KSharedPtr< IDocumentation > documentation = documentationForDeclaration(dec);
-        if(documentation) {
-            showDocumentation(documentation);
-        }
+
+    Declaration* decl = usefulDeclaration(DUChainUtils::itemUnderCursor(view->document()->url(), KTextEditor::Cursor(view->cursorPosition())));
+    auto documentation = documentationForDeclaration(decl);
+    if (documentation) {
+        showDocumentation(documentation);
     }
 }
 
-
-Q_DECLARE_METATYPE(KSharedPtr<KDevelop::IDocumentation>)
-
 KDevelop::ContextMenuExtension KDevelop::DocumentationController::contextMenuExtension ( Context* context )
 {
     ContextMenuExtension menuExt;
-    
-    qRegisterMetaType<KSharedPtr<KDevelop::IDocumentation> >("KSharedPtr<KDevelop::IDocumentation>");
-    
+
     DeclarationContext* ctx = dynamic_cast<DeclarationContext*>(context);
     if(ctx) {
         DUChainReadLocker lock(DUChain::lock());
         if(!ctx->declaration().data())
             return menuExt;
-        
-        KSharedPtr< IDocumentation > doc = documentationForDeclaration(ctx->declaration().data());
-        if(doc) {
+
+        auto doc = documentationForDeclaration(ctx->declaration().data());
+        if (doc) {
             menuExt.addAction(ContextMenuExtension::ExtensionGroup, m_showDocumentation);;
         }
     }
-    
+
     return menuExt;
 }
 
-KSharedPtr< KDevelop::IDocumentation > DocumentationController::documentationForDeclaration(Declaration* decl)
+IDocumentation::Ptr DocumentationController::documentationForDeclaration(Declaration* decl)
 {
-    KSharedPtr<KDevelop::IDocumentation> ret;
-    
-    foreach(IDocumentationProvider* doc, documentationProviders())
-    {
-        kDebug(9529) << "Documentation provider found:" << doc;
-        ret=doc->documentationForDeclaration(decl);
-        
-        kDebug(9529) << "Documentation proposed: " << ret;
-        if(ret)
-            break;
+    if (!decl)
+        return {};
+
+    foreach (IDocumentationProvider* doc, documentationProviders()) {
+        qCDebug(SHELL) << "Documentation provider found:" << doc;
+        auto ret = doc->documentationForDeclaration(decl);
+
+        qCDebug(SHELL) << "Documentation proposed: " << ret.data();
+        if (ret) {
+            return ret;
+        }
     }
-    
-    return ret;
+
+    return {};
 }
 
 
@@ -159,42 +186,42 @@ QList< IDocumentationProvider* > DocumentationController::documentationProviders
 {
     QList<IPlugin*> plugins=ICore::self()->pluginController()->allPluginsForExtension("org.kdevelop.IDocumentationProvider");
     QList<IPlugin*> pluginsProvider=ICore::self()->pluginController()->allPluginsForExtension("org.kdevelop.IDocumentationProviderProvider");
-    
+
     QList<IDocumentationProvider*> ret;
     foreach(IPlugin* p, pluginsProvider)
     {
         IDocumentationProviderProvider *docProvider=p->extension<IDocumentationProviderProvider>();
         if (!docProvider) {
-            kWarning() << "plugin" << p << "does not implement ProviderProvider extension, rerun kbuildsycoca4";
+            qWarning() << "plugin" << p << "does not implement ProviderProvider extension, rerun kbuildsycoca5";
             continue;
         }
         ret.append(docProvider->providers());
     }
-    
+
     foreach(IPlugin* p, plugins)
     {
         IDocumentationProvider *doc=p->extension<IDocumentationProvider>();
         if (!doc) {
-            kWarning() << "plugin" << p << "does not implement Provider extension, rerun kbuildsycoca4";
+            qWarning() << "plugin" << p << "does not implement Provider extension, rerun kbuildsycoca5";
             continue;
         }
         ret.append(doc);
     }
-    
+
     return ret;
 }
 
-void KDevelop::DocumentationController::showDocumentation(KSharedPtr< KDevelop::IDocumentation > doc)
+void KDevelop::DocumentationController::showDocumentation(const IDocumentation::Ptr& doc)
 {
     QWidget* w = ICore::self()->uiController()->findToolView(i18n("Documentation"), m_factory, KDevelop::IUiController::CreateAndRaise);
     if(!w) {
-        kWarning() << "Could not add documentation toolview";
+        qWarning() << "Could not add documentation toolview";
         return;
     }
-    
+
     DocumentationView* view = dynamic_cast<DocumentationView*>(w);
     if( !view ) {
-        kWarning() << "Could not cast toolview" << w << "to DocumentationView class!";
+        qWarning() << "Could not cast toolview" << w << "to DocumentationView class!";
         return;
     }
     view->showDocumentation(doc);
@@ -205,4 +232,3 @@ void DocumentationController::changedDocumentationProviders()
     emit providersChanged();
 }
 
-#include "documentationcontroller.moc"
