@@ -1,7 +1,7 @@
 /*
    Copyright 2009 Aleix Pol Gonzalez <aleixpol@kde.org>
    Copyright 2010 Benjamin Port <port.benjamin@gmail.com>
-   
+
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License version 2 as published by the Free Software Foundation.
@@ -21,41 +21,40 @@
 #define KDEVPLATFORM_DOCUMENTATIONCONTROLLER_H
 
 #include <interfaces/idocumentationcontroller.h>
-#include <QObject>
-#include <KAction>
 
 class DocumentationViewFactory;
+
 class QAction;
 
 namespace KDevelop
 {
 
-class IDocumentationProvider;
 class Core;
 class Context;
 class ContextMenuExtension;
 
-class DocumentationController : public KDevelop::IDocumentationController
+class DocumentationController : public IDocumentationController
 {
-        Q_OBJECT
-    public:
-        DocumentationController(Core* core);
-        
-        void initialize();
-        
-        virtual QList<IDocumentationProvider*> documentationProviders() const;
-        virtual KSharedPtr< KDevelop::IDocumentation > documentationForDeclaration(KDevelop::Declaration* declaration);
-        virtual void showDocumentation(KSharedPtr< KDevelop::IDocumentation > doc);
-        ContextMenuExtension contextMenuExtension( Context* context );
-        
-    public slots:
-        virtual void changedDocumentationProviders();
-    private slots:
-        void doShowDocumentation();
-    private:
-        DocumentationViewFactory* m_factory;
+    Q_OBJECT
+public:
+    explicit DocumentationController(Core* core);
 
-        KAction* m_showDocumentation;
+    void initialize();
+
+    virtual QList<IDocumentationProvider*> documentationProviders() const override;
+    virtual IDocumentation::Ptr documentationForDeclaration(Declaration* declaration) override;
+    virtual void showDocumentation(const IDocumentation::Ptr& doc) override;
+    ContextMenuExtension contextMenuExtension( Context* context );
+
+public slots:
+    virtual void changedDocumentationProviders() override;
+
+private slots:
+    void doShowDocumentation();
+
+private:
+    DocumentationViewFactory* m_factory;
+    QAction* m_showDocumentation;
 };
 
 }
