@@ -33,6 +33,10 @@ Boston, MA 02110-1301, USA.
 
 #include "shellexport.h"
 
+namespace KTextEditor {
+class View;
+}
+
 namespace Sublime {
     class Document;
     class Area;
@@ -59,36 +63,32 @@ public:
 
     /**Constructor.
     @param parent The parent object.*/
-    DocumentController( QObject *parent = 0 );
+    explicit DocumentController( QObject *parent = 0 );
     virtual ~DocumentController();
 
-    /**Call this before a call to @ref editDocument to set the encoding of the
-    document to be opened.
-    @param encoding The encoding to open as.*/
-    virtual void setEncoding( const QString &encoding );
-    virtual QString encoding() const;
-
     /**Finds the first document object corresponding to a given url.
     @param url The Url of the document.
     @return The corresponding document, or null if not found.*/
-    virtual IDocument* documentForUrl( const KUrl & url ) const;
+    virtual IDocument* documentForUrl( const QUrl & url ) const override;
 
     /**@return The list of open documents*/
-    virtual QList<IDocument*> openDocuments() const;
+    virtual QList<IDocument*> openDocuments() const override;
 
     /**Refers to the document currently active or focused.
     @return The active document.*/
-    virtual IDocument* activeDocument() const;
-    
-    virtual void activateDocument( IDocument * document, const KTextEditor::Range& range = KTextEditor::Range::invalid() );
+    virtual IDocument* activeDocument() const override;
 
-    virtual void registerDocumentForMimetype( const QString&, KDevelop::IDocumentFactory* );
+    virtual KTextEditor::View* activeTextDocumentView() const override;
+    
+    virtual void activateDocument( IDocument * document, const KTextEditor::Range& range = KTextEditor::Range::invalid() ) override;
+
+    virtual void registerDocumentForMimetype( const QString&, KDevelop::IDocumentFactory* ) override;
 
     /// Request the document controller to save all documents.
     /// If the \a mode is not IDocument::Silent, ask the user which documents to save.
     /// Returns false if the user cancels the save dialog.
-    virtual bool saveAllDocuments(IDocument::DocumentSaveMode mode);
-    bool saveAllDocumentsForWindow(KParts::MainWindow* mw, IDocument::DocumentSaveMode mode, bool currentAreaOnly = false);
+    virtual bool saveAllDocuments(IDocument::DocumentSaveMode mode) override;
+    bool saveAllDocumentsForWindow(KParts::MainWindow* mw, IDocument::DocumentSaveMode mode, bool currentAreaOnly = false) override;
 
     void initialize();
 
@@ -101,18 +101,18 @@ public:
     using IDocumentController::openDocument;
 
     /**checks that url is an url of empty document*/
-    static bool isEmptyDocumentUrl(const KUrl &url);
-    static KUrl nextEmptyDocumentUrl();
+    static bool isEmptyDocumentUrl(const QUrl &url);
+    static QUrl nextEmptyDocumentUrl();
     
-    virtual IDocumentFactory* factory(const QString& mime) const;
+    virtual IDocumentFactory* factory(const QString& mime) const override;
 
     
     virtual bool openDocument(IDocument* doc,
                               const KTextEditor::Range& range = KTextEditor::Range::invalid(),
                               DocumentActivationParams activationParams = 0,
-                              IDocument* buddy = 0);
+                              IDocument* buddy = 0) override;
 
-    virtual KTextEditor::Document* globalTextEditorInstance();
+    virtual KTextEditor::Document* globalTextEditorInstance() override;
     
 public Q_SLOTS:
     /**Opens a new or existing document.
@@ -122,25 +122,25 @@ public Q_SLOTS:
     @param buddy The buddy document
     @return The opened document
     */
-    virtual Q_SCRIPTABLE IDocument* openDocument( const KUrl &url,
+    virtual Q_SCRIPTABLE IDocument* openDocument( const QUrl &url,
             const KTextEditor::Range& range = KTextEditor::Range::invalid(),
             DocumentActivationParams activationParams = 0,
-            const QString& encoding = "",
-            IDocument* buddy = 0 );
+            const QString& encoding = {},
+            IDocument* buddy = 0 ) override;
 
-    virtual Q_SCRIPTABLE IDocument* openDocumentFromText( const QString& data );
+    virtual Q_SCRIPTABLE IDocument* openDocumentFromText( const QString& data ) override;
     
-    virtual KDevelop::IDocument* openDocument( const KUrl &url, const QString& prefname );
+    virtual KDevelop::IDocument* openDocument( const QUrl &url, const QString& prefname ) override;
 
-    virtual void closeDocument( const KUrl &url );
+    virtual void closeDocument( const QUrl &url );
     void fileClose();
     void slotSaveAllDocuments();
-    virtual void closeAllDocuments();
+    virtual bool closeAllDocuments() override;
     void closeAllOtherDocuments();
     void reloadAllDocuments();
 
     // DBUS-compatible versions of openDocument
-    virtual Q_SCRIPTABLE bool openDocumentSimple( QString url );
+    virtual Q_SCRIPTABLE bool openDocumentSimple( QString url, int line = -1, int column = 0 );
     // Opens a list of documents, with optional split-view separators, like: "file1 / [ file2 - fil3 ]" (see kdevplatform_shell_environment.sh)
     virtual Q_SCRIPTABLE bool openDocumentsSimple( QStringList urls );
     virtual Q_SCRIPTABLE bool openDocumentFromTextSimple( QString text );
@@ -150,16 +150,14 @@ public Q_SLOTS:
     // If 'target' is "[selection]", returns the path of the currently active selection.
     // If 'target' is the name of a project, returns the root-path of that project.
     // Whenever the returned path corresponds to a directory, a '/.' suffix is appended.
-    Q_SCRIPTABLE QString activeDocumentPath(QString target="") const;
+    Q_SCRIPTABLE QString activeDocumentPath(QString target = {}) const;
 
     // Returns all open documents in the current area
     Q_SCRIPTABLE QStringList activeDocumentPaths() const;
     void vcsAnnotateCurrentDocument();
 
-    void reloaded(KTextEditor::Document* doc);
-    
 private Q_SLOTS:
-    virtual void slotOpenDocument(const KUrl &url);
+    virtual void slotOpenDocument(const QUrl &url);
     void notifyDocumentClosed(Sublime::Document* doc);
 
 private:
@@ -168,7 +166,7 @@ private:
     QList<IDocument*> documentsExclusivelyInWindow(MainWindow* mw, bool currentAreaOnly = false) const;
     QList<IDocument*> modifiedDocuments(const QList<IDocument*>& list) const;
 
-    bool saveSomeDocuments(const QList<IDocument*>& list, IDocument::DocumentSaveMode mode);
+    bool saveSomeDocuments(const QList<IDocument*>& list, IDocument::DocumentSaveMode mode) override;
 
     void setupActions();
     Q_PRIVATE_SLOT(d, void removeDocument(Sublime::Document*))
