@@ -18,19 +18,19 @@
 */
 
 #include "launchconfigurationdialog.h"
-#include <QtGui/QSplitter>
-#include <QtGui/QTreeView>
-#include <QtGui/QStackedWidget>
-#include <QtGui/QGridLayout>
-#include <QtGui/QToolButton>
 
-#include <klocale.h>
-#include <klineedit.h>
-#include <kcombobox.h>
-#include <kdebug.h>
-#include <kpushbutton.h>
-#include <ktabwidget.h>
-#include <kmessagebox.h>
+#include <QDialogButtonBox>
+#include <QLabel>
+#include <QMenu>
+#include <QPushButton>
+#include <QTabWidget>
+#include <QToolButton>
+#include <QTreeView>
+#include <QVBoxLayout>
+
+#include <KComboBox>
+#include <KLocalizedString>
+#include <KMessageBox>
 
 #include <interfaces/launchconfigurationpage.h>
 #include <interfaces/iproject.h>
@@ -40,40 +40,42 @@
 #include "core.h"
 #include "runcontroller.h"
 #include "launchconfiguration.h"
+#include "debug.h"
 
 #include <interfaces/ilauncher.h>
 #include <interfaces/ilaunchmode.h>
-#include <QLayout>
-#include <QMenu>
-#include <QLabel>
+#include <interfaces/launchconfigurationtype.h>
 
 namespace KDevelop
 {
-    
+
 bool launchConfigGreaterThan(KDevelop::LaunchConfigurationType* a, KDevelop::LaunchConfigurationType* b)
 {
     return a->name()>b->name();
 }
 
 //TODO: Maybe use KPageDialog instead, might make the model stuff easier and the default-size stuff as well
-LaunchConfigurationDialog::LaunchConfigurationDialog(QWidget* parent): KDialog(parent), currentPageChanged( false )
+LaunchConfigurationDialog::LaunchConfigurationDialog(QWidget* parent)
+    : QDialog(parent)
+    , currentPageChanged(false)
 {
-    setButtons( KDialog::Ok | KDialog::Cancel | KDialog::Apply );
-    setButtonFocus( KDialog::Ok );
     setWindowTitle( i18n( "Launch Configurations" ) );
-    button( KDialog::Apply )->setEnabled( false );
-    
-    setupUi( mainWidget() );
-    mainWidget()->layout()->setContentsMargins( 0, 0, 0, 0 );
+
+    QWidget *mainWidget = new QWidget(this);
+    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    mainLayout->addWidget(mainWidget);
+
+    setupUi(mainWidget);
+    mainLayout->setContentsMargins( 0, 0, 0, 0 );
     splitter->setSizes(QList<int>() << 260 << 620);
-    
-    addConfig->setIcon( KIcon("list-add") );
+
+    addConfig->setIcon( QIcon::fromTheme("list-add") );
     addConfig->setEnabled( false );
     addConfig->setToolTip(i18nc("@info:tooltip", "Add a new launch configuration."));
-    deleteConfig->setIcon( KIcon("list-remove") );
+    deleteConfig->setIcon( QIcon::fromTheme("list-remove") );
     deleteConfig->setEnabled( false );
     deleteConfig->setToolTip(i18nc("@info:tooltip", "Delete selected launch configuration."));
-    
+
     model = new LaunchConfigurationsModel( tree );
     tree->setModel( model );
     tree->setExpandsOnDoubleClick( true );
@@ -85,14 +87,14 @@ LaunchConfigurationDialog::LaunchConfigurationDialog(QWidget* parent): KDialog(p
     for(int row=0; row<model->rowCount(); row++) {
         tree->setExpanded(model->index(row, 0), true);
     }
-    
+
     tree->setContextMenuPolicy(Qt::CustomContextMenu);
-    connect( tree, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(doTreeContextMenu(QPoint)) );
-    connect( deleteConfig, SIGNAL(clicked()), this, SLOT(deleteConfiguration()));
-    connect( model, SIGNAL(dataChanged(QModelIndex,QModelIndex)), SLOT(modelChanged(QModelIndex,QModelIndex)) );
-    connect( tree->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)), SLOT(selectionChanged(QItemSelection,QItemSelection)));
+    connect( tree, &QTreeView::customContextMenuRequested, this, &LaunchConfigurationDialog::doTreeContextMenu );
+    connect( deleteConfig, &QToolButton::clicked, this, &LaunchConfigurationDialog::deleteConfiguration);
+    connect( model, &LaunchConfigurationsModel::dataChanged, this, &LaunchConfigurationDialog::modelChanged );
+    connect( tree->selectionModel(), &QItemSelectionModel::selectionChanged, this, &LaunchConfigurationDialog::selectionChanged);
     QModelIndex idx = model->indexForConfig( Core::self()->runControllerInternal()->defaultLaunch() );
-    kDebug() << "selecting index:" << idx;
+    qCDebug(SHELL) << "selecting index:" << idx;
     if( !idx.isValid() )
     {
         for( int i = 0; i < model->rowCount(); i++ )
@@ -110,8 +112,8 @@ LaunchConfigurationDialog::LaunchConfigurationDialog(QWidget* parent): KDialog(p
     }
     tree->selectionModel()->select( QItemSelection( idx, idx ), QItemSelectionModel::ClearAndSelect | QItemSelectionModel::Rows );
     tree->selectionModel()->setCurrentIndex( idx, QItemSelectionModel::ClearAndSelect | QItemSelectionModel::Rows );
-    
-    // Unfortunately tree->resizeColumnToContents() only looks at the top-level 
+
+    // Unfortunately tree->resizeColumnToContents() only looks at the top-level
     // items, instead of all open ones. Hence we're calculating it ourselves like
     // this:
     // Take the selected index, check if it has childs, if so take the first child
@@ -145,12 +147,12 @@ LaunchConfigurationDialog::LaunchConfigurationDialog(QWidget* parent): KDialog(p
 
     QMenu* m = new QMenu(this);
     QList<LaunchConfigurationType*> types = Core::self()->runController()->launchConfigurationTypes();
-    qSort(types.begin(), types.end(), launchConfigGreaterThan); //we want it in reverse order
+    std::sort(types.begin(), types.end(), launchConfigGreaterThan); //we want it in reverse order
     foreach(LaunchConfigurationType* type, types)
     {
-        connect(type, SIGNAL(signalAddLaunchConfiguration(KDevelop::ILaunchConfiguration*)), SLOT(addConfiguration(KDevelop::ILaunchConfiguration*)));
+        connect(type, &LaunchConfigurationType::signalAddLaunchConfiguration, this, &LaunchConfigurationDialog::addConfiguration);
         QMenu* suggestionsMenu = type->launcherSuggestions();
-        
+
         if(suggestionsMenu) {
             m->addMenu(suggestionsMenu);
         }
@@ -169,25 +171,28 @@ LaunchConfigurationDialog::LaunchConfigurationDialog(QWidget* parent): KDialog(p
         separator->setSeparator(true);
         m->insertAction(m->actions().first(), separator);
     }
-    
+
     foreach(LaunchConfigurationType* type, types) {
         QAction* action = new QAction(type->icon(), type->name(), m);
         action->setProperty("configtype", qVariantFromValue<QObject*>(type));
-        connect(action, SIGNAL(triggered(bool)), SLOT(createEmptyLauncher()));
-        
+        connect(action, &QAction::triggered, this, &LaunchConfigurationDialog::createEmptyLauncher);
+
         if(!m->actions().isEmpty())
             m->insertAction(m->actions().first(), action);
         else
             m->addAction(action);
     }
     addConfig->setMenu(m);
-    
-    connect(debugger, SIGNAL(currentIndexChanged(int)), SLOT(launchModeChanged(int)));
 
-    connect( this, SIGNAL(okClicked()), SLOT(saveConfig()) );
-    connect( this, SIGNAL(applyClicked()), SLOT(saveConfig()) );
-    
-    setInitialSize( QSize(qMax(700, sizeHint().width()), qMax(500, sizeHint().height())) );
+    connect(debugger, static_cast<void(QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &LaunchConfigurationDialog::launchModeChanged);
+
+    connect(buttonBox, &QDialogButtonBox::accepted, this, &LaunchConfigurationDialog::accept);
+    connect(buttonBox, &QDialogButtonBox::rejected, this, &LaunchConfigurationDialog::reject);
+    connect(buttonBox->button(QDialogButtonBox::Ok), &QPushButton::clicked, this, static_cast<void(LaunchConfigurationDialog::*)()>(&LaunchConfigurationDialog::saveConfig) );
+    connect(buttonBox->button(QDialogButtonBox::Apply), &QPushButton::clicked, this, static_cast<void(LaunchConfigurationDialog::*)()>(&LaunchConfigurationDialog::saveConfig) );
+    mainLayout->addWidget(buttonBox);
+
+    resize( QSize(qMax(700, sizeHint().width()), qMax(500, sizeHint().height())) );
 }
 
 void LaunchConfigurationDialog::doTreeContextMenu(QPoint point)
@@ -197,10 +202,10 @@ void LaunchConfigurationDialog::doTreeContextMenu(QPoint point)
         if ( selected.parent().isValid() && ! selected.parent().parent().isValid() ) {
             // only display the menu if a launch config is clicked
             QMenu menu;
-            QAction* rename = new QAction(KIcon("edit-rename"), i18n("Rename configuration"), &menu);
-            QAction* delete_ = new QAction(KIcon("edit-delete"), i18n("Delete configuration"), &menu);
-            connect(rename, SIGNAL(triggered(bool)), this, SLOT(renameSelected()));
-            connect(delete_, SIGNAL(triggered(bool)), this, SLOT(deleteConfiguration()));
+            QAction* rename = new QAction(QIcon::fromTheme("edit-rename"), i18n("Rename configuration"), &menu);
+            QAction* delete_ = new QAction(QIcon::fromTheme("edit-delete"), i18n("Delete configuration"), &menu);
+            connect(rename, &QAction::triggered, this, &LaunchConfigurationDialog::renameSelected);
+            connect(delete_, &QAction::triggered, this, &LaunchConfigurationDialog::deleteConfiguration);
             menu.addAction(rename);
             menu.addAction(delete_);
             menu.exec(tree->mapToGlobal(point));
@@ -224,7 +229,7 @@ void LaunchConfigurationDialog::renameSelected()
 
 QSize LaunchConfigurationDialog::sizeHint() const
 {
-    QSize s = KDialog::sizeHint();
+    QSize s = QDialog::sizeHint();
     return s.expandedTo(QSize(880, 520));
 }
 
@@ -232,10 +237,10 @@ void LaunchConfigurationDialog::createEmptyLauncher()
 {
     QAction* action = qobject_cast<QAction*>(sender());
     Q_ASSERT(action);
-    
+
     LaunchConfigurationType* type = qobject_cast<LaunchConfigurationType*>(action->property("configtype").value<QObject*>());
     Q_ASSERT(type);
-    
+
     IProject* p = model->projectForIndex(tree->currentIndex());
     QPair< QString, QString > launcher( type->launchers().at( 0 )->supportedModes().at(0), type->launchers().at( 0 )->id() );
     ILaunchConfiguration* l = ICore::self()->runController()->createLaunchConfiguration(type, launcher, p);
@@ -249,7 +254,7 @@ void LaunchConfigurationDialog::selectionChanged(QItemSelection selected, QItemS
         LaunchConfiguration* l = model->configForIndex( deselected.indexes().first() );
         if( l )
         {
-            disconnect(l, SIGNAL(nameChanged(LaunchConfiguration*)), this,  SLOT(updateNameLabel(LaunchConfiguration*)));
+            disconnect(l, &LaunchConfiguration::nameChanged, this,  &LaunchConfigurationDialog::updateNameLabel);
             if( currentPageChanged )
             {
                 if( KMessageBox::questionYesNo( this, i18n("Selected Launch Configuration has unsaved changes. Do you want to save it?"), i18n("Unsaved Changes") ) == KMessageBox::Yes )
@@ -258,33 +263,33 @@ void LaunchConfigurationDialog::selectionChanged(QItemSelection selected, QItemS
                 } else {
                     LaunchConfigPagesContainer* tab = qobject_cast<LaunchConfigPagesContainer*>( stack->currentWidget() );
                     tab->setLaunchConfiguration( l );
-                    button( KDialog::Apply )->setEnabled( false );
+                    buttonBox->button(QDialogButtonBox::Apply)->setEnabled( false );
                     currentPageChanged = false;
                 }
             }
         }
     }
     updateNameLabel(0);
-    
+
     for( int i = 1; i < stack->count(); i++ )
     {
         QWidget* w = stack->widget(i);
         stack->removeWidget(w);
         delete w;
     }
-    
+
     debugger->clear();
     if( !selected.indexes().isEmpty() )
     {
         QModelIndex idx = selected.indexes().first();
         LaunchConfiguration* l = model->configForIndex( idx );
         ILaunchMode* lm = model->modeForIndex( idx );
-        
+
         if( l )
         {
             updateNameLabel( l );
             tree->expand( model->indexForConfig( l ) );
-            connect( l, SIGNAL(nameChanged(LaunchConfiguration*)), SLOT(updateNameLabel(LaunchConfiguration*)) );
+            connect( l, &LaunchConfiguration::nameChanged, this, &LaunchConfigurationDialog::updateNameLabel );
             if( lm )
             {
                 bool b = debugger->blockSignals(true);
@@ -296,13 +301,13 @@ void LaunchConfigurationDialog::selectionChanged(QItemSelection selected, QItemS
                     }
                 }
                 debugger->blockSignals(b);
-                
+
                 debugger->setVisible(debugger->count()>0);
                 debugLabel->setVisible(debugger->count()>0);
-                
+
                 QVariant currentLaunchMode = idx.sibling(idx.row(), 1).data(Qt::EditRole);
                 debugger->setCurrentIndex(debugger->findData(currentLaunchMode));
-                
+
                 ILauncher* launcher = l->type()->launcherForId( currentLaunchMode.toString() );
                 if( launcher )
                 {
@@ -312,11 +317,11 @@ void LaunchConfigurationDialog::selectionChanged(QItemSelection selected, QItemS
                         QList<KDevelop::LaunchConfigurationPageFactory*> pages = launcher->configPages();
                         if(!pages.isEmpty()) {
                             tab = new LaunchConfigPagesContainer( launcher->configPages(), stack );
-                            connect( tab, SIGNAL(changed()), SLOT(pageChanged()) );
+                            connect( tab, &LaunchConfigPagesContainer::changed, this, &LaunchConfigurationDialog::pageChanged );
                             stack->addWidget( tab );
                         }
                     }
-                    
+
                     if(tab) {
                         tab->setLaunchConfiguration( l );
                         stack->setCurrentWidget( tab );
@@ -331,7 +336,7 @@ void LaunchConfigurationDialog::selectionChanged(QItemSelection selected, QItemS
                         stack->addWidget(label);
                         stack->setCurrentWidget(label);
                     }
-                    
+
                     updateNameLabel( l );
                     addConfig->setEnabled( false );
                     deleteConfig->setEnabled( false );
@@ -341,7 +346,7 @@ void LaunchConfigurationDialog::selectionChanged(QItemSelection selected, QItemS
                     deleteConfig->setEnabled( false );
                     stack->setCurrentIndex( 0 );
                 }
-            } else 
+            } else
             {
                 //TODO: enable removal button
                 LaunchConfigurationType* type = l->type();
@@ -349,19 +354,19 @@ void LaunchConfigurationDialog::selectionChanged(QItemSelection selected, QItemS
                 if( !tab )
                 {
                     tab = new LaunchConfigPagesContainer( type->configPages(), stack );
-                    connect( tab, SIGNAL(changed()), SLOT(pageChanged()) );
+                    connect( tab, &LaunchConfigPagesContainer::changed, this, &LaunchConfigurationDialog::pageChanged );
                     stack->addWidget( tab );
                 }
-                kDebug() << "created pages, setting config up";
+                qCDebug(SHELL) << "created pages, setting config up";
                 tab->setLaunchConfiguration( l );
                 stack->setCurrentWidget( tab );
-                
+
                 addConfig->setEnabled( true );
                 deleteConfig->setEnabled( true );
                 debugger->setVisible( false );
                 debugLabel->setVisible( false );
             }
-        } else 
+        } else
         {
             addConfig->setEnabled( true );
             deleteConfig->setEnabled( false );
@@ -374,7 +379,7 @@ void LaunchConfigurationDialog::selectionChanged(QItemSelection selected, QItemS
             debugger->setVisible( false );
             debugLabel->setVisible( false );
         }
-    } else 
+    } else
     {
         debugger->setVisible( false );
         debugLabel->setVisible( false );
@@ -391,7 +396,7 @@ void LaunchConfigurationDialog::saveConfig( const QModelIndex& idx )
     if( tab )
     {
         tab->save();
-        button( KDialog::Apply )->setEnabled( false );
+        buttonBox->button(QDialogButtonBox::Apply)->setEnabled( false );
         currentPageChanged = false;
     }
 }
@@ -408,7 +413,7 @@ void LaunchConfigurationDialog::saveConfig()
 void LaunchConfigurationDialog::pageChanged()
 {
     currentPageChanged = true;
-    button( KDialog::Apply )->setEnabled( true );
+    buttonBox->button(QDialogButtonBox::Apply)->setEnabled( true );
 }
 
 void LaunchConfigurationDialog::modelChanged(QModelIndex topLeft, QModelIndex bottomRight)
@@ -465,9 +470,9 @@ void LaunchConfigurationDialog::addConfiguration(ILaunchConfiguration* _launch)
     Q_ASSERT(launch);
     int row = launch->project() ? model->findItemForProject(launch->project())->row : 0;
     QModelIndex idx  = model->index(row, 0);
-    
+
     model->addConfiguration(launch, idx);
-    
+
     QModelIndex newindex = model->index( model->rowCount( idx ) - 1, 0, idx );
     tree->selectionModel()->select( newindex, QItemSelectionModel::ClearAndSelect | QItemSelectionModel::Rows );
     tree->selectionModel()->setCurrentIndex( newindex, QItemSelectionModel::ClearAndSelect | QItemSelectionModel::Rows );
@@ -491,7 +496,7 @@ LaunchConfigurationsModel::LaunchConfigurationsModel(QObject* parent): QAbstract
     foreach( LaunchConfiguration* l, Core::self()->runControllerInternal()->launchConfigurationsInternal() )
     {
         addItemForLaunchConfig( l );
-    }    
+    }
 }
 
 void LaunchConfigurationsModel::addItemForLaunchConfig( LaunchConfiguration* l )
@@ -543,7 +548,7 @@ LaunchConfigurationsModel::ProjectItem* LaunchConfigurationsModel::findItemForPr
     foreach( TreeItem* t, topItems )
     {
         ProjectItem* pi = dynamic_cast<ProjectItem*>( t );
-        if( pi && pi->project == p ) 
+        if( pi && pi->project == p )
         {
             return pi;
         }
@@ -563,23 +568,23 @@ QVariant LaunchConfigurationsModel::data(const QModelIndex& index, int role) con
     if( index.isValid() && index.column() >= 0 && index.column() < 2 )
     {
         TreeItem* t = static_cast<TreeItem*>( index.internalPointer() );
-        switch( role ) 
+        switch( role )
         {
             case Qt::DisplayRole:
             {
                 LaunchItem* li = dynamic_cast<LaunchItem*>( t );
-                if( li ) 
+                if( li )
                 {
                     if( index.column() == 0 )
                     {
-                        return li->launch->name();   
+                        return li->launch->name();
                     } else if( index.column() == 1 )
                     {
                         return li->launch->type()->name();
                     }
                 }
                 ProjectItem* pi = dynamic_cast<ProjectItem*>( t );
-                if( pi && index.column() == 0 ) 
+                if( pi && index.column() == 0 )
                 {
                     return pi->project->name();
                 }
@@ -617,10 +622,10 @@ QVariant LaunchConfigurationsModel::data(const QModelIndex& index, int role) con
                 if ( index.column() == 0 && !index.parent().isValid() ) {
                     if (index.row() == 0) {
                         // global item
-                        return KIcon("folder");
+                        return QIcon::fromTheme("folder");
                     } else {
                         // project item
-                        return KIcon("folder-development");
+                        return QIcon::fromTheme("folder-development");
                     }
                 }
             }
@@ -656,11 +661,11 @@ QModelIndex LaunchConfigurationsModel::index(int row, int column, const QModelIn
     if( !hasIndex( row, column, parent ) )
         return QModelIndex();
     TreeItem* tree;
-    
+
     if( !parent.isValid() )
-    {   
+    {
         tree = topItems.at( row );
-    } else 
+    } else
     {
         TreeItem* t = static_cast<TreeItem*>( parent.internalPointer() );
         tree = t->children.at( row );
@@ -702,12 +707,12 @@ int LaunchConfigurationsModel::rowCount(const QModelIndex& parent) const
 
 QVariant LaunchConfigurationsModel::headerData(int section, Qt::Orientation orientation, int role) const
 {
-    if( orientation == Qt::Horizontal && role == Qt::DisplayRole ) 
+    if( orientation == Qt::Horizontal && role == Qt::DisplayRole )
     {
-        if( section == 0 ) 
+        if( section == 0 )
         {
             return i18nc("Name of the Launch Configurations", "Name");
-        } else if( section == 1 ) 
+        } else if( section == 1 )
         {
             return i18nc("The type of the Launch Configurations (i.e. Python Application, C++ Application)", "Type");
         }
@@ -717,8 +722,8 @@ QVariant LaunchConfigurationsModel::headerData(int section, Qt::Orientation orie
 
 Qt::ItemFlags LaunchConfigurationsModel::flags(const QModelIndex& index) const
 {
-    if( index.isValid() && index.column() >= 0 
-        && index.column() < columnCount( QModelIndex() ) ) 
+    if( index.isValid() && index.column() >= 0
+        && index.column() < columnCount( QModelIndex() ) )
     {
         TreeItem* t = static_cast<TreeItem*>( index.internalPointer() );
         if( t && ( dynamic_cast<LaunchItem*>( t ) || ( dynamic_cast<LaunchModeItem*>( t ) && index.column() == 1 ) ) )
@@ -734,9 +739,9 @@ Qt::ItemFlags LaunchConfigurationsModel::flags(const QModelIndex& index) const
 
 bool LaunchConfigurationsModel::setData(const QModelIndex& index, const QVariant& value, int role)
 {
-    if( index.isValid() && index.parent().isValid() && role == Qt::EditRole ) 
+    if( index.isValid() && index.parent().isValid() && role == Qt::EditRole )
     {
-        if( index.row() >= 0 && index.row() < rowCount( index.parent() ) ) 
+        if( index.row() >= 0 && index.row() < rowCount( index.parent() ) )
         {
             LaunchItem* t = dynamic_cast<LaunchItem*>( static_cast<TreeItem*>( index.internalPointer() ) );
             if( t )
@@ -749,7 +754,7 @@ bool LaunchConfigurationsModel::setData(const QModelIndex& index, const QVariant
                     if (t->launch->type()->id() != value.toString()) {
                         t->launch->setType( value.toString() );
                         QModelIndex p = indexForConfig(t->launch);
-                        kDebug() << data(p);
+                        qCDebug(SHELL) << data(p);
                         beginRemoveRows( p, 0, t->children.count() );
                         qDeleteAll( t->children );
                         t->children.clear();
@@ -797,9 +802,9 @@ LaunchConfiguration* LaunchConfigurationsModel::configForIndex(const QModelIndex
         if( item )
         {
             return item->launch;
-        } 
+        }
         LaunchModeItem* lmitem = dynamic_cast<LaunchModeItem*>( static_cast<TreeItem*>( idx.internalPointer() ) );
-        if( lmitem ) 
+        if( lmitem )
         {
             return dynamic_cast<LaunchItem*>( lmitem->parent )->launch;
         }
@@ -824,7 +829,7 @@ QModelIndex LaunchConfigurationsModel::indexForConfig( LaunchConfiguration* l )
                 }
             }
         }
-        
+
         if( tparent )
         {
             foreach( TreeItem* c, tparent->children )
@@ -858,12 +863,12 @@ void LaunchConfigurationsModel::createConfiguration(const QModelIndex& parent )
     {
         TreeItem* t = static_cast<TreeItem*>( parent.internalPointer() );
         ProjectItem* ti = dynamic_cast<ProjectItem*>( t );
-        
+
         LaunchConfigurationType* type = Core::self()->runController()->launchConfigurationTypes().at(0);
         QPair<QString,QString> launcher = qMakePair( type->launchers().at( 0 )->supportedModes().at(0), type->launchers().at( 0 )->id() );
         IProject* p = ( ti ? ti->project : 0 );
         ILaunchConfiguration* l = Core::self()->runController()->createLaunchConfiguration( type, launcher, p );
-        
+
         addConfiguration(l, parent);
     }
 }
@@ -893,16 +898,16 @@ IProject* LaunchConfigurationsModel::projectForIndex(const QModelIndex& idx)
     }
 }
 
-LaunchConfigPagesContainer::LaunchConfigPagesContainer( const QList<LaunchConfigurationPageFactory*>& factories, QWidget* parent ) 
+LaunchConfigPagesContainer::LaunchConfigPagesContainer( const QList<LaunchConfigurationPageFactory*>& factories, QWidget* parent )
     : QWidget(parent)
 {
     setLayout( new QVBoxLayout( this ) );
     layout()->setContentsMargins( 0, 0, 0, 0 );
     QWidget* parentwidget = this;
-    KTabWidget* tab = 0;
+    QTabWidget* tab = 0;
     if( factories.count() > 1 )
     {
-        tab = new KTabWidget( this );
+        tab = new QTabWidget( this );
         parentwidget = tab;
         layout()->addWidget( tab );
     }
@@ -913,10 +918,10 @@ LaunchConfigPagesContainer::LaunchConfigPagesContainer( const QList<LaunchConfig
             page->layout()->setContentsMargins( 0, 0, 0, 0 );
         }
         pages.append( page );
-        connect( page, SIGNAL(changed()), SIGNAL(changed()) );
+        connect( page, &LaunchConfigurationPage::changed, this, &LaunchConfigPagesContainer::changed );
         if( tab ) {
             tab->addTab( page, page->icon(), page->title() );
-        } else 
+        } else
         {
             layout()->addWidget( page );
         }
@@ -947,7 +952,7 @@ QWidget* LaunchConfigurationModelDelegate::createEditor ( QWidget* parent, const
     const LaunchConfigurationsModel* model = dynamic_cast<const LaunchConfigurationsModel*>( index.model() );
     ILaunchMode* mode = model->modeForIndex( index );
     LaunchConfiguration* config = model->configForIndex( index );
-    if( index.column() == 1 && mode && config ) 
+    if( index.column() == 1 && mode && config )
     {
         KComboBox* box = new KComboBox( parent );
         QList<ILauncher*> launchers = config->type()->launchers();
@@ -980,7 +985,7 @@ void LaunchConfigurationModelDelegate::setEditorData ( QWidget* editor, const QM
 {
     const LaunchConfigurationsModel* model = dynamic_cast<const LaunchConfigurationsModel*>( index.model() );
     LaunchConfiguration* config = model->configForIndex( index );
-    if( index.column() == 1 && config ) 
+    if( index.column() == 1 && config )
     {
         KComboBox* box = qobject_cast<KComboBox*>( editor );
         box->setCurrentIndex( box->findData( index.data( Qt::EditRole ) ) );
@@ -995,7 +1000,7 @@ void LaunchConfigurationModelDelegate::setModelData ( QWidget* editor, QAbstract
 {
     LaunchConfigurationsModel* lmodel = dynamic_cast<LaunchConfigurationsModel*>( model );
     LaunchConfiguration* config = lmodel->configForIndex( index );
-    if( index.column() == 1 && config ) 
+    if( index.column() == 1 && config )
     {
         KComboBox* box = qobject_cast<KComboBox*>( editor );
         lmodel->setData( index, box->itemData( box->currentIndex() ) );
@@ -1015,4 +1020,3 @@ void LaunchConfigurationDialog::launchModeChanged(int item)
 
 }
 
-#include "launchconfigurationdialog.moc"
