@@ -22,33 +22,30 @@ Boston, MA 02110-1301, USA.
 #include "mainwindow.h"
 #include "mainwindow_p.h"
 
-#include <QtCore/QHash>
-#include <QtGui/QDockWidget>
-#include <QtGui/QDragEnterEvent>
-#include <QtGui/QDropEvent>
-#include <QtGui/QMenuBar>
-#include <QtDBus/QDBusConnection>
+#include <QDBusConnection>
+#include <QDomDocument>
+#include <QDragEnterEvent>
+#include <QDropEvent>
+#include <QMenu>
+#include <QMenuBar>
+#include <QMimeData>
+#include <QUrl>
 
-#include <KDE/KApplication>
-#include <KDE/KActionCollection>
-#include <kmenu.h>
-#include <kglobal.h>
-#include <klocale.h>
-#include <ktemporaryfile.h>
-#include <kactioncollection.h>
-#include <kdebug.h>
-#include <ktexteditor/document.h>
-#include <ktexteditor/view.h>
-#include <kshortcutsdialog.h>
-#include <kxmlguifactory.h>
-#include <ktoggleaction.h>
+#include <KActionCollection>
+#include <KLocalizedString>
+#include <KShortcutsDialog>
+#include <KTextEditor/Document>
+#include <KTextEditor/View>
+#include <KTextEditor/MainWindow>
 #include <KWindowSystem>
-#include <KMenuBar>
+#include <KXMLGUIFactory>
+#include <KColorScheme>
 
 #include <sublime/area.h>
 #include "shellextension.h"
 #include "partcontroller.h"
 #include "plugincontroller.h"
+#include "projectcontroller.h"
 #include "uicontroller.h"
 #include "documentcontroller.h"
 #include "debugcontroller.h"
@@ -56,34 +53,58 @@ Boston, MA 02110-1301, USA.
 #include "sessioncontroller.h"
 #include "sourceformattercontroller.h"
 #include "areadisplay.h"
+#include "project.h"
+#include "debug.h"
+#include "uiconfig.h"
 
 #include <interfaces/isession.h>
 #include <interfaces/iprojectcontroller.h>
 #include <sublime/view.h>
 #include <sublime/document.h>
 #include <sublime/urldocument.h>
+#include <sublime/container.h>
+#include <util/path.h>
+#include <util/widgetcolorizer.h>
 
-namespace KDevelop
-{
+using namespace KDevelop;
 
-void MainWindow::applyMainWindowSettings(const KConfigGroup& config, bool force)
+namespace {
+
+QColor defaultColor(const QPalette& palette)
 {
-    if(!d->changingActiveView())
-        KXmlGuiWindow::applyMainWindowSettings(config, force);
+    const KColorScheme scheme(palette.currentColorGroup());
+    return scheme.foreground(KColorScheme::NormalText).color();
 }
 
-MainWindow::MainWindow( Sublime::Controller *parent, Qt::WFlags flags )
+QColor colorForDocument(const QUrl& url, const QPalette& palette)
+{
+    auto project = Core::self()->projectController()->findProjectForUrl(url);
+    if (!project)
+        return QColor();
+
+    return WidgetColorizer::colorForId(qHash(project->path()), palette);
+}
+
+}
+
+void MainWindow::applyMainWindowSettings(const KConfigGroup& config)
+{
+    if(!d->changingActiveView())
+        KXmlGuiWindow::applyMainWindowSettings(config);
+}
+
+MainWindow::MainWindow( Sublime::Controller *parent, Qt::WindowFlags flags )
         : Sublime::MainWindow( parent, flags )
 {
     QDBusConnection::sessionBus().registerObject( "/kdevelop/MainWindow",
         this, QDBusConnection::ExportScriptableSlots );
 
     setAcceptDrops( true );
-    KConfigGroup cg = KGlobal::config()->group( "UiSettings" );
+    KConfigGroup cg = KSharedConfig::openConfig()->group( "UiSettings" );
     int bottomleft = cg.readEntry( "BottomLeftCornerOwner", 0 );
     int bottomright = cg.readEntry( "BottomRightCornerOwner", 0 );
-    kDebug() << "Bottom Left:" << bottomleft;
-    kDebug() << "Bottom Right:" << bottomright;
+    qCDebug(SHELL) << "Bottom Left:" << bottomleft;
+    qCDebug(SHELL) << "Bottom Right:" << bottomright;
 
     // 0 means vertical dock (left, right), 1 means horizontal dock( top, bottom )
     if( bottomleft == 0 )
@@ -112,8 +133,6 @@ MainWindow::MainWindow( Sublime::Controller *parent, Qt::WFlags flags )
 
 MainWindow::~ MainWindow()
 {
-    Core::self()->uiControllerInternal()->mainWindowDeleted(this);
-
     if (memberList().count() == 1) {
         // We're closing down...
         Core::self()->shutdown();
@@ -122,6 +141,11 @@ MainWindow::~ MainWindow()
     delete d;
 }
 
+KTextEditorIntegration::MainWindow *MainWindow::kateWrapper() const
+{
+    return d->kateWrapper();
+}
+
 void MainWindow::ensureVisible()
 {
     if (isMinimized()) {
@@ -169,24 +193,24 @@ void MainWindow::dropEvent( QDropEvent* ev )
     Sublime::View* dropToView = viewForPosition(mapToGlobal(ev->pos()));
     if(dropToView)
         activateView(dropToView);
-    
+
     foreach( const QUrl& u, ev->mimeData()->urls() )
     {
-        Core::self()->documentController()->openDocument( KUrl( u ) );
+        Core::self()->documentController()->openDocument( u );
     }
     ev->acceptProposedAction();
 }
 
 void MainWindow::loadSettings()
 {
-    kDebug() << "Loading Settings";
-    KConfigGroup cg = KGlobal::config()->group( "UiSettings" );
+    qCDebug(SHELL) << "Loading Settings";
+    KConfigGroup cg = KSharedConfig::openConfig()->group( "UiSettings" );
 
     // dock widget corner layout
     int bottomleft = cg.readEntry( "BottomLeftCornerOwner", 0 );
     int bottomright = cg.readEntry( "BottomRightCornerOwner", 0 );
-    kDebug() << "Bottom Left:" << bottomleft;
-    kDebug() << "Bottom Right:" << bottomright;
+    qCDebug(SHELL) << "Bottom Left:" << bottomleft;
+    qCDebug(SHELL) << "Bottom Right:" << bottomright;
 
     // 0 means vertical dock (left, right), 1 means horizontal dock( top, bottom )
     if( bottomleft == 0 )
@@ -199,22 +223,18 @@ void MainWindow::loadSettings()
     else if( bottomright == 1 )
         setCorner( Qt::BottomRightCorner, Qt::BottomDockWidgetArea );
 
+    updateAllTabColors();
+
     Sublime::MainWindow::loadSettings();
 }
 
-void MainWindow::saveSettings()
-{
-    Sublime::MainWindow::saveSettings();
-}
-
-
 void MainWindow::configureShortcuts()
 {
     ///Workaround for a problem with the actions: Always start the shortcut-configuration in the first mainwindow, then propagate the updated
     ///settings into the other windows
 
 
-// We need to bring up the shortcut dialog ourself instead of 
+// We need to bring up the shortcut dialog ourself instead of
 //      Core::self()->uiControllerInternal()->mainWindows()[0]->guiFactory()->configureShortcuts();
 // so we can connect to the saved() signal to propagate changes in the editor shortcuts
 
@@ -224,8 +244,8 @@ void MainWindow::configureShortcuts()
         if(client && !client->xmlFile().isEmpty())
             dlg.addCollection( client->actionCollection() );
     }
-    
-    connect(&dlg, SIGNAL(saved()), SLOT(shortcutsChanged()));
+
+    connect(&dlg, &KShortcutsDialog::saved, this, &MainWindow::shortcutsChanged);
     dlg.configure(true);
 
     QMap<QString, QKeySequence> shortcuts;
@@ -236,29 +256,25 @@ void MainWindow::configureShortcuts()
             }
         }
     }
-    
+
     for(int a = 1; a < Core::self()->uiControllerInternal()->mainWindows().size(); ++a) {
         foreach(KXMLGUIClient* client, Core::self()->uiControllerInternal()->mainWindows()[a]->guiFactory()->clients()) {
             foreach(QAction* action, client->actionCollection()->actions()) {
-                kDebug() << "transferring setting shortcut for" << action->objectName();
+                qCDebug(SHELL) << "transferring setting shortcut for" << action->objectName();
                 if(shortcuts.contains(action->objectName())) {
                     action->setShortcut(shortcuts[action->objectName()]);
                 }
             }
         }
     }
-    
+
 }
 
 void MainWindow::shortcutsChanged()
 {
-    //propagate shortcut changes to all the opened text documents by reloading the UI XML file
-    IDocument* activeDoc = Core::self()->documentController()->activeDocument();
-    if (!activeDoc || !activeDoc->textDocument()) {
+    KTextEditor::View *activeClient = Core::self()->documentController()->activeTextDocumentView();
+    if(!activeClient)
         return;
-    }
-
-    KTextEditor::View *activeClient = activeDoc->textDocument()->activeView();
 
     foreach(IDocument * doc, Core::self()->documentController()->openDocuments()) {
         KTextEditor::Document *textDocument = doc->textDocument();
@@ -277,39 +293,40 @@ void MainWindow::initialize()
 {
     KStandardAction::keyBindings(this, SLOT(configureShortcuts()), actionCollection());
     setupGUI( KXmlGuiWindow::ToolBar | KXmlGuiWindow::Create | KXmlGuiWindow::Save );
-    
+
     Core::self()->partController()->addManagedTopLevelWidget(this);
-    kDebug() << "Adding plugin-added connection";
-    
-    connect( Core::self()->pluginController(), SIGNAL(pluginLoaded(KDevelop::IPlugin*)),
-             d, SLOT(addPlugin(KDevelop::IPlugin*)));
-    connect( Core::self()->pluginController(), SIGNAL(pluginUnloaded(KDevelop::IPlugin*)),
-             d, SLOT(removePlugin(KDevelop::IPlugin*)));
-    connect( Core::self()->partController(), SIGNAL(activePartChanged(KParts::Part*)),
-        d, SLOT(activePartChanged(KParts::Part*)));
-    connect( this, SIGNAL(activeViewChanged(Sublime::View*)),
-        d, SLOT(changeActiveView(Sublime::View*)));
-    
+    qCDebug(SHELL) << "Adding plugin-added connection";
+
+    connect( Core::self()->pluginController(), &IPluginController::pluginLoaded,
+             d, &MainWindowPrivate::addPlugin);
+    connect( Core::self()->pluginController(), &IPluginController::pluginUnloaded,
+             d, &MainWindowPrivate::removePlugin);
+    connect( Core::self()->partController(), &IPartController::activePartChanged,
+        d, &MainWindowPrivate::activePartChanged);
+    connect( this, &MainWindow::activeViewChanged,
+        d, &MainWindowPrivate::changeActiveView);
+
     foreach(IPlugin* plugin, Core::self()->pluginController()->loadedPlugins())
         d->addPlugin(plugin);
-    
+
     guiFactory()->addClient(Core::self()->sessionController());
     guiFactory()->addClient(Core::self()->sourceFormatterControllerInternal());
     // Needed to re-plug the actions from the sessioncontroller as xmlguiclients don't
     // seem to remember which actions where plugged in.
     Core::self()->sessionController()->plugActions();
     d->setupGui();
-    
-    //Queued so we process it with some delay, to make sure the rest of the UI has already adapted
-    connect(Core::self()->documentController(), SIGNAL(documentActivated(KDevelop::IDocument*)), SLOT(updateCaption()), Qt::QueuedConnection);
-    connect(Core::self()->documentController(), SIGNAL(documentClosed(KDevelop::IDocument*)), SLOT(updateCaption()), Qt::QueuedConnection);
-    connect(Core::self()->documentController(), SIGNAL(documentUrlChanged(KDevelop::IDocument*)), SLOT(updateCaption()), Qt::QueuedConnection);
-    
-    connect(Core::self()->projectController(), SIGNAL(projectOpened(KDevelop::IProject*)), SLOT(updateCaption()));
-    connect(Core::self()->projectController(), SIGNAL(projectClosed(KDevelop::IProject*)), SLOT(updateCaption()));
 
-    connect(Core::self()->sessionController()->activeSession(), SIGNAL(nameChanged(QString,QString)), SLOT(updateCaption()));
-    
+    //Queued so we process it with some delay, to make sure the rest of the UI has already adapted
+    connect(Core::self()->documentController(), &IDocumentController::documentActivated, this, &MainWindow::updateCaption, Qt::QueuedConnection);
+    connect(Core::self()->documentController(), &IDocumentController::documentClosed, this, &MainWindow::updateCaption, Qt::QueuedConnection);
+    connect(Core::self()->documentController(), &IDocumentController::documentUrlChanged, this, &MainWindow::updateCaption, Qt::QueuedConnection);
+    connect(Core::self()->sessionController()->activeSession(), &ISession::sessionUpdated, this, &MainWindow::updateCaption);
+
+    connect(Core::self()->documentController(), &IDocumentController::documentOpened, this, &MainWindow::updateTabColor, Qt::QueuedConnection);
+    connect(Core::self()->documentController(), &IDocumentController::documentUrlChanged, this, &MainWindow::updateTabColor, Qt::QueuedConnection);
+    connect(this, &Sublime::MainWindow::viewAdded, this, &MainWindow::updateAllTabColors);
+    connect(Core::self()->projectController(), &ProjectController::projectOpened, this, &MainWindow::updateAllTabColors, Qt::QueuedConnection);
+
     updateCaption();
 }
 
@@ -333,26 +350,68 @@ bool MainWindow::queryClose()
 
 void MainWindow::updateCaption()
 {
-    QString title = Core::self()->sessionController()->activeSession()->description();
-    
+    const auto activeSession = Core::self()->sessionController()->activeSession();
+    QString title = activeSession ? activeSession->description() : QString();
+
     if(area()->activeView())
     {
         if(!title.isEmpty())
             title += " - [ ";
-        
+
         Sublime::Document* doc = area()->activeView()->document();
         Sublime::UrlDocument* urlDoc = dynamic_cast<Sublime::UrlDocument*>(doc);
         if(urlDoc)
-            title += Core::self()->projectController()->prettyFileName(KUrl(urlDoc->documentSpecifier()), KDevelop::IProjectController::FormatPlain);
+            title += Core::self()->projectController()->prettyFileName(urlDoc->url(), KDevelop::IProjectController::FormatPlain);
         else
             title += doc->title();
-        
+
         title += " ]";
     }
-    
+
     setCaption(title);
 }
 
+void MainWindow::updateAllTabColors()
+{
+    auto documentController = Core::self()->documentController();
+    if (!documentController)
+        return;
+
+    const auto defaultColor = ::defaultColor(palette());
+    if (UiConfig::colorizeByProject()){
+        foreach (auto container, containers()) {
+            foreach (auto view, container->views()) {
+                const auto urlDoc = qobject_cast<Sublime::UrlDocument*>(view->document());
+                if (urlDoc) {
+                    const auto color = colorForDocument(urlDoc->url(), palette());
+                    container->setTabColor(view, color.isValid() ? color : defaultColor);
+                }
+            }
+        }
+    } else {
+        foreach (auto container, containers()) {
+            container->resetTabColors(defaultColor);
+        }
+    }
+}
+
+void MainWindow::updateTabColor(IDocument* doc)
+{
+    if (!UiConfig::self()->colorizeByProject())
+        return;
+
+    const auto defaultColor = ::defaultColor(palette());
+    const auto color = colorForDocument(doc->url(), palette());
+    foreach (auto container, containers()) {
+        foreach (auto view, container->views()) {
+            const auto urlDoc = qobject_cast<Sublime::UrlDocument*>(view->document());
+            if (urlDoc && urlDoc->url() == doc->url()) {
+                container->setTabColor(view, color.isValid() ? color : defaultColor);
+            }
+        }
+    }
+}
+
 void MainWindow::registerStatus(QObject* status)
 {
     d->registerStatus(status);
@@ -368,7 +427,7 @@ void MainWindow::showErrorMessage(const QString& message, int timeout)
     d->showErrorMessage(message, timeout);
 }
 
-void MainWindow::tabContextMenuRequested(Sublime::View* view, KMenu* menu)
+void MainWindow::tabContextMenuRequested(Sublime::View* view, QMenu* menu)
 {
     Sublime::MainWindow::tabContextMenuRequested(view, menu);
     d->tabContextMenuRequested(view, menu);
@@ -384,6 +443,9 @@ void MainWindow::dockBarContextMenuRequested(Qt::DockWidgetArea area, const QPoi
     d->dockBarContextMenuRequested(area, position);
 }
 
-}
+void MainWindow::newTabRequested()
+{
+    Sublime::MainWindow::newTabRequested();
 
-#include "mainwindow.moc"
+    d->fileNew();
+}
