@@ -22,21 +22,17 @@ Boston, MA 02110-1301, USA.
 #include "mainwindow_p.h"
 
 #include <QApplication>
-#include <QBoxLayout>
-#include <QLabel>
+#include <QLayout>
+#include <QMenu>
 
-#include <kmenu.h>
-#include <kdebug.h>
-#include <kxmlguiclient.h>
-#include <kxmlguifactory.h>
-#include <kstandardaction.h>
-#include <ktogglefullscreenaction.h>
-#include <kactioncollection.h>
-
-#include <kparts/part.h>
-#include <ktexteditor/view.h>
-#include <ktexteditor/document.h>
-#include <ktexteditor/editor.h>
+#include <KActionCollection>
+#include <KStandardAction>
+#include <KTextEditor/Document>
+#include <KTextEditor/Editor>
+#include <KTextEditor/View>
+#include <KToggleFullScreenAction>
+#include <KXMLGUIClient>
+#include <KXMLGUIFactory>
 
 #include <sublime/area.h>
 #include <sublime/view.h>
@@ -55,6 +51,8 @@ Boston, MA 02110-1301, USA.
 #include "mainwindow.h"
 #include "textdocument.h"
 #include "sessioncontroller.h"
+#include "debug.h"
+#include "ktexteditorpluginintegration.h"
 
 #include <language/duchain/duchainlock.h>
 #include <language/duchain/duchainutils.h>
@@ -62,12 +60,16 @@ Boston, MA 02110-1301, USA.
 #include <sublime/container.h>
 #include <sublime/holdupdates.h>
 
+
 namespace KDevelop {
 
-bool MainWindowPrivate::s_quitRequested = false;
-
 MainWindowPrivate::MainWindowPrivate(MainWindow *mainWindow)
-: m_mainWindow(mainWindow), m_statusBar(0), lastXMLGUIClientView(0), m_changingActiveView(false)
+    : QObject(mainWindow)
+    , m_mainWindow(mainWindow)
+    , m_statusBar(0)
+    , lastXMLGUIClientView(0)
+    , m_changingActiveView(false)
+    , m_kateWrapper(new KTextEditorIntegration::MainWindow(mainWindow))
 {
 }
 
@@ -86,19 +88,19 @@ void MainWindowPrivate::setupStatusBar()
 
 void MainWindowPrivate::addPlugin( IPlugin *plugin )
 {
-    kDebug() << "add plugin" << plugin << plugin->componentData().componentName();
+    qCDebug(SHELL) << "add plugin" << plugin << plugin->componentName();
     Q_ASSERT( plugin );
 
     //The direct plugin client can only be added to the first mainwindow
     if(m_mainWindow == Core::self()->uiControllerInternal()->mainWindows()[0])
         m_mainWindow->guiFactory()->addClient( plugin );
-    
+
     Q_ASSERT(!m_pluginCustomClients.contains(plugin));
-    
+
     KXMLGUIClient* ownClient = plugin->createGUIForMainWindow(m_mainWindow);
     if(ownClient) {
         m_pluginCustomClients[plugin] = ownClient;
-        connect(plugin, SIGNAL(destroyed(QObject*)), SLOT(pluginDestroyed(QObject*)));
+        connect(plugin, &IPlugin::destroyed, this, &MainWindowPrivate::pluginDestroyed);
         m_mainWindow->guiFactory()->addClient(ownClient);
     }
 }
@@ -106,29 +108,23 @@ void MainWindowPrivate::addPlugin( IPlugin *plugin )
 void MainWindowPrivate::pluginDestroyed(QObject* pluginObj)
 {
     IPlugin* plugin = static_cast<IPlugin*>(pluginObj);
-    Q_ASSERT(m_pluginCustomClients.contains(plugin));
-    m_mainWindow->guiFactory()->removeClient( m_pluginCustomClients[plugin] );
-    delete m_pluginCustomClients[plugin];
-    m_pluginCustomClients.remove(plugin);
+    KXMLGUIClient* p = m_pluginCustomClients.take(plugin);
+    m_mainWindow->guiFactory()->removeClient( p );
+    delete p;
 }
 
 MainWindowPrivate::~MainWindowPrivate()
 {
-    foreach(KXMLGUIClient* client, m_pluginCustomClients.values())
-        delete client;
+    qDeleteAll(m_pluginCustomClients);
 }
 
 void MainWindowPrivate::removePlugin( IPlugin *plugin )
 {
     Q_ASSERT( plugin );
 
-    if(m_pluginCustomClients.contains(plugin)) {
-        m_mainWindow->guiFactory()->removeClient( m_pluginCustomClients[plugin] );
-        delete m_pluginCustomClients[plugin];
-        m_pluginCustomClients.remove(plugin);
-        disconnect(plugin, SIGNAL(destroyed(QObject*)), this, SLOT(pluginDestroyed(QObject*)));
-    }
-    
+    pluginDestroyed(plugin);
+    disconnect(plugin, &IPlugin::destroyed, this, &MainWindowPrivate::pluginDestroyed);
+
     m_mainWindow->guiFactory()->removeClient( plugin );
 }
 
@@ -172,11 +168,11 @@ void MainWindowPrivate::mergeView(Sublime::View* view)
     // client, I think.
     if (lastXMLGUIClientView)
     {
-        kDebug() << "clearing last XML GUI client" << lastXMLGUIClientView;
-        
+        qCDebug(SHELL) << "clearing last XML GUI client" << lastXMLGUIClientView;
+
         m_mainWindow->guiFactory()->removeClient(dynamic_cast<KXMLGUIClient*>(lastXMLGUIClientView));
-        
-        disconnect (lastXMLGUIClientView, SIGNAL(destroyed(QObject*)), this, 0);
+
+        disconnect (lastXMLGUIClientView, &QWidget::destroyed, this, 0);
 
         lastXMLGUIClientView = NULL;
     }
@@ -187,16 +183,16 @@ void MainWindowPrivate::mergeView(Sublime::View* view)
     QWidget* viewWidget = view->widget();
     Q_ASSERT(viewWidget);
 
-    kDebug() << "changing active view to" << view << "doc" << view->document() << "mw" << m_mainWindow;
+    qCDebug(SHELL) << "changing active view to" << view << "doc" << view->document() << "mw" << m_mainWindow;
 
     // If the new view is KXMLGUIClient, add it.
     if (KXMLGUIClient* c = dynamic_cast<KXMLGUIClient*>(viewWidget))
     {
-        kDebug() << "setting new XMLGUI client" << viewWidget;
+        qCDebug(SHELL) << "setting new XMLGUI client" << viewWidget;
         lastXMLGUIClientView = viewWidget;
         m_mainWindow->guiFactory()->addClient(c);
-        connect(viewWidget, SIGNAL(destroyed(QObject*)),
-                this, SLOT(xmlguiclientDestroyed(QObject*)));
+        connect(viewWidget, &QWidget::destroyed,
+                this, &MainWindowPrivate::xmlguiclientDestroyed);
     }
 }
 
@@ -218,22 +214,16 @@ void MainWindowPrivate::xmlguiclientDestroyed(QObject* obj)
 
 void MainWindowPrivate::setupActions()
 {
-    connect(Core::self()->sessionController(), SIGNAL(quitSession()), SLOT(quitAll()));
+    connect(Core::self()->sessionController(), &SessionController::quitSession, this, &MainWindowPrivate::quitAll);
 
-    KAction *action;
+    QAction* action;
 
-    QString app = qApp->applicationName();
-    QString text = i18nc( "%1 = application name", "Configure %1", app );
+    const QString app = qApp->applicationName();
     action = KStandardAction::preferences( this, SLOT(settingsDialog()),
                                       actionCollection());
-    action->setToolTip( text );
+    action->setToolTip( i18nc( "%1 = application name", "Configure %1", app ) );
     action->setWhatsThis( i18n( "Lets you customize %1.", app ) );
 
-    action = actionCollection()->addAction( "show_editorconfig", this, SLOT(showEditorConfig()) );
-    action->setIcon( KIcon("preferences-other") );
-    action->setText( i18n("Configure Editor..."));
-    action->setWhatsThis( i18nc("@info:whatsthis", "Configure various aspects of this editor.") );
-
     action =  KStandardAction::configureNotifications(this, SLOT(configureNotifications()), actionCollection());
     action->setText( i18n("Configure Notifications...") );
     action->setToolTip( i18nc("@info:tooltip", "Configure notifications") );
@@ -251,68 +241,80 @@ void MainWindowPrivate::setupActions()
 
     action = actionCollection()->addAction( "view_next_window" );
     action->setText( i18n( "&Next Window" ) );
-    connect( action, SIGNAL(triggered(bool)), SLOT(gotoNextWindow()) );
-    action->setShortcut( Qt::ALT + Qt::SHIFT + Qt::Key_Right );
+    connect( action, &QAction::triggered, this, &MainWindowPrivate::gotoNextWindow );
+    actionCollection()->setDefaultShortcut(action, Qt::ALT + Qt::SHIFT + Qt::Key_Right );
     action->setToolTip( i18nc( "@info:tooltip", "Next window" ) );
     action->setWhatsThis( i18nc( "@info:whatsthis", "Switches to the next window." ) );
-    action->setIcon(KIcon("go-next"));
+    action->setIcon(QIcon::fromTheme("go-next"));
 
     action = actionCollection()->addAction( "view_previous_window" );
     action->setText( i18n( "&Previous Window" ) );
-    connect( action, SIGNAL(triggered(bool)), SLOT(gotoPreviousWindow()) );
-    action->setShortcut( Qt::ALT + Qt::SHIFT + Qt::Key_Left );
+    connect( action, &QAction::triggered, this, &MainWindowPrivate::gotoPreviousWindow );
+    actionCollection()->setDefaultShortcut(action, Qt::ALT + Qt::SHIFT + Qt::Key_Left );
     action->setToolTip( i18nc( "@info:tooltip", "Previous window" ) );
     action->setWhatsThis( i18nc( "@info:whatsthis", "Switches to the previous window." ) );
-    action->setIcon(KIcon("go-previous"));
+    action->setIcon(QIcon::fromTheme("go-previous"));
+
+    action = actionCollection()->addAction("next_error");
+    action->setText(i18n("Jump to Next Outputmark"));
+    actionCollection()->setDefaultShortcut( action, QKeySequence(Qt::Key_F4) );
+    action->setIcon(QIcon::fromTheme("arrow-right"));
+    connect(action, &QAction::triggered, this, &MainWindowPrivate::selectNextItem);
+
+    action = actionCollection()->addAction("prev_error");
+    action->setText(i18n("Jump to Previous Outputmark"));
+    actionCollection()->setDefaultShortcut( action, QKeySequence(Qt::SHIFT | Qt::Key_F4) );
+    action->setIcon(QIcon::fromTheme("arrow-left"));
+    connect(action, &QAction::triggered, this, &MainWindowPrivate::selectPrevItem);
 
     action = actionCollection()->addAction( "split_horizontal" );
-    action->setIcon(KIcon( "view-split-top-bottom" ));
+    action->setIcon(QIcon::fromTheme( "view-split-top-bottom" ));
     action->setText( i18n( "Split View &Top/Bottom" ) );
-    action->setShortcut( Qt::CTRL + Qt::SHIFT + Qt::Key_T );
-    connect( action, SIGNAL(triggered(bool)), SLOT(splitHorizontal()) );
+    actionCollection()->setDefaultShortcut(action, Qt::CTRL + Qt::SHIFT + Qt::Key_T );
+    connect( action, &QAction::triggered, this, &MainWindowPrivate::splitHorizontal );
     action->setToolTip( i18nc( "@info:tooltip", "Split horizontal" ) );
     action->setWhatsThis( i18nc( "@info:whatsthis", "Splits the current view horizontally." ) );
 
     action = actionCollection()->addAction( "split_vertical" );
-    action->setIcon(KIcon( "view-split-left-right" ));
+    action->setIcon(QIcon::fromTheme( "view-split-left-right" ));
     action->setText( i18n( "Split View &Left/Right" ) );
-    action->setShortcut( Qt::CTRL + Qt::SHIFT + Qt::Key_L );
-    connect( action, SIGNAL(triggered(bool)), SLOT(splitVertical()) );
+    actionCollection()->setDefaultShortcut(action, Qt::CTRL + Qt::SHIFT + Qt::Key_L );
+    connect( action, &QAction::triggered, this, &MainWindowPrivate::splitVertical );
     action->setToolTip( i18nc( "@info:tooltip", "Split vertical" ) );
     action->setWhatsThis( i18nc( "@info:whatsthis", "Splits the current view vertically." ) );
 
     action = actionCollection()->addAction( "view_next_split" );
     action->setText( i18n( "&Next Split View" ) );
-    connect( action, SIGNAL(triggered(bool)), SLOT(gotoNextSplit()) );
-    action->setShortcut( Qt::CTRL + Qt::SHIFT + Qt::Key_N );
+    connect( action, &QAction::triggered, this, &MainWindowPrivate::gotoNextSplit );
+    actionCollection()->setDefaultShortcut(action, Qt::CTRL + Qt::SHIFT + Qt::Key_N );
     action->setToolTip( i18nc( "@info:tooltip", "Next split view" ) );
     action->setWhatsThis( i18nc( "@info:whatsthis", "Switches to the next split view." ) );
-    action->setIcon(KIcon("go-next"));
+    action->setIcon(QIcon::fromTheme("go-next"));
 
     action = actionCollection()->addAction( "view_previous_split" );
     action->setText( i18n( "&Previous Split View" ) );
-    connect( action, SIGNAL(triggered(bool)), SLOT(gotoPreviousSplit()) );
-    action->setShortcut( Qt::CTRL + Qt::SHIFT + Qt::Key_P );
+    connect( action, &QAction::triggered, this, &MainWindowPrivate::gotoPreviousSplit );
+    actionCollection()->setDefaultShortcut(action, Qt::CTRL + Qt::SHIFT + Qt::Key_P );
     action->setToolTip( i18nc( "@info:tooltip", "Previous split view" ) );
     action->setWhatsThis( i18nc( "@info:whatsthis", "Switches to the previous split view." ) );
-    action->setIcon(KIcon("go-previous"));
+    action->setIcon(QIcon::fromTheme("go-previous"));
 
     action = KStandardAction::fullScreen( this, SLOT(toggleFullScreen(bool)), m_mainWindow, actionCollection() );
 
     action = actionCollection()->addAction( "file_new" );
-    action->setIcon(KIcon("document-new"));
-    action->setShortcut( Qt::CTRL + Qt::Key_N );
+    action->setIcon(QIcon::fromTheme("document-new"));
+    actionCollection()->setDefaultShortcut(action, Qt::CTRL + Qt::Key_N );
     action->setText( i18n( "&New" ) );
     action->setIconText( i18nc( "Shorter Text for 'New File' shown in the toolbar", "New") );
-    connect( action, SIGNAL(triggered(bool)), SLOT(fileNew()) );
+    connect( action, &QAction::triggered, this, &MainWindowPrivate::fileNew );
     action->setToolTip( i18nc( "@info:tooltip", "New file" ) );
     action->setWhatsThis( i18nc( "@info:whatsthis", "Creates an empty file." ) );
 
     action = actionCollection()->addAction( "add_toolview" );
-    action->setIcon(KIcon("window-new"));
-    action->setShortcut( Qt::CTRL + Qt::SHIFT + Qt::Key_V );
+    action->setIcon(QIcon::fromTheme("window-new"));
+    actionCollection()->setDefaultShortcut(action, Qt::CTRL + Qt::SHIFT + Qt::Key_V );
     action->setText( i18n( "&Add Tool View..." ) );
-    connect( action, SIGNAL(triggered(bool)),  SLOT(viewAddNewToolView()) );
+    connect( action, &QAction::triggered,  this, &MainWindowPrivate::viewAddNewToolView );
     action->setToolTip( i18nc( "@info:tooltip", "Add tool view" ) );
     action->setWhatsThis( i18nc( "@info:whatsthis", "Adds a new tool view to this window." ) );
 }
@@ -320,7 +322,7 @@ void MainWindowPrivate::setupActions()
 void MainWindowPrivate::toggleArea(bool b)
 {
     if (!b) return;
-    KAction *action = qobject_cast<KAction*>(sender());
+    QAction* action = qobject_cast<QAction*>(sender());
     if (!action) return;
     m_mainWindow->controller()->showArea(action->data().toString(), m_mainWindow);
 }
@@ -330,11 +332,6 @@ KActionCollection * MainWindowPrivate::actionCollection()
     return m_mainWindow->actionCollection();
 }
 
-bool MainWindowPrivate::applicationQuitRequested() const
-{
-    return s_quitRequested;
-}
-
 void MainWindowPrivate::registerStatus(QObject* status)
 {
     m_statusBar->registerStatus(status);
@@ -346,29 +343,31 @@ void MainWindowPrivate::showErrorMessage(QString message, int timeout)
     m_statusBar->showErrorMessage(message, timeout);
 }
 
-void MainWindowPrivate::tabContextMenuRequested(Sublime::View* view, KMenu* menu)
+void MainWindowPrivate::tabContextMenuRequested(Sublime::View* view, QMenu* menu)
 {
     m_tabView = view;
 
     QAction* action;
 
-    action = menu->addAction(KIcon("view-split-top-bottom"), i18n("Split View Top/Bottom"));
-    connect(action, SIGNAL(triggered(bool)), this, SLOT(contextMenuSplitHorizontal()));
+    action = menu->addAction(QIcon::fromTheme("view-split-top-bottom"), i18n("Split View Top/Bottom"));
+    connect(action, &QAction::triggered, this, &MainWindowPrivate::contextMenuSplitHorizontal);
 
-    action = menu->addAction(KIcon("view-split-left-right"), i18n("Split View Left/Right"));
-    connect(action, SIGNAL(triggered(bool)), this, SLOT(contextMenuSplitVertical()));
+    action = menu->addAction(QIcon::fromTheme("view-split-left-right"), i18n("Split View Left/Right"));
+    connect(action, &QAction::triggered, this, &MainWindowPrivate::contextMenuSplitVertical);
     menu->addSeparator();
 
-    action = menu->addAction(KIcon("document-new"), i18n("New File"));
+    action = menu->addAction(QIcon::fromTheme("document-new"), i18n("New File"));
 
-    connect(action, SIGNAL(triggered(bool)), this, SLOT(contextMenuFileNew()));
+    connect(action, &QAction::triggered, this, &MainWindowPrivate::contextMenuFileNew);
 
-    if ( TextDocument* doc = dynamic_cast<TextDocument*>(view->document()) ) {
-        action = menu->addAction(KIcon("view-refresh"), i18n("Reload"));
-        connect(action, SIGNAL(triggered(bool)), doc, SLOT(reload()));
+    if (view) {
+        if (TextDocument* doc = dynamic_cast<TextDocument*>(view->document())) {
+            action = menu->addAction(QIcon::fromTheme("view-refresh"), i18n("Reload"));
+            connect(action, &QAction::triggered, doc, &TextDocument::reload);
 
-        action = menu->addAction(KIcon("view-refresh"), i18n("Reload All"));
-        connect(action, SIGNAL(triggered(bool)), this, SLOT(reloadAll()));
+            action = menu->addAction(QIcon::fromTheme("view-refresh"), i18n("Reload All"));
+            connect(action, &QAction::triggered, this, &MainWindowPrivate::reloadAll);
+        }
     }
 }
 
@@ -383,18 +382,17 @@ void MainWindowPrivate::tabToolTipRequested(Sublime::View* view, Sublime::Contai
         }
     }
 
-    DUChainReadLocker lock;
-
     Sublime::UrlDocument* urlDoc = dynamic_cast<Sublime::UrlDocument*>(view->document());
 
     if (urlDoc) {
+        DUChainReadLocker lock;
         TopDUContext* top = DUChainUtils::standardContextForUrl(urlDoc->url());
 
         if (top) {
             if ( QWidget* navigationWidget = top->createNavigationWidget() ) {
                 NavigationToolTip* tooltip = new KDevelop::NavigationToolTip(m_mainWindow, QCursor::pos() + QPoint(20, 20), navigationWidget);
                 tooltip->resize(navigationWidget->sizeHint() + QSize(10, 10));
-                tooltip->addExtendRect(container->tabRect(tab));
+                tooltip->setHandleRect(container->tabRect(tab));
 
                 m_tabTooltip.first = view;
                 m_tabTooltip.second = tooltip;
@@ -406,8 +404,8 @@ void MainWindowPrivate::tabToolTipRequested(Sublime::View* view, Sublime::Contai
 
 void MainWindowPrivate::dockBarContextMenuRequested(Qt::DockWidgetArea area, const QPoint& position)
 {
-    KMenu menu;
-    menu.addTitle(KIcon("window-new"), i18n("Add Tool View"));
+    QMenu menu;
+    menu.addSection(QIcon::fromTheme("window-new"), i18n("Add Tool View"));
     QMap<IToolViewFactory*, Sublime::ToolDocument*> factories =
         Core::self()->uiControllerInternal()->factoryDocuments();
     QMap<QAction*, IToolViewFactory*> actionToFactory;
@@ -443,8 +441,12 @@ bool MainWindowPrivate::changingActiveView() const
     return m_changingActiveView;
 }
 
+KTextEditorIntegration::MainWindow *MainWindowPrivate::kateWrapper() const
+{
+    return m_kateWrapper;
+}
+
 }
 
 #include "mainwindow_actions.cpp"
-#include "mainwindow_p.moc"
 
