@@ -24,12 +24,14 @@ Boston, MA 02110-1301, USA.
 
 #include <QObject>
 #include <QPointer>
-#include <qwidget.h>
-#include <kxmlguiclient.h>
+#include <QWidget>
+
+#include <KXMLGUIClient>
+
 #include <language/util/navigationtooltip.h>
 
 class KActionCollection;
-class KMenu;
+class QMenu;
 
 namespace Sublime {
 class View;
@@ -44,6 +46,10 @@ namespace KTextEditor {
 class View;
 }
 
+namespace KTextEditorIntegration {
+class MainWindow;
+}
+
 namespace KDevelop {
 
 class IPlugin;
@@ -53,7 +59,7 @@ class StatusBar;
 class MainWindowPrivate: public QObject {
     Q_OBJECT
 public:
-    MainWindowPrivate(MainWindow *mainWindow);
+    explicit MainWindowPrivate(MainWindow *mainWindow);
     ~MainWindowPrivate();
 
     QPointer<QWidget> centralPlugin;
@@ -63,7 +69,7 @@ public:
     void setupStatusBar();
     void registerStatus(QObject*);
 
-    void tabContextMenuRequested(Sublime::View *view, KMenu* menu);
+    void tabContextMenuRequested(Sublime::View *view, QMenu* menu);
     void tabToolTipRequested(Sublime::View* view, Sublime::Container* container, int tab);
     void dockBarContextMenuRequested(Qt::DockWidgetArea area, const QPoint& position);
 
@@ -82,6 +88,9 @@ public Q_SLOTS:
     void gotoNextWindow();
     void gotoPreviousWindow();
 
+    void selectPrevItem();
+    void selectNextItem();
+
     void viewAddNewToolView();
 
     void newWindow();
@@ -104,12 +113,9 @@ public Q_SLOTS:
     ///Returns true if we're currently changing the active view through changeActiveView()
     bool changingActiveView() const ;
 
-    bool applicationQuitRequested() const;
-
     void configureNotifications();
     void showAboutPlatform();
     void showLoadedPlugins();
-    void showEditorConfig();
 
     void toggleArea(bool b);
     void showErrorMessage(QString message, int timeout);
@@ -125,6 +131,8 @@ public Q_SLOTS:
     /// reload all open documents
     void reloadAll();
 
+    KTextEditorIntegration::MainWindow *kateWrapper() const;
+
 private:
     KActionCollection *actionCollection();
 
@@ -132,14 +140,14 @@ private:
     StatusBar* m_statusBar;
     QWidget* lastXMLGUIClientView;
     QPointer<QWidget> m_workingSetCornerWidget;
-    
+
     QMap<IPlugin*, KXMLGUIClient*> m_pluginCustomClients;
-    
-    static bool s_quitRequested;
+
     bool m_changingActiveView;
     /// the view of the tab that got it's context menu connected
     Sublime::View* m_tabView;
-    QPair<Sublime::View*, QWeakPointer<NavigationToolTip> > m_tabTooltip;
+    QPair<Sublime::View*, QPointer<NavigationToolTip> > m_tabTooltip;
+    KTextEditorIntegration::MainWindow* m_kateWrapper;
 };
 
 }
