@@ -10,33 +10,22 @@
 
 #include "openprojectpage.h"
 
-#include <QtCore/QDir>
-#include <QtCore/QModelIndex>
-#include <QtGui/QVBoxLayout>
-#include <QtGui/QHeaderView>
+#include <QHBoxLayout>
 
-#include <kconfiggroup.h>
-#include <kurlcompletion.h>
-#include <kurlcombobox.h>
-#include <kurlpixmapprovider.h>
-#include <kglobal.h>
-#include <kfileitem.h>
-#include <ksharedconfig.h>
-#include <kdebug.h>
-#include <kplugininfo.h>
-#include <kfilewidget.h>
+#include <KDirOperator>
+#include <KFileItem>
+#include <KFileWidget>
+#include <KLocalizedString>
+#include <KUrlComboBox>
 
 #include "shellextension.h"
 #include "core.h"
 #include "plugincontroller.h"
-#include <kdiroperator.h>
-#include <kactioncollection.h>
-#include <KIO/NetAccess>
 
 namespace KDevelop
 {
 
-OpenProjectPage::OpenProjectPage( const KUrl& startUrl, QWidget* parent )
+OpenProjectPage::OpenProjectPage( const QUrl& startUrl, QWidget* parent )
         : QWidget( parent )
 {
     QHBoxLayout* layout = new QHBoxLayout( this );
@@ -46,20 +35,19 @@ OpenProjectPage::OpenProjectPage( const KUrl& startUrl, QWidget* parent )
     QStringList filters;
     QStringList allEntry;
     allEntry << "*."+ShellExtension::getInstance()->projectFileExtension();
-    filters << QString( "%1|%2 (%1)").arg("*."+ShellExtension::getInstance()->projectFileExtension()).arg(ShellExtension::getInstance()->projectFileDescription());
-    foreach(const KPluginInfo& info, ICore::self()->pluginController()->queryExtensionPlugins( "org.kdevelop.IProjectFileManager" ) )
+    filters << QStringLiteral( "%1|%2 (%1)").arg("*."+ShellExtension::getInstance()->projectFileExtension()).arg(ShellExtension::getInstance()->projectFileDescription());
+    foreach(const KPluginMetaData& info, ICore::self()->pluginController()->queryExtensionPlugins( "org.kdevelop.IProjectFileManager" ) )
     {
-        QVariant filter = info.property("X-KDevelop-ProjectFilesFilter");
-	    QVariant desc = info.property("X-KDevelop-ProjectFilesFilterDescription");
+        QStringList filter = KPluginMetaData::readStringList(info.rawData(), "X-KDevelop-ProjectFilesFilter");
+	    QString desc = info.value("X-KDevelop-ProjectFilesFilterDescription");
         QString filterline;
-        if( filter.isValid() && desc.isValid() )
-        {
-            m_projectFilters.insert( info.name(), filter.toStringList() );
-            allEntry += filter.toStringList();
-            filters << QString("%1|%2 (%1)").arg(filter.toStringList().join(" ")).arg(desc.toString());
+        if(!filter.isEmpty() && !desc.isEmpty()) {
+            m_projectFilters.insert(info.name(), filter);
+            allEntry += filter;
+            filters << QStringLiteral("%1|%2 (%1)").arg(filter.join(" ")).arg(desc);
         }
     }
-	
+
     filters.prepend( i18n( "%1|All Project Files (%1)", allEntry.join(" ") ) );
 
     fileWidget->setFilter( filters.join("\n") );
@@ -68,39 +56,38 @@ OpenProjectPage::OpenProjectPage( const KUrl& startUrl, QWidget* parent )
 
     layout->addWidget( fileWidget );
 
-    QWidget* ops= fileWidget->findChild<QWidget*>( "KFileWidget::ops" );
+    KDirOperator* ops = fileWidget->dirOperator();
     // Emitted for changes in the places view, the url navigator and when using the back/forward/up buttons
-    connect( ops, SIGNAL(urlEntered(KUrl)), SLOT(opsEntered(KUrl)));
+    connect(ops, &KDirOperator::urlEntered, this, &OpenProjectPage::opsEntered);
 
     // Emitted when selecting an entry from the "Name" box or editing in there
-    connect( fileWidget->locationEdit(), SIGNAL(editTextChanged(QString)), 
-             SLOT(comboTextChanged(QString)));
+    connect( fileWidget->locationEdit(), &KUrlComboBox::editTextChanged,
+             this, &OpenProjectPage::comboTextChanged);
 
     // Emitted when clicking on a file in the fileview area
-    connect( fileWidget, SIGNAL(fileHighlighted(QString)), SLOT(highlightFile(QString)) );
-    
-    connect( fileWidget->dirOperator()->dirLister(), SIGNAL(completed(KUrl)), SLOT(dirChanged(KUrl)));
+    connect( fileWidget, &KFileWidget::fileHighlighted, this, &OpenProjectPage::highlightFile );
 
-    connect( fileWidget, SIGNAL(accepted()), SIGNAL(accepted()));
+    connect( fileWidget->dirOperator()->dirLister(), static_cast<void(KDirLister::*)(const QUrl&)>(&KDirLister::completed), this, &OpenProjectPage::dirChanged);
+
+    connect( fileWidget, &KFileWidget::accepted, this, &OpenProjectPage::accepted);
 }
 
-KUrl OpenProjectPage::getAbsoluteUrl( const QString& file ) const
+QUrl OpenProjectPage::getAbsoluteUrl( const QString& file ) const
 {
-    KUrl u(file);
+    QUrl u(file);
     if( u.isRelative() )
     {
-        u = fileWidget->baseUrl();
-        u.addPath( file );
+        u = fileWidget->baseUrl().resolved( u );
     }
     return u;
 }
 
-void OpenProjectPage::setUrl(const KUrl& url)
+void OpenProjectPage::setUrl(const QUrl& url)
 {
     fileWidget->setUrl(url, false);
 }
 
-void OpenProjectPage::dirChanged(const KUrl& /*url*/)
+void OpenProjectPage::dirChanged(const QUrl& /*url*/)
 {
     if(fileWidget->selectedFiles().isEmpty()) {
         KFileItemList items=fileWidget->dirOperator()->dirLister()->items();
@@ -117,14 +104,14 @@ void OpenProjectPage::showEvent(QShowEvent* ev)
     QWidget::showEvent(ev);
 }
 
-void OpenProjectPage::highlightFile( const QString& file )
+void OpenProjectPage::highlightFile(const QUrl& file)
 {
-    emit urlSelected( getAbsoluteUrl( file ) );
+    emit urlSelected(file);
 }
 
-void OpenProjectPage::opsEntered( const KUrl& url )
+void OpenProjectPage::opsEntered(const QUrl& url)
 {
-    emit urlSelected( getAbsoluteUrl( url.url() ) );
+    emit urlSelected(url);
 }
 
 void OpenProjectPage::comboTextChanged( const QString& file )
@@ -139,4 +126,3 @@ QMap<QString,QStringList> OpenProjectPage::projectFilters() const
 
 }
 
-#include "openprojectpage.moc"
