@@ -1,6 +1,7 @@
 /***************************************************************************
- *   Copyright 2006 Adam Treat  <treat@kde.org>                     *
- *   Copyright 2007 Alexander Dymo  <adymo@kdevelop.org>            *
+ *   Copyright 2006 Adam Treat  <treat@kde.org>                            *
+ *   Copyright 2007 Alexander Dymo  <adymo@kdevelop.org>                   *
+ *   Copyright 2015 Kevin Funk <kfunk@kde.org>                             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU Library General Public License as       *
@@ -19,32 +20,33 @@
  ***************************************************************************/
 
 #include "partcontroller.h"
-#include <unistd.h>
-#include <sys/stat.h>
-#include <sys/types.h>
 
-#include <QFile>
-#include <QTimer>
-#include <QMutexLocker>
-#include <QApplication>
+#include <QAction>
+#include <QDebug>
+#include <QMimeDatabase>
+#include <QMimeType>
 
-#include <kdebug.h>
-#include <klocale.h>
-#include <kmimetype.h>
-#include <kmimetypetrader.h>
-#include <KMessageBox>
+#include <KActionCollection>
+#include <KLocalizedString>
+#include <KMimeTypeTrader>
+#include <KToggleAction>
 
-#include <kparts/part.h>
-#include <kparts/factory.h>
-#include <kparts/partmanager.h>
-#include <kparts/browserextension.h>
+#include <KParts/Part>
+#include <KParts/BrowserExtension>
 
-#include <ktexteditor/view.h>
-#include <ktexteditor/editor.h>
-#include <ktexteditor/document.h>
-#include <ktexteditor/factory.h>
+#include <KTextEditor/View>
+#include <KTextEditor/Editor>
+#include <KTextEditor/Document>
 
 #include "core.h"
+#include "textdocument.h"
+#include "debug.h"
+#include "uicontroller.h"
+#include "mainwindow.h"
+#include <interfaces/isession.h>
+#include <interfaces/iuicontroller.h>
+#include <interfaces/idocumentcontroller.h>
+#include <sublime/area.h>
 
 namespace KDevelop
 {
@@ -52,15 +54,13 @@ namespace KDevelop
 class PartControllerPrivate
 {
 public:
-    PartControllerPrivate(): m_textEditor(0) {}
+    PartControllerPrivate() {}
 
+    bool m_showTextEditorStatusBar = false;
     QString m_editor;
     QStringList m_textTypes;
 
     Core *m_core;
-
-    KTextEditor::Editor *m_textEditor;
-
 };
 
 PartController::PartController(Core *core, QWidget *toplevel)
@@ -77,6 +77,12 @@ PartController::PartController(Core *core, QWidget *toplevel)
     //
     //     config ->setGroup( "Editor" );
     //     d->m_editor = config->readPathEntry( "EmbeddedKTextEditor", QString() );
+
+    // required early because some actions are checkable and need to be initialized
+    loadSettings(false);
+
+    if (!(Core::self()->setupFlags() & Core::NoUi))
+        setupActions();
 }
 
 PartController::~PartController()
@@ -84,48 +90,57 @@ PartController::~PartController()
     delete d;
 }
 
+bool PartController::showTextEditorStatusBar() const
+{
+    return d->m_showTextEditorStatusBar;
+}
+
+void PartController::setShowTextEditorStatusBar(bool show)
+{
+    if (d->m_showTextEditorStatusBar == show)
+        return;
+
+    d->m_showTextEditorStatusBar = show;
+
+    // update
+    foreach (Sublime::Area* area, Core::self()->uiControllerInternal()->allAreas()) {
+        foreach (Sublime::View* view, area->views()) {
+            if (!view->hasWidget())
+                continue;
+
+            auto textView = qobject_cast<KTextEditor::View*>(view->widget());
+            if (textView) {
+                textView->setStatusBarEnabled(show);
+            }
+        }
+    }
+
+    // also notify active view that it should update the "view status"
+    TextView* textView = qobject_cast<TextView*>(Core::self()->uiControllerInternal()->activeSublimeWindow()->activeView());
+    if (textView) {
+        emit textView->statusChanged(textView);
+    }
+}
+
 //MOVE BACK TO DOCUMENTCONTROLLER OR MULTIBUFFER EVENTUALLY
-bool PartController::isTextType( KMimeType::Ptr mimeType )
+bool PartController::isTextType(const QMimeType& mimeType)
 {
     bool isTextType = false;
-    if ( d->m_textTypes.contains( mimeType->name() ) )
+    if (d->m_textTypes.contains(mimeType.name()))
     {
         isTextType = true;
     }
 
-    bool isKDEText = false;
-    QVariant v = mimeType->property( "X-KDE-text" );
-    if ( v.isValid() )
-        isKDEText = v.toBool();
-
     // is this regular text - open in editor
-    return ( isTextType || isKDEText
-             || mimeType->is( "text/plain" )
-             || mimeType->is( "text/html" )
-             || mimeType->is( "application/x-zerosize" ) );
+    return ( isTextType
+             || mimeType.inherits("text/plain")
+             || mimeType.inherits("text/html")
+             || mimeType.inherits("application/x-zerosize"));
 }
 
 KTextEditor::Editor* PartController::editorPart() const
 {
-    if (!d->m_textEditor)
-    {
-        KTextEditor::Factory * editorFactory = qobject_cast<KTextEditor::Factory*>(findPartFactory(
-            "text/plain",
-            "KTextEditor/Document",
-            "KTextEditor::Editor" ));
-
-        if (!editorFactory) {
-            KMessageBox::error(qApp->activeWindow(), i18n("System Configuration Error"),
-                               i18n("Could not find KTextEditor::Factory, check your installation.\n"
-                                    "Make sure that KDEDIRS is set properly and that you ran kbuildsycoca4." ));
-            qApp->quit();
-	    exit(EXIT_FAILURE);
-            return 0;
-        }
-
-        d->m_textEditor = editorFactory->editor();
-    }
-    return d->m_textEditor;
+    return KTextEditor::Editor::instance();
 }
 
 KTextEditor::Document* PartController::createTextPart(const QString &encoding)
@@ -147,14 +162,14 @@ KParts::Part* PartController::createPart( const QString & mimeType,
         const QString & className,
         const QString & preferredName )
 {
-    KParts::Factory * editorFactory = findPartFactory(
+    KPluginFactory * editorFactory = findPartFactory(
                                           mimeType,
                                           partType,
                                           preferredName );
 
     if ( !className.isEmpty() && editorFactory )
     {
-        return editorFactory->createPart(
+        return editorFactory->create<KParts::Part>(
                    0,
                    this,
                    className.toLatin1() );
@@ -163,7 +178,7 @@ KParts::Part* PartController::createPart( const QString & mimeType,
     return 0;
 }
 
-bool PartController::canCreatePart(const KUrl& url)
+bool PartController::canCreatePart(const QUrl& url)
 {
     if (!url.isValid()) return false;
 
@@ -171,7 +186,7 @@ bool PartController::canCreatePart(const KUrl& url)
     if ( url.isEmpty() )
         mimeType = QString::fromLatin1("text/plain");
     else
-        mimeType = KMimeType::findByUrl( url )->name();
+        mimeType = QMimeDatabase().mimeTypeForUrl(url).name();
 
     KService::List offers = KMimeTypeTrader::self()->query(
                                 mimeType,
@@ -180,9 +195,9 @@ bool PartController::canCreatePart(const KUrl& url)
     return offers.count() > 0;
 }
 
-KParts::Part* PartController::createPart( const KUrl & url, const QString& preferredPart )
+KParts::Part* PartController::createPart( const QUrl & url, const QString& preferredPart )
 {
-    kDebug() << "creating part with url" << url << "and pref part:" << preferredPart;
+    qCDebug(SHELL) << "creating part with url" << url << "and pref part:" << preferredPart;
     QString mimeType;
     if ( url.isEmpty() )
         //create a part for empty text file
@@ -190,7 +205,7 @@ KParts::Part* PartController::createPart( const KUrl & url, const QString& prefe
     else if ( !url.isValid() )
         return 0;
     else
-        mimeType = KMimeType::findByUrl( url )->name();
+        mimeType = QMimeDatabase().mimeTypeForUrl(url).name();
 
     KParts::Part* part = createPart( mimeType, preferredPart );
     if( part )
@@ -225,19 +240,88 @@ KParts::ReadWritePart* PartController::readWrite( KParts::Part * part ) const
 void PartController::loadSettings( bool projectIsLoaded )
 {
     Q_UNUSED( projectIsLoaded );
+
+    KConfigGroup cg(KSharedConfig::openConfig(), "UiSettings");
+    d->m_showTextEditorStatusBar = cg.readEntry("ShowTextEditorStatusBar", false);
 }
 
 void PartController::saveSettings( bool projectIsLoaded )
 {
     Q_UNUSED( projectIsLoaded );
+
+    KConfigGroup cg(KSharedConfig::openConfig(), "UiSettings");
+    cg.writeEntry("ShowTextEditorStatusBar", d->m_showTextEditorStatusBar);
 }
 
 void PartController::initialize()
-{}
+{
+}
 
 void PartController::cleanup()
-{}
+{
+    saveSettings(false);
+}
+
+void PartController::setupActions()
+{
+    KActionCollection* actionCollection =
+        d->m_core->uiControllerInternal()->defaultMainWindow()->actionCollection();
+
+    QAction* action;
+
+    action = KStandardAction::showStatusbar(this, SLOT(setShowTextEditorStatusBar(bool)), actionCollection);
+    action->setWhatsThis(i18n("Use this command to show or hide the view's statusbar"));
+    action->setChecked(showTextEditorStatusBar());
+}
+
+//BEGIN KTextEditor::MdiContainer
+void PartController::setActiveView(KTextEditor::View *view)
+{
+  Q_UNUSED(view)
+  // NOTE: not implemented
+}
+
+KTextEditor::View *PartController::activeView()
+{
+    TextView* textView = dynamic_cast<TextView*>(Core::self()->uiController()->activeArea()->activeView());
+    if (textView) {
+        return textView->textView();
+    }
+    return 0;
+}
+
+KTextEditor::Document *PartController::createDocument()
+{
+  // NOTE: not implemented
+  qWarning() << "WARNING: interface call not implemented";
+  return 0;
+}
+
+bool PartController::closeDocument(KTextEditor::Document *doc)
+{
+  Q_UNUSED(doc)
+  // NOTE: not implemented
+  qWarning() << "WARNING: interface call not implemented";
+  return false;
+}
+
+KTextEditor::View *PartController::createView(KTextEditor::Document *doc)
+{
+  Q_UNUSED(doc)
+  // NOTE: not implemented
+  qWarning() << "WARNING: interface call not implemented";
+  return 0;
+}
+
+bool PartController::closeView(KTextEditor::View *view)
+{
+  Q_UNUSED(view)
+  // NOTE: not implemented
+  qWarning() << "WARNING: interface call not implemented";
+  return false;
+}
+//END KTextEditor::MdiContainer
+
 
 }
-#include "partcontroller.moc"
 
