@@ -27,11 +27,6 @@ Boston, MA 02110-1301, USA.
 
 #include <QtCore/QHash>
 
-#include <KDE/KUrl>
-#include <KDE/KService>
-#include <KDE/KPluginInfo>
-#include <KDE/KServiceTypeTrader>
-
 #include <interfaces/iplugincontroller.h>
 
 #include "shellexport.h"
@@ -56,7 +51,7 @@ friend class CorePrivate;
 
 public:
 
-    PluginController(Core *core);
+    explicit PluginController(Core *core);
 
     virtual ~PluginController();
 
@@ -69,19 +64,24 @@ public:
     /**
      * Get the plugin info for a loaded plugin
      */
-    KPluginInfo pluginInfo( const IPlugin* ) const;
+    KPluginMetaData pluginInfo( const IPlugin* ) const override;
+
+    /**
+     * Find the KPluginMetaData structure for the given @p pluginId.
+     */
+    KPluginMetaData infoForPluginId(const QString &pluginId) const override;
 
     /**
      * Get a list of currently loaded plugins
      */
-    QList<IPlugin*> loadedPlugins() const;
+    QList<IPlugin*> loadedPlugins() const override;
 
     /**
      * Returns a uniquely specified plugin. If it isn't already loaded, it will be.
      * @param pluginName the name of the plugin, as given in the X-KDE-PluginInfo-Name property
      * @returns a pointer to the plugin instance or 0
      */
-    IPlugin * loadPlugin( const QString & pluginName );
+    IPlugin * loadPlugin( const QString & pluginName ) override;
 
     /**
      * @brief Unloads the plugin specified by @p plugin
@@ -89,7 +89,7 @@ public:
      * @param plugin The name of the plugin as specified by the
      * X-KDE-PluginInfo-Name key of the .desktop file for the plugin
      */
-    bool unloadPlugin( const QString & plugin );
+    bool unloadPlugin( const QString & plugin ) override;
 
     enum PluginDeletion {
         Now,
@@ -99,7 +99,7 @@ public:
     /**
      * retrieve all plugin infos
      */
-    QList<KPluginInfo> allPluginInfos() const;
+    QVector<KPluginMetaData> allPluginInfos() const;
 
     /**
      * loads not-yet-loaded plugins and unloads plugins
@@ -108,23 +108,26 @@ public:
     void updateLoadedPlugins();
 
 
-       /**
+    /**
      * Queries for the plugin which supports given extension interface.
+     *
      * All already loaded plugins will be queried and the first one to support the extension interface
      * will be returned. Any plugin can be an extension, only "ServiceTypes=..." entry is
      * required in .desktop file for that plugin.
+     *
      * @param extension The extension interface
      * @param pluginname The name of the plugin to load if multiple plugins for the extension exist, corresponds to the X-KDE-PluginInfo-Name
      * @return A KDevelop extension plugin for given service type or 0 if no plugin supports it
      */
-    IPlugin *pluginForExtension(const QString &extension, const QString &pluginname = "");
-    IPlugin *pluginForExtension(const QString &extension, const QStringList &constraints);
+    IPlugin *pluginForExtension(const QString &extension, const QString &pluginName = {}, const QVariantMap& constraints = QVariantMap()) override;
 
-    QList<IPlugin*> allPluginsForExtension(const QString &extension, const QStringList &constraints = QStringList());
+    QList<IPlugin*> allPluginsForExtension(const QString &extension, const QVariantMap& constraints = QVariantMap()) override;
 
     QStringList allPluginNames();
 
-    QList<ContextMenuExtension> queryPluginsForContextMenuExtensions( KDevelop::Context* context ) const;
+    QVector<KPluginMetaData> queryExtensionPlugins(const QString& extension, const QVariantMap& constraints = QVariantMap()) const override;
+
+    QList<ContextMenuExtension> queryPluginsForContextMenuExtensions( KDevelop::Context* context ) const override;
 
     QStringList projectPlugins();
 
@@ -132,7 +135,7 @@ public:
     void unloadProjectPlugins();
 
     void resetToDefaults();
-
+    bool isEnabled(const KPluginMetaData& info) const;
 
 private:
     /**
@@ -154,24 +157,24 @@ private:
     IPlugin* loadPluginInternal( const QString &pluginId );
 
     /**
-     * @internal
+     * Check whether the plugin identified by @p info has unresolved dependencies.
      *
-     * Find the KPluginInfo structure by key. Reduces some code duplication.
+     * Assume a plugin depends on the interfaces Foo and Bar. Then, all available enabled
+     * plugins are queried to check whether any fulfills the interfaces. If any of the
+     * interfaces is not found, then it is inserted into @p missing and this method returns
+     * true. Otherwise, @p missing is empty and this method returns true, indicating that all
+     * dependencies can be fulfilled.
      *
-     * Returns a null pointer when no plugin info is found.
+     * @return true when there are unresolved dependencies, false otherwise.
      */
-    KPluginInfo infoForPluginId( const QString &pluginId ) const;
+    bool hasUnresolvedDependencies( const KPluginMetaData& info, QStringList& missing ) const;
 
-    bool checkForDependencies( const KPluginInfo& info, QStringList& missing ) const;
-
-    bool loadDependencies( const KPluginInfo&, QString& failedPlugin );
-    void loadOptionalDependencies( const KPluginInfo& info );
+    bool loadDependencies(const KPluginMetaData&, QString& failedPlugin);
+    void loadOptionalDependencies(const KPluginMetaData& info);
 
     void cleanup();
     virtual void initialize();
 
-    bool isEnabled( const KPluginInfo& info );
-
 private:
     class PluginControllerPrivate* const d;
 };
