@@ -235,7 +235,7 @@ private:
     QString mId;
     QString mLabel;
     QString mStatus;
-    QWeakPointer<ProgressItem>mParent;
+    QPointer<ProgressItem> mParent;
     bool mCanBeCanceled;
     unsigned int mProgress;
     ProgressItemMap mChildren;
