@@ -32,7 +32,7 @@
 class QBoxLayout;
 class QEvent;
 class QProgressBar;
-class QToolButton;
+class QPushButton;
 class QStackedWidget;
 class QBoxLayout;
 class QLabel;
@@ -69,12 +69,12 @@ protected:
     void connectSingleItem();
     void activateSingleItemMode();
 
-    virtual bool eventFilter( QObject *, QEvent * );
+    virtual bool eventFilter( QObject *, QEvent * ) override;
 
 private:
     QProgressBar* m_pProgressBar;
     QLabel* m_pLabel;
-    QToolButton* m_pButton;
+    QPushButton* m_pButton;
 
     enum Mode { None, /*Label,*/ Progress };
 
