@@ -26,22 +26,19 @@
 
 #include "project.h"
 
+#include <QDBusConnection>
+#include <QDebug>
 #include <QSet>
-#include <QtGlobal>
-#include <QFileInfo>
-#include <QtDBus/QtDBus>
-#include <QStandardItemModel>
+#include <QTemporaryFile>
+#include <QTimer>
 
-#include <kconfig.h>
-#include <kconfiggroup.h>
-#include <klocale.h>
-#include <kio/job.h>
-#include <kio/netaccess.h>
-#include <kio/global.h>
-#include <kmessagebox.h>
-#include <kio/jobclasses.h>
-#include <ktemporaryfile.h>
-#include <kdebug.h>
+#include <KConfigGroup>
+#include <KIO/FileCopyJob>
+#include <KIO/MkdirJob>
+#include <KIO/StatJob>
+#include <KJobWidgets>
+#include <KLocalizedString>
+#include <KMessageBox>
 
 #include <project/interfaces/iprojectfilemanager.h>
 #include <project/interfaces/ibuildsystemmanager.h>
@@ -51,13 +48,14 @@
 #include <interfaces/isession.h>
 #include <project/projectmodel.h>
 #include <util/path.h>
-#include <language/duchain/indexedstring.h>
+#include <serialization/indexedstring.h>
 #include <vcs/interfaces/ibasicversioncontrol.h>
 
 #include "core.h"
 #include "mainwindow.h"
 #include "projectcontroller.h"
 #include "uicontroller.h"
+#include "debug.h"
 
 namespace KDevelop
 {
@@ -70,7 +68,7 @@ class ProjectProgress : public QObject, public IStatus
     public:
         ProjectProgress();
         virtual ~ProjectProgress();
-        virtual QString statusName() const;
+        virtual QString statusName() const override;
 
         /*! Show indeterminate mode progress bar */
         void setBuzzy();
@@ -84,11 +82,11 @@ class ProjectProgress : public QObject, public IStatus
         void slotClean();
 
     Q_SIGNALS:
-        void clearMessage(KDevelop::IStatus*);
-        void showMessage(KDevelop::IStatus*,const QString & message, int timeout = 0);
-        void showErrorMessage(const QString & message, int timeout = 0);
-        void hideProgress(KDevelop::IStatus*);
-        void showProgress(KDevelop::IStatus*,int minimum, int maximum, int value);
+        void clearMessage(KDevelop::IStatus*) override;
+        void showMessage(KDevelop::IStatus*,const QString & message, int timeout = 0) override;
+        void showErrorMessage(const QString & message, int timeout = 0) override;
+        void hideProgress(KDevelop::IStatus*) override;
+        void showProgress(KDevelop::IStatus*,int minimum, int maximum, int value) override;
 
     private:
         QTimer* m_timer;
@@ -101,7 +99,7 @@ ProjectProgress::ProjectProgress()
     m_timer = new QTimer(this);
     m_timer->setSingleShot( true );
     m_timer->setInterval( 1000 );
-    connect(m_timer, SIGNAL(timeout()),SLOT(slotClean()));
+    connect(m_timer, &QTimer::timeout,this, &ProjectProgress::slotClean);
 }
 
 ProjectProgress::~ProjectProgress()
@@ -115,7 +113,7 @@ QString ProjectProgress::statusName() const
 
 void ProjectProgress::setBuzzy()
 {
-    kDebug() << "showing busy progress" << statusName();
+    qCDebug(SHELL) << "showing busy progress" << statusName();
     // show an indeterminate progressbar
     emit showProgress(this, 0,0,0);
     emit showMessage(this, i18nc("%1: Project name", "Loading %1", projectName));
@@ -124,7 +122,7 @@ void ProjectProgress::setBuzzy()
 
 void ProjectProgress::setDone()
 {
-    kDebug() << "showing done progress" << statusName();
+    qCDebug(SHELL) << "showing done progress" << statusName();
     // first show 100% bar for a second, then hide.
     emit showProgress(this, 0,1,1);
     m_timer->start();
@@ -143,12 +141,12 @@ public:
     Path projectFile;
     Path developerFile;
     QString developerTempFile;
-    QString projectTempFile;
+    QTemporaryFile projectTempFile;
     IPlugin* manager;
-    QWeakPointer<IPlugin> vcsPlugin;
+    QPointer<IPlugin> vcsPlugin;
     ProjectFolderItem* topItem;
     QString name;
-    KSharedConfig::Ptr m_cfg;
+    KSharedConfigPtr m_cfg;
     IProject *project;
     QSet<KDevelop::IndexedString> fileSet;
     bool loading;
@@ -162,7 +160,8 @@ public:
         loading = false;
 
         ProjectController* projCtrl = Core::self()->projectControllerInternal();
-        if (job->errorText().isEmpty() && !Core::self()->shuttingDown()) {
+        if (job->error() == 0 && !Core::self()->shuttingDown()) {
+
             if(fullReload)
                 projCtrl->projectModel()->appendRow(topItem);
 
@@ -175,36 +174,6 @@ public:
         }
     }
 
-    QList<ProjectFileItem*> recurseFiles( ProjectBaseItem * projectItem )
-    {
-        QList<ProjectFileItem*> files;
-        if ( ProjectFolderItem * folder = projectItem->folder() )
-        {
-            QList<ProjectFolderItem*> folder_list = folder->folderList();
-            for ( QList<ProjectFolderItem*>::Iterator it = folder_list.begin(); it != folder_list.end(); ++it )
-            {
-                files += recurseFiles( ( *it ) );
-            }
-
-            QList<ProjectTargetItem*> target_list = folder->targetList();
-            for ( QList<ProjectTargetItem*>::Iterator it = target_list.begin(); it != target_list.end(); ++it )
-            {
-                files += recurseFiles( ( *it ) );
-            }
-
-            files += folder->fileList();
-        }
-        else if ( ProjectTargetItem * target = projectItem->target() )
-        {
-            files += target->fileList();
-        }
-        else if ( ProjectFileItem * file = projectItem->file() )
-        {
-            files.append( file );
-        }
-        return files;
-    }
-
     QList<ProjectBaseItem*> itemsForPath( const IndexedString& path ) const
     {
         if ( path.isEmpty() ) {
@@ -240,7 +209,7 @@ public:
         progress->setDone();
         ProjectController* projCtrl = Core::self()->projectControllerInternal();
 
-        if(job->errorText().isEmpty() && !Core::self()->shuttingDown()) {
+        if(job->error() == 0 && !Core::self()->shuttingDown()) {
             loading=false;
             projCtrl->projectModel()->appendRow(topItem);
             projCtrl->projectImportingFinished( project );
@@ -277,7 +246,7 @@ public:
         {
             // the developerfile does not exist yet, check if its folder exists
             // the developerfile itself will get created below
-            KUrl dir = developerFile.parent().toUrl();
+            QUrl dir = developerFile.parent().toUrl();
             statJob = KIO::stat( dir, KIO::HideProgressInfo );
             if( !statJob->exec() )
             {
@@ -287,16 +256,20 @@ public:
                     KMessageBox::sorry(
                         Core::self()->uiController()->activeMainWindow(),
                         i18n("Unable to create hidden dir (%1) for developer file",
-                        dir.pathOrUrl() )
+                        dir.toDisplayString(QUrl::PreferLocalFile) )
                         );
                     return false;
                 }
             }
         }
 
-        if( !KIO::NetAccess::download( projectFile.toUrl(), projectTempFile,
-                        Core::self()->uiController()->activeMainWindow() ) )
+        projectTempFile.open();
+        auto copyJob = KIO::file_copy(projectFile.toUrl(), QUrl::fromLocalFile(projectTempFile.fileName()), -1, KIO::Overwrite);
+        KJobWidgets::setWindow(copyJob, Core::self()->uiController()->activeMainWindow());
+        if (!copyJob->exec())
         {
+            qCDebug(SHELL) << "Job failed:" << copyJob->errorString();
+
             KMessageBox::sorry( Core::self()->uiController()->activeMainWindow(),
                             i18n("Unable to get project file: %1",
                             projectFile.pathOrUrl() ) );
@@ -308,14 +281,13 @@ public:
             developerTempFile = developerFile.toLocalFile();
         }
         else {
-            statJob = KIO::stat( developerFile.toUrl(), KIO::HideProgressInfo );
-            if( !statJob->exec() || !KIO::NetAccess::download( developerFile.toUrl(), developerTempFile,
-                Core::self()->uiController()->activeMainWindow() ) )
-            {
-                KTemporaryFile tmp;
-                tmp.open();
-                developerTempFile = tmp.fileName();
-            }
+            QTemporaryFile tmp;
+            tmp.open();
+            developerTempFile = tmp.fileName();
+
+            auto job = KIO::file_copy(developerFile.toUrl(), QUrl::fromLocalFile(developerTempFile), -1, KIO::HideProgressInfo | KIO::Overwrite);
+            KJobWidgets::setWindow(job, Core::self()->uiController()->activeMainWindow());
+            job->exec();
         }
         return true;
     }
@@ -323,9 +295,9 @@ public:
     KConfigGroup initKConfigObject()
     {
         // helper method for open()
-        kDebug() << "Creating KConfig object for project files" << developerTempFile << projectTempFile;
+        qCDebug(SHELL) << "Creating KConfig object for project files" << developerTempFile << projectTempFile.fileName();
         m_cfg = KSharedConfig::openConfig( developerTempFile );
-        m_cfg->addConfigSources( QStringList() << projectTempFile );
+        m_cfg->addConfigSources( QStringList() << projectTempFile.fileName() );
         KConfigGroup projectGroup( m_cfg, "Project" );
         return projectGroup;
     }
@@ -341,7 +313,7 @@ public:
                                 i18n( "Could not load %1, a project with the same name '%2' is already open.",
                                 projectFile.pathOrUrl(), name ) );
 
-            kWarning() << "Trying to open a project with a name thats already used by another open project";
+            qWarning() << "Trying to open a project with a name thats already used by another open project";
             return true;
         }
         return false;
@@ -372,6 +344,7 @@ public:
                             i18n( "Could not load project management plugin %1.",
                                   managerSetting ) );
             manager = 0;
+            return 0;
         }
         if (iface == 0)
         {
@@ -402,7 +375,7 @@ public:
                 if( iface && iface->isVersionControlled( topItem->path().toUrl() ) )
                 {
                     vcsPlugin = p;
-                    projectGroup.writeEntry("VersionControlSupport", pluginManager->pluginInfo( p ).pluginName() );
+                    projectGroup.writeEntry("VersionControlSupport", pluginManager->pluginInfo(p).pluginId());
                     projectGroup.sync();
                 }
             }
@@ -462,21 +435,14 @@ QString Project::developerTempFile() const
 
 QString Project::projectTempFile() const
 {
-    return d->projectTempFile;
+    return d->projectTempFile.fileName();
 }
 
-KSharedConfig::Ptr Project::projectConfiguration() const
+KSharedConfigPtr Project::projectConfiguration() const
 {
     return d->m_cfg;
 }
 
-const KUrl Project::folder() const
-{
-    KUrl url = d->projectPath.toUrl();
-    url.adjustPath(KUrl::AddTrailingSlash);
-    return url;
-}
-
 Path Project::path() const
 {
     return d->projectPath;
@@ -484,7 +450,6 @@ Path Project::path() const
 
 void Project::reloadModel()
 {
-    qDebug() << "reload!!!!!!!" << d->loading;
     if (d->loading) {
         d->scheduleReload = true;
         return;
@@ -516,7 +481,7 @@ void Project::setReloadJob(KJob* job)
     d->loading = true;
     d->fullReload = false;
     d->progress->setBuzzy();
-    connect(job, SIGNAL(finished(KJob*)), SLOT(reloadDone(KJob*)));
+    connect(job, &KJob::finished, this, [&] (KJob* job) { d->reloadDone(job); });
 }
 
 bool Project::open( const Path& projectFile )
@@ -546,7 +511,7 @@ bool Project::open( const Path& projectFile )
     d->loadVersionControlPlugin(projectGroup);
     d->progress->setBuzzy();
     KJob* importJob = iface->createImportJob(d->topItem );
-    connect( importJob, SIGNAL(result(KJob*)), this, SLOT(importDone(KJob*)) );
+    connect( importJob, &KJob::result, this, [&] (KJob* job) { d->importDone(job); } );
     Core::self()->runController()->registerJob( importJob );
     return true;
 }
@@ -555,19 +520,23 @@ void Project::close()
 {
     Q_ASSERT(d->topItem);
     if (d->topItem->row() == -1) {
-        kWarning() << "Something went wrong. ProjectFolderItem detached. Project closed during reload?";
+        qWarning() << "Something went wrong. ProjectFolderItem detached. Project closed during reload?";
         return;
     }
 
     Core::self()->projectController()->projectModel()->removeRow( d->topItem->row() );
 
-    if( !d->developerFile.isLocalFile() && !KIO::NetAccess::upload( d->developerTempFile, d->developerFile.toUrl(),
-                Core::self()->uiController()->activeMainWindow() ) )
+    if (!d->developerFile.isLocalFile())
     {
-        KMessageBox::sorry( Core::self()->uiController()->activeMainWindow(),
-                    i18n("Could not store developer specific project configuration.\n"
-                         "Attention: The project settings you changed will be lost."
-                    ) );
+        auto copyJob = KIO::file_copy(QUrl::fromLocalFile(d->developerTempFile), d->developerFile.toUrl());
+        KJobWidgets::setWindow(copyJob, Core::self()->uiController()->activeMainWindow());
+        if (!copyJob->exec()) {
+            qCDebug(SHELL) << "Job failed:" << copyJob->errorString();
+
+            KMessageBox::sorry(Core::self()->uiController()->activeMainWindow(),
+                               i18n("Could not store developer specific project configuration.\n"
+                                    "Attention: The project settings you changed will be lost."));
+        }
     }
 }
 
@@ -579,40 +548,11 @@ bool Project::inProject( const IndexedString& path ) const
     return !d->itemsForPath( path ).isEmpty();
 }
 
-ProjectFileItem* Project::fileAt( int num ) const
-{
-    QList<ProjectFileItem*> files;
-    if ( d->topItem )
-        files = d->recurseFiles( d->topItem );
-
-    if( !files.isEmpty() && num >= 0 && num < files.count() )
-        return files.at( num );
-    return 0;
-}
-
-QList<ProjectFileItem *> Project::files() const
-{
-    QList<ProjectFileItem *> files;
-    if ( d->topItem )
-        files = d->recurseFiles( d->topItem );
-    return files;
-}
-
-QList< ProjectBaseItem* > Project::itemsForUrl(const KUrl& url) const
-{
-    return d->itemsForPath(IndexedString(url));
-}
-
 QList< ProjectBaseItem* > Project::itemsForPath(const IndexedString& path) const
 {
     return d->itemsForPath(path);
 }
 
-QList<ProjectFileItem*> Project::filesForUrl(const KUrl& url) const
-{
-    return filesForPath(IndexedString(url));
-}
-
 QList< ProjectFileItem* > Project::filesForPath(const IndexedString& file) const
 {
     QList<ProjectFileItem*> items;
@@ -624,11 +564,6 @@ QList< ProjectFileItem* > Project::filesForPath(const IndexedString& file) const
     return items;
 }
 
-QList< ProjectFolderItem* > Project::foldersForUrl(const KUrl& url) const
-{
-    return foldersForPath(IndexedString(url));
-}
-
 QList<ProjectFolderItem*> Project::foldersForPath(const IndexedString& folder) const
 {
     QList<ProjectFolderItem*> items;
@@ -640,14 +575,6 @@ QList<ProjectFolderItem*> Project::foldersForPath(const IndexedString& folder) c
     return items;
 }
 
-int Project::fileCount() const
-{
-    QList<ProjectFileItem*> files;
-    if ( d->topItem )
-        files = d->recurseFiles( d->topItem );
-    return files.count();
-}
-
 IProjectFileManager* Project::projectFileManager() const
 {
     return d->manager->extension<IProjectFileManager>();
@@ -673,21 +600,11 @@ Path Project::projectFile() const
     return d->projectFile;
 }
 
-KUrl Project::projectFileUrl() const
-{
-    return d->projectFile.toUrl();
-}
-
 Path Project::developerFile() const
 {
     return d->developerFile;
 }
 
-KUrl Project::developerFileUrl() const
-{
-    return d->developerFile.toUrl();
-}
-
 ProjectFolderItem* Project::projectItem() const
 {
     return d->topItem;
