@@ -22,7 +22,10 @@ Boston, MA 02110-1301, USA.
 #define KDEVPLATFORM_PROJECTCONTROLLER_H
 
 #include <interfaces/iprojectcontroller.h>
-#include <kio/udsentry.h>
+
+#include <QUrl>
+
+#include <KIO/UDSEntry>
 
 #include "shellexport.h"
 
@@ -53,11 +56,11 @@ public:
 public Q_SLOTS:
     /**
      * Displays some UI to ask the user for the project location.
-     * 
+     *
      * @param fetch will tell the UI that the user might want to fetch the project first
      * @param startUrl tells where to look first
      */
-    virtual KUrl askProjectConfigLocation(bool fetch, const KUrl& startUrl = KUrl()) = 0;
+    virtual QUrl askProjectConfigLocation(bool fetch, const QUrl& startUrl = QUrl()) = 0;
     virtual bool userWantsReopen() = 0;
 };
 
@@ -70,46 +73,46 @@ class KDEVPLATFORMSHELL_EXPORT ProjectController : public IProjectController
     friend class ProjectPreferences;
 
 public:
-    ProjectController( Core* core );
+    explicit ProjectController( Core* core );
     virtual ~ProjectController();
 
-    virtual IProject* projectAt( int ) const;
-    virtual int projectCount() const;
-    virtual QList<IProject*> projects() const;
+    virtual IProject* projectAt( int ) const override;
+    virtual int projectCount() const override;
+    virtual QList<IProject*> projects() const override;
 
-    virtual ProjectBuildSetModel* buildSetModel();
-    virtual ProjectModel* projectModel();
-    virtual ProjectChangesModel* changesModel();
+    virtual ProjectBuildSetModel* buildSetModel() override;
+    virtual ProjectModel* projectModel() override;
+    virtual ProjectChangesModel* changesModel() override;
     virtual QItemSelectionModel* projectSelectionModel();
-    virtual IProject* findProjectByName( const QString& name );
-    IProject* findProjectForUrl( const KUrl& ) const;
+    virtual IProject* findProjectByName( const QString& name ) override;
+    IProject* findProjectForUrl( const QUrl& ) const override;
     void addProject(IProject*);
 //     IProject* currentProject() const;
 
-    virtual bool isProjectNameUsed( const QString& name ) const;
+    virtual bool isProjectNameUsed( const QString& name ) const override;
     void setDialogProvider(IProjectDialogProvider*);
 
-    KUrl projectsBaseDirectory() const;
-    QString prettyFileName(const KUrl& url, FormattingOptions format = FormatHtml) const override;
-    QString prettyFilePath(const KUrl& url, FormattingOptions format = FormatHtml) const override;
+    QUrl projectsBaseDirectory() const override;
+    QString prettyFileName(const QUrl& url, FormattingOptions format = FormatHtml) const override;
+    QString prettyFilePath(const QUrl& url, FormattingOptions format = FormatHtml) const override;
 
     ContextMenuExtension contextMenuExtension( KDevelop::Context* ctx );
 
 public Q_SLOTS:
-    virtual void openProjectForUrl( const KUrl &sourceUrl );
+    virtual void openProjectForUrl( const QUrl &sourceUrl ) override;
     virtual void fetchProject();
-    virtual void openProject( const KUrl &KDev4ProjectFile = KUrl() );
+    virtual void openProject( const QUrl &KDev4ProjectFile = QUrl() ) override;
     virtual void abortOpeningProject( IProject* );
     void projectImportingFinished( IProject* );
-    virtual void closeProject( IProject* );
-    virtual void configureProject( IProject* );
+    virtual void closeProject( IProject* ) override;
+    virtual void configureProject( IProject* ) override;
 
     virtual void reparseProject( IProject* project, bool forceUpdate = false  ) override;
 
     void eventuallyOpenProjectFile(KIO::Job*,KIO::UDSEntryList);
     void openProjectForUrlSlot(bool);
 //     void changeCurrentProject( ProjectBaseItem* );
-    void openProjects(const KUrl::List& projects);
+    void openProjects(const QList<QUrl>& projects);
     void commitCurrentProject();
 
     // Maps the given path from the source to the equivalent path within the build directory
@@ -139,7 +142,6 @@ private:
 private:
     Q_PRIVATE_SLOT(d, void projectConfig( QObject* ) )
     Q_PRIVATE_SLOT(d, void unloadAllProjectPlugins() )
-    Q_PRIVATE_SLOT(d, void notifyProjectConfigurationChanged() )
     Q_PRIVATE_SLOT(d, void updateActionStates( KDevelop::Context* ) )
     Q_PRIVATE_SLOT(d, void closeSelectedProjects() )
     Q_PRIVATE_SLOT(d, void openProjectConfig() )
@@ -152,13 +154,13 @@ class ProjectDialogProvider : public IProjectDialogProvider
 {
 Q_OBJECT
 public:
-    ProjectDialogProvider(ProjectControllerPrivate* const p);
+    explicit ProjectDialogProvider(ProjectControllerPrivate* const p);
     virtual ~ProjectDialogProvider();
     ProjectControllerPrivate* const d;
 
 public Q_SLOTS:
-    virtual KUrl askProjectConfigLocation(bool fetch, const KUrl& sta);
-    virtual bool userWantsReopen();
+    virtual QUrl askProjectConfigLocation(bool fetch, const QUrl& sta) override;
+    virtual bool userWantsReopen() override;
 };
 
 
