@@ -11,9 +11,6 @@
 #include "projectinfopage.h"
 #include "ui_projectinfopage.h"
 
-#include <kplugininfo.h>
-#include <kdebug.h>
-
 #include "core.h"
 #include "plugincontroller.h"
 
@@ -25,16 +22,20 @@ ProjectInfoPage::ProjectInfoPage( QWidget* parent )
 {
     page_ui = new Ui::ProjectInfoPage;
     page_ui->setupUi( this );
-    connect( page_ui->nameEdit, SIGNAL(textEdited(QString)), 
-             this, SIGNAL(projectNameChanged(QString)) );
-    connect( page_ui->managerCombo, SIGNAL(activated(int)),
-             this, SLOT(changeProjectManager(int)) );
-    foreach( const KPluginInfo& info, Core::self()->pluginControllerInternal()->queryExtensionPlugins( "org.kdevelop.IProjectFileManager" ) )
-    {
-        page_ui->managerCombo->addItem( KIcon(info.icon()), info.name(), info.pluginName() );
+    connect( page_ui->nameEdit, &QLineEdit::textEdited, 
+             this, &ProjectInfoPage::projectNameChanged );
+    connect( page_ui->managerCombo, static_cast<void(QComboBox::*)(int)>(&QComboBox::activated),
+             this, &ProjectInfoPage::changeProjectManager );
+    for (auto&& info : Core::self()->pluginControllerInternal()->queryExtensionPlugins("org.kdevelop.IProjectFileManager")) {
+        page_ui->managerCombo->addItem(QIcon::fromTheme(info.iconName()), info.name(), info.pluginId());
     }
 }
 
+ProjectInfoPage::~ProjectInfoPage()
+{
+    delete page_ui;
+}
+
 void ProjectInfoPage::changeProjectManager( int idx )
 {
     emit projectManagerChanged( page_ui->managerCombo->itemData( idx ).toString() );
@@ -58,4 +59,3 @@ void ProjectInfoPage::setProjectManager( const QString& name )
 
 }
 
-#include "projectinfopage.moc"
