@@ -8,18 +8,16 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef PROJECTINFOPAGE_H
-#define PROJECTINFOPAGE_H
+#ifndef KDEVPLATFORM_PROJECTINFOPAGE_H
+#define KDEVPLATFORM_PROJECTINFOPAGE_H
 
-#include <QtGui/QWidget>
+#include <QWidget>
 
 namespace Ui
 {
     class ProjectInfoPage;
 }
 
-class KUrl;
-
 namespace KDevelop
 {
 
@@ -27,7 +25,8 @@ class ProjectInfoPage : public QWidget
 {
 Q_OBJECT
 public:
-    ProjectInfoPage( QWidget* parent = 0 );
+    explicit ProjectInfoPage( QWidget* parent = 0 );
+    virtual ~ProjectInfoPage();
     void setProjectName( const QString& );
     void setProjectManager( const QString& );
 signals:
