@@ -8,13 +8,13 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef PROJECTSOURCEPAGE_H
-#define PROJECTSOURCEPAGE_H
+#ifndef KDEVPLATFORM_PROJECTSOURCEPAGE_H
+#define KDEVPLATFORM_PROJECTSOURCEPAGE_H
 
 #include <QWidget>
 
 class KJob;
-class KUrl;
+class QUrl;
 namespace Ui { class ProjectSourcePage; }
 namespace KDevelop
 {
@@ -29,10 +29,10 @@ class ProjectSourcePage : public QWidget
 {
     Q_OBJECT
     public:
-        ProjectSourcePage(const KUrl& initial, QWidget* parent = 0);
+        explicit ProjectSourcePage(const QUrl& initial, QWidget* parent = 0);
         virtual ~ProjectSourcePage();
 
-        KUrl workingDir() const;
+        QUrl workingDir() const;
         
     private slots:
         void setSourceIndex(int index);
@@ -62,4 +62,4 @@ class ProjectSourcePage : public QWidget
 };
 
 }
-#endif // PROJECTSOURCEPAGE_H
+#endif // KDEVPLATFORM_PROJECTSOURCEPAGE_H
