@@ -20,18 +20,17 @@ Boston, MA 02110-1301, USA.
 
 #include "runcontroller.h"
 
-#include <QApplication>
-#include <QStandardItemModel>
+#include <QDebug>
 #include <QPalette>
+#include <QSignalMapper>
 
-#include <KDE/KSelectAction>
-#include <KDE/KActionMenu>
-#include <KDE/KActionCollection>
-#include <KDE/KMessageBox>
-#include <KDE/KLocale>
-#include <KDE/KDebug>
-#include <KDE/KColorScheme>
-#include <kdialogjobuidelegate.h>
+#include <KActionCollection>
+#include <KActionMenu>
+#include <KColorScheme>
+#include <KDialogJobUiDelegate>
+#include <KMessageBox>
+#include <KLocalizedString>
+#include <KSelectAction>
 
 #include <interfaces/iproject.h>
 #include <interfaces/idocumentcontroller.h>
@@ -51,20 +50,43 @@ Boston, MA 02110-1301, USA.
 #include "mainwindow.h"
 #include "launchconfiguration.h"
 #include "launchconfigurationdialog.h"
+#include "debug.h"
 #include <interfaces/isession.h>
-#include <QSignalMapper>
+
 #include <interfaces/contextmenuextension.h>
 #include <interfaces/context.h>
 #include <sublime/area.h>
-#include <kmenu.h>
 
 using namespace KDevelop;
 
-QString RunController::LaunchConfigurationsGroup = "Launch";
-QString RunController::LaunchConfigurationsListEntry = "Launch Configurations";
-static QString CurrentLaunchConfigProjectEntry = "Current Launch Config Project";
-static QString CurrentLaunchConfigNameEntry = "Current Launch Config GroupName";
-static QString ConfiguredFromProjectItemEntry = "Configured from ProjectItem";
+namespace {
+namespace Strings {
+QString LaunchConfigurationsGroup()
+{
+    return QStringLiteral("Launch");
+}
+
+QString LaunchConfigurationsListEntry()
+{
+    return QStringLiteral("Launch Configurations");
+}
+
+QString CurrentLaunchConfigProjectEntry()
+{
+    return QStringLiteral("Current Launch Config Project");
+}
+
+QString CurrentLaunchConfigNameEntry()
+{
+    return QStringLiteral("Current Launch Config GroupName");
+}
+
+QString ConfiguredFromProjectItemEntry()
+{
+    return QStringLiteral("Configured from ProjectItem");
+}
+}
+}
 
 typedef QPair<QString, IProject*> Target;
 Q_DECLARE_METATYPE(Target)
@@ -77,27 +99,27 @@ class DebugMode : public ILaunchMode
 {
 public:
     DebugMode() {}
-    virtual KIcon icon() const { return KIcon("tools-report-bug"); }
-    virtual QString id() const { return "debug"; }
-    virtual QString name() const { return i18n("Debug"); }
+    virtual QIcon icon() const override { return QIcon::fromTheme("tools-report-bug"); }
+    virtual QString id() const override { return "debug"; }
+    virtual QString name() const override { return i18n("Debug"); }
 };
 
 class ProfileMode : public ILaunchMode
 {
 public:
     ProfileMode() {}
-    virtual KIcon icon() const { return KIcon("office-chart-area"); }
-    virtual QString id() const { return "profile"; }
-    virtual QString name() const { return i18n("Profile"); }
+    virtual QIcon icon() const override { return QIcon::fromTheme("office-chart-area"); }
+    virtual QString id() const override { return "profile"; }
+    virtual QString name() const override { return i18n("Profile"); }
 };
 
 class ExecuteMode : public ILaunchMode
 {
 public:
     ExecuteMode() {}
-    virtual KIcon icon() const { return KIcon("system-run"); }
-    virtual QString id() const { return "execute"; }
-    virtual QString name() const { return i18n("Execute"); }
+    virtual QIcon icon() const override { return QIcon::fromTheme("system-run"); }
+    virtual QString id() const override { return "execute"; }
+    virtual QString name() const override { return i18n("Execute"); }
 };
 
 class RunController::RunControllerPrivate
@@ -109,11 +131,11 @@ public:
 
     RunController* q;
 
-    QHash<KJob*, KAction*> jobs;
-    KAction* stopAction;
+    QHash<KJob*, QAction*> jobs;
+    QAction* stopAction;
     KActionMenu* stopJobsMenu;
-    KAction* runAction;
-    KAction* dbgAction;
+    QAction* runAction;
+    QAction* dbgAction;
     KSelectAction* currentTargetAction;
     QMap<QString,LaunchConfigurationType*> launchConfigurationTypes;
     QList<LaunchConfiguration*> launchConfigurations;
@@ -135,14 +157,14 @@ public:
 
         if( currentTargetAction->currentAction() )
         {
-            KConfigGroup grp = Core::self()->activeSession()->config()->group( RunController::LaunchConfigurationsGroup );
-            LaunchConfiguration* l = static_cast<LaunchConfiguration*>( qVariantValue<void*>( currentTargetAction->currentAction()->data() ) );
-            grp.writeEntry( CurrentLaunchConfigProjectEntry, l->project() ? l->project()->name() : "" );
-            grp.writeEntry( CurrentLaunchConfigNameEntry, l->configGroupName() );
+            KConfigGroup grp = Core::self()->activeSession()->config()->group( Strings::LaunchConfigurationsGroup() );
+            LaunchConfiguration* l = static_cast<LaunchConfiguration*>( currentTargetAction->currentAction()->data().value<void*>() );
+            grp.writeEntry( Strings::CurrentLaunchConfigProjectEntry(), l->project() ? l->project()->name() : "" );
+            grp.writeEntry( Strings::CurrentLaunchConfigNameEntry(), l->configGroupName() );
             grp.sync();
         }
     }
-    
+
     void configureLaunches()
     {
         LaunchConfigurationDialog dlg;
@@ -154,29 +176,29 @@ public:
         QString label;
         if( l->project() )
         {
-            label = QString("%1 : %2").arg( l->project()->name()).arg(l->name());
+            label = QStringLiteral("%1 : %2").arg( l->project()->name()).arg(l->name());
         } else
         {
-            label = QString("%1" ).arg(l->name());
+            label = l->name();
         }
         return label;
     }
 
     void launchAs( int id )
     {
-        //kDebug() << "Launching id:" << id;
+        //qCDebug(SHELL) << "Launching id:" << id;
         QPair<QString,QString> info = launchAsInfo[id];
-        //kDebug() << "fetching type and mode:" << info.first << info.second;
+        //qCDebug(SHELL) << "fetching type and mode:" << info.first << info.second;
         LaunchConfigurationType* type = launchConfigurationTypeForId( info.first );
         ILaunchMode* mode = q->launchModeForId( info.second );
 
-        //kDebug() << "got mode and type:" << type << type->id() << mode << mode->id();
+        //qCDebug(SHELL) << "got mode and type:" << type << type->id() << mode << mode->id();
         if( type && mode )
         {
             ILauncher* launcher = 0;
             foreach (ILauncher *l, type->launchers())
             {
-                //kDebug() << "available launcher" << l << l->id() << l->supportedModes();
+                //qCDebug(SHELL) << "available launcher" << l << l->id() << l->supportedModes();
                 if (l->supportedModes().contains(mode->id())) {
                     launcher = l;
                     break;
@@ -187,9 +209,9 @@ public:
                 QStringList itemPath = Core::self()->projectController()->projectModel()->pathFromIndex(contextItem->index());
                 ILaunchConfiguration* ilaunch = 0;
                 foreach (LaunchConfiguration *l, launchConfigurations) {
-                    QStringList path = l->config().readEntry(ConfiguredFromProjectItemEntry, QStringList());
+                    QStringList path = l->config().readEntry(Strings::ConfiguredFromProjectItemEntry(), QStringList());
                     if (l->type() == type && path == itemPath) {
-                        kDebug() << "already generated ilaunch" << path;
+                        qCDebug(SHELL) << "already generated ilaunch" << path;
                         ilaunch = l;
                         break;
                     }
@@ -201,10 +223,10 @@ public:
                                                             contextItem->text() );
                     LaunchConfiguration* launch = dynamic_cast<LaunchConfiguration*>( ilaunch );
                     type->configureLaunchFromItem( launch->config(), contextItem );
-                    launch->config().writeEntry(ConfiguredFromProjectItemEntry, itemPath);
-                    //kDebug() << "created config, launching";
+                    launch->config().writeEntry(Strings::ConfiguredFromProjectItemEntry(), itemPath);
+                    //qCDebug(SHELL) << "created config, launching";
                 } else {
-                    //kDebug() << "reusing generated config, launching";
+                    //qCDebug(SHELL) << "reusing generated config, launching";
                 }
                 q->setDefaultLaunch(ilaunch);
                 q->execute( mode->id(), ilaunch );
@@ -216,14 +238,14 @@ public:
     {
         if (!currentTargetAction) return;
 
-        KConfigGroup launchGrp = Core::self()->activeSession()->config()->group( RunController::LaunchConfigurationsGroup );
-        QString currentLaunchProject = launchGrp.readEntry( CurrentLaunchConfigProjectEntry, "" );
-        QString currentLaunchName = launchGrp.readEntry( CurrentLaunchConfigNameEntry, "" );
+        KConfigGroup launchGrp = Core::self()->activeSession()->config()->group( Strings::LaunchConfigurationsGroup() );
+        QString currentLaunchProject = launchGrp.readEntry( Strings::CurrentLaunchConfigProjectEntry(), "" );
+        QString currentLaunchName = launchGrp.readEntry( Strings::CurrentLaunchConfigNameEntry(), "" );
 
         LaunchConfiguration* l = 0;
         if( currentTargetAction->currentAction() )
         {
-            l = static_cast<LaunchConfiguration*>( qVariantValue<void*>( currentTargetAction->currentAction()->data() ) );
+            l = static_cast<LaunchConfiguration*>( currentTargetAction->currentAction()->data().value<void*>() );
         } else if( !launchConfigurations.isEmpty() )
         {
             l = launchConfigurations.at( 0 );
@@ -245,7 +267,7 @@ public:
         }
         if( !currentTargetAction->currentAction() )
         {
-            kDebug() << "oops no current action, using first if list is non-empty";
+            qCDebug(SHELL) << "oops no current action, using first if list is non-empty";
             if( !currentTargetAction->actions().isEmpty() )
             {
                 currentTargetAction->actions().first()->setChecked( true );
@@ -257,18 +279,18 @@ public:
     {
         if (!currentTargetAction) return;
 
-        KAction* action = currentTargetAction->addAction(launchActionText( l ));
+        QAction* action = currentTargetAction->addAction(launchActionText( l ));
         action->setData(qVariantFromValue<void*>(l));
     }
     void readLaunchConfigs( KSharedConfigPtr cfg, IProject* prj )
     {
-        KConfigGroup group(cfg, RunController::LaunchConfigurationsGroup);
-        QStringList configs = group.readEntry( RunController::LaunchConfigurationsListEntry, QStringList() );
+        KConfigGroup group(cfg, Strings::LaunchConfigurationsGroup());
+        QStringList configs = group.readEntry( Strings::LaunchConfigurationsListEntry(), QStringList() );
 
         foreach( const QString& cfg, configs )
         {
             KConfigGroup grp = group.group( cfg );
-            if( launchConfigurationTypeForId( grp.readEntry( LaunchConfiguration::LaunchConfigurationTypeEntry, "" ) ) )
+            if( launchConfigurationTypeForId( grp.readEntry( LaunchConfiguration::LaunchConfigurationTypeEntry(), "" ) ) )
             {
                 q->addLaunchConfiguration( new LaunchConfiguration( grp, prj ) );
             }
@@ -282,7 +304,7 @@ public:
             return it.value();
         } else
         {
-            kWarning() << "couldn't find type for id:" << id << ". Known types:" << launchConfigurationTypes.keys();
+            qWarning() << "couldn't find type for id:" << id << ". Known types:" << launchConfigurationTypes.keys();
         }
         return 0;
 
@@ -324,7 +346,7 @@ void KDevelop::RunController::launchChanged( LaunchConfiguration* l )
 {
     foreach( QAction* a, d->currentTargetAction->actions() )
     {
-        if( static_cast<LaunchConfiguration*>( qVariantValue<void*>( a->data() ) ) == l )
+        if( static_cast<LaunchConfiguration*>( a->data().value<void*>() ) == l )
         {
             a->setText( d->launchActionText( l ) );
             break;
@@ -358,12 +380,12 @@ void RunController::initialize()
     foreach (IProject* project, Core::self()->projectController()->projects()) {
         slotProjectOpened(project);
     }
-    connect(Core::self()->projectController(), SIGNAL(projectOpened(KDevelop::IProject*)),
-            this, SLOT(slotProjectOpened(KDevelop::IProject*)));
-    connect(Core::self()->projectController(), SIGNAL(projectClosing(KDevelop::IProject*)),
-            this, SLOT(slotProjectClosing(KDevelop::IProject*)));
-    connect(Core::self()->projectController(), SIGNAL(projectConfigurationChanged(KDevelop::IProject*)),
-             this, SLOT(slotRefreshProject(KDevelop::IProject*)));
+    connect(Core::self()->projectController(), &IProjectController::projectOpened,
+            this, &RunController::slotProjectOpened);
+    connect(Core::self()->projectController(), &IProjectController::projectClosing,
+            this, &RunController::slotProjectClosing);
+    connect(Core::self()->projectController(), &IProjectController::projectConfigurationChanged,
+             this, &RunController::slotRefreshProject);
 
     if( (Core::self()->setupFlags() & Core::NoUi) == 0 )
     {
@@ -376,7 +398,7 @@ KJob* RunController::execute(const QString& runMode, ILaunchConfiguration* launc
 {
     if( !launch )
     {
-        kDebug() << "execute called without launch config!";
+        qCDebug(SHELL) << "execute called without launch config!";
         return 0;
     }
     LaunchConfiguration *run = dynamic_cast<LaunchConfiguration*>(launch);
@@ -389,15 +411,15 @@ KJob* RunController::execute(const QString& runMode, ILaunchConfiguration* launc
     //    jobs.append(job);
     //}
 
-    kDebug() << "mode:" << runMode;
+    qCDebug(SHELL) << "mode:" << runMode;
     QString launcherId = run->launcherForMode( runMode );
-    kDebug() << "launcher id:" << launcherId;
+    qCDebug(SHELL) << "launcher id:" << launcherId;
 
     ILauncher* launcher = run->type()->launcherForId( launcherId );
 
     if( !launcher ) {
         KMessageBox::error(
-            qApp->activeWindow(), 
+            qApp->activeWindow(),
             i18n("The current launch configuration does not support the '%1' mode.", runMode),
             "");
         return 0;
@@ -410,57 +432,57 @@ KJob* RunController::execute(const QString& runMode, ILaunchConfiguration* launc
 
 void RunController::setupActions()
 {
-    KAction *action;
+    QAction* action;
 
     // TODO not multi-window friendly, FIXME
     KActionCollection* ac = Core::self()->uiControllerInternal()->defaultMainWindow()->actionCollection();
 
-    action = new KAction (i18n("Configure Launches..."), this);
+    action = new QAction(i18n("Configure Launches..."), this);
     ac->addAction("configure_launches", action);
     action->setStatusTip(i18n("Open Launch Configuration Dialog"));
     action->setToolTip(i18nc("@info:tooltip", "Open Launch Configuration Dialog"));
     action->setWhatsThis(i18nc("@info:whatsthis", "Opens a dialog to setup new launch configurations, or to change the existing ones."));
-    connect(action, SIGNAL(triggered(bool)), SLOT(configureLaunches()));
+    connect(action, &QAction::triggered, this, [&] { d->configureLaunches(); });
 
-    d->runAction = new KAction( KIcon("system-run"), i18n("Execute Launch"), this);
+    d->runAction = new QAction( QIcon::fromTheme("system-run"), i18n("Execute Launch"), this);
     d->runAction->setIconText( i18nc("Short text for 'Execute launch' used in the toolbar", "Execute") );
-    d->runAction->setShortcut(Qt::SHIFT + Qt::Key_F9);
+    ac->setDefaultShortcut( d->runAction, Qt::SHIFT + Qt::Key_F9);
     d->runAction->setToolTip(i18nc("@info:tooltip", "Execute current launch"));
     d->runAction->setStatusTip(i18n("Execute current launch"));
     d->runAction->setWhatsThis(i18nc("@info:whatsthis", "Executes the target or the program specified in currently active launch configuration."));
     ac->addAction("run_execute", d->runAction);
-    connect(d->runAction, SIGNAL(triggered(bool)), this, SLOT(slotExecute()));
+    connect(d->runAction, &QAction::triggered, this, &RunController::slotExecute);
 
-    d->dbgAction = new KAction( KIcon("debug-run"), i18n("Debug Launch"), this);
-    d->dbgAction->setShortcut(Qt::Key_F9);
+    d->dbgAction = new QAction( QIcon::fromTheme("debug-run"), i18n("Debug Launch"), this);
+    ac->setDefaultShortcut( d->dbgAction, Qt::Key_F9);
     d->dbgAction->setIconText( i18nc("Short text for 'Debug launch' used in the toolbar", "Debug") );
     d->dbgAction->setToolTip(i18nc("@info:tooltip", "Debug current launch"));
     d->dbgAction->setStatusTip(i18n("Debug current launch"));
     d->dbgAction->setWhatsThis(i18nc("@info:whatsthis", "Executes the target or the program specified in currently active launch configuration inside a Debugger."));
     ac->addAction("run_debug", d->dbgAction);
-    connect(d->dbgAction, SIGNAL(triggered(bool)), this, SLOT(slotDebug()));
+    connect(d->dbgAction, &QAction::triggered, this, &RunController::slotDebug);
     Core::self()->uiControllerInternal()->area(0, "code")->addAction(d->dbgAction);
 
 //     TODO: at least get a profile target, it's sad to have the menu entry without a profiler
-//     KAction* profileAction = new KAction( KIcon(""), i18n("Profile Launch"), this);
+//     QAction* profileAction = new QAction( QIcon::fromTheme(""), i18n("Profile Launch"), this);
 //     profileAction->setToolTip(i18nc("@info:tooltip", "Profile current launch"));
 //     profileAction->setStatusTip(i18n("Profile current launch"));
 //     profileAction->setWhatsThis(i18nc("@info:whatsthis", "Executes the target or the program specified in currently active launch configuration inside a Profiler."));
 //     ac->addAction("run_profile", profileAction);
 //     connect(profileAction, SIGNAL(triggered(bool)), this, SLOT(slotProfile()));
 
-    action = d->stopAction = new KAction( KIcon("process-stop"), i18n("Stop All Jobs"), this);
+    action = d->stopAction = new QAction( QIcon::fromTheme("process-stop"), i18n("Stop All Jobs"), this);
     action->setIconText(i18nc("Short text for 'Stop All Jobs' used in the toolbar", "Stop All"));
     // Ctrl+Escape would be nicer, but thats taken by the ksysguard desktop shortcut
-    action->setShortcut(QKeySequence("Ctrl+Shift+Escape"));
+    ac->setDefaultShortcut( action, QKeySequence("Ctrl+Shift+Escape"));
     action->setToolTip(i18nc("@info:tooltip", "Stop all currently running jobs"));
     action->setWhatsThis(i18nc("@info:whatsthis", "Requests that all running jobs are stopped."));
     action->setEnabled(false);
     ac->addAction("run_stop_all", action);
-    connect(action, SIGNAL(triggered(bool)), this, SLOT(stopAllProcesses()));
+    connect(action, &QAction::triggered, this, &RunController::stopAllProcesses);
     Core::self()->uiControllerInternal()->area(0, "debug")->addAction(action);
 
-    action = d->stopJobsMenu = new KActionMenu( KIcon("process-stop"), i18n("Stop"), this);
+    action = d->stopJobsMenu = new KActionMenu( QIcon::fromTheme("process-stop"), i18n("Stop"), this);
     action->setIconText(i18nc("Short text for 'Stop' used in the toolbar", "Stop"));
     action->setToolTip(i18nc("@info:tooltip", "Menu allowing to stop individual jobs"));
     action->setWhatsThis(i18nc("@info:whatsthis", "List of jobs that can be stopped individually."));
@@ -515,7 +537,7 @@ void RunController::slotDebug()
         LaunchConfigurationDialog d;
         d.exec();
     }
-    
+
     if(!d->launchConfigurations.isEmpty())
         executeDefaultLaunch( "debug" );
 }
@@ -526,19 +548,19 @@ void RunController::slotProfile()
         LaunchConfigurationDialog d;
         d.exec();
     }
-    
+
     if(!d->launchConfigurations.isEmpty())
         executeDefaultLaunch( "profile" );
 }
 
 void RunController::slotExecute()
 {
-    
+
     if(d->launchConfigurations.isEmpty()) {
         LaunchConfigurationDialog d;
         d.exec();
     }
-    
+
     if(!d->launchConfigurations.isEmpty())
         executeDefaultLaunch( "execute" );
 }
@@ -558,24 +580,24 @@ void KDevelop::RunController::registerJob(KJob * job)
 
     if (!(job->capabilities() & KJob::Killable)) {
         // see e.g. https://bugs.kde.org/show_bug.cgi?id=314187
-        kWarning() << "non-killable job" << job << "registered - this might lead to crashes on shutdown.";
+        qWarning() << "non-killable job" << job << "registered - this might lead to crashes on shutdown.";
     }
 
     if (!d->jobs.contains(job)) {
-        KAction* stopJobAction = 0;
+        QAction* stopJobAction = 0;
         if (Core::self()->setupFlags() != Core::NoUi) {
-            stopJobAction = new KAction(job->objectName().isEmpty() ? i18n("<%1> Unnamed job", job->staticMetaObject.className()) : job->objectName(), this);
+            stopJobAction = new QAction(job->objectName().isEmpty() ? i18n("<%1> Unnamed job", job->staticMetaObject.className()) : job->objectName(), this);
             stopJobAction->setData(QVariant::fromValue(static_cast<void*>(job)));
             d->stopJobsMenu->addAction(stopJobAction);
-            connect (stopJobAction, SIGNAL(triggered(bool)), SLOT(slotKillJob()));
+            connect (stopJobAction, &QAction::triggered, this, &RunController::slotKillJob);
 
             job->setUiDelegate( new KDialogJobUiDelegate() );
         }
 
         d->jobs.insert(job, stopJobAction);
 
-        connect( job, SIGNAL(finished(KJob*)), SLOT(finished(KJob*)) );
-        connect( job, SIGNAL(destroyed(QObject*)), SLOT(jobDestroyed(QObject*)) );
+        connect( job, &KJob::finished, this, &RunController::finished );
+        connect( job, &KJob::destroyed, this, &RunController::jobDestroyed );
 
         IRunController::registerJob(job);
 
@@ -637,14 +659,14 @@ void KDevelop::RunController::stopAllProcesses()
         if (job->capabilities() & KJob::Killable) {
             job->kill(KJob::EmitResult);
         } else {
-            kWarning() << "cannot stop non-killable job: " << job;
+            qWarning() << "cannot stop non-killable job: " << job;
         }
     }
 }
 
 void KDevelop::RunController::slotKillJob()
 {
-    KAction* action = dynamic_cast<KAction*>(sender());
+    QAction* action = dynamic_cast<QAction*>(sender());
     Q_ASSERT(action);
 
     KJob* job = static_cast<KJob*>(qvariant_cast<void*>(action->data()));
@@ -667,14 +689,13 @@ void KDevelop::RunController::finished(KJob * job)
             ///WARNING: do *not* use a nested event loop here, it might cause
             ///         random crashes later on, see e.g.:
             ///         https://bugs.kde.org/show_bug.cgi?id=309811
-            KDialog* dialog = new KDialog(qApp->activeWindow());
+            auto dialog = new QDialog(qApp->activeWindow());
             dialog->setAttribute(Qt::WA_DeleteOnClose);
             dialog->setWindowTitle(i18n("Process Error"));
-            dialog->setButtons(KDialog::Close);
-            KMessageBox::createKMessageBox(dialog, QMessageBox::Warning,
+            auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Close, dialog);
+            KMessageBox::createKMessageBox(dialog, buttonBox, QMessageBox::Warning,
                                            job->errorString(), QStringList(),
-                                           QString(), 0, KMessageBox::NoExec
-            );
+                                           QString(), 0, KMessageBox::NoExec);
             dialog->show();
         }
     }
@@ -684,7 +705,7 @@ void RunController::jobDestroyed(QObject* job)
 {
     KJob* kjob = static_cast<KJob*>(job);
     if (d->jobs.contains(kjob)) {
-        kWarning() << "job destroyed without emitting finished signal!";
+        qWarning() << "job destroyed without emitting finished signal!";
         unregisterJob(kjob);
     }
 }
@@ -788,7 +809,7 @@ void KDevelop::RunController::addLaunchConfiguration(KDevelop::LaunchConfigurati
                 d->currentTargetAction->actions().first()->setChecked( true );
             }
         }
-        connect( l, SIGNAL(nameChanged(LaunchConfiguration*)), SLOT(launchChanged(LaunchConfiguration*)) );
+        connect( l, &LaunchConfiguration::nameChanged, this, &RunController::launchChanged );
     }
 }
 
@@ -796,19 +817,19 @@ void KDevelop::RunController::removeLaunchConfiguration(KDevelop::LaunchConfigur
 {
     KConfigGroup launcherGroup;
     if( l->project() ) {
-        launcherGroup = l->project()->projectConfiguration()->group( LaunchConfigurationsGroup );
+        launcherGroup = l->project()->projectConfiguration()->group( Strings::LaunchConfigurationsGroup() );
     } else {
-        launcherGroup = Core::self()->activeSession()->config()->group( LaunchConfigurationsGroup );
+        launcherGroup = Core::self()->activeSession()->config()->group( Strings::LaunchConfigurationsGroup() );
     }
-    QStringList configs = launcherGroup.readEntry( RunController::LaunchConfigurationsListEntry, QStringList() );
+    QStringList configs = launcherGroup.readEntry( Strings::LaunchConfigurationsListEntry(), QStringList() );
     configs.removeAll( l->configGroupName() );
     launcherGroup.deleteGroup( l->configGroupName() );
-    launcherGroup.writeEntry( RunController::LaunchConfigurationsListEntry, configs );
+    launcherGroup.writeEntry( Strings::LaunchConfigurationsListEntry(), configs );
     launcherGroup.sync();
 
     foreach( QAction* a, d->currentTargetAction->actions() )
     {
-        if( static_cast<LaunchConfiguration*>( qVariantValue<void*>( a->data() ) ) == l )
+        if( static_cast<LaunchConfiguration*>( a->data().value<void*>() ) == l )
         {
             bool wasSelected = a->isChecked();
             d->currentTargetAction->removeAction( a );
@@ -827,19 +848,20 @@ void KDevelop::RunController::removeLaunchConfiguration(KDevelop::LaunchConfigur
 
 void KDevelop::RunController::executeDefaultLaunch(const QString& runMode)
 {
-    if( !defaultLaunch() )
+    auto dl = defaultLaunch();
+    if( !dl )
     {
-        kWarning() << "no default launch!";
+        qWarning() << "no default launch!";
         return;
     }
-    execute( runMode, defaultLaunch() );
+    execute( runMode, dl );
 }
 
 void RunController::setDefaultLaunch(ILaunchConfiguration* l)
 {
     foreach( QAction* a, d->currentTargetAction->actions() )
     {
-        if( static_cast<ILaunchConfiguration*>( qVariantValue<void*>( a->data() ) ) == l )
+        if( static_cast<ILaunchConfiguration*>( a->data().value<void*>() ) == l )
         {
             a->setChecked(true);
             break;
@@ -860,7 +882,7 @@ QString makeUnique(const QString& name)
 {
     if(launcherNameExists(name)) {
         for(int i=2; ; i++) {
-            QString proposed = QString("%1 (%2)").arg(name).arg(i);
+            QString proposed = QStringLiteral("%1 (%2)").arg(name).arg(i);
             if(!launcherNameExists(proposed)) {
                 return proposed;
             }
@@ -876,21 +898,21 @@ ILaunchConfiguration* RunController::createLaunchConfiguration ( LaunchConfigura
     KConfigGroup launchGroup;
     if( project )
     {
-        launchGroup = project->projectConfiguration()->group( RunController::LaunchConfigurationsGroup );
+        launchGroup = project->projectConfiguration()->group( Strings::LaunchConfigurationsGroup() );
 
     } else
     {
-        launchGroup = Core::self()->activeSession()->config()->group( RunController::LaunchConfigurationsGroup );
+        launchGroup = Core::self()->activeSession()->config()->group( Strings::LaunchConfigurationsGroup() );
 
     }
-    QStringList configs = launchGroup.readEntry( RunController::LaunchConfigurationsListEntry, QStringList() );
+    QStringList configs = launchGroup.readEntry( Strings::LaunchConfigurationsListEntry(), QStringList() );
     uint num = 0;
     QString baseName = "Launch Configuration";
-    while( configs.contains( QString( "%1 %2" ).arg( baseName ).arg( num ) ) )
+    while( configs.contains( QStringLiteral( "%1 %2" ).arg( baseName ).arg( num ) ) )
     {
         num++;
     }
-    QString groupName = QString( "%1 %2" ).arg( baseName ).arg( num );
+    QString groupName = QStringLiteral( "%1 %2" ).arg( baseName ).arg( num );
     KConfigGroup launchConfigGroup = launchGroup.group( groupName );
     QString cfgName = name;
     if( name.isEmpty() )
@@ -898,12 +920,12 @@ ILaunchConfiguration* RunController::createLaunchConfiguration ( LaunchConfigura
         cfgName = i18n("New %1 Launcher", type->name() );
         cfgName = makeUnique(cfgName);
     }
-    
-    launchConfigGroup.writeEntry(LaunchConfiguration::LaunchConfigurationNameEntry, cfgName );
-    launchConfigGroup.writeEntry(LaunchConfiguration::LaunchConfigurationTypeEntry, type->id() );
+
+    launchConfigGroup.writeEntry(LaunchConfiguration::LaunchConfigurationNameEntry(), cfgName );
+    launchConfigGroup.writeEntry(LaunchConfiguration::LaunchConfigurationTypeEntry(), type->id() );
     launchConfigGroup.sync();
     configs << groupName;
-    launchGroup.writeEntry( RunController::LaunchConfigurationsListEntry, configs );
+    launchGroup.writeEntry( Strings::LaunchConfigurationsListEntry(), configs );
     launchGroup.sync();
     LaunchConfiguration* l = new LaunchConfiguration( launchConfigGroup, project );
     l->setLauncherForMode( launcher.first, launcher.second );
@@ -920,7 +942,7 @@ ContextMenuExtension RunController::contextMenuExtension ( Context* ctx )
 {
     delete d->launchAsMapper;
     d->launchAsMapper = new QSignalMapper( this );
-    connect( d->launchAsMapper, SIGNAL(mapped(int)), SLOT(launchAs(int)) );
+    connect( d->launchAsMapper, static_cast<void(QSignalMapper::*)(int)>(&QSignalMapper::mapped), this, [&] (int id) { d->launchAs(id); } );
     d->launchAsInfo.clear();
     d->contextItem = 0;
     ContextMenuExtension ext;
@@ -946,11 +968,11 @@ ContextMenuExtension RunController::contextMenuExtension ( Context* ctx )
                     if( hasLauncher && type->canLaunch(itm) )
                     {
                         d->launchAsInfo[i] = qMakePair( type->id(), mode->id() );
-                        KAction* act = new KAction( d->launchAsMapper );
+                        QAction* act = new QAction( d->launchAsMapper );
                         act->setText( type->name() );
-                        kDebug() << "Setting up mapping for:" << i << "for action" << act->text() << "in mode" << mode->name();
+                        qCDebug(SHELL) << "Setting up mapping for:" << i << "for action" << act->text() << "in mode" << mode->name();
                         d->launchAsMapper->setMapping( act, i );
-                        connect( act, SIGNAL(triggered()), d->launchAsMapper, SLOT(map()) );
+                        connect( act, &QAction::triggered, d->launchAsMapper, static_cast<void(QSignalMapper::*)()>(&QSignalMapper::map) );
                         menu->addAction(act);
                         i++;
                     }
@@ -996,4 +1018,4 @@ void RunDelegate::paint( QPainter* painter, const QStyleOptionViewItem& option,
 }
 
 
-#include "runcontroller.moc"
+#include "moc_runcontroller.cpp"
