@@ -20,20 +20,30 @@ Boston, MA 02110-1301, USA.
 
 #include "sessioncontroller.h"
 
-#include <QtCore/QHash>
 #include <QtCore/QDir>
+#include <QtCore/QHash>
 #include <QtCore/QStringList>
 #include <QtCore/QTimer>
+#include <QAction>
+#include <QApplication>
+#include <QDBusConnectionInterface>
+#include <QGroupBox>
+#include <QLabel>
+#include <QLineEdit>
+#include <QListView>
+#include <QSortFilterProxyModel>
+#include <QStandardItemModel>
+#include <QPushButton>
+#include <QVBoxLayout>
 
-#include <kglobal.h>
-#include <kcmdlineargs.h>
-#include <kconfiggroup.h>
-#include <kstandarddirs.h>
-#include <klocale.h>
-#include <kio/netaccess.h>
-#include <kparts/mainwindow.h>
-#include <kactioncollection.h>
-#include <kpushbutton.h>
+#include <KActionCollection>
+#include <KConfigGroup>
+#include <KIO/CopyJob>
+#include <KJobWidgets>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KProcess>
+#include <KStringHandler>
 
 #include "session.h"
 #include "core.h"
@@ -42,37 +52,14 @@ Boston, MA 02110-1301, USA.
 #include "shellextension.h"
 #include "sessionlock.h"
 #include "sessionchooserdialog.h"
+#include "debug.h"
 #include <interfaces/iprojectcontroller.h>
-#include <util/fileutils.h>
-#include <qapplication.h>
-#include <kprocess.h>
 #include <sublime/mainwindow.h>
-#include <KApplication>
-#include <QLineEdit>
-#include <KMessageBox>
-#include <KAboutData>
-#include <KLineEdit>
-#include <KStringHandler>
-#include <QGroupBox>
-#include <QBoxLayout>
-#include <QStandardItemModel>
-#include <QListView>
-#include <QHeaderView>
 #include <interfaces/idocumentcontroller.h>
-#include <language/duchain/repositories/itemrepositoryregistry.h>
+#include <serialization/itemrepositoryregistry.h>
 #include <ktexteditor/document.h>
-#include <QLabel>
-#include <QSortFilterProxyModel>
-#include <QDBusConnectionInterface>
 
 
-#include <kdeversion.h>
-
-#if KDE_IS_VERSION(4,5,60)
-    #define HAVE_RECOVERY_INTERFACE
-    #include <ktexteditor/recoveryinterface.h>
-#endif
-
 const int recoveryStorageInterval = 10; ///@todo Make this configurable
 
 namespace KDevelop
@@ -80,7 +67,7 @@ namespace KDevelop
 
 namespace {
     int argc = 0;
-    char** argv = 0; 
+    char** argv = 0;
 };
 
 void SessionController::setArguments(int _argc, char** _argv)
@@ -95,11 +82,6 @@ static QStringList standardArguments()
     for(int a = 0; a < argc; ++a)
     {
         QString arg = QString::fromLocal8Bit(argv[a]);
-        kWarning() << "ARG:" << "" + arg + "";
-/*        if(arg.startsWith("--graphicssystem=") || arg.startsWith("--style="))
-        {
-            ret << arg;
-        }else */
         if(arg.startsWith("-graphicssystem") || arg.startsWith("-style"))
         {
             ret << '-' + arg;
@@ -107,9 +89,6 @@ static QStringList standardArguments()
                 ret << QString::fromLocal8Bit(argv[a+1]);
         }
     }
-    
-    kWarning() << "ARGUMENTS: " << ret << "from" << argc;
-    
     return ret;
 }
 
@@ -124,11 +103,11 @@ public:
         , recoveryDirectoryIsOwn(false)
     {
         recoveryTimer.setInterval(recoveryStorageInterval * 1000);
-        connect(&recoveryTimer, SIGNAL(timeout()), SLOT(recoveryStorageTimeout()));
-        
+        connect(&recoveryTimer, &QTimer::timeout, this, &SessionControllerPrivate::recoveryStorageTimeout);
+
         // Try the recovery only after the initialization has finished
-        connect(ICore::self(), SIGNAL(initializationCompleted()), SLOT(lateInitialization()), Qt::QueuedConnection);
-        
+        connect(ICore::self(), &ICore::initializationCompleted, this, &SessionControllerPrivate::lateInitialization, Qt::QueuedConnection);
+
         recoveryTimer.setSingleShot(false);
         recoveryTimer.start();
     }
@@ -150,11 +129,11 @@ public:
         }
         return 0;
     }
-    
+
     Session* findSessionForId(QString idString)
     {
         QUuid id(idString);
-        
+
         foreach( Session* s, sessionActions.keys() )
         {
             if( s->id() == id)
@@ -162,21 +141,21 @@ public:
         }
         return 0;
     }
-    
+
     void newSession()
     {
         qsrand(QDateTime::currentDateTime().toTime_t());
-        Session* session = new Session( QUuid::createUuid() );
-        
+        Session* session = new Session( QUuid::createUuid().toString() );
+
         KProcess::startDetached(ShellExtension::getInstance()->binaryPath(), QStringList() << "-s" << session->id().toString() << standardArguments());
         delete session;
-#if 0        
+#if 0
         //Terminate this instance of kdevelop if the user agrees
         foreach(Sublime::MainWindow* window, Core::self()->uiController()->controller()->mainWindows())
             window->close();
 #endif
     }
-    
+
     void configureSessions()
     {
         SessionDialog dlg(ICore::self()->uiController()-> activeMainWindow());
@@ -186,7 +165,7 @@ public:
     void deleteCurrentSession()
     {
         int choice = KMessageBox::warningContinueCancel(Core::self()->uiController()->activeMainWindow(), i18n("The current session and all contained settings will be deleted. The projects will stay unaffected. Do you really want to continue?"));
-        
+
         if(choice == KMessageBox::Continue)
         {
             q->deleteSessionFromDisk(sessionLock);
@@ -196,20 +175,29 @@ public:
 
     void renameSession()
     {
-        KDialog dialog;
+        QDialog dialog;
         dialog.setWindowTitle(i18n("Rename Session"));
+
+        auto mainLayout = new QVBoxLayout(&dialog);
+
         QGroupBox box;
         QHBoxLayout layout(&box);
-        
         box.setTitle(i18n("New Session Name"));
         QLineEdit edit;
         layout.addWidget(&edit);
-        dialog.setButtons(KDialog::Ok | KDialog::Cancel);
+        mainLayout->addWidget(&box);
+
+        auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
+        auto okButton = buttonBox->button(QDialogButtonBox::Ok);
+        okButton->setDefault(true);
+        okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+        connect(buttonBox, &QDialogButtonBox::accepted, &dialog, &QDialog::accept);
+        connect(buttonBox, &QDialogButtonBox::rejected, &dialog, &QDialog::reject);
+        mainLayout->addWidget(buttonBox);
+
         edit.setText(q->activeSession()->name());
-        dialog.setMainWidget(&box);
-        
         edit.setFocus();
-        
+
         if(dialog.exec() == QDialog::Accepted)
         {
             static_cast<Session*>(q->activeSession())->setName(edit.text());
@@ -222,7 +210,7 @@ public:
         KProcess::startDetached(ShellExtension::getInstance()->binaryPath(), QStringList() << "-s" << s->id().toString() << standardArguments());
         return true;
     }
-    
+
     TryLockSessionResult activateSession( Session* s )
     {
         Q_ASSERT( s );
@@ -236,7 +224,7 @@ public:
         Q_ASSERT(s->id().toString() == result.lock->id());
         sessionLock = result.lock;
 
-        KConfigGroup grp = KGlobal::config()->group( SessionController::cfgSessionGroup() );
+        KConfigGroup grp = KSharedConfig::openConfig()->group( SessionController::cfgSessionGroup() );
         grp.writeEntry( SessionController::cfgActiveSessionEntry(), s->id().toString() );
         grp.sync();
         if (Core::self()->setupFlags() & Core::NoUi) return result;
@@ -252,11 +240,6 @@ public:
                 (*it)->setCheckable(false);
         }
 
-        connect(Core::self()->projectController(), SIGNAL(projectClosed(KDevelop::IProject*)),
-                activeSession, SLOT(updateContainedProjects()));
-        connect(Core::self()->projectController(), SIGNAL(projectOpened(KDevelop::IProject*)),
-                activeSession, SLOT(updateContainedProjects()));
-
         return result;
     }
 
@@ -278,15 +261,18 @@ public:
             return;
         }
 
-        KAction* a = new KAction( grp );
+        QAction* a = new QAction( grp );
         a->setText( s->description() );
         a->setCheckable( false );
         a->setData( s->id().toString() );
+
         sessionActions[s] = a;
         q->actionCollection()->addAction( "session_"+s->id().toString(), a );
         q->unplugActionList( "available_sessions" );
         q->plugActionList( "available_sessions", grp->actions() );
-        connect(s, SIGNAL(nameChanged(QString,QString)), SLOT(nameChanged()));
+
+        connect( s, &Session::sessionUpdated, this, &SessionControllerPrivate::sessionUpdated );
+        sessionUpdated( s );
     }
 
     SessionController* q;
@@ -294,18 +280,19 @@ public:
     QHash<Session*, QAction*> sessionActions;
     ISession* activeSession;
     QActionGroup* grp;
-    
+
     ISessionLock::Ptr sessionLock;
-    
+
     // Whether this process owns the recovery directory
     bool recoveryDirectoryIsOwn;
-    
+
     QTimer recoveryTimer;
-    QMap<KUrl, QStringList > currentRecoveryFiles;
+    QMap<QUrl, QStringList > currentRecoveryFiles;
 
     static QString sessionBaseDirectory()
     {
-        return KGlobal::mainComponent().dirs()->saveLocation( "data", KGlobal::mainComponent().componentName() + "/sessions/", true );
+        return QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation)
+            +'/'+ qApp->applicationName() + "/sessions/";
     }
 
     QString ownSessionDirectory() const
@@ -316,7 +303,7 @@ public:
 
     void clearRecoveryDirectory()
     {
-        removeDirectory(ownSessionDirectory() + "/recovery");
+        QDir(ownSessionDirectory() + "/recovery").removeRecursively();
     }
 
 public slots:
@@ -324,64 +311,64 @@ public slots:
     {
         if(currentRecoveryFiles.contains(document->url()))
         {
-            kDebug() << "deleting recovery-info for" << document->url();
+            qCDebug(SHELL) << "deleting recovery-info for" << document->url();
             foreach(const QString& recoveryFileName, currentRecoveryFiles[document->url()])
             {
                 bool result = QFile::remove(recoveryFileName);
-                kDebug() << "deleted" << recoveryFileName << result;
+                qCDebug(SHELL) << "deleted" << recoveryFileName << result;
             }
             currentRecoveryFiles.remove(document->url());
         }
     }
-    
+
 private slots:
     void lateInitialization()
     {
         performRecovery();
-        connect(Core::self()->documentController(), SIGNAL(documentSaved(KDevelop::IDocument*)), SLOT(documentSavedOrClosed(KDevelop::IDocument*)));
-        connect(Core::self()->documentController(), SIGNAL(documentClosed(KDevelop::IDocument*)), SLOT(documentSavedOrClosed(KDevelop::IDocument*)));
+        connect(Core::self()->documentController(), &IDocumentController::documentSaved, this, &SessionControllerPrivate::documentSavedOrClosed);
+        connect(Core::self()->documentController(), &IDocumentController::documentClosed, this, &SessionControllerPrivate::documentSavedOrClosed);
     }
 
     void performRecovery()
     {
-        kDebug() << "Checking recovery";
+        qCDebug(SHELL) << "Checking recovery";
         QDir recoveryDir(ownSessionDirectory() + "/recovery");
-        
+
         if(recoveryDir.exists())
         {
-            kDebug() << "Have recovery directory, starting recovery";
+            qCDebug(SHELL) << "Have recovery directory, starting recovery";
             QFile dateFile(recoveryDir.path() + "/date");
             dateFile.open(QIODevice::ReadOnly);
             QString date = QString::fromUtf8(dateFile.readAll());
-            
+
             QDir recoverySubDir(recoveryDir.path() + "/current");
-            
+
             if(!recoverySubDir.exists())
                 recoverySubDir = QDir(recoveryDir.path() + "/backup");
-            
+
             if(recoverySubDir.exists())
             {
-                kWarning() << "Starting recovery from " << recoverySubDir.absolutePath();
-                
+                qWarning() << "Starting recovery from " << recoverySubDir.absolutePath();
+
                 QStringList urlList;
-                
+
                 for(uint num = 0; ; ++num)
                 {
-                    QFile urlFile(recoverySubDir.path() + QString("/%1_url").arg(num));
+                    QFile urlFile(recoverySubDir.path() + QStringLiteral("/%1_url").arg(num));
                     if(!urlFile.exists())
                         break;
                     urlFile.open(QIODevice::ReadOnly);
-                    KUrl originalFile(QString::fromUtf8(urlFile.readAll()));
-                    urlList << originalFile.pathOrUrl();
+                    QUrl originalFile = QUrl::fromLocalFile(QString::fromUtf8(urlFile.readAll()));
+                    urlList << originalFile.toDisplayString(QUrl::PreferLocalFile);
                 }
-                
+
                 if(!urlList.isEmpty())
                 {
                     //Either recover, or delete the recovery directory
                     ///TODO: user proper runtime locale for date, it might be different
                     ///      from what was used when the recovery file was saved
                     KGuiItem recover = KStandardGuiItem::cont();
-                    recover.setIcon(KIcon("edit-redo"));
+                    recover.setIcon(QIcon::fromTheme("edit-redo"));
                     recover.setText(i18n("Recover"));
                     KGuiItem discard = KStandardGuiItem::discard();
                     int choice = KMessageBox::warningContinueCancelList(qApp->activeWindow(),
@@ -393,71 +380,64 @@ private slots:
                     if(choice == KMessageBox::Continue)
                     {
                         //Recover the files
-                        
+
                         for(uint num = 0; ; ++num)
                         {
-                            QFile urlFile(recoverySubDir.path() + QString("/%1_url").arg(num));
+                            QFile urlFile(recoverySubDir.path() + QStringLiteral("/%1_url").arg(num));
                             if(!urlFile.exists())
                                 break;
                             urlFile.open(QIODevice::ReadOnly);
-                            KUrl originalFile(QString::fromUtf8(urlFile.readAll()));
-                            
-                            QFile f(recoverySubDir.path() + '/' + QString("/%1_text").arg(num));
+                            QUrl originalFile = QUrl::fromLocalFile(QString::fromUtf8(urlFile.readAll()));
+
+                            QFile f(recoverySubDir.path() + '/' + QStringLiteral("/%1_text").arg(num));
                             f.open(QIODevice::ReadOnly);
                             QString text = QString::fromUtf8(f.readAll());
-                            
+
                             if(text.isEmpty())
                             {
-                                KMessageBox::error(ICore::self()->uiController()->activeMainWindow(), i18n("Could not recover %1, the recovery file is empty", originalFile.pathOrUrl()), i18n("Recovery"));
+                                KMessageBox::error(ICore::self()->uiController()->activeMainWindow(), i18n("Could not recover %1, the recovery file is empty", originalFile.toDisplayString(QUrl::PreferLocalFile)), i18n("Recovery"));
                                 continue;
                             }
-                            
-                            kDebug() << "opening" << originalFile << "for recovery";
+
+                            qCDebug(SHELL) << "opening" << originalFile << "for recovery";
                             KDevelop::IDocument* doc = ICore::self()->documentController()->openDocument(originalFile);
                             if(!doc || !doc->textDocument())
                             {
-                                kWarning() << "The document " << originalFile.prettyUrl() << " could not be opened as a text-document, creating a new document with the recovered contents";
+                                qWarning() << "The document " << originalFile << " could not be opened as a text-document, creating a new document with the recovered contents";
                                 doc = ICore::self()->documentController()->openDocumentFromText(text);
                             }else{
-                                #ifdef HAVE_RECOVERY_INTERFACE
-                                KTextEditor::RecoveryInterface* recovery = qobject_cast<KTextEditor::RecoveryInterface*>(doc->textDocument());
-                                
+                                KTextEditor::Document* recovery = doc->textDocument();
+
                                 if(recovery && recovery->isDataRecoveryAvailable())
                                     // Use the recovery from the kate swap-file if possible
                                     recovery->recoverData();
                                 else
                                     // Use a simple recovery through "replace text"
                                     doc->textDocument()->setText(text);
-                                #else
-                                    // Use a simple recovery through "replace text"
-                                    doc->textDocument()->setText(text);
-                                #endif
                             }
                         }
                     }
                 }
             }
         }
-        
+
         recoveryDirectoryIsOwn = true;
     }
-    
-    void nameChanged()
+
+    void sessionUpdated( KDevelop::ISession* s )
     {
-        Q_ASSERT(qobject_cast<Session*>(sender()));
-        Session* s = static_cast<Session*>(sender());
-        sessionActions[s]->setText( KStringHandler::rsqueeze(s->description()) );
+        sessionActions[static_cast<Session*>( s )]->setText( KStringHandler::rsqueeze(s->description()) );
     }
-    
+
     void recoveryStorageTimeout()
     {
         if(!recoveryDirectoryIsOwn)
             return;
-        
+
         currentRecoveryFiles.clear();
-        
+
         QDir recoveryDir(ownSessionDirectory() + "/recovery");
-        
+
         if(!recoveryDir.exists())
         {
             // Try "taking" the recovery directory
@@ -468,23 +448,23 @@ private slots:
 
         if (recoveryDir.exists("backup")) {
             // Clear the old backup recovery directory, as we will create a new one
-            if (!removeDirectory(recoveryDir.absoluteFilePath("backup"))) {
-                kWarning() << "RECOVERY ERROR: Removing the old recovery backup directory failed in " << recoveryDir;
+            if (!QDir(recoveryDir.absoluteFilePath("backup")).removeRecursively()) {
+                qWarning() << "RECOVERY ERROR: Removing the old recovery backup directory failed in " << recoveryDir;
                 return;
             }
         }
-        
+
         //Make the current recovery dir the backup dir, so we always have a recovery available
         //This may fail, because "current" might be nonexistent
         recoveryDir.rename("current", "backup");
 
         {
             recoveryDir.mkdir("current_incomplete");
-            
+
             QDir recoveryCurrentDir(recoveryDir.path() + "/current_incomplete");
 
             uint num = 0;
-            
+
             foreach(KDevelop::IDocument* document, ICore::self()->documentController()->openDocuments())
             {
                 if(document->state() == IDocument::Modified || document->state() == IDocument::DirtyAndModified)
@@ -494,43 +474,43 @@ private slots:
                     {
                         //Currently we can only back-up text documents
                         QString text = document->textDocument()->text();
-                        
+
                         if(!text.isEmpty())
                         {
-                            QString urlFilePath = recoveryCurrentDir.path() + QString("/%1_url").arg(num);
+                            QString urlFilePath = recoveryCurrentDir.path() + QStringLiteral("/%1_url").arg(num);
                             QFile urlFile(urlFilePath);
                             urlFile.open(QIODevice::WriteOnly);
-                            urlFile.write(document->url().pathOrUrl().toUtf8());
+                            urlFile.write(document->url().toString().toUtf8());
                             urlFile.close();
-                            
-                            QString textFilePath = recoveryCurrentDir.path() + '/' + QString("/%1_text").arg(num);
+
+                            QString textFilePath = recoveryCurrentDir.path() + '/' + QStringLiteral("/%1_text").arg(num);
                             QFile f(textFilePath);
                             f.open(QIODevice::WriteOnly);
                             f.write(text.toUtf8());
                             f.close();
-                            
+
                             currentRecoveryFiles[document->url()] =
-                                        QStringList() <<  (recoveryDir.path() + "/current" + QString("/%1_url").arg(num))
-                                                      << (recoveryDir.path() + "/current" + QString("/%1_text").arg(num));
-                            
+                                        QStringList() <<  (recoveryDir.path() + "/current" + QStringLiteral("/%1_url").arg(num))
+                                                      << (recoveryDir.path() + "/current" + QStringLiteral("/%1_text").arg(num));
+
                             if(urlFile.error() != QFile::NoError || f.error() != QFile::NoError)
                             {
-                                kWarning() << "RECOVERY ERROR: Failed to write recovery for" << document->url() << "to" << textFilePath;
+                                qWarning() << "RECOVERY ERROR: Failed to write recovery for" << document->url() << "to" << textFilePath;
                                 KMessageBox::error(ICore::self()->uiController()->activeMainWindow(),
                                                     i18n("Failed to write recovery copies to %1. Please make sure that your home directory is writable and not full. This application requires available space in the home directory to run stable. You may experience application crashes until you free up some space.", recoveryCurrentDir.path()),
                                                     i18n("Recovery Error"));
                                 return;
                             }
-                                                      
+
                             ++num;
                         }
                     }
                 }
             }
         }
-        
+
         recoveryDir.rename("current_incomplete", "current");
-        
+
         {
             //Write down the date of the recovery
             QFile dateFile(recoveryDir.path() + "/date");
@@ -541,20 +521,12 @@ private slots:
 };
 
 
-void SessionController::updateSessionDescriptions()
-{
-    for(QHash< Session*, QAction* >::iterator it = d->sessionActions.begin(); it != d->sessionActions.end(); ++it) {
-        it.key()->updateDescription();
-        if (*it) (*it)->setText(KStringHandler::rsqueeze(it.key()->description()));
-    }
-}
-
 SessionController::SessionController( QObject *parent )
         : QObject( parent ), d(new SessionControllerPrivate(this))
 {
     setObjectName("SessionController");
-    setComponentData(KComponentData("kdevsession"));
-    
+    setComponentName(QStringLiteral("kdevsession"), QStringLiteral("KDevSession"));
+
     setXMLFile("kdevsessionui.rc");
 
     QDBusConnection::sessionBus().registerObject( "/kdevelop/SessionController",
@@ -562,23 +534,23 @@ SessionController::SessionController( QObject *parent )
 
     if (Core::self()->setupFlags() & Core::NoUi) return;
 
-    KAction* action = actionCollection()->addAction( "new_session", this, SLOT(newSession()) );
+    QAction* action = actionCollection()->addAction( "new_session", this, SLOT(newSession()) );
     action->setText( i18nc("@action:inmenu", "Start New Session") );
     action->setToolTip( i18nc("@info:tooltip", "Start a new KDevelop instance with an empty session") );
-    action->setIcon(KIcon("window-new"));
+    action->setIcon(QIcon::fromTheme("window-new"));
 
     action = actionCollection()->addAction( "rename_session", this, SLOT(renameSession()) );
     action->setText( i18n("Rename Current Session...") );
-    action->setIcon(KIcon("edit-rename"));
+    action->setIcon(QIcon::fromTheme("edit-rename"));
 
     action = actionCollection()->addAction( "delete_session", this, SLOT(deleteCurrentSession()) );
     action->setText( i18n("Delete Current Session...") );
-    action->setIcon(KIcon("edit-delete"));
+    action->setIcon(QIcon::fromTheme("edit-delete"));
 
     action = actionCollection()->addAction( "quit", this, SIGNAL(quitSession()) );
     action->setText( i18n("Quit") );
-    action->setShortcut(Qt::CTRL | Qt::Key_Q);
-    action->setIcon(KIcon("application-exit"));
+    actionCollection()->setDefaultShortcut( action, Qt::CTRL | Qt::Key_Q );
+    action->setIcon(QIcon::fromTheme("application-exit"));
 
     #if 0
     action = actionCollection()->addAction( "configure_sessions", this, SLOT(configureSessions()) );
@@ -588,7 +560,7 @@ SessionController::SessionController( QObject *parent )
     #endif
 
     d->grp = new QActionGroup( this );
-    connect( d->grp, SIGNAL(triggered(QAction*)), this, SLOT(loadSessionFromAction(QAction*)) );
+    connect( d->grp, &QActionGroup::triggered, this, [&] (QAction* a) { d->loadSessionFromAction(a); } );
 }
 
 SessionController::~SessionController()
@@ -605,13 +577,15 @@ void SessionController::cleanup()
 {
     d->recoveryTimer.stop();
 
-    Q_ASSERT(d->activeSession->id().toString() == d->sessionLock->id());
+    if (d->activeSession) {
+        Q_ASSERT(d->activeSession->id().toString() == d->sessionLock->id());
 
-    ISession* active = d->activeSession;
-    d->activeSession = 0;
-    if (active->isTemporary()) {
-        deleteSessionFromDisk(d->sessionLock);
+        if (d->activeSession->isTemporary()) {
+            deleteSessionFromDisk(d->sessionLock);
+        }
+        d->activeSession = 0;
     }
+
     d->sessionLock.clear();
     qDeleteAll(d->sessionActions);
     d->sessionActions.clear();
@@ -627,7 +601,7 @@ void SessionController::initialize( const QString& session )
         if( id.isNull() )
             continue;
         // Only create sessions for directories that represent proper uuid's
-        Session* ses = new Session( id, this );
+        Session* ses = new Session( id.toString(), this );
 
         //Delete sessions that have no name and are empty
         if( ses->containedProjects().isEmpty() && ses->name().isEmpty()
@@ -643,10 +617,6 @@ void SessionController::initialize( const QString& session )
         }
     }
     loadDefaultSession( session );
-
-    connect(Core::self()->projectController(), SIGNAL(projectClosed(KDevelop::IProject*)), SLOT(updateSessionDescriptions()));
-    connect(Core::self()->projectController(), SIGNAL(projectOpened(KDevelop::IProject*)), SLOT(updateSessionDescriptions()));
-    updateSessionDescriptions();
 }
 
 
@@ -690,10 +660,10 @@ Session* SessionController::createSession( const QString& name )
     Session* s;
     if(name.startsWith('{'))
     {
-        s = new Session( QUuid(name) );
+        s = new Session( QUuid(name).toString() );
     }else{
         qsrand(QDateTime::currentDateTime().toTime_t());
-        s = new Session( QUuid::createUuid() );
+        s = new Session( QUuid::createUuid().toString() );
         s->setName( name );
     }
     d->addSession( s );
@@ -714,16 +684,21 @@ void SessionController::deleteSession( const ISessionLock::Ptr& lock )
         plugActionList( "available_sessions", d->grp->actions() );
     }
 
+    if (s == d->activeSession) {
+        d->activeSession = nullptr;
+    }
     deleteSessionFromDisk(lock);
 
     emit sessionDeleted( s->id().toString() );
     d->sessionActions.remove(s);
-    s->deleteLater();
+    delete s;
 }
 
 void SessionController::deleteSessionFromDisk( const ISessionLock::Ptr& lock )
 {
-    removeDirectory( sessionDirectory(lock->id()) );
+    qCDebug(SHELL) << "Deleting session:" << lock->id();
+
+    QDir(sessionDirectory(lock->id())).removeRecursively();
     ItemRepositoryRegistry::deleteRepositoryFromDisk( lock );
 }
 
@@ -731,7 +706,7 @@ void SessionController::loadDefaultSession( const QString& session )
 {
     QString load = session;
     if (load.isEmpty()) {
-        KConfigGroup grp = KGlobal::config()->group( cfgSessionGroup() );
+        KConfigGroup grp = KSharedConfig::openConfig()->group( cfgSessionGroup() );
         load = grp.readEntry( cfgActiveSessionEntry(), "default" );
     }
 
@@ -768,10 +743,12 @@ QString SessionController::cloneSession( const QString& nameOrid )
     Session* origSession = session( nameOrid );
     qsrand(QDateTime::currentDateTime().toTime_t());
     QUuid id = QUuid::createUuid();
-    KIO::NetAccess::dircopy( sessionDirectory( origSession->id().toString() ),
-                             sessionDirectory( id.toString() ),
-                             Core::self()->uiController()->activeMainWindow() );
-    Session* newSession = new Session( id );
+    auto copyJob = KIO::copy(QUrl::fromLocalFile(sessionDirectory(origSession->id().toString())),
+                             QUrl::fromLocalFile(sessionDirectory( id.toString())));
+    KJobWidgets::setWindow(copyJob, Core::self()->uiController()->activeMainWindow());
+    copyJob->exec();
+
+    Session* newSession = new Session( id.toString() );
     newSession->setName( i18n( "Copy of %1", origSession->name() ) );
     d->addSession(newSession);
     return newSession->name();
@@ -820,14 +797,11 @@ SessionRunInfo SessionController::sessionRunInfo(const QString& id)
 
 QString SessionController::showSessionChooserDialog(QString headerText, bool onlyRunning)
 {
-    // The catalog hasn't been loaded yet
-    KGlobal::locale()->insertCatalog("kdevplatform");
-
     ///FIXME: move this code into sessiondialog.cpp
     QListView* view = new QListView;
-    KLineEdit* filter = new KLineEdit;
-    filter->setClearButtonShown( true );
-    filter->setClickMessage(i18n("Search"));
+    QLineEdit* filter = new QLineEdit;
+    filter->setClearButtonEnabled( true );
+    filter->setPlaceholderText(i18n("Search"));
 
     QStandardItemModel* model = new QStandardItemModel(view);
 
@@ -835,7 +809,7 @@ QString SessionController::showSessionChooserDialog(QString headerText, bool onl
     proxy->setSourceModel(model);
     proxy->setFilterKeyColumn( 1 );
     proxy->setFilterCaseSensitivity( Qt::CaseInsensitive );
-    connect(filter, SIGNAL(textChanged(QString)), proxy, SLOT(setFilterFixedString(QString)));
+    connect(filter, &QLineEdit::textChanged, proxy, &QSortFilterProxyModel::setFilterFixedString);
 
     SessionChooserDialog dialog(view, proxy, filter);
     view->setEditTriggers(QAbstractItemView::NoEditTriggers);
@@ -865,10 +839,8 @@ QString SessionController::showSessionChooserDialog(QString headerText, bool onl
     filter->setFocus();
 
     int row = 0;
-    int defaultRow = 0;
-
-    QString defaultSession = KGlobal::config()->group( cfgSessionGroup() ).readEntry( cfgActiveSessionEntry(), "default" );
 
+    QString defaultSession = KSharedConfig::openConfig()->group( cfgSessionGroup() ).readEntry( cfgActiveSessionEntry(), "default" );
 
     foreach(const KDevelop::SessionInfo& si, KDevelop::SessionController::availableSessionInfo())
     {
@@ -881,33 +853,27 @@ QString SessionController::showSessionChooserDialog(QString headerText, bool onl
         if(onlyRunning && !running)
             continue;
 
-        if(si.uuid.toString() == defaultSession)
-            defaultRow = row;
-
         model->setItem(row, 0, new QStandardItem(si.uuid.toString()));
         model->setItem(row, 1, new QStandardItem(si.description));
         model->setItem(row, 2, new QStandardItem);
 
-        if(defaultRow == row && running)
-            ++defaultRow;
-
         ++row;
     }
     model->sort(1);
 
-    int cnsRow = row;
     if(!onlyRunning) {
         model->setItem(row, 0, new QStandardItem);
-        model->setItem(row, 1, new QStandardItem(KIcon("window-new"), i18n("Create New Session")));
+        model->setItem(row, 1, new QStandardItem(QIcon::fromTheme("window-new"), i18n("Create New Session")));
     }
 
     dialog.updateState();
     dialog.mainWidget()->layout()->setContentsMargins(0,0,0,0);
 
-    view->selectionModel()->setCurrentIndex(proxy->mapFromSource(model->index(defaultRow, 0)), QItemSelectionModel::ClearAndSelect | QItemSelectionModel::Rows);
+    const QModelIndex defaultSessionIndex = model->match(model->index(0, 0), Qt::DisplayRole, defaultSession, 1, Qt::MatchExactly).value(0);
+    view->selectionModel()->setCurrentIndex(proxy->mapFromSource(defaultSessionIndex), QItemSelectionModel::ClearAndSelect | QItemSelectionModel::Rows);
     view->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
     ///@todo We need a way to get a proper size-hint from the view, but unfortunately, that only seems possible after the view was shown.
-    dialog.setInitialSize(QSize(900, 600));
+    dialog.resize(QSize(900, 600));
 
     if(dialog.exec() != QDialog::Accepted)
     {
@@ -915,20 +881,16 @@ QString SessionController::showSessionChooserDialog(QString headerText, bool onl
     }
 
     QModelIndex selected = view->selectionModel()->currentIndex();
-    if(selected.isValid())
-    {
-        QString ret;
-        if( selected.row() == cnsRow ) {
-            qsrand(QDateTime::currentDateTime().toTime_t());
-            ret = QUuid::createUuid().toString();
-        } else {
-            selected = selected.sibling(selected.row(), 0);
-            ret = selected.data().toString();
-        }
-        return ret;
-    }
+    if (!selected.isValid())
+        return QString();
 
-    return QString();
+    const QString selectedSessionId = selected.sibling(selected.row(), 0).data().toString();
+    if (selectedSessionId.isEmpty()) {
+        // "Create New Session" item selected, return a fresh UUID
+        qsrand(QDateTime::currentDateTime().toTime_t());
+        return QUuid::createUuid().toString();
+    }
+    return selectedSessionId;
 }
 
 QString SessionController::handleLockedSession( const QString& sessionName, const QString& sessionId,
