@@ -26,9 +26,9 @@ Boston, MA 02110-1301, USA.
 #include "session.h"
 #include <interfaces/isessionlock.h>
 
-#include <QtCore/QObject>
+#include <QObject>
 
-#include <kxmlguiclient.h>
+#include <KXMLGUIClient>
 
 namespace KDevelop
 {
@@ -51,7 +51,7 @@ struct SessionRunInfo
     // if this is true, this session is currently running in an external process
     bool isRunning;
     // if the session is running, this contains the PID of its process
-    int holderPid;
+    qint64 holderPid;
     // if the session is running, this contains the name of its process
     QString holderApp;
     // if the session is running, this contains the host name where the process runs
@@ -76,7 +76,7 @@ class KDEVPLATFORMSHELL_EXPORT SessionController : public QObject, public KXMLGU
 {
     Q_OBJECT
 public:
-    SessionController( QObject *parent = 0 );
+    explicit SessionController( QObject *parent = 0 );
     virtual ~SessionController();
     void initialize( const QString& session );
     void cleanup();
@@ -106,13 +106,13 @@ public:
     ISessionLock::Ptr activeSessionLock() const;
     QList<QString> sessionNames() const;
     Session* createSession( const QString& name );
-    
+
     QList<const Session*> sessions() const;
-    
+
     void loadDefaultSession( const QString& session );
 
     void startNewSession();
-    
+
     void loadSession( const QString& nameOrId );
     void deleteSession( const ISessionLock::Ptr& lock );
     static void deleteSessionFromDisk( const ISessionLock::Ptr& lock );
@@ -125,10 +125,13 @@ public:
     static QString cfgActiveSessionEntry();
 
     static QList< SessionInfo > availableSessionInfo();
-    
-    /// Shows a dialog where the user can choose the session
-    /// @param headerText an additional text that will be shown at the top in a label
-    /// @param onlyRunning whether only currently running sessions should be shown
+
+    /**
+     * Shows a dialog where the user can choose the session
+     * @param headerText an additional text that will be shown at the top in a label
+     * @param onlyRunning whether only currently running sessions should be shown
+     * @return UUID on success, empty string in any other case
+     */
     static QString showSessionChooserDialog(QString headerText = QString(), bool onlyRunning = false);
 
     /// Should be called if session to be opened is locked.
@@ -144,12 +147,12 @@ public:
     static QString handleLockedSession( const QString& sessionName, const QString& currentSessionId, const SessionRunInfo& runInfo );
 
     void plugActions();
-    
+
     void emitQuitSession()
     {
         emit quitSession();
     }
-    
+
 public Q_SLOTS:
     // Returns the pretty name of the currently active session (used in the shell integration)
     virtual Q_SCRIPTABLE QString sessionName();
@@ -160,8 +163,6 @@ Q_SIGNALS:
     void sessionLoaded( ISession* );
     void sessionDeleted( const QString& id);
     void quitSession();
-private slots:
-    void updateSessionDescriptions();
 private:
     Q_PRIVATE_SLOT( d, void newSession() )
     Q_PRIVATE_SLOT( d, void configureSessions() )
