@@ -22,31 +22,32 @@
 #ifndef KDEVPLATFORM_BGPREFERENCES_H
 #define KDEVPLATFORM_BGPREFERENCES_H
 
-#include <kcmodule.h>
-
-#include <kurl.h>
-#include <kstandarddirs.h>
+#include <interfaces/configpage.h>
 
 namespace Ui
 {
-class BGSettings;
+class BGPreferences;
 }
 
 namespace KDevelop
 {
 
-class BGPreferences : public KCModule
+class BGPreferences : public ConfigPage
 {
     Q_OBJECT
 public:
-    BGPreferences( QWidget *parent, const QVariantList &args );
+    explicit BGPreferences(QWidget* parent);
     virtual ~BGPreferences();
 
-    virtual void save();
-    virtual void load();
+    virtual QString name() const override;
+    virtual QString fullName() const override;
+    virtual QIcon icon() const override;
+
+    virtual void apply() override;
+    virtual void reset() override;
 
 private:
-    Ui::BGSettings *preferencesDialog;
+    Ui::BGPreferences *preferencesDialog;
 
 };
 
