@@ -21,33 +21,34 @@
 #ifndef KDEVPLATFORM_PROJECTPREFERENCES_H
 #define KDEVPLATFORM_PROJECTPREFERENCES_H
 
-#include <kcmodule.h>
-
-#include <kurl.h>
-#include <kstandarddirs.h>
+#include <interfaces/configpage.h>
 
 namespace Ui
 {
-class ProjectSettings;
+class ProjectPreferences;
 }
 
 namespace KDevelop
 {
 
-class ProjectPreferences : public KCModule
+class ProjectPreferences : public ConfigPage
 {
     Q_OBJECT
 public:
-    ProjectPreferences( QWidget *parent, const QVariantList &args );
+    explicit ProjectPreferences(QWidget *parent);
     virtual ~ProjectPreferences();
 
-    virtual void save();
+    virtual QString name() const override;
+    virtual QString fullName() const override;
+    virtual QIcon icon() const override;
+
+    virtual void apply() override;
 
 private slots:
     void slotSettingsChanged();
 
 private:
-    Ui::ProjectSettings *preferencesDialog;
+    Ui::ProjectPreferences *preferencesDialog;
 
 };
 
