@@ -23,70 +23,72 @@ Boston, MA 02110-1301, USA.
 #include <QList>
 #include <QListWidgetItem>
 #include <QInputDialog>
+#include <QMimeDatabase>
+#include <QDebug>
 #include <KMessageBox>
-#include <KIconLoader>
 #include <ktexteditor/document.h>
 #include <ktexteditor/view.h>
 #include <ktexteditor/editor.h>
-#include <ktexteditor/editorchooser.h>
 #include <ktexteditor/configinterface.h>
+#include <KCoreAddons/KAboutData>
+#include <KI18n/KLocalizedString>
+#include <KConfigGroup>
 
 #include <interfaces/iplugin.h>
-#include <interfaces/ilanguage.h>
 #include <interfaces/isourceformatter.h>
+#include <language/interfaces/ilanguagesupport.h>
 #include <shell/core.h>
 #include <shell/plugincontroller.h>
 #include <shell/languagecontroller.h>
 
 #include "editstyledialog.h"
+#include "../debug.h"
 
 #define STYLE_ROLE (Qt::UserRole+1)
 
-K_PLUGIN_FACTORY(SourceFormatterSettingsFactory, registerPlugin<SourceFormatterSettings>();)
-K_EXPORT_PLUGIN(SourceFormatterSettingsFactory("kcm_kdevsourceformattersettings"))
-
 using KDevelop::Core;
 using KDevelop::ISourceFormatter;
 using KDevelop::SourceFormatterStyle;
 using KDevelop::SourceFormatterController;
 using KDevelop::SourceFormatter;
 
-const QString SourceFormatterSettings::userStylePrefix( "User" );
+namespace {
+namespace Strings {
+QString userStylePrefix() { return QStringLiteral("User"); }
+}
+}
 
 LanguageSettings::LanguageSettings()
     : selectedFormatter(0), selectedStyle(0) {
 }
 
-SourceFormatterSettings::SourceFormatterSettings(QWidget *parent, const QVariantList &args)
-    : KCModule(SourceFormatterSettingsFactory::componentData(), parent, args)
+SourceFormatterSettings::SourceFormatterSettings(QWidget* parent)
+    : KDevelop::ConfigPage(nullptr, nullptr, parent)
 {
     setupUi(this);
-    connect( cbLanguages, SIGNAL(currentIndexChanged(int)), SLOT(selectLanguage(int)) );
-    connect( cbFormatters, SIGNAL(currentIndexChanged(int)), SLOT(selectFormatter(int)) );
-    connect( chkKateModelines, SIGNAL(toggled(bool)), SLOT(somethingChanged()) );
-    connect( chkKateOverrideIndentation, SIGNAL(toggled(bool)), SLOT(somethingChanged()) );
-    connect( styleList, SIGNAL(currentRowChanged(int)), SLOT(selectStyle(int)) );
-    connect( btnDelStyle, SIGNAL(clicked()), SLOT(deleteStyle()) );
-    connect( btnNewStyle, SIGNAL(clicked()), SLOT(newStyle()) );
-    connect( btnEditStyle, SIGNAL(clicked()), SLOT(editStyle()) );
-    connect( styleList, SIGNAL(itemChanged(QListWidgetItem*)), SLOT(styleNameChanged(QListWidgetItem*)) );
+    connect( cbLanguages, static_cast<void(KComboBox::*)(int)>(&KComboBox::currentIndexChanged), this, &SourceFormatterSettings::selectLanguage );
+    connect( cbFormatters, static_cast<void(KComboBox::*)(int)>(&KComboBox::currentIndexChanged), this, &SourceFormatterSettings::selectFormatter );
+    connect( chkKateModelines, &QCheckBox::toggled, this, &SourceFormatterSettings::somethingChanged );
+    connect( chkKateOverrideIndentation, &QCheckBox::toggled, this, &SourceFormatterSettings::somethingChanged );
+    connect( styleList, &QListWidget::currentRowChanged, this, &SourceFormatterSettings::selectStyle );
+    connect( btnDelStyle, &QPushButton::clicked, this, &SourceFormatterSettings::deleteStyle );
+    connect( btnNewStyle, &QPushButton::clicked, this, &SourceFormatterSettings::newStyle );
+    connect( btnEditStyle, &QPushButton::clicked, this, &SourceFormatterSettings::editStyle );
+    connect( styleList, &QListWidget::itemChanged, this, &SourceFormatterSettings::styleNameChanged );
 
-    KTextEditor::Editor *editor = KTextEditor::EditorChooser::editor();
-    if (!editor)
-        KMessageBox::error(this, i18n("A KDE text-editor component could not be found.\n"
-        "Please check your KDE installation."));
-
-    m_document = editor->createDocument(this);
+    m_document = KTextEditor::Editor::instance()->createDocument(this);
     m_document->setReadWrite(false);
 
-    KTextEditor::View* view = qobject_cast<KTextEditor::View*>(m_document->createView(textEditor));
+    m_view = m_document->createView(textEditor);
+    m_view->setStatusBarEnabled(false);
+
     QVBoxLayout *layout2 = new QVBoxLayout(textEditor);
-    layout2->addWidget(view);
+    layout2->addWidget(m_view);
     textEditor->setLayout(layout2);
-    view->show();
+    m_view->show();
 
     KTextEditor::ConfigInterface *iface =
-    qobject_cast<KTextEditor::ConfigInterface*>(view);
+    qobject_cast<KTextEditor::ConfigInterface*>(m_view);
     if (iface) {
         iface->setConfigValue("dynamic-word-wrap", false);
         iface->setConfigValue("icon-bar", false);
@@ -103,13 +105,13 @@ void selectAvailableStyle(LanguageSettings& lang) {
     lang.selectedStyle = *lang.selectedFormatter->styles.begin();
 }
 
-void SourceFormatterSettings::load()
+void SourceFormatterSettings::reset()
 {
     SourceFormatterController* fmtctrl = Core::self()->sourceFormatterControllerInternal();
     foreach( KDevelop::IPlugin* plugin, KDevelop::ICore::self()->pluginController()->allPluginsForExtension( "org.kdevelop.ISourceFormatter" ) )
     {
         KDevelop::ISourceFormatter* ifmt = plugin->extension<ISourceFormatter>();
-        KPluginInfo info = KDevelop::Core::self()->pluginControllerInternal()->pluginInfo( plugin );
+        auto info = KDevelop::Core::self()->pluginControllerInternal()->pluginInfo( plugin );
         KDevelop::SourceFormatter* formatter;
         FormatterMap::const_iterator iter = formatters.constFind(ifmt->name());
         if (iter == formatters.constEnd()) {
@@ -120,25 +122,25 @@ void SourceFormatterSettings::load()
         }
         for( const SourceFormatterStyle* style: formatter->styles ) {
             for ( const SourceFormatterStyle::MimeHighlightPair& item: style->mimeTypes() ) {
-                KMimeType::Ptr mimePtr = KMimeType::mimeType(item.mimeType);
-                if (!mimePtr) {
-                    kWarning() << "plugin" << info.name() << "supports unknown mimetype entry" << item.mimeType;
+                QMimeType mime = QMimeDatabase().mimeTypeForName(item.mimeType);
+                if (!mime.isValid()) {
+                    qWarning() << "plugin" << info.name() << "supports unknown mimetype entry" << item.mimeType;
                     continue;
                 }
                 QString languageName = item.highlightMode;
                 LanguageSettings& l = languages[languageName];
-                l.mimetypes.append( mimePtr );
+                l.mimetypes.append(mime);
                 l.formatters.insert( formatter );
             }
         }
     }
-    
+
     // Sort the languages, preferring firstly active, then loaded languages
     QList<QString> sortedLanguages;
-    
-    foreach( KDevelop::ILanguage* language, 
+
+    foreach(const auto& language,
                 KDevelop::ICore::self()->languageController()->activeLanguages() +
-                KDevelop::ICore::self()->languageController()->loadedLanguages() )
+                KDevelop::ICore::self()->languageController()->loadedLanguages())
     {
         if( languages.contains( language->name() ) && !sortedLanguages.contains(language->name()) ) {
             sortedLanguages.push_back( language->name() );
@@ -148,17 +150,17 @@ void SourceFormatterSettings::load()
     foreach( const QString& name, languages.keys() )
         if( !sortedLanguages.contains( name ) )
             sortedLanguages.push_back( name );
-        
+
     foreach( const QString& name, sortedLanguages )
     {
         // Pick the first appropriate mimetype for this language
-        KConfigGroup grp = fmtctrl->configuration();
+        KConfigGroup grp = fmtctrl->sessionConfig();
         LanguageSettings& l = languages[name];
-        foreach (const KMimeType::Ptr& mimetype, l.mimetypes) {
-            QStringList formatterAndStyleName = grp.readEntry( mimetype->name(), "" ).split( "||", QString::KeepEmptyParts );
+        foreach (const QMimeType& mimetype, l.mimetypes) {
+            QStringList formatterAndStyleName = grp.readEntry(mimetype.name(), QString()).split("||", QString::KeepEmptyParts);
             FormatterMap::const_iterator formatterIter = formatters.constFind(formatterAndStyleName.first());
             if (formatterIter == formatters.constEnd()) {
-                kDebug() << "Reference to unknown formatter" << formatterAndStyleName.first();
+                qCDebug(SHELL) << "Reference to unknown formatter" << formatterAndStyleName.first();
                 Q_ASSERT(!l.formatters.empty());        // otherwise there should be no entry for 'name'
                 l.selectedFormatter = *l.formatters.begin();
                 selectAvailableStyle(l);
@@ -166,7 +168,7 @@ void SourceFormatterSettings::load()
                 l.selectedFormatter = formatterIter.value();
                 SourceFormatter::StyleMap::const_iterator styleIter = l.selectedFormatter->styles.constFind(formatterAndStyleName.at( 1 ));
                 if (styleIter == l.selectedFormatter->styles.constEnd()) {
-                    kDebug() << "No style" << formatterAndStyleName.at( 1 ) << "found for formatter" << formatterAndStyleName.first();
+                    qCDebug(SHELL) << "No style" << formatterAndStyleName.at( 1 ) << "found for formatter" << formatterAndStyleName.first();
                     selectAvailableStyle(l);
                 } else {
                     l.selectedStyle = styleIter.value();
@@ -191,8 +193,8 @@ void SourceFormatterSettings::load()
     cbLanguages->clear();
     cbFormatters->clear();
     styleList->clear();
-    chkKateModelines->setChecked( fmtctrl->configuration().readEntry( SourceFormatterController::kateModeLineConfigKey, false ) );
-    chkKateOverrideIndentation->setChecked( fmtctrl->configuration().readEntry( SourceFormatterController::kateOverrideIndentationConfigKey, false ) );
+    chkKateModelines->setChecked( fmtctrl->sessionConfig().readEntry( SourceFormatterController::kateModeLineConfigKey(), false ) );
+    chkKateOverrideIndentation->setChecked( fmtctrl->sessionConfig().readEntry( SourceFormatterController::kateOverrideIndentationConfigKey(), false ) );
     foreach( const QString& name, sortedLanguages )
     {
         cbLanguages->addItem( name );
@@ -215,50 +217,59 @@ void SourceFormatterSettings::load()
     chkKateOverrideIndentation->blockSignals( b );
 }
 
-void SourceFormatterSettings::save()
+void SourceFormatterSettings::apply()
 {
-    KConfigGroup grp = Core::self()->sourceFormatterControllerInternal()->configuration();
+    KConfigGroup globalConfig = Core::self()->sourceFormatterControllerInternal()->globalConfig();
 
-    for ( LanguageMap::const_iterator iter = languages.constBegin(); iter != languages.constEnd(); ++iter ) {
-        foreach( const KMimeType::Ptr& mime, iter.value().mimetypes ) {
-            grp.writeEntry( mime->name(), QString("%1||%2").arg(iter.value().selectedFormatter->formatter->name()).arg( iter.value().selectedStyle->name() ) );
-        }
-    }
     foreach( SourceFormatter* fmt, formatters )
     {
-        KConfigGroup fmtgrp = grp.group( fmt->formatter->name() );
+        KConfigGroup fmtgrp = globalConfig.group( fmt->formatter->name() );
 
         // delete all styles so we don't leave any behind when all user styles are deleted
         foreach( const QString& subgrp, fmtgrp.groupList() )
         {
-            if( subgrp.startsWith( userStylePrefix ) ) {
+            if( subgrp.startsWith( Strings::userStylePrefix() ) ) {
                 fmtgrp.deleteGroup( subgrp );
             }
         }
         foreach( const SourceFormatterStyle* style, fmt->styles )
         {
-            if( style->name().startsWith( userStylePrefix ) )
+            if( style->name().startsWith( Strings::userStylePrefix() ) )
             {
                 KConfigGroup stylegrp = fmtgrp.group( style->name() );
-                stylegrp.writeEntry( SourceFormatterController::styleCaptionKey, style->caption() );
-                stylegrp.writeEntry( SourceFormatterController::styleContentKey, style->content() );
-                stylegrp.writeEntry( SourceFormatterController::styleMimeTypesKey, style->mimeTypesVariant() );
-                stylegrp.writeEntry( SourceFormatterController::styleSampleKey, style->overrideSample() );
+                stylegrp.writeEntry( SourceFormatterController::styleCaptionKey(), style->caption() );
+                stylegrp.writeEntry( SourceFormatterController::styleContentKey(), style->content() );
+                stylegrp.writeEntry( SourceFormatterController::styleMimeTypesKey(), style->mimeTypesVariant() );
+                stylegrp.writeEntry( SourceFormatterController::styleSampleKey(), style->overrideSample() );
             }
         }
     }
-    grp.writeEntry( SourceFormatterController::kateModeLineConfigKey, chkKateModelines->isChecked() );
-    grp.writeEntry( SourceFormatterController::kateOverrideIndentationConfigKey, chkKateOverrideIndentation->isChecked() );
-    
-    grp.sync();
-    
+
+    KConfigGroup sessionConfig = Core::self()->sourceFormatterControllerInternal()->sessionConfig();
+    for ( LanguageMap::const_iterator iter = languages.constBegin(); iter != languages.constEnd(); ++iter ) {
+        foreach(const QMimeType& mime, iter.value().mimetypes) {
+            sessionConfig.writeEntry(mime.name(), QStringLiteral("%1||%2").arg(iter.value().selectedFormatter->formatter->name()).arg(iter.value().selectedStyle->name()));
+        }
+    }
+    sessionConfig.writeEntry( SourceFormatterController::kateModeLineConfigKey(), chkKateModelines->isChecked() );
+    sessionConfig.writeEntry( SourceFormatterController::kateOverrideIndentationConfigKey(), chkKateOverrideIndentation->isChecked() );
+
+    sessionConfig.sync();
+    globalConfig.sync();
+
     Core::self()->sourceFormatterControllerInternal()->settingsChanged();
 }
 
+void SourceFormatterSettings::defaults()
+{
+    // do nothing
+}
+
+
 void SourceFormatterSettings::enableStyleButtons()
 {
     bool userEntry = styleList->currentItem()
-                     && styleList->currentItem()->data( STYLE_ROLE ).toString().startsWith( userStylePrefix );
+                     && styleList->currentItem()->data( STYLE_ROLE ).toString().startsWith( Strings::userStylePrefix() );
 
     QString languageName = cbLanguages->currentText();
     QMap< QString, LanguageSettings >::const_iterator it = languages.constFind(languageName);
@@ -293,7 +304,7 @@ void SourceFormatterSettings::selectLanguage( int idx )
     cbFormatters->setCurrentIndex(cbFormatters->findData(l.selectedFormatter->formatter->name()));
     cbFormatters->blockSignals(b);
     selectFormatter( cbFormatters->currentIndex() );
-    emit changed( true );
+    emit changed();
 }
 
 void SourceFormatterSettings::selectFormatter( int idx )
@@ -329,7 +340,7 @@ void SourceFormatterSettings::selectFormatter( int idx )
         styleList->setCurrentRow(0);
     }
     enableStyleButtons();
-    emit changed( true );
+    emit changed();
 }
 
 void SourceFormatterSettings::selectStyle( int row )
@@ -344,7 +355,7 @@ void SourceFormatterSettings::selectStyle( int row )
     l.selectedStyle = l.selectedFormatter->styles[styleList->item( row )->data( STYLE_ROLE ).toString()];
     enableStyleButtons();
     updatePreview();
-    emit changed( true );
+    emit changed();
 }
 
 void SourceFormatterSettings::deleteStyle()
@@ -378,7 +389,7 @@ void SourceFormatterSettings::deleteStyle()
         selectAvailableStyle(*lang);
     }
     updatePreview();
-    emit changed( true );
+    emit changed();
 }
 
 void SourceFormatterSettings::editStyle()
@@ -388,7 +399,7 @@ void SourceFormatterSettings::editStyle()
     LanguageSettings& l = languages[ language ];
     SourceFormatter* fmt = l.selectedFormatter;
 
-    KMimeType::Ptr mimetype = l.mimetypes.first();
+    QMimeType mimetype = l.mimetypes.first();
     if( fmt->formatter->editStyleWidget( mimetype ) != 0 ) {
         EditStyleDialog dlg( fmt->formatter, mimetype, *l.selectedStyle, this );
         if( dlg.exec() == QDialog::Accepted )
@@ -396,7 +407,7 @@ void SourceFormatterSettings::editStyle()
             l.selectedStyle->setContent(dlg.content());
         }
         updatePreview();
-        emit changed( true );
+        emit changed();
     }
 }
 
@@ -409,14 +420,14 @@ void SourceFormatterSettings::newStyle()
     for( int i = 0; i < styleList->count(); i++ )
     {
         QString name = styleList->item( i )->data( STYLE_ROLE ).toString();
-        if( name.startsWith( userStylePrefix ) && name.mid( userStylePrefix.length() ).toInt() >= idx )
+        if( name.startsWith( Strings::userStylePrefix() ) && name.mid( Strings::userStylePrefix().length() ).toInt() >= idx )
         {
-            idx = name.mid( userStylePrefix.length() ).toInt();
+            idx = name.mid( Strings::userStylePrefix().length() ).toInt();
         }
     }
     // Increase number for next style
     idx++;
-    SourceFormatterStyle* s = new SourceFormatterStyle( QString( "%1%2" ).arg( userStylePrefix ).arg( idx ) );
+    SourceFormatterStyle* s = new SourceFormatterStyle( QStringLiteral( "%1%2" ).arg( Strings::userStylePrefix() ).arg( idx ) );
     if( item ) {
         SourceFormatterStyle* existstyle = fmt->styles[ item->data( STYLE_ROLE ).toString() ];
         s->setCaption( i18n( "New %1", existstyle->caption() ) );
@@ -428,7 +439,7 @@ void SourceFormatterSettings::newStyle()
     QListWidgetItem* newitem = addStyle( *s );
     selectStyle( styleList->row( newitem ) );
     styleList->editItem( newitem );
-    emit changed( true );
+    emit changed();
 }
 
 void SourceFormatterSettings::styleNameChanged( QListWidgetItem* item )
@@ -439,7 +450,7 @@ void SourceFormatterSettings::styleNameChanged( QListWidgetItem* item )
 
     LanguageSettings& l = languages[ cbLanguages->currentText() ];
     l.selectedStyle->setCaption( item->text() );
-    emit changed( true );
+    emit changed();
 }
 
 QListWidgetItem* SourceFormatterSettings::addStyle( const SourceFormatterStyle& s )
@@ -447,7 +458,7 @@ QListWidgetItem* SourceFormatterSettings::addStyle( const SourceFormatterStyle&
     QListWidgetItem* item = new QListWidgetItem( styleList );
     item->setText( s.caption() );
     item->setData( STYLE_ROLE, s.name() );
-    if( s.name().startsWith( userStylePrefix ) )
+    if( s.name().startsWith( Strings::userStylePrefix() ) )
     {
         item->setFlags( item->flags() | Qt::ItemIsEditable );
     }
@@ -475,7 +486,7 @@ void SourceFormatterSettings::updatePreview()
         if( style->usePreview() )
         {
             ISourceFormatter* ifmt = fmt->formatter;
-            KMimeType::Ptr mime = l.mimetypes.first();
+            QMimeType mime = l.mimetypes.first();
             m_document->setHighlightingMode( style->modeForMimetype( mime ) );
 
             //NOTE: this is ugly, but otherwise kate might remove tabs again :-/
@@ -487,7 +498,7 @@ void SourceFormatterSettings::updatePreview()
                 iface->setConfigValue("replace-tabs", false);
             }
 
-            m_document->setText( ifmt->formatSourceWithStyle( *style, ifmt->previewText( *style, mime ), KUrl(), mime ) );
+            m_document->setText( ifmt->formatSourceWithStyle( *style, ifmt->previewText( *style, mime ), QUrl(), mime ) );
 
             if (iface) {
                 iface->setConfigValue("replace-tabs", oldReplaceTabs);
@@ -503,7 +514,7 @@ void SourceFormatterSettings::updatePreview()
     {
         m_document->setText( i18n( "No Language selected" ) );
     }
-    m_document->activeView()->setCursorPosition( KTextEditor::Cursor( 0, 0 ) );
+    m_view->setCursorPosition( KTextEditor::Cursor( 0, 0 ) );
     m_document->setReadWrite( false );
 }
 
@@ -512,7 +523,20 @@ void SourceFormatterSettings::somethingChanged()
     // Widgets are managed manually, so we have to explicitly tell KCModule
     // that we have some changes, otherwise it won't call "save" and/or will not activate
     // "Appy"
-    unmanagedWidgetChangeState(true);
+    emit changed();
 }
 
-#include "sourceformattersettings.moc"
+QString SourceFormatterSettings::name() const
+{
+    return i18n("Source Formatter");
+}
+
+QString SourceFormatterSettings::fullName() const
+{
+    return i18n("Configure Source Formatter");
+}
+
+QIcon SourceFormatterSettings::icon() const
+{
+    return QIcon::fromTheme(QStringLiteral("text-field"));
+}
