@@ -18,30 +18,26 @@
  ***************************************************************************/
 #include "textdocument.h"
 
-#include <QFile>
-#include <QPointer>
-#include <QTextCodec>
-#include <QMenu>
 #include <QAction>
-#include <QVBoxLayout>
+#include <QCoreApplication>
+#include <QDebug>
+#include <QFile>
+#include <QMenu>
+#include <QMimeDatabase>
+#include <QPointer>
 #include <QWidget>
-#include <QLabel>
-#include <QLayout>
 
-#include <klocale.h>
-#include <kmessagebox.h>
-#include <kconfiggroup.h>
-#include <kstandarddirs.h>
-#include <kxmlguifactory.h>
-#include <kdeversion.h>
-
-#include <ktexteditor/view.h>
-#include <ktexteditor/document.h>
-#include <ktexteditor/modificationinterface.h>
-#include <ktexteditor/codecompletioninterface.h>
-#include <ktexteditor/markinterface.h>
-#include <ktexteditor/configinterface.h>
-#include <ktexteditor/sessionconfiginterface.h>
+#include <KActionCollection>
+#include <KConfigGroup>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KTextEditor/View>
+#include <KTextEditor/Document>
+#include <KTextEditor/ModificationInterface>
+#include <KTextEditor/CodeCompletionInterface>
+#include <KTextEditor/MarkInterface>
+#include <KTextEditor/ConfigInterface>
+#include <KTextEditor/SessionConfigInterface>
 
 #include <interfaces/context.h>
 #include <interfaces/contextmenuextension.h>
@@ -53,8 +49,10 @@
 #include <vcs/interfaces/icontentawareversioncontrol.h>
 
 #include <language/interfaces/editorcontext.h>
+#include <language/backgroundparser/backgroundparser.h>
 
 #include <project/projectutils.h>
+#include <project/projectmodel.h>
 
 #include "core.h"
 #include "mainwindow.h"
@@ -62,6 +60,8 @@
 #include "partcontroller.h"
 #include "plugincontroller.h"
 #include "documentcontroller.h"
+#include "debug.h"
+#include <path.h>
 
 namespace KDevelop {
 
@@ -82,72 +82,130 @@ static void selectAndReveal( KTextEditor::View* view, const KTextEditor::Range&
 
 struct TextDocumentPrivate {
     TextDocumentPrivate(TextDocument *textDocument)
-        : encoding(""), m_textDocument(textDocument)
+        : document(nullptr), state(IDocument::Clean), encoding(), q(textDocument)
         , m_loaded(false), m_addedContextMenu(0)
     {
-        document = 0;
-        state = IDocument::Clean;
     }
 
     ~TextDocumentPrivate()
     {
-        if (m_addedContextMenu) {
-            delete m_addedContextMenu;
-            m_addedContextMenu = 0;
-        }
-        if (document) {
-            saveSessionConfig();
-            delete document;
-        }
+        delete m_addedContextMenu;
+        m_addedContextMenu = 0;
+
+        saveSessionConfig();
+        delete document;
     }
 
     QPointer<KTextEditor::Document> document;
     IDocument::DocumentState state;
     QString encoding;
 
-    void newDocumentStatus(KTextEditor::Document *document)
+    void setStatus(KTextEditor::Document* document, bool dirty)
     {
-        bool dirty = (state == IDocument::Dirty || state == IDocument::DirtyAndModified);
+        QIcon statusIcon;
 
-        setStatus(document, dirty);
+        if (document->isModified())
+            if (dirty) {
+                state = IDocument::DirtyAndModified;
+                statusIcon = QIcon::fromTheme("edit-delete");
+            } else {
+                state = IDocument::Modified;
+                statusIcon = QIcon::fromTheme("document-save");
+            }
+        else
+            if (dirty) {
+                state = IDocument::Dirty;
+                statusIcon = QIcon::fromTheme("document-revert");
+            } else {
+                state = IDocument::Clean;
+            }
+
+        q->notifyStateChanged();
+        Core::self()->uiControllerInternal()->setStatusIcon(q, statusIcon);
     }
 
-    void textChanged(KTextEditor::Document *document)
+    inline KConfigGroup katePartSettingsGroup() const
     {
-        Q_UNUSED(document);
-        m_textDocument->notifyContentChanged();
+        return KSharedConfig::openConfig()->group("KatePart Settings");
     }
-    
-    void populateContextMenu( KTextEditor::View* v, QMenu* menu )
+
+    inline QString docConfigGroupName() const
     {
-        if (m_addedContextMenu) {
-            foreach ( QAction* action, m_addedContextMenu->actions() ) {
-                menu->removeAction(action);
+        return document->url().toDisplayString(QUrl::PreferLocalFile);
+    }
+
+    inline KConfigGroup docConfigGroup() const
+    {
+        return katePartSettingsGroup().group(docConfigGroupName());
+    }
+
+    void saveSessionConfig()
+    {
+        if(document && document->url().isValid()) {
+            // make sure only MAX_DOC_SETTINGS entries are stored
+            KConfigGroup katePartSettings = katePartSettingsGroup();
+            // ordered list of documents
+            QStringList documents = katePartSettings.readEntry("documents", QStringList());
+            // ensure this document is "new", i.e. at the end of the list
+            documents.removeOne(docConfigGroupName());
+            documents.append(docConfigGroupName());
+            // remove "old" documents + their group
+            while(documents.size() >= MAX_DOC_SETTINGS) {
+                katePartSettings.group(documents.takeFirst()).deleteGroup();
             }
-            delete m_addedContextMenu;
+            // update order
+            katePartSettings.writeEntry("documents", documents);
+
+            // actually save session config
+            KConfigGroup group = docConfigGroup();
+            document->writeSessionConfig(group);
+        }
+    }
+
+    void loadSessionConfig()
+    {
+        if (!document || !katePartSettingsGroup().hasGroup(docConfigGroupName())) {
+            return;
         }
 
-        m_addedContextMenu = new QMenu();
+        document->readSessionConfig(docConfigGroup(), {"SkipUrl"});
+    }
 
-        Context* c = new EditorContext( v, v->cursorPosition() );
-        QList<ContextMenuExtension> extensions = Core::self()->pluginController()->queryPluginsForContextMenuExtensions( c );
-        
-        ContextMenuExtension::populateMenu(m_addedContextMenu, extensions);
-        
-        {
-            KUrl url = v->document()->url();
-            IProject* project = Core::self()->projectController()->findProjectForUrl( url );
-            if(project)
-            {
-                QList< ProjectBaseItem* > items = project->itemsForUrl( url );
-                if(!items.isEmpty())
-                    populateParentItemsMenu( items.front(), m_addedContextMenu );
+    // Determines whether the current contents of this document in the editor
+    // could be retrieved from the VCS if they were dismissed.
+    void queryCanRecreateFromVcs(KTextEditor::Document* document) const {
+        IProject* project = 0;
+        // Find projects by checking which one contains the file's parent directory,
+        // to avoid issues with the cmake manager temporarily removing files from a project
+        // during reloading.
+        KDevelop::Path path(document->url());
+        foreach ( KDevelop::IProject* current, Core::self()->projectController()->projects() ) {
+            if ( current->path().isParentOf(path) ) {
+                project = current;
+                break;
             }
         }
-        
-        foreach ( QAction* action, m_addedContextMenu->actions() ) {
-            menu->addAction(action);
+        if (!project) {
+            return;
         }
+        IContentAwareVersionControl* iface;
+        iface = qobject_cast< KDevelop::IContentAwareVersionControl* >(project->versionControlPlugin());
+        if (!iface) {
+            return;
+        }
+        if ( !qobject_cast<KTextEditor::ModificationInterface*>( document ) ) {
+            return;
+        }
+
+        CheckInRepositoryJob* req = iface->isInRepository( document );
+        if ( !req ) {
+            return;
+        }
+        QObject::connect(req, &CheckInRepositoryJob::finished,
+                            q, &TextDocument::repositoryCheckFinished);
+        // Abort the request when the user edits the document
+        QObject::connect(q->textDocument(), &KTextEditor::Document::textChanged,
+                            req, &CheckInRepositoryJob::abort);
     }
 
     void modifiedOnDisk(KTextEditor::Document *document, bool /*isModified*/,
@@ -174,223 +232,22 @@ struct TextDocumentPrivate {
         setStatus(document, dirty);
     }
 
-    // Determines whether the current contents of this document in the editor
-    // could be retrieved from the VCS if they were dismissed.
-    void queryCanRecreateFromVcs(KTextEditor::Document* document) const {
-        IProject* project = 0;
-        // Find projects by checking which one contains the file's parent directory,
-        // to avoid issues with the cmake manager temporarily removing files from a project
-        // during reloading.
-        foreach ( KDevelop::IProject* current, Core::self()->projectController()->projects() ) {
-            if ( current->folder().isParentOf(document->url()) ) {
-                project = current;
-                break;
-            }
-        }
-        if (!project) {
-            return;
-        }
-        IContentAwareVersionControl* iface;
-        iface = qobject_cast< KDevelop::IContentAwareVersionControl* >(project->versionControlPlugin());
-        if (!iface) {
-            return;
-        }
-        if ( !qobject_cast<KTextEditor::ModificationInterface*>( document ) ) {
-            return;
-        }
-
-        CheckInRepositoryJob* req = iface->isInRepository( document );
-        if ( !req ) {
-            return;
-        }
-        QObject::connect(req, SIGNAL(finished(bool)),
-                         m_textDocument, SLOT(repositoryCheckFinished(bool)));
-        // Abort the request when the user edits the document
-        QObject::connect(m_textDocument->textDocument(), SIGNAL(textChanged(KTextEditor::Document*)),
-                         req, SLOT(abort()));
-    }
-
-    void repositoryCheckFinished(bool canRecreate) {
-        if ( state != IDocument::Dirty && state != IDocument::DirtyAndModified ) {
-            // document is not dirty for whatever reason, nothing to do.
-            return;
-        }
-        if ( ! canRecreate ) {
-            return;
-        }
-        KTextEditor::ModificationInterface* modIface = qobject_cast<KTextEditor::ModificationInterface*>( document );
-        Q_ASSERT(modIface);
-        // Ok, all safe, we can clean up the document. Close it if the file is gone,
-        // and reload if it's still there.
-        setStatus(document, false);
-        modIface->setModifiedOnDisk(KTextEditor::ModificationInterface::OnDiskUnmodified);
-        if ( QFile::exists(document->url().path()) ) {
-            m_textDocument->reload();
-        } else {
-            m_textDocument->close(KDevelop::IDocument::Discard);
-        }
-    }
-
-    void setStatus(KTextEditor::Document* document, bool dirty)
-    {
-        QIcon statusIcon;
-
-        if (document->isModified())
-            if (dirty) {
-                state = IDocument::DirtyAndModified;
-                statusIcon = KIcon("edit-delete");
-            } else {
-                state = IDocument::Modified;
-                statusIcon = KIcon("document-save");
-            }
-        else
-            if (dirty) {
-                state = IDocument::Dirty;
-                statusIcon = KIcon("document-revert");
-            } else {
-                state = IDocument::Clean;
-            }
-
-        m_textDocument->notifyStateChanged();
-        Core::self()->uiControllerInternal()->setStatusIcon(m_textDocument, statusIcon);
-    }
-
-    void documentUrlChanged(KTextEditor::Document* document)
-    {
-        if (m_textDocument->url() != document->url())
-            m_textDocument->setUrl(document->url());
-    }
-
-    void slotDocumentLoaded()
-    {
-        if (m_loaded)
-            return;
-        // Tell the editor integrator first
-        m_loaded = true;
-        m_textDocument->notifyLoaded();
-    }
-
-    void documentSaved(KTextEditor::Document* document, bool saveAs)
-    {
-        Q_UNUSED(document);
-        Q_UNUSED(saveAs);
-        m_textDocument->notifySaved();
-        m_textDocument->notifyStateChanged();
-    }
-
-    inline KConfigGroup katePartSettingsGroup() const
-    {
-        return KGlobal::config()->group("KatePart Settings");
-    }
-
-    inline QString docConfigGroupName() const
-    {
-        return document->url().pathOrUrl();
-    }
-
-    inline KConfigGroup docConfigGroup() const
-    {
-        return katePartSettingsGroup().group(docConfigGroupName());
-    }
-
-    void saveSessionConfig()
-    {
-        if(!document->url().isValid()) {
-            return;
-        }
-        if (KTextEditor::ParameterizedSessionConfigInterface *sessionConfigIface =
-            qobject_cast<KTextEditor::ParameterizedSessionConfigInterface*>(document))
-        {
-            // make sure only MAX_DOC_SETTINGS entries are stored
-            KConfigGroup katePartSettings = katePartSettingsGroup();
-            // ordered list of documents
-            QStringList documents = katePartSettings.readEntry("documents", QStringList());
-            // ensure this document is "new", i.e. at the end of the list
-            documents.removeOne(docConfigGroupName());
-            documents.append(docConfigGroupName());
-            // remove "old" documents + their group
-            while(documents.size() >= MAX_DOC_SETTINGS) {
-                katePartSettings.group(documents.takeFirst()).deleteGroup();
-            }
-            // update order
-            katePartSettings.writeEntry("documents", documents);
-
-            // actually save session config
-            KConfigGroup group = docConfigGroup();
-            sessionConfigIface->writeParameterizedSessionConfig(group,
-                KTextEditor::ParameterizedSessionConfigInterface::SkipUrl);
-        }
-    }
-
-    void loadSessionConfig()
-    {
-        if (!document || !katePartSettingsGroup().hasGroup(docConfigGroupName())) {
-            return;
-        }
-        if (KTextEditor::ParameterizedSessionConfigInterface *sessionConfigIface =
-            qobject_cast<KTextEditor::ParameterizedSessionConfigInterface*>(document))
-        {
-            sessionConfigIface->readParameterizedSessionConfig(docConfigGroup(),
-                KTextEditor::ParameterizedSessionConfigInterface::SkipUrl);
-        }
-    }
-
-
-private:
-    TextDocument *m_textDocument;
+    TextDocument * const q;
     bool m_loaded;
     // we want to remove the added stuff when the menu hides
     QMenu* m_addedContextMenu;
 };
 
-class TextViewPrivate
+struct TextViewPrivate
 {
-public:
-    TextViewPrivate() : editor(0) {}
-    TextEditorWidget* editor;
+    TextViewPrivate(TextView* q) : q(q) {}
+
+    TextView* const q;
+    QPointer<KTextEditor::View> view;
     KTextEditor::Range initialRange;
 };
 
-class TextEditorWidgetPrivate
-{
-public:
-    TextEditorWidgetPrivate()
-    {
-        widget = 0;
-        widgetLayout = 0;
-        view = 0;
-        statusLabel = 0;
-    }
-
-    void viewEditModeChanged(KTextEditor::View* view, KTextEditor::View::EditMode mode)
-    {
-#ifdef KTEXTEDITOR_HAS_VIMODE
-        if ( ! statusLabel ) {
-            statusLabel = new QLabel();
-            view->layout()->addWidget(statusLabel);
-        }
-        if ( mode == KTextEditor::View::EditViMode ) {
-            statusLabel->setText(view->viewMode() + "    <i>" + view->document()->url().fileName() + "</i>");
-            statusLabel->setHidden(false);
-        }
-        else {
-            statusLabel->setHidden(true);
-        }
-#else
-        Q_UNUSED(view);
-        Q_UNUSED(mode);
-#endif
-    }
-    QWidget* widget;
-    QVBoxLayout* widgetLayout;
-    QPointer<KTextEditor::View> view;
-    QLabel* statusLabel;
-    QString status;
-    const TextView* textView;
-
-};
-
-TextDocument::TextDocument(const KUrl &url, ICore* core, const QString& encoding)
+TextDocument::TextDocument(const QUrl &url, ICore* core, const QString& encoding)
     :PartDocument(url, core), d(new TextDocumentPrivate(this))
 {
     d->encoding = encoding;
@@ -410,7 +267,7 @@ bool TextDocument::isTextDocument() const
         qWarning() << "Broken text-document: " << url();
         return false;
     }
-    
+
     return true;
 }
 
@@ -425,12 +282,20 @@ QWidget *TextDocument::createViewWidget(QWidget *parent)
 
     if (!d->document)
     {
-        d->document = Core::self()->partControllerInternal()->createTextPart(Core::self()->documentController()->encoding());
+        d->document = Core::self()->partControllerInternal()->createTextPart();
 
         // Connect to the first text changed signal, it occurs before the completed() signal
-        connect(d->document, SIGNAL(textChanged(KTextEditor::Document*)), this, SLOT(slotDocumentLoaded()));
+        connect(d->document.data(), &KTextEditor::Document::textChanged, this, &TextDocument::slotDocumentLoaded);
         // Also connect to the completed signal, sometimes the first text changed signal is missed because the part loads too quickly (? TODO - confirm this is necessary)
-        connect(d->document, SIGNAL(completed()), this, SLOT(slotDocumentLoaded()));
+        connect(d->document.data(), static_cast<void(KTextEditor::Document::*)()>(&KTextEditor::Document::completed), this, &TextDocument::slotDocumentLoaded);
+
+        // force a reparse when a document gets reloaded
+        connect(d->document.data(), &KTextEditor::Document::reloaded,
+                this, [] (KTextEditor::Document* document) {
+            ICore::self()->languageController()->backgroundParser()->addDocument(IndexedString(document->url()),
+                    (TopDUContext::Features) ( TopDUContext::AllDeclarationsContextsAndUses | TopDUContext::ForceUpdate ),
+                    BackgroundParser::BestPriority, 0);
+        });
 
         // Set encoding passed via constructor
         // Needs to be done before openUrl, else katepart won't use the encoding
@@ -452,22 +317,25 @@ QWidget *TextDocument::createViewWidget(QWidget *parent)
 
         d->loadSessionConfig();
 
-        connect(d->document, SIGNAL(modifiedChanged(KTextEditor::Document*)),
-                 this, SLOT(newDocumentStatus(KTextEditor::Document*)));
-        connect(d->document, SIGNAL(textChanged(KTextEditor::Document*)),
-                 this, SLOT(textChanged(KTextEditor::Document*)));
-        connect(d->document, SIGNAL(documentUrlChanged(KTextEditor::Document*)),
-                 this, SLOT(documentUrlChanged(KTextEditor::Document*)));
-        connect(d->document, SIGNAL(documentSavedOrUploaded(KTextEditor::Document*,bool)),
-                 this, SLOT(documentSaved(KTextEditor::Document*,bool)));
-        connect(d->document, SIGNAL(marksChanged(KTextEditor::Document*)),
-                 this, SLOT(saveSessionConfig()));
+        connect(d->document.data(), &KTextEditor::Document::modifiedChanged,
+                 this, &TextDocument::newDocumentStatus);
+        connect(d->document.data(), &KTextEditor::Document::textChanged,
+                 this, &TextDocument::textChanged);
+        connect(d->document.data(), &KTextEditor::Document::documentUrlChanged,
+                 this, &TextDocument::documentUrlChanged);
+        connect(d->document.data(), &KTextEditor::Document::documentSavedOrUploaded,
+                 this, &TextDocument::documentSaved );
 
-        KTextEditor::ModificationInterface *iface = qobject_cast<KTextEditor::ModificationInterface*>(d->document);
-        if (iface)
-        {
+        if (qobject_cast<KTextEditor::MarkInterface*>(d->document)) {
+            // can't use new signal/slot syntax here, MarkInterface is not a QObject
+            connect(d->document.data(), SIGNAL(marksChanged(KTextEditor::Document*)),
+                    this, SLOT(saveSessionConfig()));
+        }
+
+        if (auto iface = qobject_cast<KTextEditor::ModificationInterface*>(d->document)) {
             iface->setModifiedOnDiskWarning(true);
-            connect(d->document, SIGNAL(modifiedOnDisk(KTextEditor::Document*,bool,KTextEditor::ModificationInterface::ModifiedOnDiskReason)),
+            // can't use new signal/slot syntax here, ModificationInterface is not a QObject
+            connect(d->document.data(), SIGNAL(modifiedOnDisk(KTextEditor::Document*,bool,KTextEditor::ModificationInterface::ModifiedOnDiskReason)),
                 this, SLOT(modifiedOnDisk(KTextEditor::Document*,bool,KTextEditor::ModificationInterface::ModifiedOnDiskReason)));
         }
 
@@ -476,28 +344,17 @@ QWidget *TextDocument::createViewWidget(QWidget *parent)
 
     view = d->document->createView(parent);
 
-    if (view) {
-        connect(view, SIGNAL(contextMenuAboutToShow(KTextEditor::View*,QMenu*)), this, SLOT(populateContextMenu(KTextEditor::View*,QMenu*)));
+    // get rid of some actions regarding the config dialog, we merge that one into the kdevelop menu already
+    delete view->actionCollection()->action(QStringLiteral("set_confdlg"));
+    delete view->actionCollection()->action(QStringLiteral("editor_options"));
 
-        //in KDE >= 4.4 we can use KXMLGuiClient::replaceXMLFile to provide
-        //katepart with our own restructured UI configuration
-        const QString uiFile = KGlobal::mainComponent().componentName() + "/katepartui.rc";
-        QStringList katePartUIs = KGlobal::mainComponent().dirs()->findAllResources("data", uiFile);
-        if (!katePartUIs.isEmpty()) {
-            const QString katePartUI = katePartUIs.last();
-            const QString katePartLocalUI = KStandardDirs::locateLocal("data", uiFile);
-            if (!QFile::exists(katePartLocalUI)) {
-                // prevent warning:
-                // kdevelop/kdeui (kdelibs): No such XML file ".../.kde/share/apps/kdevelop/katepartui.rc"
-                QFile::copy(katePartUI, katePartLocalUI);
-            }
-            view->replaceXMLFile(katePartUI, katePartLocalUI);
-        }
-    }
+    view->setStatusBarEnabled(Core::self()->partControllerInternal()->showTextEditorStatusBar());
+
+    connect(view, &KTextEditor::View::contextMenuAboutToShow, this, &TextDocument::populateContextMenu);
 
     if (KTextEditor::CodeCompletionInterface* cc = dynamic_cast<KTextEditor::CodeCompletionInterface*>(view))
         cc->setAutomaticInvocationEnabled(core()->languageController()->completionSettings()->automaticCompletionEnabled());
-    
+
     if (KTextEditor::ConfigInterface *config = qobject_cast<KTextEditor::ConfigInterface*>(view)) {
         config->setConfigValue("allow-mark-menu", false);
         config->setConfigValue("default-mark-type", KTextEditor::MarkInterface::BreakpointActive);
@@ -573,7 +430,7 @@ bool TextDocument::save(DocumentSaveMode mode)
             break;
     }
 
-    KUrl urlBeforeSave = d->document->url();
+    QUrl urlBeforeSave = d->document->url();
     if (d->document->documentSave())
     {
         if (d->document->url() != urlBeforeSave)
@@ -594,7 +451,7 @@ KTextEditor::Cursor KDevelop::TextDocument::cursorPosition() const
         return KTextEditor::Cursor::invalid();
     }
 
-    KTextEditor::View *view = d->document->activeView();
+    KTextEditor::View *view = activeTextView();
 
     if (view)
         return view->cursorPosition();
@@ -607,7 +464,7 @@ void TextDocument::setCursorPosition(const KTextEditor::Cursor &cursor)
     if (!cursor.isValid() || !d->document)
         return;
 
-    KTextEditor::View *view = d->document->activeView();
+    KTextEditor::View *view = activeTextView();
 
     // Rodda: Cursor must be accurate here, to the definition of accurate for KTextEditor::Cursor.
     // ie, starting from 0,0
@@ -622,7 +479,7 @@ KTextEditor::Range TextDocument::textSelection() const
         return KTextEditor::Range::invalid();
     }
 
-    KTextEditor::View *view = d->document->activeView();
+    KTextEditor::View *view = activeTextView();
 
     if (view && view->selection()) {
         return view->selectionRange();
@@ -637,7 +494,7 @@ QString TextDocument::textLine() const
         return QString();
     }
 
-    KTextEditor::View *view = d->document->activeView();
+    KTextEditor::View *view = activeTextView();
 
     if (view) {
         return d->document->line( view->cursorPosition().line() );
@@ -652,11 +509,11 @@ QString TextDocument::textWord() const
         return QString();
     }
 
-    KTextEditor::View *view = d->document->activeView();
+    KTextEditor::View *view = activeTextView();
 
     if (view) {
         KTextEditor::Cursor start = view->cursorPosition();
-        kDebug() << "got start position from view:" << start.line() << start.column();
+        qCDebug(SHELL) << "got start position from view:" << start.line() << start.column();
         QString linestr = textLine();
         int startPos = qMax( qMin( start.column(), linestr.length() - 1 ), 0 );
         int endPos = startPos;
@@ -672,7 +529,7 @@ QString TextDocument::textWord() const
         }
         if( startPos != endPos )
         {
-            kDebug() << "found word" << startPos << endPos << linestr.mid( startPos+1, endPos - startPos - 1 );
+            qCDebug(SHELL) << "found word" << startPos << endPos << linestr.mid( startPos+1, endPos - startPos - 1 );
             return linestr.mid( startPos + 1, endPos - startPos - 1 );
         }
     }
@@ -685,7 +542,7 @@ void TextDocument::setTextSelection(const KTextEditor::Range &range)
     if (!range.isValid() || !d->document)
         return;
 
-    KTextEditor::View *view = d->document->activeView();
+    KTextEditor::View *view = activeTextView();
 
     if (view) {
         selectAndReveal(view, range);
@@ -716,59 +573,53 @@ Sublime::View* TextDocument::newView(Sublime::Document* doc)
 }
 
 KDevelop::TextView::TextView(TextDocument * doc)
-    : View(doc, View::TakeOwnership), d( new TextViewPrivate )
+    : View(doc, View::TakeOwnership), d(new TextViewPrivate(this))
 {
 }
 
 KDevelop::TextView::~TextView()
 {
-    delete d->editor; //We have to delete the view right now, to prevent random crashes in the event handler
-    d->editor = 0;
     delete d;
 }
 
 QWidget * KDevelop::TextView::createWidget(QWidget * parent)
 {
-    TextEditorWidget* teWidget = new TextEditorWidget(this, parent);
-    connect(teWidget, SIGNAL(statusChanged()), this, SLOT(sendStatusChanged()));
-
-    d->editor = teWidget;
-    connect(d->editor, SIGNAL(destroyed(QObject*)), this, SLOT(editorDestroyed(QObject*)));
-    
-    return teWidget;
-}
-
-void KDevelop::TextView::editorDestroyed(QObject* obj) {
-    if(obj == d->editor)
-        d->editor = 0;
+    auto textDocument = qobject_cast<TextDocument*>(document());
+    Q_ASSERT(textDocument);
+    QWidget* widget = textDocument->createViewWidget(parent);
+    d->view = qobject_cast<KTextEditor::View*>(widget);
+    Q_ASSERT(d->view);
+    connect(d->view.data(), &KTextEditor::View::cursorPositionChanged, this, &KDevelop::TextView::sendStatusChanged);
+    return widget;
 }
 
 QString KDevelop::TextView::viewState() const
 {
-    if( d->editor && d->editor->editorView() )
-    {
-        if (d->editor->editorView()->selection()) {
-            KTextEditor::Range selection = d->editor->editorView()->selectionRange();
-            return QString("Selection=%1,%2,%3,%4").arg(selection.start().line())
+    if (d->view) {
+        if (d->view->selection()) {
+            KTextEditor::Range selection = d->view->selectionRange();
+            return QStringLiteral("Selection=%1,%2,%3,%4").arg(selection.start().line())
                                                    .arg(selection.start().column())
                                                    .arg(selection.end().line())
                                                    .arg(selection.end().column());
         } else {
-            KTextEditor::Cursor cursor = d->editor->editorView()->cursorPosition();
-            return QString("Cursor=%1,%2").arg(cursor.line()).arg(cursor.column());
+            KTextEditor::Cursor cursor = d->view->cursorPosition();
+            return QStringLiteral("Cursor=%1,%2").arg(cursor.line()).arg(cursor.column());
         }
     }
-    else
-    {
-        kDebug() << "TextView's internal KTE view disappeared!";
-        return QString();
+    else {
+        KTextEditor::Range selection = d->initialRange;
+        return QStringLiteral("Selection=%1,%2,%3,%4").arg(selection.start().line())
+                                                   .arg(selection.start().column())
+                                                   .arg(selection.end().line())
+                                                   .arg(selection.end().column());
     }
 }
 
 void KDevelop::TextView::setInitialRange(const KTextEditor::Range& range)
 {
-    if(d->editor && d->editor->isInitialized()) {
-        selectAndReveal(d->editor->editorView(), range);
+    if (d->view) {
+        selectAndReveal(d->view, range);
     } else {
         d->initialRange = range;
     }
@@ -799,8 +650,8 @@ QString KDevelop::TextDocument::documentType() const
 QIcon KDevelop::TextDocument::defaultIcon() const
 {
     if (d->document) {
-        KMimeType::Ptr mime = KMimeType::mimeType(d->document->mimeType());
-        KIcon icon(mime->iconName());
+        QMimeType mime = QMimeDatabase().mimeTypeForName(d->document->mimeType());
+        QIcon icon = QIcon::fromTheme(mime.iconName());
         if (!icon.isNull()) {
             return icon;
         }
@@ -809,19 +660,20 @@ QIcon KDevelop::TextDocument::defaultIcon() const
 }
 
 KTextEditor::View *KDevelop::TextView::textView() const
-{  
-    if (d->editor)
-        return d->editor->editorView();
-
-    return 0;
+{
+    return d->view;
 }
 
 QString KDevelop::TextView::viewStatus() const
 {
-    if (d->editor)
-        return d->editor->status();
+    // only show status when KTextEditor's own status bar isn't already enabled
+    const bool showStatus = !Core::self()->partControllerInternal()->showTextEditorStatusBar();
+    if (!showStatus) {
+        return QString();
+    }
 
-    return QString();
+    const KTextEditor::Cursor pos = d->view ? d->view->cursorPosition() : KTextEditor::Cursor::invalid();
+    return i18n(" Line: %1 Col: %2 ", pos.line() + 1, pos.column() + 1);
 }
 
 void KDevelop::TextView::sendStatusChanged()
@@ -829,88 +681,110 @@ void KDevelop::TextView::sendStatusChanged()
     emit statusChanged(this);
 }
 
-KDevelop::TextEditorWidget::TextEditorWidget(const TextView* view, QWidget* parent)
-: QWidget(parent), KXMLGUIClient(), d(new TextEditorWidgetPrivate)
+KTextEditor::View* KDevelop::TextDocument::activeTextView() const
 {
-    d->widgetLayout = new QVBoxLayout(this);
-    d->widgetLayout->setMargin(0);
-    d->widgetLayout->setSpacing(0);
-    d->textView = view;
-    d->view = 0;
-
-    setLayout(d->widgetLayout);
-    initialize();
+    KTextEditor::View* fallback = nullptr;
+    for (auto view : views()) {
+        auto textView = qobject_cast<TextView*>(view)->textView();
+        if (!textView) {
+            continue;
+        }
+        if (textView->hasFocus()) {
+            return textView;
+        } else if (textView->isVisible()) {
+            fallback = textView;
+        } else if (!fallback) {
+            fallback = textView;
+        }
+    }
+    return fallback;
 }
 
-KDevelop::TextEditorWidget::~TextEditorWidget()
+void KDevelop::TextDocument::newDocumentStatus(KTextEditor::Document *document)
 {
-    delete d;
+    bool dirty = (d->state == IDocument::Dirty || d->state == IDocument::DirtyAndModified);
+
+    d->setStatus(document, dirty);
 }
 
-void KDevelop::TextEditorWidget::initialize()
+void KDevelop::TextDocument::textChanged(KTextEditor::Document *document)
 {
-    if(d->view)
-        return;
-    TextDocument* doc = static_cast<TextDocument*>(d->textView->document());
-    KTextEditor::View* view = qobject_cast<KTextEditor::View*>(doc->createViewWidget(this));
-    KTextEditor::Range ir = d->textView->initialRange();
-    selectAndReveal(view, ir);
-    setEditorView(view);
+    Q_UNUSED(document);
+    notifyContentChanged();
 }
 
-void KDevelop::TextEditorWidget::viewStatusChanged(KTextEditor::View* view, const KTextEditor::Cursor& )
+void KDevelop::TextDocument::populateContextMenu( KTextEditor::View* v, QMenu* menu )
 {
-    // This fetches the virtual cursor, which expands tab characters properly, i.e. instead of col == 1
-    // you'll get col == 9 with this when a tab is at the start of the line.
-    KTextEditor::Cursor pos = view->cursorPositionVirtual();
-    d->status = i18n(" Line: %1 Col: %2 ", KGlobal::locale()->formatNumber(pos.line() + 1, 0), KGlobal::locale()->formatNumber(pos.column() + 1, 0));
-    emit statusChanged();
-}
-
-void KDevelop::TextEditorWidget::setEditorView(KTextEditor::View* view)
-{
-    if (d->view)
-    {
-        disconnect(view, SIGNAL(cursorPositionChanged(KTextEditor::View*,KTextEditor::Cursor)));
-        removeChildClient(view);
+    if (d->m_addedContextMenu) {
+        foreach ( QAction* action, d->m_addedContextMenu->actions() ) {
+            menu->removeAction(action);
+        }
+        delete d->m_addedContextMenu;
     }
 
-    d->view = view;
-    insertChildClient(d->view);
-    connect(view, SIGNAL(cursorPositionChanged(KTextEditor::View*,KTextEditor::Cursor)), 
-            this, SLOT(viewStatusChanged(KTextEditor::View*,KTextEditor::Cursor)));
-    
-    viewStatusChanged(view, view->cursorPosition());
+    d->m_addedContextMenu = new QMenu();
 
-    connect(view, SIGNAL(viewEditModeChanged(KTextEditor::View*,KTextEditor::View::EditMode)),
-            this, SLOT(viewEditModeChanged(KTextEditor::View*,KTextEditor::View::EditMode)));
+    Context* c = new EditorContext( v, v->cursorPosition() );
+    QList<ContextMenuExtension> extensions = Core::self()->pluginController()->queryPluginsForContextMenuExtensions( c );
 
-    d->widgetLayout->insertWidget(0, d->view);
-    setFocusProxy(view);
+    ContextMenuExtension::populateMenu(d->m_addedContextMenu, extensions);
+
+    {
+        QUrl url = v->document()->url();
+        QList< ProjectBaseItem* > items = Core::self()->projectController()->projectModel()->itemsForPath( IndexedString(url) );
+        if (!items.isEmpty()) {
+            populateParentItemsMenu( items.front(), d->m_addedContextMenu );
+        }
+    }
+
+    foreach ( QAction* action, d->m_addedContextMenu->actions() ) {
+        menu->addAction(action);
+    }
 }
 
-QString KDevelop::TextEditorWidget::status() const
+void KDevelop::TextDocument::repositoryCheckFinished(bool canRecreate) {
+    if ( d->state != IDocument::Dirty && d->state != IDocument::DirtyAndModified ) {
+        // document is not dirty for whatever reason, nothing to do.
+        return;
+    }
+    if ( ! canRecreate ) {
+        return;
+    }
+    KTextEditor::ModificationInterface* modIface = qobject_cast<KTextEditor::ModificationInterface*>( d->document );
+    Q_ASSERT(modIface);
+    // Ok, all safe, we can clean up the document. Close it if the file is gone,
+    // and reload if it's still there.
+    d->setStatus(d->document, false);
+    modIface->setModifiedOnDisk(KTextEditor::ModificationInterface::OnDiskUnmodified);
+    if ( QFile::exists(d->document->url().path()) ) {
+        reload();
+    } else {
+        close(KDevelop::IDocument::Discard);
+    }
+}
+
+void KDevelop::TextDocument::slotDocumentLoaded()
 {
-    return d->status;
+    if (d->m_loaded)
+        return;
+    // Tell the editor integrator first
+    d->m_loaded = true;
+    notifyLoaded();
 }
 
-KTextEditor::View* KDevelop::TextEditorWidget::editorView()
+void KDevelop::TextDocument::documentSaved(KTextEditor::Document* document, bool saveAs)
 {
-    if(!d->view)
-        initialize();
-    return d->view;
+    Q_UNUSED(document);
+    Q_UNUSED(saveAs);
+    notifySaved();
+    notifyStateChanged();
 }
 
-bool KDevelop::TextEditorWidget::isInitialized() const
+void KDevelop::TextDocument::documentUrlChanged(KTextEditor::Document* document)
 {
-    return d->view!=0;
+    Q_UNUSED(document);
+    if (url() != d->document->url())
+        setUrl(d->document->url());
 }
 
-void KDevelop::TextEditorWidget::showEvent(QShowEvent* event)
-{
-    if(!d->view)
-        initialize();
-    QWidget::showEvent(event);
-}
-
-#include "textdocument.moc"
+#include "moc_textdocument.cpp"
