@@ -18,30 +18,30 @@
  ***************************************************************************/
 #include "uicontroller.h"
 
-#include <QMap>
 #include <QAction>
+#include <QApplication>
+#include <QDialog>
+#include <QListWidget>
+#include <QMap>
 #include <QPointer>
 #include <QTimer>
-#include <QApplication>
-#include <QListWidget>
-#include <QToolBar>
+#include <QVBoxLayout>
 
-#include <kdebug.h>
-#include <kdialog.h>
-#include <klocale.h>
-#include <kmenubar.h>
-#include <ksettings/dialog.h>
-#include <ksettings/dispatcher.h>
-#include <kcmultidialog.h>
-#include <kxmlguifactory.h>
-#include <kxmlguiclient.h>
+#include <KLocalizedString>
+#include <KXMLGUIClient>
 
 #include <sublime/area.h>
 #include <sublime/view.h>
 #include <sublime/tooldocument.h>
 #include <sublime/holdupdates.h>
 
+#include <interfaces/itoolviewactionlistener.h>
+
 #include "core.h"
+#include "configpage.h"
+#include "configdialog.h"
+#include "debug.h"
+#include "editorconfigpage.h"
 #include "shellextension.h"
 #include "partcontroller.h"
 #include "plugincontroller.h"
@@ -49,11 +49,17 @@
 #include "partdocument.h"
 #include "textdocument.h"
 #include "documentcontroller.h"
-#include "assistantpopup.h"
-#include <kactioncollection.h>
 #include <ktexteditor/view.h>
 #include "workingsetcontroller.h"
 #include "workingsets/workingset.h"
+#include "settings/bgpreferences.h"
+#include "settings/languagepreferences.h"
+#include "settings/environmentpreferences.h"
+#include "settings/pluginpreferences.h"
+#include "settings/projectpreferences.h"
+#include "settings/sourceformattersettings.h"
+#include "settings/uipreferences.h"
+#include "settings/templateconfig.h"
 
 namespace KDevelop {
 
@@ -65,6 +71,8 @@ public:
         if (Core::self()->workingSetControllerInternal())
             Core::self()->workingSetControllerInternal()->initializeController(m_controller);
 
+        m_controller->connect(m_controller, &Sublime::Controller::mainWindowAdded, m_controller, &UiController::mainWindowAdded);
+
         QMap<QString, Sublime::Position> desired;
 
         desired["org.kdevelop.ClassBrowserView"] = Sublime::Left;
@@ -97,13 +105,13 @@ public:
         desired.clear();
         desired["org.kdevelop.ProjectsView"] = Sublime::Left;
         desired["org.kdevelop.PatchReview"] = Sublime::Bottom;
-        
+
         a = new Sublime::Area(m_controller, "review", i18n("Review"));
         a->setDesiredToolViews(desired);
         a->setIconName("applications-engineering");
         m_controller->addDefaultArea(a);
 
-        if(!(Core::self()->setupFlags() & Core::NoUi)) 
+        if(!(Core::self()->setupFlags() & Core::NoUi))
         {
             defaultMainWindow = new MainWindow(m_controller);
             m_controller->addMainWindow(defaultMainWindow);
@@ -130,15 +138,15 @@ public:
     }
 
     Core *core;
-    MainWindow* defaultMainWindow;
+    QPointer<MainWindow> defaultMainWindow;
 
     QMap<IToolViewFactory*, Sublime::ToolDocument*> factoryDocuments;
 
-    Sublime::MainWindow* activeSublimeWindow;
+    QPointer<Sublime::MainWindow> activeSublimeWindow;
     bool areasRestored;
 
-    //Currently shown assistant popup.
-    QPointer<AssistantPopup> currentShownAssistant;
+    /// QWidget implementing IToolViewActionListener interface, or null
+    QPointer<QWidget> activeActionListener;
     QTimer m_assistantTimer;
 
 private:
@@ -150,23 +158,23 @@ class UiToolViewFactory: public Sublime::ToolFactory {
 public:
     UiToolViewFactory(IToolViewFactory *factory): m_factory(factory) {}
     ~UiToolViewFactory() { delete m_factory; }
-    virtual QWidget* create(Sublime::ToolDocument *doc, QWidget *parent = 0)
+    virtual QWidget* create(Sublime::ToolDocument *doc, QWidget *parent = 0) override
     {
         Q_UNUSED( doc );
         return m_factory->create(parent);
     }
 
-    virtual QList< QAction* > contextMenuActions(QWidget* viewWidget) const
+    virtual QList< QAction* > contextMenuActions(QWidget* viewWidget) const override
     {
         return m_factory->contextMenuActions( viewWidget );
     }
 
-    QList<QAction*> toolBarActions( QWidget* viewWidget ) const
+    QList<QAction*> toolBarActions( QWidget* viewWidget ) const override
     {
         return m_factory->toolBarActions( viewWidget );
     }
 
-    QString id() const { return m_factory->id(); }
+    QString id() const override { return m_factory->id(); }
 private:
     IToolViewFactory *m_factory;
 };
@@ -187,7 +195,7 @@ public:
     NewToolViewListWidget(MainWindow *mw, QWidget* parent = 0)
         :QListWidget(parent), m_mw(mw)
     {
-        connect(this, SIGNAL(doubleClicked(QModelIndex)), this, SLOT(addNewToolViewByDoubleClick(QModelIndex)));
+        connect(this, &NewToolViewListWidget::doubleClicked, this, &NewToolViewListWidget::addNewToolViewByDoubleClick);
     }
 
 Q_SIGNALS:
@@ -206,7 +214,6 @@ private:
     MainWindow *m_mw;
 };
 
-
 UiController::UiController(Core *core)
     :Sublime::Controller(0), IUiController(), d(new UiControllerPrivate(this))
 {
@@ -216,9 +223,8 @@ UiController::UiController(Core *core)
     if (!defaultMainWindow() || (Core::self()->setupFlags() & Core::NoUi))
         return;
 
-    connect( QApplication::instance(),
-             SIGNAL(focusChanged(QWidget*,QWidget*)),
-            this, SLOT(widgetChanged(QWidget*,QWidget*)) );
+    connect(qApp, &QApplication::focusChanged,
+            this, [&] (QWidget* old, QWidget* now) { d->widgetChanged(old, now); } );
 
     setupActions();
 }
@@ -232,13 +238,10 @@ void UiController::setupActions()
 {
 }
 
-void UiController::mainWindowDeleted(MainWindow* mw)
+void UiController::mainWindowAdded(Sublime::MainWindow* mainWindow)
 {
-    if (d->defaultMainWindow == mw)
-        d->defaultMainWindow = 0L;
-
-    if (d->activeSublimeWindow == mw)
-        d->activeSublimeWindow = 0L;
+    connect(mainWindow, &MainWindow::activeToolViewChanged, this, &UiController::slotActiveToolViewChanged);
+    connect(mainWindow, &MainWindow::areaChanged, this, &UiController::slotAreaChanged); // also check after area reconstruction
 }
 
 // FIXME: currently, this always create new window. Probably,
@@ -251,13 +254,6 @@ void UiController::switchToArea(const QString &areaName, SwitchMode switchMode)
     }
 
     MainWindow *main = new MainWindow(this);
-    // FIXME: what this is supposed to do?
-    // Answer: Its notifying the mainwindow to reload its settings when one of
-    // the KCM's changes its settings and it works
-    KSettings::Dispatcher::registerComponent( KGlobal::mainComponent(),
-                                    main, "loadSettings" );
-    KSettings::Dispatcher::registerComponent( Core::self()->componentData(),
-                                    main, "loadSettings" );
 
     addMainWindow(main);
     showArea(areaName, main);
@@ -292,20 +288,21 @@ QWidget* UiController::findToolView(const QString& name, IToolViewFactory *facto
             return view->widget();
         }
     }
-    
+
     QWidget* ret = 0;
-    
+
     if(flags & Create)
     {
-        if(!d->factoryDocuments.contains(factory))
-            d->factoryDocuments[factory] = new Sublime::ToolDocument(name, this, new UiToolViewFactory(factory));
-        
-        Sublime::ToolDocument *doc = d->factoryDocuments[factory];
+        Sublime::ToolDocument* doc = d->factoryDocuments.value(factory);
+        if(!doc) {
+            doc = new Sublime::ToolDocument(name, this, new UiToolViewFactory(factory));
+            d->factoryDocuments.insert(factory, doc);
+        }
 
         Sublime::View* view = addToolViewToArea(factory, doc, activeArea());
         if(view)
             ret = view->widget();
-        
+
         if(flags & Raise)
             findToolView(name, factory, Raise);
     }
@@ -329,7 +326,10 @@ void UiController::raiseToolView(QWidget* toolViewWidget)
 
 void UiController::addToolView(const QString & name, IToolViewFactory *factory)
 {
-    kDebug() ;
+    if (!factory)
+        return;
+
+    qCDebug(SHELL) ;
     Sublime::ToolDocument *doc = new Sublime::ToolDocument(name, this, new UiToolViewFactory(factory));
     d->factoryDocuments[factory] = doc;
 
@@ -348,13 +348,46 @@ void KDevelop::UiController::raiseToolView(Sublime::View * view)
         if( area->toolViews().contains( view ) )
             area->raiseToolView( view );
     }
+
+    slotActiveToolViewChanged(view);
+}
+
+void UiController::slotAreaChanged(Sublime::Area*)
+{
+    // this slot gets call if an area in *any* MainWindow changed
+    // so let's first get the "active area"
+    const auto area = activeSublimeWindow()->area();
+    if (area) {
+        // walk through shown tool views and maku sure the
+        const auto shownIds = area->shownToolViews(Sublime::AllPositions);
+        foreach (Sublime::View* toolView, area->toolViews()) {
+            if (shownIds.contains(toolView->document()->documentSpecifier())) {
+                slotActiveToolViewChanged(toolView);
+            }
+        }
+    }
+}
+
+void UiController::slotActiveToolViewChanged(Sublime::View* view)
+{
+    if (!view) {
+        return;
+    }
+
+    // record the last active tool view action listener
+    if (qobject_cast<IToolViewActionListener*>(view->widget())) {
+        d->activeActionListener = view->widget();
+    }
 }
 
 void KDevelop::UiController::removeToolView(IToolViewFactory *factory)
 {
-    kDebug() ;
+    if (!factory)
+        return;
+
+    qCDebug(SHELL) ;
     //delete the tooldocument
-    Sublime::ToolDocument *doc = d->factoryDocuments[factory];
+    Sublime::ToolDocument *doc = d->factoryDocuments.value(factory);
 
     ///@todo adymo: on document deletion all its views shall be also deleted
     foreach (Sublime::View *view, doc->views()) {
@@ -390,20 +423,24 @@ void UiController::initialize()
     defaultMainWindow()->initialize();
 }
 
+
 void UiController::cleanup()
 {
     foreach (Sublime::MainWindow* w, mainWindows())
         w->saveSettings();
-    saveAllAreas(KGlobal::config());
+    saveAllAreas(KSharedConfig::openConfig());
 }
 
 void UiController::selectNewToolViewToAdd(MainWindow *mw)
 {
     if (!mw || !mw->area())
         return;
-    KDialog *dia = new KDialog(mw);
-    dia->setCaption(i18n("Select Tool View to Add"));
-    dia->setButtons(KDialog::Ok | KDialog::Cancel);
+
+    QDialog *dia = new QDialog(mw);
+    dia->setWindowTitle(i18n("Select Tool View to Add"));
+
+    auto mainLayout = new QVBoxLayout(dia);
+
     NewToolViewListWidget *list = new NewToolViewListWidget(mw, dia);
 
     list->setSelectionMode(QAbstractItemView::ExtendedSelection);
@@ -421,8 +458,17 @@ void UiController::selectNewToolViewToAdd(MainWindow *mw)
     }
 
     list->setFocus();
-    connect(list, SIGNAL(addNewToolView(MainWindow*,QListWidgetItem*)), this, SLOT(addNewToolView(MainWindow*,QListWidgetItem*)));
-    dia->setMainWidget(list);
+    connect(list, &NewToolViewListWidget::addNewToolView, this, &UiController::addNewToolView);
+    mainLayout->addWidget(list);
+
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
+    auto okButton = buttonBox->button(QDialogButtonBox::Ok);
+    okButton->setDefault(true);
+    okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+    dia->connect(buttonBox, &QDialogButtonBox::accepted, dia, &QDialog::accept);
+    dia->connect(buttonBox, &QDialogButtonBox::rejected, dia, &QDialog::reject);
+    mainLayout->addWidget(buttonBox);
+
     if (dia->exec() == QDialog::Accepted)
     {
         foreach (QListWidgetItem* item, list->selectedItems())
@@ -445,17 +491,44 @@ void UiController::addNewToolView(MainWindow *mw, QListWidgetItem* item)
 
 void UiController::showSettingsDialog()
 {
-    QStringList blacklist = d->core->pluginControllerInternal()->projectPlugins();
-    foreach(const KPluginInfo& info, d->core->pluginControllerInternal()->allPluginInfos()) {
-        if (!blacklist.contains(info.pluginName()) && !info.isPluginEnabled()) {
-            blacklist << info.pluginName();
+    auto editorConfigPage = new EditorConfigPage(activeMainWindow());
+    auto languageConfigPage = new LanguagePreferences(activeMainWindow());
+
+    auto configPages = QVector<KDevelop::ConfigPage*> {
+        new UiPreferences(activeMainWindow()),
+        new PluginPreferences(activeMainWindow()),
+        new SourceFormatterSettings(activeMainWindow()),
+        new ProjectPreferences(activeMainWindow()),
+        new EnvironmentPreferences(QString(), activeMainWindow()),
+        new BGPreferences(activeMainWindow()),
+        new TemplateConfig(activeMainWindow()),
+        editorConfigPage
+    };
+
+    ConfigDialog cfgDlg(configPages, activeMainWindow());
+
+    auto addPluginPages = [&](IPlugin* plugin) {
+        for (int i = 0, numPages = plugin->configPages(); i < numPages; ++i) {
+            auto page = plugin->configPage(i, &cfgDlg);
+            if(page && page->configPageType() == ConfigPage::LanguageConfigPage){
+                cfgDlg.addSubConfigPage(languageConfigPage, page);
+            } else {
+                // insert them before the editor config page
+                cfgDlg.addConfigPage(page, editorConfigPage);
+            }
         }
+    };
+
+    cfgDlg.addConfigPage(languageConfigPage, configPages[5]);
+
+    for (IPlugin* plugin : ICore::self()->pluginController()->loadedPlugins()) {
+        addPluginPages(plugin);
     }
-    kDebug() << "blacklist" << blacklist;
-    KSettings::Dialog cfgDlg( QStringList() << "kdevplatform",
-                                        activeMainWindow() );
-    cfgDlg.setMinimumSize( 550, 300 );
-    cfgDlg.setComponentBlacklist( blacklist );
+    // TODO: only load settings if a UI related page was changed?
+    connect(&cfgDlg, &ConfigDialog::configSaved, activeSublimeWindow(), &Sublime::MainWindow::loadSettings);
+    // make sure that pages get added whenever a new plugin is loaded (probably from the plugin selection dialog)
+    // removal on plugin unload is already handled in ConfigDialog
+    connect(ICore::self()->pluginController(), &IPluginController::pluginLoaded, &cfgDlg, addPluginPages);
     cfgDlg.exec();
 }
 
@@ -466,7 +539,7 @@ Sublime::Controller* UiController::controller()
 
 KParts::MainWindow *UiController::activeMainWindow()
 {
-    return (KParts::MainWindow*)(activeSublimeWindow());
+    return activeSublimeWindow();
 }
 
 void UiController::saveArea(Sublime::Area * area, KConfigGroup & group)
@@ -488,7 +561,7 @@ void UiController::loadArea(Sublime::Area * area, const KConfigGroup & group)
     }
 }
 
-void UiController::saveAllAreas(KSharedConfig::Ptr config)
+void UiController::saveAllAreas(KSharedConfigPtr config)
 {
     KConfigGroup uiConfig(config, "User Interface");
     int wc = mainWindows().size();
@@ -496,7 +569,7 @@ void UiController::saveAllAreas(KSharedConfig::Ptr config)
     for (int w = 0; w < wc; ++w)
     {
         KConfigGroup mainWindowConfig(&uiConfig,
-                                      QString("Main Window %1").arg(w));
+                                      QStringLiteral("Main Window %1").arg(w));
 
         foreach (Sublime::Area* defaultArea, defaultAreas())
         {
@@ -514,7 +587,7 @@ void UiController::saveAllAreas(KSharedConfig::Ptr config)
     uiConfig.sync();
 }
 
-void UiController::loadAllAreas(KSharedConfig::Ptr config)
+void UiController::loadAllAreas(KSharedConfigPtr config)
 {
     KConfigGroup uiConfig(config, "User Interface");
     int wc = uiConfig.readEntry("Main Windows Count", 1);
@@ -541,8 +614,8 @@ void UiController::loadAllAreas(KSharedConfig::Ptr config)
     for (int w = 0; w < wc; ++w)
     {
         KConfigGroup mainWindowConfig(&uiConfig,
-                                      QString("Main Window %1").arg(w));
-        
+                                      QStringLiteral("Main Window %1").arg(w));
+
         Sublime::MainWindow *mw = mainWindows()[w];
 
         /* We loop over default areas.  This means that if
@@ -558,14 +631,14 @@ void UiController::loadAllAreas(KSharedConfig::Ptr config)
 
             KConfigGroup areaConfig(&mainWindowConfig, "Area " + type);
 
-            kDebug() << "Trying to restore area " << type;
+            qCDebug(SHELL) << "Trying to restore area " << type;
 
             /* This is just an easy check that a group exists, to
                avoid "restoring" area from empty config group, wiping
                away programmatically installed defaults.  */
             if (areaConfig.readEntry("id", "") == type)
             {
-                kDebug() << "Restoring area " << type;
+                qCDebug(SHELL) << "Restoring area " << type;
                 loadArea(area, areaConfig);
             }
 
@@ -590,7 +663,7 @@ void UiController::loadAllAreas(KSharedConfig::Ptr config)
 
 void UiController::addToolViewToDockArea(IToolViewFactory* factory, Qt::DockWidgetArea area)
 {
-    addToolViewToArea(factory, d->factoryDocuments[factory], activeArea(), Sublime::dockAreaToPosition(area));
+    addToolViewToArea(factory, d->factoryDocuments.value(factory), activeArea(), Sublime::dockAreaToPosition(area));
 }
 
 bool UiController::toolViewPresent(Sublime::ToolDocument* doc, Sublime::Area* area)
@@ -621,8 +694,8 @@ Sublime::View* UiController::addToolViewToArea(IToolViewFactory* factory,
         view,
         p == Sublime::AllPositions ? Sublime::dockAreaToPosition(factory->defaultPosition()) : p);
 
-    connect(view, SIGNAL(raise(Sublime::View*)),
-            SLOT(raiseToolView(Sublime::View*)));
+    connect(view, &Sublime::View::raise,
+            this, static_cast<void(UiController::*)(Sublime::View*)>(&UiController::raiseToolView));
 
     factory->viewCreated(view);
     return view;
@@ -646,73 +719,22 @@ void UiController::showErrorMessage(const QString& message, int timeout)
     QMetaObject::invokeMethod(mw, "showErrorMessage", Q_ARG(QString, message), Q_ARG(int, timeout));
 }
 
-void UiController::hideAssistant()
-{
-    if(d->currentShownAssistant) {
-        disconnect(d->currentShownAssistant->assistant().data(), SIGNAL(hide()), this, SLOT(assistantHide()));
-        disconnect(d->currentShownAssistant->assistant().data(), SIGNAL(actionsChanged()), this, SLOT(assistantActionsChanged()));
-        
-        Sublime::HoldUpdates hold(ICore::self()->uiController()->activeMainWindow());
-        d->currentShownAssistant->hide();
-    }
-}
-
-void UiController::popUpAssistant(const KDevelop::IAssistant::Ptr& assistant)
-{
-    if(!assistant)
-        return;
-
-    Sublime::View* view = d->activeSublimeWindow->activeView();
-    if( !view )
-    {
-        kDebug() << "no active view in mainwindow";
-        return;
-    }
-    TextEditorWidget* textWidget = dynamic_cast<TextEditorWidget*>(view->widget());
-    bool wasVisible = d->currentShownAssistant && d->currentShownAssistant->isVisible();
-    if(textWidget && textWidget->editorView()) {
-        if ( ! d->currentShownAssistant ) {
-            d->currentShownAssistant = new AssistantPopup(textWidget->editorView(), assistant);
-        } else {
-            d->currentShownAssistant->reset(textWidget->editorView(), assistant);
-        }
-        if(assistant->actions().count() && !wasVisible) {
-            Sublime::HoldUpdates hold(ICore::self()->uiController()->activeMainWindow());
-            // stop any pending hide actions
-            d->m_assistantTimer.stop();
-            d->currentShownAssistant->show();
-        }
-
-        connect(assistant.data(), SIGNAL(hide()), SLOT(assistantHide()), Qt::UniqueConnection);
-        connect(assistant.data(), SIGNAL(actionsChanged()), SLOT(assistantActionsChanged()), Qt::UniqueConnection);
-    }
-    if( d->currentShownAssistant ) {
-        // when the assistant was still open, avoid flickering
-        d->currentShownAssistant->notifyReopened(wasVisible);
-        d->m_assistantTimer.stop();
-    }
-}
-
 const QMap< IToolViewFactory*, Sublime::ToolDocument* >& UiController::factoryDocuments() const
 {
     return d->factoryDocuments;
 }
 
-void UiController::assistantHide() {
-    if(d->currentShownAssistant) {
-        connect(&d->m_assistantTimer, SIGNAL(timeout()), SLOT(hideAssistant()), Qt::UniqueConnection);
-        d->m_assistantTimer.start();
-    }
+QWidget* UiController::activeToolViewActionListener() const
+{
+    return d->activeActionListener;
 }
 
-void UiController::assistantActionsChanged() {
-    if(d->currentShownAssistant) {
-        popUpAssistant(d->currentShownAssistant->assistant());
-    }
+QList<Sublime::Area*> UiController::allAreas() const
+{
+    return Sublime::Controller::allAreas();
 }
 
 }
 
-
 #include "uicontroller.moc"
 #include "moc_uicontroller.cpp"
