@@ -38,6 +38,7 @@
 #include "workingsets/workingsetwidget.h"
 #include "workingsets/closedworkingsetswidget.h"
 #include "core.h"
+#include "debug.h"
 
 using namespace KDevelop;
 
@@ -83,9 +84,9 @@ void WorkingSetController::cleanup()
     }
 
     foreach(WorkingSet* set, m_workingSets) {
-        kDebug() << "set" << set->id() << "persistent" << set->isPersistent() << "has areas:" << set->hasConnectedAreas() << "files" << set->fileList();
+        qCDebug(SHELL) << "set" << set->id() << "persistent" << set->isPersistent() << "has areas:" << set->hasConnectedAreas() << "files" << set->fileList();
         if(!set->isPersistent() && !set->hasConnectedAreas()) {
-            kDebug() << "deleting";
+            qCDebug(SHELL) << "deleting";
             set->deleteSet(true, true);
         }
         delete set;
@@ -102,7 +103,7 @@ const QString WorkingSetController::makeSetId(const QString& prefix) const
     QString newId;
     const uint maxRetries = 10;
     for(uint retry = 2; retry <= maxRetries; retry++) {
-        newId = QString("%1_%2").arg(prefix).arg(qrand() % 10000000);
+        newId = QStringLiteral("%1_%2").arg(prefix).arg(qrand() % 10000000);
         WorkingSetIconParameters params(newId);
         foreach(WorkingSet* set, m_workingSets) {
             if(set->isEmpty()) {
@@ -123,7 +124,6 @@ const QString WorkingSetController::makeSetId(const QString& prefix) const
 
 WorkingSet* WorkingSetController::newWorkingSet(const QString& prefix)
 {
-
     return getWorkingSet(makeSetId(prefix));
 }
 
@@ -131,11 +131,11 @@ WorkingSet* WorkingSetController::getWorkingSet(const QString& id)
 {
     if(id.isEmpty())
         return m_emptyWorkingSet;
-    
+
     if(!m_workingSets.contains(id)) {
         WorkingSet* set = new WorkingSet(id);
-        connect(set, SIGNAL(aboutToRemove(WorkingSet*)),
-                this, SIGNAL(aboutToRemoveWorkingSet(WorkingSet*)));
+        connect(set, &WorkingSet::aboutToRemove,
+                this, &WorkingSetController::aboutToRemoveWorkingSet);
         m_workingSets[id] = set;
         emit workingSetAdded(set);
     }
@@ -157,11 +157,11 @@ void WorkingSetController::setupActions()
     KActionCollection * ac =
         Core::self()->uiControllerInternal()->defaultMainWindow()->actionCollection();
 
-    KAction *action;
+    QAction* action;
 
     action = ac->addAction ( "view_next_window" );
     action->setText( i18n( "Next Document" ) );
-    action->setIcon( KIcon("go-next") );
+    action->setIcon( QIcon::fromTheme("go-next") );
     action->setShortcut( Qt::ALT + Qt::SHIFT + Qt::Key_Right );
     action->setWhatsThis( i18n( "Switch the focus to the next open document." ) );
     action->setStatusTip( i18n( "Switch the focus to the next open document." ) );
@@ -169,7 +169,7 @@ void WorkingSetController::setupActions()
 
     action = ac->addAction ( "view_previous_window" );
     action->setText( i18n( "Previous Document" ) );
-    action->setIcon( KIcon("go-previous") );
+    action->setIcon( QIcon::fromTheme("go-previous") );
     action->setShortcut( Qt::ALT + Qt::SHIFT + Qt::Key_Left );
     action->setWhatsThis( i18n( "Switch the focus to the previous open document." ) );
     action->setStatusTip( i18n( "Switch the focus to the previous open document." ) );
@@ -195,7 +195,7 @@ void WorkingSetController::showToolTip(WorkingSet* set, const QPoint& pos)
     layout->addWidget(widget);
     m_tooltip->resize( m_tooltip->sizeHint() );
 
-    connect(widget, SIGNAL(shouldClose()), m_tooltip, SLOT(close()));
+    connect(widget, &WorkingSetToolTipWidget::shouldClose, m_tooltip.data(), &ActiveToolTip::close);
 
     ActiveToolTip::showToolTip(m_tooltip);
 }
@@ -207,10 +207,10 @@ void WorkingSetController::showGlobalToolTip()
     showToolTip(getWorkingSet(window->area()->workingSet()),
                               window->mapToGlobal(window->geometry().topRight()));
 
-    connect(m_hideToolTipTimer, SIGNAL(timeout()),  m_tooltip, SLOT(deleteLater()));
+    connect(m_hideToolTipTimer, &QTimer::timeout,  m_tooltip.data(), &ActiveToolTip::deleteLater);
     m_hideToolTipTimer->start();
-    connect(m_tooltip, SIGNAL(mouseIn()), m_hideToolTipTimer, SLOT(stop()));
-    connect(m_tooltip, SIGNAL(mouseOut()), m_hideToolTipTimer, SLOT(start()));
+    connect(m_tooltip.data(), &ActiveToolTip::mouseIn, m_hideToolTipTimer, &QTimer::stop);
+    connect(m_tooltip.data(), &ActiveToolTip::mouseOut, m_hideToolTipTimer, static_cast<void(QTimer::*)()>(&QTimer::start));
 }
 
 void WorkingSetController::nextDocument()
@@ -247,7 +247,7 @@ void WorkingSetController::previousDocument()
 
 void WorkingSetController::initializeController( UiController* controller )
 {
-  connect( controller, SIGNAL(areaCreated(Sublime::Area*)), this, SLOT(areaCreated(Sublime::Area*)) );
+  connect( controller, &UiController::areaCreated, this, &WorkingSetController::areaCreated );
 }
 
 QList< WorkingSet* > WorkingSetController::allWorkingSets() const
@@ -262,17 +262,19 @@ void WorkingSetController::areaCreated( Sublime::Area* area )
         set->connectArea( area );
     }
 
-    connect(area, SIGNAL(changingWorkingSet(Sublime::Area*,QString,QString)),
-            this, SLOT(changingWorkingSet(Sublime::Area*,QString,QString)));
-    connect(area, SIGNAL(changedWorkingSet(Sublime::Area*,QString,QString)),
-            this, SLOT(changedWorkingSet(Sublime::Area*,QString,QString)));
-    connect(area, SIGNAL(viewAdded(Sublime::AreaIndex*,Sublime::View*)),
-            this, SLOT(viewAdded(Sublime::AreaIndex*,Sublime::View*)));
+    connect(area, &Sublime::Area::changingWorkingSet,
+            this, &WorkingSetController::changingWorkingSet);
+    connect(area, &Sublime::Area::changedWorkingSet,
+            this, &WorkingSetController::changedWorkingSet);
+    connect(area, &Sublime::Area::viewAdded,
+            this, &WorkingSetController::viewAdded);
+    connect(area, &Sublime::Area::clearWorkingSet,
+            this, &WorkingSetController::clearWorkingSet);
 }
 
 void WorkingSetController::changingWorkingSet(Sublime::Area* area, const QString& from, const QString& to)
 {
-    kDebug() << "changing working-set from" << from << "to" << to << "area" << area;
+    qCDebug(SHELL) << "changing working-set from" << from << "to" << to << "area" << area;
     if (from == to)
         return;
 
@@ -287,10 +289,10 @@ void WorkingSetController::changingWorkingSet(Sublime::Area* area, const QString
 
 void WorkingSetController::changedWorkingSet(Sublime::Area* area, const QString& from, const QString& to)
 {
-    kDebug() << "changed working-set from" << from << "to" << to << "area" << area;
+    qCDebug(SHELL) << "changed working-set from" << from << "to" << to << "area" << area;
     if (from == to || m_changingWorkingSet)
         return;
-    
+
     if (!to.isEmpty()) {
         WorkingSet* newSet = getWorkingSet(to);
         newSet->connectArea(area);
@@ -312,7 +314,7 @@ void WorkingSetController::viewAdded( Sublime::AreaIndex* , Sublime::View* )
         //Spawn a new working-set
         m_changingWorkingSet = true;
         WorkingSet* set = Core::self()->workingSetControllerInternal()->newWorkingSet(area->objectName());
-        kDebug() << "Spawned new working-set" << set->id() << "because a view was added";
+        qCDebug(SHELL) << "Spawned new working-set" << set->id() << "because a view was added";
         set->connectArea(area);
         set->saveFromArea(area, area->rootIndex());
         area->setWorkingSet(set->id());
@@ -320,5 +322,19 @@ void WorkingSetController::viewAdded( Sublime::AreaIndex* , Sublime::View* )
     }
 }
 
+void WorkingSetController::clearWorkingSet(Sublime::Area * area)
+{
+    const QString workingSet = area->workingSet();
+    if (workingSet.isEmpty()) {
+        // Nothing to do - area has no working set
+        return;
+    }
 
-#include "workingsetcontroller.moc"
+    WorkingSet* set = getWorkingSet(workingSet);
+    set->deleteSet(true);
+
+    WorkingSet* newSet = getWorkingSet(workingSet);
+    newSet->connectArea(area);
+    newSet->loadToArea(area, area->rootIndex());
+    Q_ASSERT(newSet->fileList().isEmpty());
+}
