@@ -17,14 +17,16 @@
 */
 
 #include "workingset.h"
+#include "../debug.h"
 
 #include <sublime/area.h>
 #include <sublime/mainwindow.h>
 
-#include <KTextEditor/Document>
-#include <KColorUtils>
-
 #include <QApplication>
+#include <QPainter>
+
+#include <KProtocolInfo>
+#include <KTextEditor/Document>
 
 #include <textdocument.h>
 #include <core.h>
@@ -42,21 +44,16 @@ bool WorkingSet::m_loading = false;
 
 namespace {
 
-QIcon generateIcon(const QString& id)
+QIcon generateIcon(const WorkingSetIconParameters& params)
 {
     QImage pixmap(16, 16, QImage::Format_ARGB32);
     // fill the background with a transparent color
     pixmap.fill(QColor::fromRgba(qRgba(0, 0, 0, 0)));
-    // calculate layout and colors depending on the working set ID
-    // modulo it so it's around 2^28, leaving some space before uint overflows
-    const uint setId = qHash(id) % 268435459;
-    // amount of colored squares in this icon (the rest is grey or whatever you set as default color)
-    // use 4-6-4-1 weighting for 1, 2, 3, 4 squares, because that's the number of arrangements for each
-    const uint coloredCount = (setId % 15 < 4) ? 1 : (setId % 15 < 10) ? 2 : (setId % 15 == 14) ? 4 : 3;
+    const uint coloredCount = params.coloredCount;
     // coordinates of the rectangles to draw, for 16x16 icons specifically
     QList<QRect> rects;
     rects << QRect(1, 1, 5, 5) << QRect(1, 9, 5, 5) << QRect(9, 1, 5, 5) << QRect(9, 9, 5, 5);
-    if ( setId % 31 < 16 ) {
+    if ( params.swapDiagonal ) {
         rects.swap(1, 2);
     }
 
@@ -67,31 +64,31 @@ QIcon generateIcon(const QString& id)
     // color for colored squares
     // this code is not fragile, you can just tune the magic formulas at random and see what looks good.
     // just make sure to keep it within the 0-360 / 0-255 / 0-255 space of the HSV model
-    QColor brightColor = QColor::fromHsv((setId % 273 * 81) % 360, qMin<uint>(255, 215 + (setId*5) % 150),
-                                         205 + (setId*11) % 50);
+    QColor brightColor = QColor::fromHsv(params.hue, qMin<uint>(255, 215 + (params.setId*5) % 150),
+                                         205 + (params.setId*11) % 50);
     // Y'UV "Y" value, the approximate "lightness" of the color
     // If it is above 0.6, then making the color darker a bit is okay,
     // if it is below 0.35, then the color should be a bit brighter.
     float brightY = 0.299 * brightColor.redF() + 0.587 * brightColor.greenF() + 0.114 * brightColor.blueF();
     if ( brightY > 0.6 ) {
-        if ( setId % 7 < 2 ) {
+        if ( params.setId % 7 < 2 ) {
             // 2/7 chance to make the color significantly darker
-            brightColor = brightColor.darker(120 + (setId*7) % 35);
+            brightColor = brightColor.darker(120 + (params.setId*7) % 35);
         }
-        else if ( setId % 5 == 0 ) {
+        else if ( params.setId % 5 == 0 ) {
             // 1/5 chance to make it a bit darker
-            brightColor = brightColor.darker(110 + (setId*3) % 10);
+            brightColor = brightColor.darker(110 + (params.setId*3) % 10);
         }
     }
     if ( brightY < 0.35 ) {
         // always make the color brighter to avoid very dark colors (like rgb(0, 0, 255))
-        brightColor = brightColor.lighter(120 + (setId*13) % 55);
+        brightColor = brightColor.lighter(120 + (params.setId*13) % 55);
     }
     int at = 0;
     foreach ( const QRect& rect, rects ) {
         QColor currentColor;
         // pick the colored squares; you can get different patterns by re-ordering the "rects" list
-        if ( (at + setId*7) % 4 < coloredCount ) {
+        if ( (at + params.setId*7) % 4 < coloredCount ) {
             currentColor = brightColor;
         }
         else {
@@ -141,11 +138,17 @@ void WorkingSet::saveFromArea( Sublime::Area* a, Sublime::AreaIndex * area, KCon
         foreach (Sublime::View* view, area->views()) {
             //The working set config gets an updated list of files
             QString docSpec = view->document()->documentSpecifier();
-            setGroup.writeEntry(QString("View %1").arg(index), docSpec);
-            setGroup.writeEntry(QString("View %1 Type").arg(index), view->document()->documentType());
+
+            //only save the documents from protocols KIO understands
+            //otherwise we try to load kdev:// too early
+            if (!KProtocolInfo::isKnownProtocol(QUrl(docSpec))) {
+                continue;
+            }
+
+            setGroup.writeEntry(QStringLiteral("View %1").arg(index), docSpec);
             //The area specific config stores the working set documents in order along with their state
-            areaGroup.writeEntry(QString("View %1").arg(index), docSpec);
-            areaGroup.writeEntry(QString("View %1 State").arg(index), view->viewState());
+            areaGroup.writeEntry(QStringLiteral("View %1").arg(index), docSpec);
+            areaGroup.writeEntry(QStringLiteral("View %1 State").arg(index), view->viewState());
             ++index;
         }
     }
@@ -204,11 +207,9 @@ void loadFileList(QStringList& ret, KConfigGroup group)
         }
 
     } else {
-
         int viewCount = group.readEntry("View Count", 0);
         for (int i = 0; i < viewCount; ++i) {
-            QString type = group.readEntry(QString("View %1 Type").arg(i), "");
-            QString specifier = group.readEntry(QString("View %1").arg(i), "");
+            QString specifier = group.readEntry(QStringLiteral("View %1").arg(i), QString());
 
             ret << specifier;
         }
@@ -234,15 +235,15 @@ void WorkingSet::loadToArea(Sublime::Area* area, Sublime::AreaIndex* areaIndex)
     /// split-view configurations and switching between them. Re-enabling the updates doesn't help.
 //     DisableMainWindowUpdatesFromArea updatesDisabler(area);
 
-    kDebug() << "loading working-set" << m_id << "into area" << area;
-    
+    qCDebug(SHELL) << "loading working-set" << m_id << "into area" << area;
+
     QMultiMap<QString, Sublime::View*> recycle;
-    
+
     foreach( Sublime::View* view, area->views() )
         recycle.insert( view->document()->documentSpecifier(), area->removeView(view) );
-    
-    kDebug() << "recycling" << recycle.size() << "old views";
-    
+
+    qCDebug(SHELL) << "recycling" << recycle.size() << "old views";
+
     Q_ASSERT( area->views().empty() );
 
     KConfigGroup setConfig(Core::self()->activeSession()->config(), "Working File Sets");
@@ -250,13 +251,13 @@ void WorkingSet::loadToArea(Sublime::Area* area, Sublime::AreaIndex* areaIndex)
     KConfigGroup areaGroup = setConfig.group(m_id + '|' + area->title());
 
     loadToArea(area, areaIndex, setGroup, areaGroup, recycle);
-    
+
     // Delete views which were not recycled
-    kDebug() << "deleting " << recycle.size() << " old views";
+    qCDebug(SHELL) << "deleting " << recycle.size() << " old views";
     qDeleteAll( recycle.values() );
-    
+
     area->setActiveView(0);
-    
+
     //activate view in the working set
     /// @todo correctly select one out of multiple equal views
     QString activeView = areaGroup.readEntry("Active View", QString());
@@ -266,10 +267,10 @@ void WorkingSet::loadToArea(Sublime::Area* area, Sublime::AreaIndex* areaIndex)
             break;
         }
     }
-    
+
     if( !area->activeView() && area->views().size() )
         area->setActiveView( area->views()[0] );
-    
+
     if( area->activeView() ) {
         foreach(Sublime::MainWindow* window, Core::self()->uiControllerInternal()->mainWindows()) {
                 if(window->area() == area) {
@@ -287,7 +288,7 @@ void WorkingSet::loadToArea(Sublime::Area* area, Sublime::AreaIndex* areaIndex,
         /// @todo also save and restore the ratio
 
         if (subgroups.contains("0") && subgroups.contains("1")) {
-//             kDebug() << "has zero, split:" << split;
+//             qCDebug(SHELL) << "has zero, split:" << split;
 
             Qt::Orientation orientation = setGroup.readEntry("Orientation", "Horizontal") == "Vertical" ? Qt::Vertical : Qt::Horizontal;
             if(!areaIndex->isSplit()){
@@ -299,20 +300,22 @@ void WorkingSet::loadToArea(Sublime::Area* area, Sublime::AreaIndex* areaIndex,
             loadToArea(area, areaIndex->first(), KConfigGroup(&setGroup, "0"), KConfigGroup(&areaGroup, "0"), recycle);
 
             loadToArea(area, areaIndex->second(), KConfigGroup(&setGroup, "1"), KConfigGroup(&areaGroup, "1"), recycle);
-            
+
             if( areaIndex->first()->viewCount() == 0 )
                 areaIndex->unsplit(areaIndex->first());
             else if( areaIndex->second()->viewCount() == 0 )
                 areaIndex->unsplit(areaIndex->second());
         }
     } else {
-        
+
         //Load all documents from the workingset into this areaIndex
         int viewCount = setGroup.readEntry("View Count", 0);
         QMap<int, Sublime::View*> createdViews;
         for (int i = 0; i < viewCount; ++i) {
-            QString type = setGroup.readEntry(QString("View %1 Type").arg(i), "");
-            QString specifier = setGroup.readEntry(QString("View %1").arg(i), "");
+            QString specifier = setGroup.readEntry(QStringLiteral("View %1").arg(i), QString());
+            if (specifier.isEmpty()) {
+                continue;
+            }
             Sublime::View* previousView = area->views().empty() ? 0 : area->views().back();
 
             QMultiMap<QString, Sublime::View*>::iterator it = recycle.find( specifier );
@@ -322,8 +325,7 @@ void WorkingSet::loadToArea(Sublime::Area* area, Sublime::AreaIndex* areaIndex,
                 recycle.erase( it );
                 continue;
             }
-            
-            IDocument* doc = Core::self()->documentControllerInternal()->openDocument(specifier,
+            IDocument* doc = Core::self()->documentControllerInternal()->openDocument(QUrl::fromUserInput(specifier),
                              KTextEditor::Cursor::invalid(), IDocumentController::DoNotActivate | IDocumentController::DoNotCreateView);
             Sublime::Document *document = dynamic_cast<Sublime::Document*>(doc);
             if (document) {
@@ -331,14 +333,14 @@ void WorkingSet::loadToArea(Sublime::Area* area, Sublime::AreaIndex* areaIndex,
                 area->addView(view, areaIndex, previousView);
                 createdViews[i] = view;
             } else {
-                kWarning() << "Unable to create view of type " << type;
+                qWarning() << "Unable to create view" << specifier;
             }
         }
-        
+
         //Load state
         for (int i = 0; i < viewCount; ++i)
         {
-            QString state = areaGroup.readEntry(QString("View %1 State").arg(i));
+            QString state = areaGroup.readEntry(QStringLiteral("View %1 State").arg(i));
             if (state.length() && createdViews.contains(i))
                 createdViews[i]->setState(state);
         }
@@ -346,7 +348,7 @@ void WorkingSet::loadToArea(Sublime::Area* area, Sublime::AreaIndex* areaIndex,
 }
 
 void deleteGroupRecursive(KConfigGroup group) {
-//     kDebug() << "deleting" << group.name();
+//     qCDebug(SHELL) << "deleting" << group.name();
     foreach(const QString& entry, group.entryMap().keys()) {
         group.deleteEntry(entry);
     }
@@ -359,10 +361,6 @@ void deleteGroupRecursive(KConfigGroup group) {
     //Why doesn't this work?
 //     Q_ASSERT(group.groupList().isEmpty());
     group.deleteGroup();
-
-#ifdef SYNC_OFTEN
-    group.sync();
-#endif
 }
 
 void WorkingSet::deleteSet(bool force, bool silent)
@@ -384,7 +382,7 @@ void WorkingSet::deleteSet(bool force, bool silent)
 
 void WorkingSet::saveFromArea(Sublime::Area* area, Sublime::AreaIndex* areaIndex)
 {
-    kDebug() << "saving" << m_id << "from area";
+    qCDebug(SHELL) << "saving" << m_id << "from area";
 
     bool wasPersistent = isPersistent();
 
@@ -414,7 +412,7 @@ void WorkingSet::saveFromArea(Sublime::Area* area, Sublime::AreaIndex* areaIndex
 #ifdef SYNC_OFTEN
     setConfig.sync();
 #endif
-    
+
     emit setChangedSignificantly();
 }
 
@@ -423,9 +421,9 @@ void WorkingSet::areaViewAdded(Sublime::AreaIndex*, Sublime::View*) {
     Q_ASSERT(area);
     Q_ASSERT(area->workingSet() == m_id);
 
-    kDebug() << "added view in" << area << ", id" << m_id;
+    qCDebug(SHELL) << "added view in" << area << ", id" << m_id;
     if (m_loading) {
-        kDebug() << "doing nothing because loading";
+        qCDebug(SHELL) << "doing nothing because loading";
         return;
     }
 
@@ -437,12 +435,12 @@ void WorkingSet::areaViewRemoved(Sublime::AreaIndex*, Sublime::View* view) {
     Q_ASSERT(area);
     Q_ASSERT(area->workingSet() == m_id);
 
-    kDebug() << "removed view in" << area << ", id" << m_id;
+    qCDebug(SHELL) << "removed view in" << area << ", id" << m_id;
     if (m_loading) {
-        kDebug() << "doing nothing because loading";
+        qCDebug(SHELL) << "doing nothing because loading";
         return;
     }
-    
+
     foreach(Sublime::Area* otherArea, m_areas)
     {
         if(otherArea == area)
@@ -458,9 +456,9 @@ void WorkingSet::areaViewRemoved(Sublime::AreaIndex*, Sublime::View* view) {
             // one of the connected areas, so the working-set has already recorded the change.
             return;
         }
-        
+
     }
-    
+
     changed(area);
 }
 
@@ -471,7 +469,7 @@ void WorkingSet::setPersistent(bool persistent) {
 #ifdef SYNC_OFTEN
     group.sync();
 #endif
-    kDebug() << "setting" << m_id << "persistent:" << persistent;
+    qCDebug(SHELL) << "setting" << m_id << "persistent:" << persistent;
 }
 
 bool WorkingSet::isPersistent() const {
@@ -513,40 +511,35 @@ bool WorkingSet::hasConnectedAreas( QList< Sublime::Area* > areas ) const
 void WorkingSet::connectArea( Sublime::Area* area )
 {
   if ( m_areas.contains( area ) ) {
-    kDebug() << "tried to double-connect area";
+    qCDebug(SHELL) << "tried to double-connect area";
     return;
   }
 
-  kDebug() << "connecting" << m_id << "to area" << area;
+  qCDebug(SHELL) << "connecting" << m_id << "to area" << area;
 
 //         Q_ASSERT(area->workingSet() == m_id);
 
   m_areas.push_back( area );
-  connect( area, SIGNAL(viewAdded(Sublime::AreaIndex*,Sublime::View*)), this, SLOT(areaViewAdded(Sublime::AreaIndex*,Sublime::View*)) );
-  connect( area, SIGNAL(viewRemoved(Sublime::AreaIndex*,Sublime::View*)), this, SLOT(areaViewRemoved(Sublime::AreaIndex*,Sublime::View*)) );
+  connect( area, &Sublime::Area::viewAdded, this, &WorkingSet::areaViewAdded );
+  connect( area, &Sublime::Area::viewRemoved, this, &WorkingSet::areaViewRemoved );
 }
 
 void WorkingSet::disconnectArea( Sublime::Area* area )
 {
   if ( !m_areas.contains( area ) ) {
-    kDebug() << "tried to disconnect not connected area";
+    qCDebug(SHELL) << "tried to disconnect not connected area";
     return;
   }
 
-  kDebug() << "disconnecting" << m_id << "from area" << area;
+  qCDebug(SHELL) << "disconnecting" << m_id << "from area" << area;
 
 //         Q_ASSERT(area->workingSet() == m_id);
 
-  disconnect( area, SIGNAL(viewAdded(Sublime::AreaIndex*,Sublime::View*)), this, SLOT(areaViewAdded(Sublime::AreaIndex*,Sublime::View*)) );
-  disconnect( area, SIGNAL(viewRemoved(Sublime::AreaIndex*,Sublime::View*)), this, SLOT(areaViewRemoved(Sublime::AreaIndex*,Sublime::View*)) );
+  disconnect( area, &Sublime::Area::viewAdded, this, &WorkingSet::areaViewAdded );
+  disconnect( area, &Sublime::Area::viewRemoved, this, &WorkingSet::areaViewRemoved );
   m_areas.removeAll( area );
 }
 
-void WorkingSet::deleteSet()
-{
-  deleteSet( false );
-}
-
 void WorkingSet::changed( Sublime::Area* area )
 {
   if ( m_loading ) {
@@ -557,7 +550,7 @@ void WorkingSet::changed( Sublime::Area* area )
     //Do not capture changes done while loading
     PushValue<bool> enableLoading( m_loading, true );
 
-    kDebug() << "recording change done to" << m_id;
+    qCDebug(SHELL) << "recording change done to" << m_id;
     saveFromArea( area, area->rootIndex() );
 
     for ( QList< QPointer< Sublime::Area > >::iterator it = m_areas.begin(); it != m_areas.end(); ++it ) {
@@ -570,4 +563,3 @@ void WorkingSet::changed( Sublime::Area* area )
   emit setChangedSignificantly();
 }
 
-#include "workingset.moc"
