@@ -18,68 +18,75 @@
  ***************************************************************************/
 #include "container.h"
 
-#include <QtCore/QMap>
-#include <QtGui/QBoxLayout>
-#include <QtGui/QLabel>
-#include <QtGui/QStylePainter>
-#include <QtGui/QStackedWidget>
-#include <QtGui/QStyleOptionTabBarBase>
-#include <QtGui/QToolButton>
-#include <QtGui/qstyle.h>
+#include <QBoxLayout>
+#include <QEvent>
+#include <QLabel>
+#include <QMap>
+#include <QMenu>
+#include <QMouseEvent>
+#include <QPointer>
+#include <QStackedWidget>
+#include <QStyleOptionTabBarBase>
+#include <QStylePainter>
+#include <QTabBar>
+#include <QToolButton>
 
-#include <kdebug.h>
-#include <klocale.h>
-#include <ktabbar.h>
-#include <kconfig.h>
-#include <kconfiggroup.h>
-#include <ksharedconfig.h>
-#include <kglobal.h>
-#include <kdeversion.h>
-#include <kacceleratormanager.h>
-#include <kmenu.h>
-#include <kicon.h>
-#include <kmimetype.h>
+#include <KAcceleratorManager>
+#include <KConfig>
+#include <KConfigGroup>
+#include <KLocalizedString>
+#include <KSharedConfig>
 
 #include "view.h"
 #include "document.h"
-#include <QEvent>
-#include <QKeyEvent>
-#include "urldocument.h"
 #include <ksqueezedtextlabel.h>
 
 namespace Sublime {
 
 // struct ContainerPrivate
 
-class ContainerTabBar : public KTabBar {
-    public:
-    ContainerTabBar(Container* container) : KTabBar(container), m_container(container) {
+class ContainerTabBar : public QTabBar
+{
+    Q_OBJECT
+
+public:
+    ContainerTabBar(Container* container) : QTabBar(container), m_container(container) {
     }
-    
-    virtual bool event(QEvent* ev) {
+
+    virtual bool event(QEvent* ev) override {
         if(ev->type() == QEvent::ToolTip)
         {
             ev->accept();
-            
+
             int tab = tabAt(mapFromGlobal(QCursor::pos()));
-            
+
             if(tab != -1)
             {
                 m_container->showTooltipForTab(tab);
             }
-            
+
             return true;
         }
-        
-        return KTabBar::event(ev);
+
+        return QTabBar::event(ev);
     }
-    virtual void mousePressEvent(QMouseEvent* event) {
+    virtual void mousePressEvent(QMouseEvent* event) override {
         if (event->button() == Qt::MidButton) {
             // just close on midbutton, drag can still be done with left mouse button
+
+            int tab = tabAt(mapFromGlobal(QCursor::pos()));
+            if (tab != -1) {
+                emit tabCloseRequested(tab);
+            }
             return;
         }
-        KTabBar::mousePressEvent(event);
+        QTabBar::mousePressEvent(event);
     }
+
+Q_SIGNALS:
+    void newTabRequested();
+
+private:
     Container* m_container;
 };
 
@@ -97,7 +104,7 @@ struct ContainerPrivate {
     KSqueezedTextLabel *fileNameCorner;
     QLabel *fileStatus;
     KSqueezedTextLabel *statusCorner;
-    QWeakPointer<QWidget> leftCornerWidget;
+    QPointer<QWidget> leftCornerWidget;
     QToolButton* documentListButton;
     QMenu* documentListMenu;
     QMap<View*, QAction*> documentListActionForView;
@@ -119,11 +126,11 @@ struct ContainerPrivate {
         QVector<View*> views;
         views.reserve(viewForWidget.size());
 
-        foreach(View* view, viewForWidget){ 
+        foreach(View* view, viewForWidget){
             views << view;
         }
 
-        qSort(views.begin(), views.end(), sortViews);
+        std::sort(views.begin(), views.end(), sortViews);
 
         foreach(View* view, views) {
             QAction* action = documentListMenu->addAction(view->document()->title());
@@ -138,13 +145,13 @@ struct ContainerPrivate {
 
 class UnderlinedLabel: public KSqueezedTextLabel {
 public:
-    UnderlinedLabel(KTabBar *tabBar, QWidget* parent = 0)
+    UnderlinedLabel(QTabBar *tabBar, QWidget* parent = 0)
         :KSqueezedTextLabel(parent), m_tabBar(tabBar)
     {
     }
 
 protected:
-    virtual void paintEvent(QPaintEvent *ev)
+    virtual void paintEvent(QPaintEvent *ev) override
     {
         if (m_tabBar->isVisible() && m_tabBar->count() > 0)
         {
@@ -158,7 +165,7 @@ protected:
             QStyleOptionTab tabOverlap;
             tabOverlap.shape = m_tabBar->shape();
             int overlap = style()->pixelMetric(QStyle::PM_TabBarBaseOverlap, &tabOverlap, m_tabBar);
-            if( overlap > 0 ) 
+            if( overlap > 0 )
             {
                 QRect rect;
                 rect.setRect(0, height()-overlap, width(), overlap);
@@ -173,20 +180,20 @@ protected:
         KSqueezedTextLabel::paintEvent(ev);
     }
 
-    KTabBar *m_tabBar;
+    QTabBar *m_tabBar;
 };
 
 
 class StatusLabel: public UnderlinedLabel {
 public:
-    StatusLabel(KTabBar *tabBar, QWidget* parent = 0):
+    StatusLabel(QTabBar *tabBar, QWidget* parent = 0):
         UnderlinedLabel(tabBar, parent)
     {
         setAlignment(Qt::AlignRight | Qt::AlignVCenter);
         setSizePolicy(QSizePolicy::Maximum, QSizePolicy::Fixed);
     }
 
-    virtual QSize minimumSizeHint() const
+    virtual QSize minimumSizeHint() const override
     {
         QRect rect = style()->itemTextRect(fontMetrics(), QRect(), Qt::AlignRight, true, i18n("Line: 00000 Col: 000"));
         rect.setHeight(m_tabBar->height());
@@ -211,7 +218,7 @@ Container::Container(QWidget *parent)
 
     d->documentListMenu = new QMenu(this);
     d->documentListButton = new QToolButton(this);
-    d->documentListButton->setIcon(KIcon("format-list-unordered"));
+    d->documentListButton->setIcon(QIcon::fromTheme("format-list-unordered"));
     d->documentListButton->setMenu(d->documentListMenu);
     d->documentListButton->setPopupMode(QToolButton::InstantPopup);
     d->documentListButton->setAutoRaise(true);
@@ -233,23 +240,28 @@ Container::Container(QWidget *parent)
     d->stack = new QStackedWidget(this);
     l->addWidget(d->stack);
 
-    connect(d->tabBar, SIGNAL(currentChanged(int)), this, SLOT(widgetActivated(int)));
-    connect(d->tabBar, SIGNAL(tabCloseRequested(int)), this, SLOT(requestClose(int)));
-    connect(d->tabBar, SIGNAL(tabMoved(int,int)), this, SLOT(tabMoved(int,int)));
-    connect(d->tabBar, SIGNAL(wheelDelta(int)), this, SLOT(wheelScroll(int)));
-    connect(d->tabBar, SIGNAL(contextMenu(int,QPoint)), this, SLOT(contextMenu(int,QPoint)));
-    connect(d->tabBar, SIGNAL(mouseMiddleClick(int)), this, SLOT(requestClose(int)));
-    connect(d->tabBar, SIGNAL(mouseDoubleClick(int)), this, SLOT(doubleClickTriggered(int)));
-    connect(d->documentListMenu, SIGNAL(triggered(QAction*)), this, SLOT(documentListActionTriggered(QAction*)));
+    connect(d->tabBar, &ContainerTabBar::currentChanged, this, &Container::widgetActivated);
+    connect(d->tabBar, &ContainerTabBar::tabCloseRequested, this, static_cast<void(Container::*)(int)>(&Container::requestClose));
+    connect(d->tabBar, &ContainerTabBar::newTabRequested, this, &Container::newTabRequested);
+    connect(d->tabBar, &ContainerTabBar::tabMoved, this, &Container::tabMoved);
+    connect(d->tabBar, &ContainerTabBar::customContextMenuRequested, this, &Container::contextMenu);
+    connect(d->tabBar, &ContainerTabBar::tabBarDoubleClicked, this, &Container::doubleClickTriggered);
+    connect(d->documentListMenu, &QMenu::triggered, this, &Container::documentListActionTriggered);
 
-    KConfigGroup group = KGlobal::config()->group("UiSettings");
-    setTabBarHidden(group.readEntry("TabBarVisibility", 1) == 0);
+
+    setTabBarHidden(!configTabBarVisible());
     d->tabBar->setTabsClosable(true);
     d->tabBar->setMovable(true);
     d->tabBar->setExpanding(false);
     d->tabBar->setSelectionBehaviorOnRemove(QTabBar::SelectPreviousTab);
 }
 
+bool Container::configTabBarVisible()
+{
+    KConfigGroup group = KSharedConfig::openConfig()->group("UiSettings");
+    return group.readEntry("TabBarVisibility", 1);
+}
+
 void Container::setLeftCornerWidget(QWidget* widget)
 {
     if(d->leftCornerWidget.data() == widget) {
@@ -272,29 +284,9 @@ Container::~Container()
     delete d;
 }
 
-void Container::wheelScroll(int delta)
+QList<View*> Container::views() const
 {
-    int nextIndex = -1;
-    if( delta > 0 )
-    {
-        if( d->tabBar->currentIndex() == 0 )
-        {
-            nextIndex = d->tabBar->count() - 1;
-        } else
-        {
-            nextIndex = d->tabBar->currentIndex() -1;
-        }
-    } else 
-    {
-        if( d->tabBar->currentIndex() == d->tabBar->count() - 1 )
-        {
-            nextIndex = 0;
-        } else
-        {
-            nextIndex = d->tabBar->currentIndex() + 1;
-        }
-    }
-    widgetActivated( nextIndex );
+    return d->viewForWidget.values();
 }
 
 void Container::requestClose(int idx)
@@ -307,8 +299,9 @@ void Container::widgetActivated(int idx)
     if (idx < 0)
         return;
     if (QWidget* w = d->stack->widget(idx)) {
-        if(d->viewForWidget.contains(w))
-            emit activateView(d->viewForWidget[w]);
+        Sublime::View* view = d->viewForWidget.value(w);
+        if(view)
+            emit activateView(view);
     }
 }
 
@@ -338,9 +331,9 @@ void Container::addWidget(View *view, int position)
     // The problem could only be fixed by closing/opening another view.
     d->tabBar->setMinimumHeight(d->tabBar->sizeHint().height());
 
-    connect(view, SIGNAL(statusChanged(Sublime::View*)), this, SLOT(statusChanged(Sublime::View*)));
-    connect(view->document(), SIGNAL(statusIconChanged(Sublime::Document*)), this, SLOT(statusIconChanged(Sublime::Document*)));
-    connect(view->document(), SIGNAL(titleChanged(Sublime::Document*)), this, SLOT(documentTitleChanged(Sublime::Document*)));
+    connect(view, &View::statusChanged, this, &Container::statusChanged);
+    connect(view->document(), &Document::statusIconChanged, this, &Container::statusIconChanged);
+    connect(view->document(), &Document::titleChanged, this, &Container::documentTitleChanged);
 }
 
 void Container::statusChanged(Sublime::View* view)
@@ -373,30 +366,19 @@ void Container::documentTitleChanged(Sublime::Document* doc)
 {
     QMapIterator<QWidget*, View*> it = d->viewForWidget;
     while (it.hasNext()) {
-        if (it.next().value()->document() == doc) {
-            QString txt = doc->title();
-            //TODO: Maybe add new virtual in Document to support supplying this
-            // extended information from subclasses like IDocument which can use
-            // the rest of the kdevplatform API
-            UrlDocument* udoc = dynamic_cast<UrlDocument*>( doc );
-            if( udoc ) {
-                QString pretty;
-                if( udoc->url().isLocalFile() ) {
-                    pretty = udoc->url().toLocalFile();
-                } else {
-                    pretty = udoc->url().prettyUrl();
-                }
-                txt = txt + " (" + pretty + ')';
+        Sublime::View* view = it.next().value();
+        if (view->document() == doc) {
+            if (currentView() == view) {
+                d->fileNameCorner->setText( doc->title(Document::Extended) );
             }
-            d->fileNameCorner->setText( txt );
             int tabIndex = d->stack->indexOf(it.key());
             if (tabIndex != -1) {
                 d->tabBar->setTabText(tabIndex, doc->title());
             }
 
             // Update document list popup title
-            Q_ASSERT(d->documentListActionForView.contains(it.value()));
-            d->documentListActionForView[it.value()]->setText(doc->title());
+            Q_ASSERT(d->documentListActionForView.contains(view));
+            d->documentListActionForView[view]->setText(doc->title());
             break;
         }
     }
@@ -444,7 +426,7 @@ int Container::indexOf(QWidget* w) const
     return d->stack->indexOf(w);
 }
 
-void Sublime::Container::removeWidget(QWidget *w)
+void Container::removeWidget(QWidget *w)
 {
     if (w) {
         int widgetIdx = d->stack->indexOf(w);
@@ -453,18 +435,18 @@ void Sublime::Container::removeWidget(QWidget *w)
         if (d->tabBar->currentIndex() != -1 && !d->tabBar->isVisible()) {
             // repaint icon and document title only in tabbar-less mode
             // tabbar will do repainting for us
-            QWidget* w = widget( d->tabBar->currentIndex() );
-            if( w ) {
-                statusIconChanged( d->viewForWidget[w]->document() );
-                documentTitleChanged( d->viewForWidget[w]->document() );
+            View* view = currentView();
+            if( view ) {
+                statusIconChanged( view->document() );
+                documentTitleChanged( view->document() );
             }
         }
         View* view = d->viewForWidget.take(w);
         if (view)
         {
-            disconnect(view->document(), SIGNAL(titleChanged(Sublime::Document*)), this, SLOT(documentTitleChanged(Sublime::Document*)));
-            disconnect(view->document(), SIGNAL(statusIconChanged(Sublime::Document*)), this, SLOT(statusIconChanged(Sublime::Document*)));
-            disconnect(view, SIGNAL(statusChanged(Sublime::View*)), this, SLOT(statusChanged(Sublime::View*)));
+            disconnect(view->document(), &Document::titleChanged, this, &Container::documentTitleChanged);
+            disconnect(view->document(), &Document::statusIconChanged, this, &Container::statusIconChanged);
+            disconnect(view, &View::statusChanged, this, &Container::statusChanged);
 
             // Update document list context menu
             Q_ASSERT(d->documentListActionForView.contains(view));
@@ -497,6 +479,26 @@ void Container::setTabBarHidden(bool hide)
         d->fileStatus->hide();
         d->tabBar->show();
     }
+    View* v = currentView();
+    if (v) {
+        documentTitleChanged(v->document());
+    }
+}
+
+void Container::resetTabColors(const QColor& color)
+{
+    for (int i = 0; i < count(); i++){
+        d->tabBar->setTabTextColor(i, color);
+    }
+}
+
+void Container::setTabColor(const View* view, const QColor& color)
+{
+    for (int i = 0; i < count(); i++){
+        if (view == viewForWidget(widget(i))) {
+            d->tabBar->setTabTextColor(i, color);
+        }
+    }
 }
 
 void Container::tabMoved(int from, int to)
@@ -507,18 +509,30 @@ void Container::tabMoved(int from, int to)
     d->viewForWidget[w]->notifyPositionChanged(to);
 }
 
-void Container::contextMenu( int currentTab, const QPoint& pos )
+void Container::contextMenu( const QPoint& pos )
 {
-    KMenu menu;
+    QWidget* senderWidget = qobject_cast<QWidget*>(sender());
+    Q_ASSERT(senderWidget);
 
-    emit tabContextMenuRequested(viewForWidget(widget(currentTab)), &menu);
+    int currentTab = d->tabBar->tabAt(pos);
+
+    QMenu menu;
+
+    Sublime::View* view = viewForWidget(widget(currentTab));
+    emit tabContextMenuRequested(view, &menu);
 
     menu.addSeparator();
-    QAction* closeTabAction = menu.addAction( KIcon("document-close"), i18n( "Close File" ) );
-    QAction* closeOtherTabsAction = menu.addAction( KIcon("document-close"), i18n( "Close Other Files" ) );
-    QAction* closeAllTabsAction = menu.addAction( KIcon("document-close"), i18n( "Close All Files" ) );
+    QAction* closeTabAction = nullptr;
+    QAction* closeOtherTabsAction = nullptr;
+    if (view) {
+        closeTabAction = menu.addAction(QIcon::fromTheme("document-close"),
+                                        i18n("Close File"));
+        closeOtherTabsAction = menu.addAction(QIcon::fromTheme("document-close"),
+                                              i18n("Close Other Files"));
+    }
+    QAction* closeAllTabsAction = menu.addAction( QIcon::fromTheme("document-close"), i18n( "Close All Files" ) );
 
-    QAction* triggered = menu.exec(pos);
+    QAction* triggered = menu.exec(senderWidget->mapToGlobal(pos));
 
     if (triggered) {
         if ( triggered == closeTabAction ) {
@@ -540,8 +554,8 @@ void Container::contextMenu( int currentTab, const QPoint& pos )
         } else if ( triggered == closeAllTabsAction ) {
             // activate last tab
             widgetActivated(count() - 1);
+
             // close all
-            QList<QWidget*> tabs;
             for ( int i = 0; i < count(); ++i ) {
                 requestClose(widget(i));
             }
@@ -566,7 +580,11 @@ QRect Container::tabRect(int tab) const
 
 void Container::doubleClickTriggered(int tab)
 {
-    emit tabDoubleClicked(viewForWidget(widget(tab)));
+    if (tab == -1) {
+        emit newTabRequested();
+    } else {
+        emit tabDoubleClicked(viewForWidget(widget(tab)));
+    }
 }
 
 void Container::documentListActionTriggered(QAction* action)
@@ -577,9 +595,11 @@ void Container::documentListActionTriggered(QAction* action)
     Q_ASSERT(widget);
     setCurrentWidget(widget);
 }
-
+Sublime::View* Container::currentView() const
+{
+    return d->viewForWidget.value(widget( d->tabBar->currentIndex() ));
+}
 
 }
 
 #include "container.moc"
-
