@@ -19,16 +19,14 @@
 #ifndef KDEVPLATFORM_SUBLIMECONTAINER_H
 #define KDEVPLATFORM_SUBLIMECONTAINER_H
 
-#include <ktabwidget.h>
-
+#include <QWidget>
+#include "urldocument.h"
 #include "sublimeexport.h"
 
+class QMenu;
 class QBoxLayout;
-
 class QPaintEvent;
 
-class KMenu;
-
 namespace Sublime {
 
 class View;
@@ -40,10 +38,10 @@ class Document;
 This container is placed inside mainwindow splitters to show widgets
 for views in the area.
 */
-class SUBLIME_EXPORT Container: public QWidget {
+class KDEVPLATFORMSUBLIME_EXPORT Container: public QWidget {
 Q_OBJECT
 public:
-    Container(QWidget *parent = 0);
+    explicit Container(QWidget *parent = 0);
     ~Container();
 
     /**Adds the widget for given @p view to the container.*/
@@ -53,6 +51,8 @@ public:
     /** @return true if widget is placed inside this container.*/
     bool hasWidget(QWidget *w);
 
+    QList<View*> views() const;
+
     int count() const;
     QWidget *currentWidget() const;
     void setCurrentWidget(QWidget *w);
@@ -63,6 +63,9 @@ public:
 
     void setTabBarHidden(bool hide);
 
+    void setTabColor(const View* view, const QColor& color);
+    void resetTabColors(const QColor& color);
+
     /** Adds a corner widget to the left of this containers tab-bar. To remove it again, just delete it.
       * The ownership otherwise goes to the container. */
     void setLeftCornerWidget(QWidget* widget);
@@ -72,16 +75,25 @@ public:
     /// @return Rect in global position of the tab identified by index @p tab
     QRect tabRect(int tab) const;
 
+    static bool configTabBarVisible();
+
 Q_SIGNALS:
     void activateView(Sublime::View* view);
     void requestClose(QWidget *w);
-    void tabContextMenuRequested(Sublime::View* view, KMenu* menu);
+    /**
+     * This signal is emitted whenever the users double clicks on the free
+     * space next to the tab bar. Typically, a new document should be
+     * created.
+     */
+    void newTabRequested();
+    void tabContextMenuRequested(Sublime::View* view, QMenu* menu);
     /**
      * @p view The view represented by the tab that was hovered
      * @p Container The tab container that triggered the event
      * @p idx The index of the tab that was hovered
      */
     void tabToolTipRequested(Sublime::View* view, Sublime::Container* container, int idx);
+    void tabDoubleClicked(Sublime::View* view);
 
 private Q_SLOTS:
     void widgetActivated(int idx);
@@ -90,15 +102,14 @@ private Q_SLOTS:
     void statusChanged(Sublime::View *view);
     void requestClose(int idx);
     void tabMoved(int from, int to);
-    void wheelScroll(int);
-    void contextMenu(int, const QPoint&);
+    void contextMenu(const QPoint&);
+    void doubleClickTriggered(int tab);
     void documentListActionTriggered(QAction*);
 
 private:
+    Sublime::View* currentView() const;
 
     struct ContainerPrivate * const d;
-
-    QBoxLayout* m_tabBarLayout;
 };
 
 }
