@@ -16,8 +16,8 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
-#ifndef SUBLIMEDOCUMENT_H
-#define SUBLIMEDOCUMENT_H
+#ifndef KDEVPLATFORM_SUBLIMEDOCUMENT_H
+#define KDEVPLATFORM_SUBLIMEDOCUMENT_H
 
 #include <QtCore/QObject>
 #include <QtCore/QList>
@@ -41,7 +41,7 @@ class Controller;
 Subclass from Document and implement createViewWidget() method
 to return a new widget for a view.
 */
-class SUBLIME_EXPORT Document: public QObject {
+class KDEVPLATFORMSUBLIME_EXPORT Document: public QObject {
     Q_OBJECT
 public:
     /**Creates a document and adds it to a @p controller.*/
@@ -58,7 +58,8 @@ public:
     Controller *controller() const;
 
     /**@return the document title.*/
-    QString title() const;
+    enum TitleType { Normal, Extended};
+    virtual QString title(TitleType type = Normal) const;
     /**Set the document title.*/
     void setTitle(const QString& newTitle);
     void setToolTip(const QString& newToolTip);
@@ -134,10 +135,8 @@ protected:
     virtual QWidget *createViewWidget(QWidget *parent = 0) = 0;
     /** Closes all views associated to this document */
     virtual void closeViews();
-    
-private:
-    Q_PRIVATE_SLOT(d, void removeView(QObject*))
 
+private:
     struct DocumentPrivate *const d;
 
     friend struct DocumentPrivate;
