@@ -22,20 +22,13 @@
 
 #include "idealcontroller.h"
 
-#include <QApplication>
 #include <QMainWindow>
-#include <QStylePainter>
-#include <KIcon>
-#include <kdebug.h>
-#include <klocale.h>
-#include <kglobal.h>
-#include <kshortcutwidget.h>
-#include <KActionCollection>
-#include <KActionMenu>
+#include <QToolBar>
+
 #include <KAcceleratorManager>
-#include <KMenu>
-#include <KToolBar>
-#include <KDialog>
+#include <KActionMenu>
+#include <KLocalizedString>
+#include <KSharedConfig>
 
 #include "area.h"
 #include "view.h"
@@ -45,8 +38,6 @@
 #include "idealtoolbutton.h"
 #include "idealdockwidget.h"
 #include "idealbuttonbarwidget.h"
-#include <QVBoxLayout>
-#include <QLabel>
 
 using namespace Sublime;
 
@@ -54,36 +45,30 @@ IdealController::IdealController(Sublime::MainWindow* mainWindow):
     QObject(mainWindow), m_mainWindow(mainWindow)
 {
     leftBarWidget = new IdealButtonBarWidget(Qt::LeftDockWidgetArea, this, m_mainWindow);
-    connect(leftBarWidget, SIGNAL(customContextMenuRequested(QPoint)),
-            this, SLOT(slotDockBarContextMenuRequested(QPoint)));
+    connect(leftBarWidget, &IdealButtonBarWidget::customContextMenuRequested,
+            this, &IdealController::slotDockBarContextMenuRequested);
 
     rightBarWidget = new IdealButtonBarWidget(Qt::RightDockWidgetArea, this, m_mainWindow);
-    connect(rightBarWidget, SIGNAL(customContextMenuRequested(QPoint)),
-            this, SLOT(slotDockBarContextMenuRequested(QPoint)));
+    connect(rightBarWidget, &IdealButtonBarWidget::customContextMenuRequested,
+            this, &IdealController::slotDockBarContextMenuRequested);
 
     bottomBarWidget = new IdealButtonBarWidget(Qt::BottomDockWidgetArea, this, m_mainWindow);
     bottomStatusBarLocation = bottomBarWidget->corner();
-    connect(bottomBarWidget, SIGNAL(customContextMenuRequested(QPoint)),
-            this, SLOT(slotDockBarContextMenuRequested(QPoint)));
+    connect(bottomBarWidget, &IdealButtonBarWidget::customContextMenuRequested,
+            this, &IdealController::slotDockBarContextMenuRequested);
 
     topBarWidget = new IdealButtonBarWidget(Qt::TopDockWidgetArea, this, m_mainWindow);
-    connect(topBarWidget, SIGNAL(customContextMenuRequested(QPoint)),
-            this, SLOT(slotDockBarContextMenuRequested(QPoint)));
+    connect(topBarWidget, &IdealButtonBarWidget::customContextMenuRequested,
+            this, &IdealController::slotDockBarContextMenuRequested);
 
     m_docks = qobject_cast<KActionMenu*>(mainWindow->action("docks_submenu"));
 
-    m_showLeftDock = qobject_cast<KAction*>(m_mainWindow->action("show_left_dock"));
-    m_showRightDock = qobject_cast<KAction*>(m_mainWindow->action("show_right_dock"));
-    m_showBottomDock = qobject_cast<KAction*>(m_mainWindow->action("show_bottom_dock"));
+    m_showLeftDock = qobject_cast<QAction*>(m_mainWindow->action("show_left_dock"));
+    m_showRightDock = qobject_cast<QAction*>(m_mainWindow->action("show_right_dock"));
+    m_showBottomDock = qobject_cast<QAction*>(m_mainWindow->action("show_bottom_dock"));
+    m_showTopDock = qobject_cast<QAction*>(m_mainWindow->action("show_top_dock"));
 
-    // the 'show top dock' action got removed (IOW, it's never created)
-    // (let's keep this code around if we ever want to reintroduce the feature...
-    auto action = m_mainWindow->action("show_top_dock");
-    if (action) {
-        m_showTopDock = qobject_cast<KAction*>(action);
-    }
-
-    connect(m_mainWindow, SIGNAL(settingsLoaded()), this, SLOT(loadSettings()));
+    connect(m_mainWindow, &MainWindow::settingsLoaded, this, &IdealController::loadSettings);
 
 }
 
@@ -113,7 +98,7 @@ void IdealController::addView(Qt::DockWidgetArea area, View* view)
       dock->setWidget(w);
     } else {
       QMainWindow *toolView = new QMainWindow();
-      KToolBar *toolBar = new KToolBar(toolView);
+      QToolBar *toolBar = new QToolBar(toolView);
       int iconSize = m_mainWindow->style()->pixelMetric(QStyle::PM_SmallIconSize);
       toolBar->setIconSize(QSize(iconSize, iconSize));
       toolBar->setToolButtonStyle(Qt::ToolButtonIconOnly);
@@ -131,16 +116,16 @@ void IdealController::addView(Qt::DockWidgetArea area, View* view)
     dock->setFocusProxy(dock->widget());
 
     if (IdealButtonBarWidget* bar = barForDockArea(area)) {
-        KAction* action = bar->addWidget(
+        QAction* action = bar->addWidget(
             view->document()->title(), dock,
             static_cast<MainWindow*>(parent())->area(), view);
         m_dockwidget_to_action[dock] = m_view_to_action[view] = action;
 
         m_docks->addAction(action);
-        connect(dock, SIGNAL(closeRequested()), action, SLOT(toggle()));
+        connect(dock, &IdealDockWidget::closeRequested, action, &QAction::toggle);
     }
 
-    connect(dock, SIGNAL(dockLocationChanged(Qt::DockWidgetArea)), this, SLOT(dockLocationChanged(Qt::DockWidgetArea)));
+    connect(dock, &IdealDockWidget::dockLocationChanged, this, &IdealController::dockLocationChanged);
 
     dock->hide();
 
@@ -166,7 +151,7 @@ void IdealController::dockLocationChanged(Qt::DockWidgetArea area)
             dock->hide();
         }
 
-        return; 
+        return;
     }
 
     if (IdealButtonBarWidget* bar = barForDockArea(dock->dockWidgetArea()))
@@ -175,7 +160,7 @@ void IdealController::dockLocationChanged(Qt::DockWidgetArea area)
     docks.insert(dock);
 
     if (IdealButtonBarWidget* bar = barForDockArea(area)) {
-        KAction* action = bar->addWidget(
+        QAction* action = bar->addWidget(
             view->document()->title(), dock,
             static_cast<MainWindow*>(parent())->area(), view);
         m_dockwidget_to_action[dock] = m_view_to_action[view] = action;
@@ -185,7 +170,7 @@ void IdealController::dockLocationChanged(Qt::DockWidgetArea area)
         bar->showWidget(action, true);
 
         // the dock should now be the "last" opened in a new area, not in the old area
-        for (QMap<Qt::DockWidgetArea, QWeakPointer<IdealDockWidget> >::iterator it = lastDockWidget.begin(); it != lastDockWidget.end(); ++it) {
+        for (auto it = lastDockWidget.begin(); it != lastDockWidget.end(); ++it) {
             if (it->data() == dock)
                 it->clear();
         }
@@ -242,7 +227,7 @@ void IdealController::raiseView(View* view, RaiseMode mode)
     ///       The problem is that views are identified purely by their factory-id, which is equal
     ///       for toolviews of the same type.
     mode = HideOtherViews;
-   
+
     QAction* action = m_view_to_action.value(view);
     Q_ASSERT(action);
 
@@ -305,7 +290,7 @@ QAction* IdealController::actionForView(View* view) const
 
 void IdealController::setShowDockStatus(Qt::DockWidgetArea area, bool checked)
 {
-    KAction* action = actionForArea(area);
+    QAction* action = actionForArea(area);
     if (action->isChecked() != checked) {
         bool blocked = action->blockSignals(true);
         action->setChecked(checked);
@@ -313,7 +298,7 @@ void IdealController::setShowDockStatus(Qt::DockWidgetArea area, bool checked)
     }
 }
 
-KAction* IdealController::actionForArea(Qt::DockWidgetArea area) const
+QAction* IdealController::actionForArea(Qt::DockWidgetArea area) const
 {
     switch (area) {
         case Qt::LeftDockWidgetArea:
@@ -390,7 +375,7 @@ void IdealController::showDock(Qt::DockWidgetArea area, bool show)
     if (lastDock && lastDock->isVisible() && !lastDock->hasFocus()) {
         lastDock->setFocus(Qt::ShortcutFocusReason);
         // re-sync action state given we may have asked for the dock to be hidden
-        KAction* action = actionForArea(area);
+        QAction* action = actionForArea(area);
         if (!action->isChecked()) {
             action->blockSignals(true);
             action->setChecked(true);
@@ -500,7 +485,7 @@ void IdealController::toggleDocksShown(IdealButtonBarWidget* bar, bool show)
 
 void IdealController::loadSettings()
 {
-    KConfigGroup cg(KGlobal::config(), "UiSettings");
+    KConfigGroup cg(KSharedConfig::openConfig(), "UiSettings");
 
     int bottomOwnsBottomLeft = cg.readEntry("BottomLeftCornerOwner", 0);
     if (bottomOwnsBottomLeft)
