@@ -25,14 +25,17 @@
 #include "area.h"
 #include "document.h"
 #include "view.h"
-#include <KMenu>
+
+#include <KConfigGroup>
 #include <KLocalizedString>
-#include <KDialog>
-#include <KShortcutWidget>
 #include <KSharedConfig>
+#include <KShortcutWidget>
 
 #include <QAbstractButton>
+#include <QDialog>
+#include <QDialogButtonBox>
 #include <QToolBar>
+#include <QVBoxLayout>
 
 using namespace Sublime;
 
@@ -45,16 +48,14 @@ IdealDockWidget::IdealDockWidget(IdealController *controller, Sublime::MainWindo
 {
     setAutoFillBackground(true);
     setContextMenuPolicy(Qt::CustomContextMenu);
-    connect(this, SIGNAL(customContextMenuRequested(QPoint)),
-            this, SLOT(contextMenuRequested(QPoint)));
-
-    QAbstractButton *closeButton =
-    qFindChild<QAbstractButton *>(this, QLatin1String("qt_dockwidget_closebutton"));
+    connect(this, &IdealDockWidget::customContextMenuRequested,
+            this, &IdealDockWidget::contextMenuRequested);
 
+    QAbstractButton *closeButton = findChild<QAbstractButton *>(QLatin1String("qt_dockwidget_closebutton"));
     if (closeButton) {
-    disconnect(closeButton, SIGNAL(clicked()), 0, 0);
+    disconnect(closeButton, &QAbstractButton::clicked, 0, 0);
 
-    connect(closeButton, SIGNAL(clicked(bool)), SIGNAL(closeRequested()));
+    connect(closeButton, &QAbstractButton::clicked, this, &IdealDockWidget::closeRequested);
     }
 
     setFeatures(QDockWidget::DockWidgetClosable | QDockWidget::DockWidgetMovable | QDockWidget::DockWidgetFloatable);
@@ -94,8 +95,8 @@ void IdealDockWidget::contextMenuRequested(const QPoint &point)
     QWidget* senderWidget = qobject_cast<QWidget*>(sender());
     Q_ASSERT(senderWidget);
 
-    KMenu menu;
-    menu.addTitle(windowIcon(), windowTitle());
+    QMenu menu;
+    menu.addSection(windowIcon(), windowTitle());
 
     QList< QAction* > viewActions = m_view->contextMenuActions();
     if(!viewActions.isEmpty()) {
@@ -135,11 +136,11 @@ void IdealDockWidget::contextMenuRequested(const QPoint &point)
 
     menu.addSeparator();
 
-    QAction *setShortcut = menu.addAction(KIcon("configure-shortcuts"), i18n("Assign Shortcut..."));
+    QAction *setShortcut = menu.addAction(QIcon::fromTheme("configure-shortcuts"), i18n("Assign Shortcut..."));
     setShortcut->setToolTip(i18n("Use this shortcut to trigger visibility of the toolview."));
 
     menu.addSeparator();
-    QAction* remove = menu.addAction(KIcon("dialog-close"), i18n("Remove Toolview"));
+    QAction* remove = menu.addAction(QIcon::fromTheme("dialog-close"), i18n("Remove Toolview"));
 
     QAction* triggered = menu.exec(senderWidget->mapToGlobal(point));
 
@@ -149,29 +150,30 @@ void IdealDockWidget::contextMenuRequested(const QPoint &point)
             slotRemove();
             return;
         } else if ( triggered == setShortcut ) {
-            KDialog *dialog = new KDialog(this);
-            dialog->setCaption(i18n("Assign Shortcut For '%1' Tool View", m_view->document()->title()));
-            dialog->setButtons( KDialog::Ok | KDialog::Cancel );
+            QDialog* dialog(new QDialog(this));
+            dialog->setWindowTitle(i18n("Assign Shortcut For '%1' Tool View", m_view->document()->title()));
             KShortcutWidget *w = new KShortcutWidget(dialog);
-            KShortcut shortcut;
-            shortcut.setPrimary(m_controller->actionForView(m_view)->shortcuts().value(0));
-            shortcut.setAlternate(m_controller->actionForView(m_view)->shortcuts().value(1));
-            w->setShortcut(shortcut);
-            dialog->setMainWidget(w);
+            w->setShortcut(m_controller->actionForView(m_view)->shortcuts());
+            QVBoxLayout* dialogLayout = new QVBoxLayout(dialog);
+            dialogLayout->addWidget(w);
+            QDialogButtonBox* buttonBox = new QDialogButtonBox( QDialogButtonBox::Ok | QDialogButtonBox::Cancel );
+            dialogLayout->addWidget(buttonBox);
+            connect(buttonBox, &QDialogButtonBox::accepted, dialog, &QDialog::accept);
+            connect(buttonBox, &QDialogButtonBox::rejected, dialog, &QDialog::reject);
 
             if (dialog->exec() == QDialog::Accepted) {
-                m_controller->actionForView(m_view)->setShortcuts(w->shortcut().toList());
+                m_controller->actionForView(m_view)->setShortcuts(w->shortcut());
 
                 //save shortcut config
-                KConfigGroup config = KGlobal::config()->group("UI");
+                KConfigGroup config = KSharedConfig::openConfig()->group("UI");
                 QStringList shortcuts;
-                shortcuts << w->shortcut().primary().toString();
-                shortcuts << w->shortcut().alternate().toString();
-                config.writeEntry(QString("Shortcut for %1").arg(m_view->document()->title()), shortcuts);
+                shortcuts << w->shortcut().value(0).toString();
+                shortcuts << w->shortcut().value(1).toString();
+                config.writeEntry(QStringLiteral("Shortcut for %1").arg(m_view->document()->title()), shortcuts);
                 config.sync();
             }
-
             delete dialog;
+
             return;
         } else if ( triggered == detach ) {
             setFloating(true);
