@@ -30,14 +30,14 @@ class IdealToolButton: public QToolButton
     Q_OBJECT
 
 public:
-    IdealToolButton(Qt::DockWidgetArea area, QWidget *parent = 0);
+    explicit IdealToolButton(Qt::DockWidgetArea area, QWidget *parent = 0);
 
     Qt::Orientation orientation() const;
 
-    virtual QSize sizeHint() const;
+    virtual QSize sizeHint() const override;
 
 protected:
-    virtual void paintEvent(QPaintEvent *event);
+    virtual void paintEvent(QPaintEvent *event) override;
 
 private:
     Qt::DockWidgetArea _area;
