@@ -19,19 +19,15 @@
 #include "mainwindow.h"
 #include "mainwindow_p.h"
 
-#include <KDE/KDebug>
-#include <KDE/KGlobal>
-#include <KDE/KConfig>
-#include <KDE/KSharedConfig>
-#include <KDE/KConfigGroup>
-#include <KDE/KToolBar>
-#include <KDE/KWindowSystem>
+#include <QApplication>
+#include <QDesktopWidget>
+#include <QMenuBar>
+#include <QStatusBar>
 
-#include <QtGui/QApplication>
-#include <QtGui/QDesktopWidget>
-#include <KDE/KStatusBar>
-#include <KDE/KMenuBar>
+#include <KConfigGroup>
 #include <KLocalizedString>
+#include <KSharedConfig>
+#include <KToolBar>
 
 #include "area.h"
 #include "view.h"
@@ -39,15 +35,18 @@
 #include "container.h"
 #include "idealcontroller.h"
 #include "holdupdates.h"
+#include "sublimedebug.h"
+
+Q_LOGGING_CATEGORY(SUBLIME, "kdevplatform.sublime")
 
 namespace Sublime {
 
 MainWindow::MainWindow(Controller *controller, Qt::WindowFlags flags)
 : KParts::MainWindow(0, flags), d(new MainWindowPrivate(this, controller))
 {
-    connect(this, SIGNAL(destroyed()), controller, SLOT(areaReleased()));
+    connect(this, &MainWindow::destroyed, controller, static_cast<void(Controller::*)()>(&Controller::areaReleased));
 
-    loadGeometry(KGlobal::config()->group("Main Window"));
+    loadGeometry(KSharedConfig::openConfig()->group("Main Window"));
 
     // don't allow AllowTabbedDocks - that doesn't make sense for "ideal" UI
     setDockOptions(QMainWindow::AnimatedDocks);
@@ -72,7 +71,7 @@ QList< Area* > MainWindow::areas() const
 
 MainWindow::~MainWindow()
 {
-    kDebug() << "destroying mainwindow";
+    qCDebug(SUBLIME) << "destroying mainwindow";
     delete d;
 }
 
@@ -100,17 +99,22 @@ QList<View*> MainWindow::getTopViews() const
     return topViews;
 }
 
+QList<Container*> MainWindow::containers() const
+{
+    return d->viewContainers.values();
+}
+
 void MainWindow::setArea(Area *area)
 {
     if (d->area)
-        disconnect(d->area, 0, this, 0);
+        disconnect(d->area, 0, d, 0);
 
     bool differentArea = (area != d->area);
     /* All views will be removed from dock area now.  However, this does
        not mean those are removed from area, so prevent slotDockShown
        from recording those views as no longer shown in the area.  */
     d->ignoreDockShown = true;
-    
+
     if (d->autoAreaSettingsSave && differentArea)
         saveSettings();
 
@@ -119,34 +123,26 @@ void MainWindow::setArea(Area *area)
         clearArea();
     d->area = area;
     d->reconstruct();
-    
+
     if(d->area->activeView())
         activateView(d->area->activeView());
     else
         d->activateFirstVisibleView();
-    
+
     initializeStatusBar();
     emit areaChanged(area);
     d->ignoreDockShown = false;
-    
+
     hu.stop();
 
     loadSettings();
-
-    connect(area, SIGNAL(viewAdded(Sublime::AreaIndex*,Sublime::View*)),
-        this, SLOT(viewAdded(Sublime::AreaIndex*,Sublime::View*)));
-    connect(area, SIGNAL(viewRemoved(Sublime::AreaIndex*,Sublime::View*)),
-        this, SLOT(viewRemovedInternal(Sublime::AreaIndex*,Sublime::View*)));
-    connect(area, SIGNAL(requestToolViewRaise(Sublime::View*)),
-        this, SLOT(raiseToolView(Sublime::View*)));
-    connect(area, SIGNAL(aboutToRemoveView(Sublime::AreaIndex*,Sublime::View*)),
-        this, SLOT(aboutToRemoveView(Sublime::AreaIndex*,Sublime::View*)));
-    connect(area, SIGNAL(toolViewAdded(Sublime::View*,Sublime::Position)),
-        this, SLOT(toolViewAdded(Sublime::View*,Sublime::Position)));
-    connect(area, SIGNAL(aboutToRemoveToolView(Sublime::View*,Sublime::Position)),
-        this, SLOT(aboutToRemoveToolView(Sublime::View*,Sublime::Position)));
-    connect(area, SIGNAL(toolViewMoved(Sublime::View*,Sublime::Position)),
-        this, SLOT(toolViewMoved(Sublime::View*,Sublime::Position)));
+    connect(area, &Area::viewAdded, d, &MainWindowPrivate::viewAdded);
+    connect(area, &Area::viewRemoved, d, &MainWindowPrivate::viewRemovedInternal);
+    connect(area, &Area::requestToolViewRaise, d, &MainWindowPrivate::raiseToolView);
+    connect(area, &Area::aboutToRemoveView, d, &MainWindowPrivate::aboutToRemoveView);
+    connect(area, &Area::toolViewAdded, d, &MainWindowPrivate::toolViewAdded);
+    connect(area, &Area::aboutToRemoveToolView, d, &MainWindowPrivate::aboutToRemoveToolView);
+    connect(area, &Area::toolViewMoved, d, &MainWindowPrivate::toolViewMoved);
 }
 
 void MainWindow::initializeStatusBar()
@@ -181,12 +177,12 @@ Controller *MainWindow::controller() const
     return d->controller;
 }
 
-View *MainWindow::activeView()
+View *MainWindow::activeView() const
 {
     return d->activeView;
 }
 
-View *MainWindow::activeToolView()
+View *MainWindow::activeToolView() const
 {
     return d->activeToolView;
 }
@@ -205,9 +201,9 @@ void MainWindow::activateView(Sublime::View* view, bool focus)
 void MainWindow::setActiveView(View *view, bool focus)
 {
     View* oldActiveView = d->activeView;
-    
+
     d->activeView = view;
-    
+
     if (focus && view && !view->widget()->hasFocus())
         view->widget()->setFocus();
 
@@ -223,10 +219,11 @@ void Sublime::MainWindow::setActiveToolView(View *view)
 
 void MainWindow::saveSettings()
 {
+    d->disableConcentrationMode();
     QString group = "MainWindow";
     if (area())
         group += '_' + area()->objectName();
-    KConfigGroup cg = KGlobal::config()->group(group);
+    KConfigGroup cg = KSharedConfig::openConfig()->group(group);
     /* This will try to save window size, too.  But it's OK, since we
        won't use this information when loading.  */
     saveMainWindowSettings(cg);
@@ -245,16 +242,16 @@ void MainWindow::loadSettings()
 {
     HoldUpdates hu(this);
 
-    kDebug(9504) << "loading settings for " << (area() ? area()->objectName() : "");
+    qCDebug(SUBLIME) << "loading settings for " << (area() ? area()->objectName() : "");
     QString group = "MainWindow";
     if (area())
         group += '_' + area()->objectName();
-    KConfigGroup cg = KGlobal::config()->group(group);
+    KConfigGroup cg = KSharedConfig::openConfig()->group(group);
 
     // What follows is copy-paste from applyMainWindowSettings.  Unfortunately,
     // we don't really want that one to try restoring window size, and we also
     // cannot stop it from doing that in any clean way.
-    QStatusBar* sb = qFindChild<KStatusBar *>(this);
+    QStatusBar* sb = findChild<QStatusBar *>();
     if (sb) {
         QString entry = cg.readEntry("StatusBar", "Enabled");
         if ( entry == "Disabled" )
@@ -263,7 +260,7 @@ void MainWindow::loadSettings()
            sb->show();
     }
 
-    QMenuBar* mb = qFindChild<KMenuBar *>(this);
+    QMenuBar* mb = findChild<QMenuBar *>();
     if (mb) {
         QString entry = cg.readEntry ("MenuBar", "Enabled");
         if ( entry == "Disabled" )
@@ -290,7 +287,7 @@ void MainWindow::loadSettings()
         state = cg.readEntry("State", state);
         state = QByteArray::fromBase64(state);
         // One day will need to load the version number, but for now, assume 0
-//         restoreState(state);
+        restoreState(state);
     } else {
         // If there's no state we use a default size of 870x650
         // Resize only when showing "code" area. If we do that for other areas,
@@ -305,10 +302,10 @@ void MainWindow::loadSettings()
         QString group("Toolbar");
         // Give a number to the toolbar, but prefer a name if there is one,
         // because there's no real guarantee on the ordering of toolbars
-        group += (toolbar->objectName().isEmpty() ? QString::number(n) : QString(" ")+toolbar->objectName());
+        group += (toolbar->objectName().isEmpty() ? QString::number(n) : QStringLiteral(" ")+toolbar->objectName());
 
         KConfigGroup toolbarGroup(&cg, group);
-        toolbar->applySettings(toolbarGroup, false);
+        toolbar->applySettings(toolbarGroup);
 
         if (toolbar->objectName() == "debugToolBar") {
             //debugToolBar visibility is stored separately to allow a area dependent default value
@@ -318,26 +315,26 @@ void MainWindow::loadSettings()
         n++;
     }
 
-    KConfigGroup uiGroup = KGlobal::config()->group("UiSettings");
-    foreach (Container *container, findChildren<Container*>())
+    const bool tabBarHidden = !Container::configTabBarVisible();
+    foreach (Container *container, d->viewContainers)
     {
-        container->setTabBarHidden(uiGroup.readEntry("TabBarVisibility", 1) == 0);
+        container->setTabBarHidden(tabBarHidden);
     }
 
-    cg.sync();
-
     hu.stop();
-    
+
     emit settingsLoaded();
+
+    d->disableConcentrationMode();
 }
 
 bool MainWindow::queryClose()
 {
 //    saveSettings();
-    KConfigGroup config(KGlobal::config(), "Main Window");
+    KConfigGroup config(KSharedConfig::openConfig(), "Main Window");
     saveGeometry(config);
     config.sync();
-    
+
     return KParts::MainWindow::queryClose();
 }
 
@@ -397,7 +394,7 @@ void MainWindow::tabDoubleClicked(View* view)
     d->toggleDocksShown();
 }
 
-void MainWindow::tabContextMenuRequested(View* , KMenu* )
+void MainWindow::tabContextMenuRequested(View* , QMenu* )
 {
     // do nothing
 }
@@ -407,6 +404,10 @@ void MainWindow::tabToolTipRequested(View*, Container*, int)
     // do nothing
 }
 
+void MainWindow::newTabRequested()
+{
+}
+
 void MainWindow::dockBarContextMenuRequested(Qt::DockWidgetArea , const QPoint& )
 {
     // do nothing
@@ -414,7 +415,7 @@ void MainWindow::dockBarContextMenuRequested(Qt::DockWidgetArea , const QPoint&
 
 View* MainWindow::viewForPosition(QPoint globalPos) const
 {
-    foreach(Container* container, d->viewContainers.values())
+    foreach(Container* container, d->viewContainers)
     {
         QRect globalGeom = QRect(container->mapToGlobal(QPoint(0,0)), container->mapToGlobal(QPoint(container->width(), container->height())));
        if(globalGeom.contains(globalPos))
@@ -422,7 +423,7 @@ View* MainWindow::viewForPosition(QPoint globalPos) const
            return d->widgetToView[container->currentWidget()];
        }
     }
-    
+
     return 0;
 }
 
@@ -433,4 +434,4 @@ void MainWindow::setBackgroundCentralWidget(QWidget* w)
 
 }
 
-#include "mainwindow.moc"
+#include "moc_mainwindow.cpp"
