@@ -18,22 +18,14 @@
  ***************************************************************************/
 #include "mainwindow_p.h"
 
-#include <QtGui/QMenu>
-#include <QtGui/QLayout>
-#include <QtGui/QSplitter>
-#include <QtGui/QDockWidget>
-#include <QtGui/QWidgetAction>
-#include <QtGui/QComboBox>
-#include <QtGui/QHBoxLayout>
-#include <QtGui/QToolButton>
-#include <QtGui/QCommonStyle>
+#include <QLayout>
+#include <QSplitter>
 #include <QTimer>
+#include <QToolBar>
 
-#include <kdebug.h>
-#include <klocale.h>
-#include <kactionmenu.h>
-#include <kacceleratormanager.h>
-#include <kactioncollection.h>
+#include <KActionMenu>
+#include <KActionCollection>
+#include <KLocalizedString>
 
 #include "area.h"
 #include "view.h"
@@ -45,47 +37,58 @@
 #include "idealcontroller.h"
 #include "holdupdates.h"
 #include "idealbuttonbarwidget.h"
-#include <KToolBar>
-#include <KSelectAction>
-#include <ktoggleaction.h>
+#include "sublimedebug.h"
 
 class IdealToolBar : public QToolBar
 {
     Q_OBJECT
     public:
-        explicit IdealToolBar(const QString& title, Sublime::IdealButtonBarWidget* buttons, QMainWindow* parent)
-            : QToolBar(title, parent), m_buttons(buttons)
+        explicit IdealToolBar(const QString& title, bool hideWhenEmpty, Sublime::IdealButtonBarWidget* buttons, QMainWindow* parent)
+            : QToolBar(title, parent)
+            , m_timer(nullptr)
+            , m_buttons(buttons)
+            , m_hideWhenEmpty(hideWhenEmpty)
+            , m_requestedVisibility(true)
         {
             setMovable(false);
             setFloatable(false);
             setObjectName(title);
             layout()->setMargin(0);
-            
+
             addWidget(m_buttons);
-        }
 
-        void hideWhenEmpty()
-        {
-            refresh();
-            
-            QTimer* t = new QTimer(this);
-            t->setInterval(100);
-            t->setSingleShot(true);
-            connect(t, SIGNAL(timeout()), SLOT(refresh()));
-            connect(this, SIGNAL(visibilityChanged(bool)), t, SLOT(start()));
-            connect(m_buttons, SIGNAL(emptyChanged()), t, SLOT(start()));
-        }
-
-    public slots:
-        void refresh()
-        {
-            if(m_buttons->isEmpty()==isVisible()) {
-                setVisible(!m_buttons->isEmpty());
+            if (m_hideWhenEmpty) {
+                m_timer = new QTimer(this);
+                m_timer->setInterval(100);
+                m_timer->setSingleShot(true);
+                connect(m_timer, &QTimer::timeout, this, &IdealToolBar::refresh);
+                connect(this, &IdealToolBar::visibilityChanged, m_timer, static_cast<void(QTimer::*)()>(&QTimer::start));
+                connect(m_buttons, &Sublime::IdealButtonBarWidget::emptyChanged, m_timer, static_cast<void(QTimer::*)()>(&QTimer::start));
             }
         }
 
+        void setVisible(bool visible) override
+        {
+            QToolBar::setVisible(visible);
+
+            m_requestedVisibility = visible;
+
+            if (m_hideWhenEmpty && visible) {
+                m_timer->start();
+            }
+        }
+
+    private slots:
+        void refresh()
+        {
+            setVisible(m_requestedVisibility && !m_buttons->isEmpty());
+        }
+
     private:
+        QTimer* m_timer;
         Sublime::IdealButtonBarWidget* m_buttons;
+        const bool m_hideWhenEmpty;
+        bool m_requestedVisibility;
 };
 
 namespace Sublime {
@@ -96,44 +99,54 @@ MainWindowPrivate::MainWindowPrivate(MainWindow *w, Controller* controller)
 {
     KActionCollection *ac = m_mainWindow->actionCollection();
 
-    KAction* action = new KAction(i18n("Show Left Dock"), this);
+    m_concentrationModeAction = new QAction(i18n("Concentration Mode"), this);
+    m_concentrationModeAction->setIcon(QIcon::fromTheme(QStringLiteral("page-zoom")));
+    m_concentrationModeAction->setToolTip(i18n("Removes most of the controls so you can focus on what matters."));
+    m_concentrationModeAction->setCheckable(true);
+    m_concentrationModeAction->setChecked(false);
+    ac->setDefaultShortcut(m_concentrationModeAction, Qt::META | Qt::Key_C);
+    connect(m_concentrationModeAction, &QAction::toggled, this, &MainWindowPrivate::restoreConcentrationMode);
+    ac->addAction("toggle_concentration_mode", m_concentrationModeAction);
+
+    QAction* action = new QAction(i18n("Show Left Dock"), this);
     action->setCheckable(true);
-    action->setShortcut(Qt::META | Qt::CTRL | Qt::Key_L);
-    connect(action, SIGNAL(toggled(bool)), SLOT(showLeftDock(bool)));
+    ac->setDefaultShortcut(action, Qt::META | Qt::CTRL | Qt::Key_Left);
+    connect(action, &QAction::toggled, this, &MainWindowPrivate::showLeftDock);
+
     ac->addAction("show_left_dock", action);
 
-    action = new KAction(i18n("Show Right Dock"), this);
+    action = new QAction(i18n("Show Right Dock"), this);
     action->setCheckable(true);
-    action->setShortcut(Qt::META | Qt::CTRL | Qt::Key_R);
-    connect(action, SIGNAL(toggled(bool)), SLOT(showRightDock(bool)));
+    ac->setDefaultShortcut(action, Qt::META | Qt::CTRL | Qt::Key_Right);
+    connect(action, &QAction::toggled, this, &MainWindowPrivate::showRightDock);
     ac->addAction("show_right_dock", action);
 
-    action = new KAction(i18n("Show Bottom Dock"), this);
+    action = new QAction(i18n("Show Bottom Dock"), this);
     action->setCheckable(true);
-    action->setShortcut(Qt::META | Qt::CTRL | Qt::Key_B);
-    connect(action, SIGNAL(toggled(bool)), SLOT(showBottomDock(bool)));
+    ac->setDefaultShortcut(action, Qt::META | Qt::CTRL | Qt::Key_Down);
+    connect(action, &QAction::toggled, this, &MainWindowPrivate::showBottomDock);
     ac->addAction("show_bottom_dock", action);
 
-    action = new KAction(i18nc("@action", "Focus Editor"), this);
-    action->setShortcuts(QList<QKeySequence>() << (Qt::META | Qt::CTRL | Qt::Key_E) << Qt::META + Qt::Key_C);
-    connect(action, SIGNAL(triggered(bool)), this, SLOT(focusEditor()));
+    action = new QAction(i18nc("@action", "Focus Editor"), this);
+    ac->setDefaultShortcut(action, Qt::META | Qt::CTRL | Qt::Key_E);
+    connect(action, &QAction::triggered, this, &MainWindowPrivate::focusEditor);
     ac->addAction("focus_editor", action);
 
-    action = new KAction(i18n("Hide/Restore Docks"), this);
-    action->setShortcut(Qt::META | Qt::CTRL | Qt::Key_H);
-    connect(action, SIGNAL(triggered(bool)), SLOT(toggleDocksShown()));
+    action = new QAction(i18n("Hide/Restore Docks"), this);
+    ac->setDefaultShortcut(action, Qt::META | Qt::CTRL | Qt::Key_Up);
+    connect(action, &QAction::triggered, this, &MainWindowPrivate::toggleDocksShown);
     ac->addAction("hide_all_docks", action);
 
-    action = new KAction(i18n("Next Tool View"), this);
-    action->setShortcut(Qt::META | Qt::CTRL | Qt::Key_N);
-    action->setIcon(KIcon("go-next"));
-    connect(action, SIGNAL(triggered(bool)), SLOT(selectNextDock()));
+    action = new QAction(i18n("Next Tool View"), this);
+    ac->setDefaultShortcut(action, Qt::META | Qt::CTRL | Qt::Key_N);
+    action->setIcon(QIcon::fromTheme("go-next"));
+    connect(action, &QAction::triggered, this, &MainWindowPrivate::selectNextDock);
     ac->addAction("select_next_dock", action);
 
-    action = new KAction(i18n("Previous Tool View"), this);
-    action->setShortcut(Qt::META | Qt::CTRL | Qt::Key_P);
-    action->setIcon(KIcon("go-previous"));
-    connect(action, SIGNAL(triggered(bool)), SLOT(selectPreviousDock()));
+    action = new QAction(i18n("Previous Tool View"), this);
+    ac->setDefaultShortcut(action, Qt::META | Qt::CTRL | Qt::Key_P);
+    action->setIcon(QIcon::fromTheme("go-previous"));
+    connect(action, &QAction::triggered, this, &MainWindowPrivate::selectPreviousDock);
     ac->addAction("select_previous_dock", action);
 
     action = new KActionMenu(i18n("Tool Views"), this);
@@ -141,16 +154,14 @@ MainWindowPrivate::MainWindowPrivate(MainWindow *w, Controller* controller)
 
     idealController = new IdealController(m_mainWindow);
 
-    IdealToolBar* leftToolBar = new IdealToolBar(i18n("Left Button Bar"), idealController->leftBarWidget, m_mainWindow);
-    leftToolBar->hideWhenEmpty();
-    m_mainWindow->addToolBar(Qt::LeftToolBarArea, leftToolBar);
+    m_leftToolBar = new IdealToolBar(i18n("Left Button Bar"), true, idealController->leftBarWidget, m_mainWindow);
+    m_mainWindow->addToolBar(Qt::LeftToolBarArea, m_leftToolBar);
 
-    IdealToolBar* rightToolBar = new IdealToolBar(i18n("Right Button Bar"), idealController->rightBarWidget, m_mainWindow);
-    rightToolBar->hideWhenEmpty();
-    m_mainWindow->addToolBar(Qt::RightToolBarArea, rightToolBar);
+    m_rightToolBar = new IdealToolBar(i18n("Right Button Bar"), true, idealController->rightBarWidget, m_mainWindow);
+    m_mainWindow->addToolBar(Qt::RightToolBarArea, m_rightToolBar);
 
-    IdealToolBar* bottomToolBar = new IdealToolBar(i18n("Bottom Button Bar"), idealController->bottomBarWidget, m_mainWindow);
-    m_mainWindow->addToolBar(Qt::BottomToolBarArea, bottomToolBar);
+    m_bottomToolBar = new IdealToolBar(i18n("Bottom Button Bar"), false, idealController->bottomBarWidget, m_mainWindow);
+    m_mainWindow->addToolBar(Qt::BottomToolBarArea, m_bottomToolBar);
 
     // adymo: intentionally do not add a toolbar for top buttonbar
     // this doesn't work well with toolbars added via xmlgui
@@ -164,17 +175,17 @@ MainWindowPrivate::MainWindowPrivate(MainWindow *w, Controller* controller)
     m_mainWindow->setCentralWidget(centralWidget);
 
     connect(idealController,
-            SIGNAL(dockShown(Sublime::View*,Sublime::Position,bool)),
+            &IdealController::dockShown,
             this,
-            SLOT(slotDockShown(Sublime::View*,Sublime::Position,bool)));
+            &MainWindowPrivate::slotDockShown);
 
     connect(idealController,
-            SIGNAL(widgetResized(Qt::DockWidgetArea,int)),
+            &IdealController::widgetResized,
             this,
-            SLOT(widgetResized(Qt::DockWidgetArea,int)));
+            &MainWindowPrivate::widgetResized);
 
-   connect(idealController, SIGNAL(dockBarContextMenuRequested(Qt::DockWidgetArea,QPoint)),
-            m_mainWindow, SLOT(dockBarContextMenuRequested(Qt::DockWidgetArea,QPoint)));
+   connect(idealController, &IdealController::dockBarContextMenuRequested,
+            m_mainWindow, &MainWindow::dockBarContextMenuRequested);
 }
 
 
@@ -184,6 +195,72 @@ MainWindowPrivate::~MainWindowPrivate()
     m_leftTabbarCornerWidget.clear();
 }
 
+void MainWindowPrivate::disableConcentrationMode()
+{
+    m_concentrationModeAction->setChecked(false);
+    restoreConcentrationMode();
+}
+
+void MainWindowPrivate::restoreConcentrationMode()
+{
+    const bool concentrationModeOn = m_concentrationModeAction->isChecked();
+    QWidget* cornerWidget = Q_NULLPTR;
+    if (m_concentrateToolBar) {
+        QLayout* l = m_concentrateToolBar->layout();
+        QLayoutItem* li = l->takeAt(1); //ensure the cornerWidget isn't destroyed with the toolbar
+        if (li) {
+            cornerWidget = li->widget();
+            delete li;
+        }
+
+        m_concentrateToolBar->deleteLater();
+    }
+
+    m_mainWindow->menuBar()->setVisible(!concentrationModeOn);
+    m_bottomToolBar->setVisible(!concentrationModeOn);
+    m_leftToolBar->setVisible(!concentrationModeOn);
+    m_rightToolBar->setVisible(!concentrationModeOn);
+    const bool hideToolBar = concentrationModeOn || !Container::configTabBarVisible();
+    foreach(Container* c, viewContainers) {
+        c->setTabBarHidden(hideToolBar);
+    }
+
+    if (concentrationModeOn) {
+        m_concentrateToolBar = new QToolBar(m_mainWindow);
+        m_concentrateToolBar->setObjectName("concentrateToolBar");
+        m_concentrateToolBar->addAction(m_concentrationModeAction);
+        QWidgetAction *action = new QWidgetAction(this);
+
+        action->setDefaultWidget(m_mainWindow->menuBar()->cornerWidget(Qt::TopRightCorner));
+        m_concentrateToolBar->addAction(action);
+        m_concentrateToolBar->setMovable(false);
+
+        m_mainWindow->addToolBar(Qt::TopToolBarArea, m_concentrateToolBar);
+        m_mainWindow->menuBar()->setCornerWidget(0, Qt::TopRightCorner);
+    } else if (cornerWidget) {
+        m_mainWindow->menuBar()->setCornerWidget(cornerWidget, Qt::TopRightCorner);
+        cornerWidget->show();
+    }
+
+    if (concentrationModeOn) {
+        m_mainWindow->installEventFilter(this);
+    } else {
+        m_mainWindow->removeEventFilter(this);
+    }
+}
+
+bool MainWindowPrivate::eventFilter(QObject* obj, QEvent* event)
+{
+    Q_ASSERT(m_mainWindow == obj);
+    if (event->type() == QEvent::KeyPress || event->type() == QEvent::KeyRelease) {
+        Qt::KeyboardModifiers modifiers = static_cast<QKeyEvent *>(event)->modifiers();
+
+        m_mainWindow->menuBar()->setVisible(modifiers == Qt::AltModifier && event->type() == QEvent::KeyPress);
+    }
+
+    return false;
+}
+
 void MainWindowPrivate::showLeftDock(bool b)
 {
     idealController->showLeftDock(b);
@@ -212,7 +289,7 @@ void MainWindowPrivate::setBackgroundVisible(bool v)
 {
     if(!bgCentralWidget)
         return;
-    
+
     bgCentralWidget->setVisible(v);
     splitterCentralWidget->setVisible(!v);
 }
@@ -259,7 +336,7 @@ Area::WalkerMode MainWindowPrivate::ViewCreator::operator() (AreaIndex *index)
         //no splitter - we shall create it and populate with views
         if (!index->parent())
         {
-            kDebug() << "reconstructing root area";
+            qCDebug(SUBLIME) << "reconstructing root area";
             //this is root area
             splitter = d->splitterCentralWidget;
             d->m_indexSplitters[index] = splitter;
@@ -275,7 +352,7 @@ Area::WalkerMode MainWindowPrivate::ViewCreator::operator() (AreaIndex *index)
             QSplitter *parent = d->m_indexSplitters.value(index->parent());
             splitter = new QSplitter(parent);
             d->m_indexSplitters[index] = splitter;
-            
+
             if(index == index->parent()->first())
                 parent->insertWidget(0, splitter);
             else
@@ -289,27 +366,32 @@ Area::WalkerMode MainWindowPrivate::ViewCreator::operator() (AreaIndex *index)
     else
     {
         Container *container = 0;
-        
+
         while(splitter->count() && qobject_cast<QSplitter*>(splitter->widget(0)))
         {
             // After unsplitting, we might have to remove old splitters
             QWidget* widget = splitter->widget(0);
-            kDebug() << "deleting" << widget;
+            qCDebug(SUBLIME) << "deleting" << widget;
             widget->setParent(0);
             delete widget;
         }
-        
+
         if (!splitter->widget(0))
         {
             //we need to create view container
             container = new Container(splitter);
-            connect(container, SIGNAL(activateView(Sublime::View*)), d->m_mainWindow, SLOT(activateView(Sublime::View*)));
-            connect(container, SIGNAL(tabContextMenuRequested(Sublime::View*,KMenu*)),
-                    d->m_mainWindow, SLOT(tabContextMenuRequested(Sublime::View*,KMenu*)));
-            connect(container, SIGNAL(tabToolTipRequested(Sublime::View*,Sublime::Container*,int)),
-                    d->m_mainWindow, SLOT(tabToolTipRequested(Sublime::View*,Sublime::Container*,int)));
-            connect(container, SIGNAL(requestClose(QWidget*)),
-                    d, SLOT(widgetCloseRequest(QWidget*)), Qt::QueuedConnection);
+            connect(container, &Container::activateView,
+                    d->m_mainWindow, &MainWindow::activateViewAndFocus);
+            connect(container, &Container::tabDoubleClicked,
+                    d->m_mainWindow, &MainWindow::tabDoubleClicked);
+            connect(container, &Container::tabContextMenuRequested,
+                    d->m_mainWindow, &MainWindow::tabContextMenuRequested);
+            connect(container, &Container::tabToolTipRequested,
+                    d->m_mainWindow, &MainWindow::tabToolTipRequested);
+            connect(container, static_cast<void(Container::*)(QWidget*)>(&Container::requestClose),
+                    d, &MainWindowPrivate::widgetCloseRequest, Qt::QueuedConnection);
+            connect(container, &Container::newTabRequested,
+                    d->m_mainWindow, &MainWindow::newTabRequested);
             splitter->addWidget(container);
         }
         else
@@ -319,11 +401,11 @@ Area::WalkerMode MainWindowPrivate::ViewCreator::operator() (AreaIndex *index)
         int position = 0;
         bool hadActiveView = false;
         Sublime::View* activeView = d->activeView;
-        
+
         foreach (View *view, index->views())
         {
             QWidget *widget = view->widget(container);
-            
+
             if (widget)
             {
                 if(!container->hasWidget(widget))
@@ -355,8 +437,8 @@ void MainWindowPrivate::reconstructViews(QList<View*> topViews)
 void MainWindowPrivate::reconstruct()
 {
     if(m_leftTabbarCornerWidget) {
-        m_leftTabbarCornerWidget.data()->hide();
-        m_leftTabbarCornerWidget.data()->setParent(0);
+        m_leftTabbarCornerWidget->hide();
+        m_leftTabbarCornerWidget->setParent(0);
     }
 
     idealController->setWidthForArea(Qt::LeftDockWidgetArea, area->thickness(Sublime::Left));
@@ -370,7 +452,7 @@ void MainWindowPrivate::reconstruct()
 
     m_mainWindow->blockSignals(true);
 
-    kDebug() << "RECONSTRUCT" << area << "  " << area->shownToolViews(Sublime::Left) << "\n";
+    qCDebug(SUBLIME) << "RECONSTRUCT" << area << area->shownToolViews(Sublime::Left);
     foreach (View *view, area->toolViews())
     {
         QString id = view->document()->documentSpecifier();
@@ -382,15 +464,15 @@ void MainWindowPrivate::reconstruct()
         }
     }
     m_mainWindow->blockSignals(false);
-    
+
     setTabBarLeftCornerWidget(m_leftTabbarCornerWidget.data());
 }
 
 void MainWindowPrivate::clearArea()
 {
     if(m_leftTabbarCornerWidget)
-        m_leftTabbarCornerWidget.data()->setParent(0);
-    
+        m_leftTabbarCornerWidget->setParent(0);
+
     //reparent toolview widgets to 0 to prevent their deletion together with dockwidgets
     foreach (View *view, area->toolViews())
     {
@@ -416,7 +498,7 @@ void MainWindowPrivate::clearArea()
     m_indexSplitters.clear();
     area = 0;
     viewContainers.clear();
-    
+
     setTabBarLeftCornerWidget(m_leftTabbarCornerWidget.data());
 }
 
@@ -464,21 +546,20 @@ void MainWindowPrivate::viewRemovedInternal(AreaIndex* index, View* view)
 void MainWindowPrivate::viewAdded(Sublime::AreaIndex *index, Sublime::View *view)
 {
     if(m_leftTabbarCornerWidget) {
-        m_leftTabbarCornerWidget.data()->hide();
-        m_leftTabbarCornerWidget.data()->setParent(0);
+        m_leftTabbarCornerWidget->hide();
+        m_leftTabbarCornerWidget->setParent(0);
     }
 
+    // Remove container objects in the hierarchy from the parents,
+    // because they are not needed anymore, and might lead to broken splitter hierarchy and crashes.
+    for(Sublime::AreaIndex* current = index; current; current = current->parent())
     {
-         // Remove container objects in the hierarchy from the parents,
-         // because they are not needed anymore, and might lead to broken splitter hierarchy and crashes.
-        for(Sublime::AreaIndex* current = index; current; current = current->parent())
-        {
         QSplitter *splitter = m_indexSplitters[current];
         if (current->isSplit() && splitter)
         {
             // Also update the orientation
             splitter->setOrientation(current->orientation());
-            
+
             for(int w = 0; w < splitter->count(); ++w)
             {
                 Container *container = qobject_cast<Sublime::Container*>(splitter->widget(w));
@@ -495,13 +576,12 @@ void MainWindowPrivate::viewAdded(Sublime::AreaIndex *index, Sublime::View *view
                 }
             }
         }
-        }
     }
 
     ViewCreator viewCreator(this);
     area->walkViews(viewCreator, index);
     emit m_mainWindow->viewAdded( view );
-    
+
     setTabBarLeftCornerWidget(m_leftTabbarCornerWidget.data());
 
     setBackgroundVisible(false);
@@ -514,20 +594,20 @@ void Sublime::MainWindowPrivate::raiseToolView(Sublime::View * view)
 
 void MainWindowPrivate::aboutToRemoveView(Sublime::AreaIndex *index, Sublime::View *view)
 {
-    if (!m_indexSplitters[index])
+    QSplitter *splitter = m_indexSplitters[index];
+    if (!splitter)
         return;
 
-    QSplitter *splitter = m_indexSplitters[index];
-    kDebug() << "index " << index << " root " << area->rootIndex();
-    kDebug() << "splitter " << splitter << " container " << splitter->widget(0);
-    kDebug() << "structure: " << index->print() << " whole structure: " << area->rootIndex()->print();
+    qCDebug(SUBLIME) << "index " << index << " root " << area->rootIndex();
+    qCDebug(SUBLIME) << "splitter " << splitter << " container " << splitter->widget(0);
+    qCDebug(SUBLIME) << "structure: " << index->print() << " whole structure: " << area->rootIndex()->print();
     //find the container for the view and remove the widget
     Container *container = qobject_cast<Container*>(splitter->widget(0));
     if (!container) {
-        kWarning() << "Splitter does not have a left widget!";
+        qWarning() << "Splitter does not have a left widget!";
         return;
     }
-    
+
     emit m_mainWindow->aboutToRemoveView( view );
 
     if (view->widget())
@@ -539,21 +619,21 @@ void MainWindowPrivate::aboutToRemoveView(Sublime::AreaIndex *index, Sublime::Vi
     {
         //container is not empty or this is a root index
         //just remove a widget
-		if( view->widget() ) {
-			container->removeWidget(view->widget());
-			view->widget()->setParent(0);
-			//activate what is visible currently in the container if the removed view was active
-			if (wasActive)
-				return m_mainWindow->setActiveView(container->viewForWidget(container->currentWidget()));
-		}
+        if( view->widget() ) {
+            container->removeWidget(view->widget());
+            view->widget()->setParent(0);
+            //activate what is visible currently in the container if the removed view was active
+            if (wasActive)
+                return m_mainWindow->setActiveView(container->viewForWidget(container->currentWidget()));
+        }
     }
     else
     {
         if(m_leftTabbarCornerWidget) {
-            m_leftTabbarCornerWidget.data()->hide();
-            m_leftTabbarCornerWidget.data()->setParent(0);
+            m_leftTabbarCornerWidget->hide();
+            m_leftTabbarCornerWidget->setParent(0);
         }
-        
+
         // We've about to remove the last view of this container.  It will
         // be empty, so have to delete it, as well.
 
@@ -565,7 +645,7 @@ void MainWindowPrivate::aboutToRemoveView(Sublime::AreaIndex *index, Sublime::Vi
         if (view->widget())
             view->widget()->setParent(0);
         else
-            kWarning() << "View does not have a widget!";
+            qWarning() << "View does not have a widget!";
 
         Q_ASSERT(container->count() == 0);
         // We can be called from signal handler of container
@@ -579,9 +659,6 @@ void MainWindowPrivate::aboutToRemoveView(Sublime::AreaIndex *index, Sublime::Vi
             /* The splitter used to have container as the only child, now it's
                time to get rid of it.  Make sure deleting splitter does not
                delete container -- per above comment, we'll delete it later.  */
-            QCommonStyle* tmpStyle = new QCommonStyle; // temp style since container uses it's parents style, which gets zeroed
-            container->setStyle(tmpStyle);
-            connect(container, SIGNAL(destroyed(QObject*)), tmpStyle, SLOT(deleteLater()));
             container->setParent(0);
             m_indexSplitters.remove(index);
             delete splitter;
@@ -616,10 +693,10 @@ void MainWindowPrivate::aboutToRemoveView(Sublime::AreaIndex *index, Sublime::Vi
                 parentSplitter->setSizes(sizes);
             }
 
-            kDebug() << "after deleation " << parent << " has "
+            qCDebug(SUBLIME) << "after deleation " << parent << " has "
                          << parentSplitter->count() << " elements";
 
-            
+
             //find the container somewhere to activate
             Container *containerToActivate = parentSplitter->findChild<Sublime::Container*>();
             //activate the current view there
@@ -676,20 +753,22 @@ Qt::DockWidgetArea MainWindowPrivate::positionToDockArea(Position position)
 
 void MainWindowPrivate::switchToArea(QAction *action)
 {
-    kDebug() << "for" << action;
-    controller->showArea(m_actionAreas[action], m_mainWindow);
+    qCDebug(SUBLIME) << "for" << action;
+    controller->showArea(m_actionAreas.value(action), m_mainWindow);
 }
 
 void MainWindowPrivate::updateAreaSwitcher(Sublime::Area *area)
 {
-    if (m_areaActions.contains(area))
-        m_areaActions[area]->setChecked(true);
+    QAction* action = m_areaActions.value(area);
+    if (action)
+        action->setChecked(true);
 }
 
 void MainWindowPrivate::activateFirstVisibleView()
 {
-    if (area->views().count() > 0)
-        m_mainWindow->activateView(area->views().first());
+    QList<Sublime::View*> views = area->views();
+    if (views.count() > 0)
+        m_mainWindow->activateView(views.first());
 }
 
 void MainWindowPrivate::widgetResized(Qt::DockWidgetArea /*dockArea*/, int /*thickness*/)
@@ -699,9 +778,8 @@ void MainWindowPrivate::widgetResized(Qt::DockWidgetArea /*dockArea*/, int /*thi
 
 void MainWindowPrivate::widgetCloseRequest(QWidget* widget)
 {
-    if (widgetToView.contains(widget))
+    if (View *view = widgetToView.value(widget))
     {
-        View *view = widgetToView[widget];
         area->closeView(view);
     }
 }
@@ -714,19 +792,19 @@ void MainWindowPrivate::setTabBarLeftCornerWidget(QWidget* widget)
         m_leftTabbarCornerWidget.clear();
     }
     m_leftTabbarCornerWidget = widget;
-    
+
     if(!widget || !area || viewContainers.isEmpty())
         return;
-    
+
     AreaIndex* putToIndex = area->rootIndex();
     QSplitter* splitter = m_indexSplitters[putToIndex];
     while(putToIndex->isSplit()) {
         putToIndex = putToIndex->first();
         splitter = m_indexSplitters[putToIndex];
     }
-    
+
 //     Q_ASSERT(splitter || putToIndex == area->rootIndex());
-    
+
     Container* c = 0;
     if(splitter) {
         c = qobject_cast<Container*>(splitter->widget(0));
@@ -734,7 +812,7 @@ void MainWindowPrivate::setTabBarLeftCornerWidget(QWidget* widget)
         c = viewContainers.values()[0];
     }
     Q_ASSERT(c);
-    
+
     c->setLeftCornerWidget(widget);
 }
 
