@@ -21,6 +21,7 @@
 
 #include <QMap>
 #include <QObject>
+#include <QPointer>
 #include <QSet>
 #include <QTabBar>
 #include <QHBoxLayout>
@@ -42,6 +43,7 @@ class QAction;
 class QSplitter;
 class QDockWidget;
 class QComboBox;
+class IdealToolBar;
 
 namespace Sublime {
 
@@ -52,20 +54,6 @@ class AreaIndex;
 class IdealMainWidget;
 class IdealController;
 
-class AreaTabButton : public QWidget {
-    public:
-    AreaTabButton(QString text, QIcon icon, uint iconSize, QWidget* parent, bool isCurrent, QWidget* _customButtonWidget) ;
-    
-    QLabel* iconLabel;
-    QLabel* textLabel;
-    QWidget* customButtonWidget;
-
-    void setIsCurrent ( bool arg1 );
-
-    private:
-    bool m_isCurrent;
-};
-
 class MainWindowPrivate: public QObject {
     Q_OBJECT
 public:
@@ -75,7 +63,7 @@ public:
     /**Use this to create tool views for an area.*/
     class IdealToolViewCreator {
     public:
-        IdealToolViewCreator(MainWindowPrivate *_d): d(_d) {}
+        explicit IdealToolViewCreator(MainWindowPrivate *_d): d(_d) {}
         Area::WalkerMode operator() (View *view, Sublime::Position position);
     private:
         MainWindowPrivate *d;
@@ -84,7 +72,7 @@ public:
     /**Use this to create views for an area.*/
     class ViewCreator {
     public:
-        ViewCreator(MainWindowPrivate *_d, QList<View*> _topViews = QList<View*>()): d(_d), topViews(_topViews.toSet()) {}
+        explicit ViewCreator(MainWindowPrivate *_d, QList<View*> _topViews = QList<View*>()): d(_d), topViews(_topViews.toSet()) {}
         Area::WalkerMode operator() (AreaIndex *index);
     private:
         MainWindowPrivate *d;
@@ -118,7 +106,10 @@ public:
 
     IdealController *idealController;
     int ignoreDockShown;
-    bool autoAreaSettingsSave;                       
+    bool autoAreaSettingsSave;
+
+    bool eventFilter(QObject* obj, QEvent* event) override;
+    void disableConcentrationMode();
 
 public slots:
     void toggleDocksShown();
@@ -148,6 +139,8 @@ private slots:
     void selectPreviousDock();
 
 private:
+    void restoreConcentrationMode();
+
     void setBackgroundVisible(bool v);
     Qt::DockWidgetArea positionToDockArea(Position position);
     void cleanCentralWidget();
@@ -155,11 +148,16 @@ private:
     MainWindow *m_mainWindow;
     // uses QPointer to make already-deleted splitters detectable
     QMap<AreaIndex*, QPointer<QSplitter> > m_indexSplitters;
-    friend class AreaSelectionAction;
 
     QMap<Area*, QAction*> m_areaActions;
     QMap<QAction*, Area*> m_actionAreas;
-    QWeakPointer<QWidget> m_leftTabbarCornerWidget;
+    QPointer<QWidget> m_leftTabbarCornerWidget;
+    QPointer<QToolBar> m_concentrateToolBar;
+    IdealToolBar* m_bottomToolBar;
+    IdealToolBar* m_rightToolBar;
+    IdealToolBar* m_leftToolBar;
+
+    QAction* m_concentrationModeAction;
 };
 
 }
