@@ -25,7 +25,7 @@
 
 #include <language/duchain/topducontext.h>
 
-#include "kdevplatformtestsexport.h"
+#include "testsexport.h"
 
 namespace KDevelop {
 
@@ -101,7 +101,17 @@ public:
      * 
      * @see KDevelop::DUChain::updateContextForUrl
      */
-    void parse(KDevelop::TopDUContext::Features features, int priority = 1);
+    void parse(TopDUContext::Features features = TopDUContext::AllDeclarationsContextsAndUses, int priority = 1);
+
+    /**
+     * Convenience method:
+     * Trigger parse and wait for the file to be parsed. Internally calls waitForParsed()
+     *
+     * @see waitForParsed()
+     * @see parse()
+     */
+    bool parseAndWait(TopDUContext::Features features = TopDUContext::AllDeclarationsContextsAndUses,
+                      int priority = 1, int timeout = 1000);
 
     /**
      * Blocks current thread and waits until the file has been parsed.
@@ -112,7 +122,7 @@ public:
      * Otherwise true is returned, indicating parsing finished
      * within the timeout interval.
      */
-    bool waitForParsed(int timeout = 60000);
+    bool waitForParsed(int timeout = 1000);
 
     /**
      * Check whether the file has been processed after the last call to @c parse().
@@ -137,6 +147,14 @@ public:
      */
     QString fileContents() const;
 
+    /**
+     * Set to true when you want to keep the DUChain data.
+     *
+     * By default the DUChain data is removed on destruction of the TestFile.
+     */
+    void setKeepDUChainData(bool keep);
+    bool keepDUChainData();
+
 private:
     struct TestFilePrivate;
     TestFilePrivate* d;
