@@ -22,28 +22,17 @@
 #ifndef KDEVPLATFORM_TESTHELPERS_H
 #define KDEVPLATFORM_TESTHELPERS_H
 
-#include "kdevplatformtestsexport.h"
+#include "testsexport.h"
 
 #include <language/editor/rangeinrevision.h>
 #include <language/duchain/types/abstracttype.h>
 #include <language/duchain/declaration.h>
+#include <serialization/indexedstring.h>
 
 #include <QTest>
 
 namespace QTest {
 
-template<>
-inline char* toString(const KDevelop::SimpleCursor& c)
-{
-    return qstrdup(qPrintable(QString("(%1, %2)").arg(c.line).arg(c.column)));
-}
-
-template<>
-inline char* toString(const KDevelop::SimpleRange& r)
-{
-    return qstrdup(qPrintable(QString("[%1, %2]").arg(toString(r.start)).arg(toString(r.end))));
-}
-
 template<>
 inline char* toString(const KDevelop::CursorInRevision& c)
 {
@@ -56,18 +45,6 @@ inline char* toString(const KDevelop::RangeInRevision& r)
     return toString(r.castToSimpleRange());
 }
 
-template<>
-inline char* toString(const KTextEditor::Cursor& c)
-{
-    return qstrdup(qPrintable(QString("(%1, %2)").arg(c.line()).arg(c.column())));
-}
-
-template<>
-inline char* toString(const KTextEditor::Range& r)
-{
-    return qstrdup(qPrintable(QString("[%1, %2]").arg(toString(r.start())).arg(toString(r.end()))));
-}
-
 template<>
 inline char* toString(const KDevelop::QualifiedIdentifier& id)
 {
@@ -83,7 +60,7 @@ inline char* toString(const KDevelop::Identifier& id)
 template<>
 inline char* toString(const KDevelop::Declaration& dec)
 {
-    QString s = QString("Declaration %1 (%2): %3")
+    QString s = QStringLiteral("Declaration %1 (%2): %3")
         .arg(dec.identifier().toString())
         .arg(dec.qualifiedIdentifier().toString())
         .arg(reinterpret_cast<qint64>(&dec));
@@ -91,13 +68,19 @@ inline char* toString(const KDevelop::Declaration& dec)
 }
 
 template<>
-inline char* toString(const TypePtr<KDevelop::AbstractType>& type)
+inline char* toString(const KDevelop::AbstractType::Ptr& type)
 {
-    QString s = QString("Type: %1")
-        .arg(type ? type->toString() : QString("<null>"));
+    QString s = QStringLiteral("Type: %1")
+        .arg(type ? type->toString() : QStringLiteral("<null>"));
     return qstrdup(s.toLatin1().constData());
 }
 
+template<>
+inline char* toString(const KDevelop::IndexedString& string)
+{
+    return qstrdup(qPrintable(string.str()));
+}
+
 }
 
 #endif // KDEVPLATFORM_TESTHELPERS_H
