@@ -19,21 +19,19 @@
 #ifndef KDEVPLATFORM_CONVENIENTFREELIST_H
 #define KDEVPLATFORM_CONVENIENTFREELIST_H
 
-#include <QtCore/QVector>
-#include <QtCore/QPair>
-
-#include <KDE/KDebug>
+#include <QPair>
+#include <QVector>
 
 #include "embeddedfreetree.h"
 #include "kdevvarlengtharray.h"
 
 namespace KDevelop {
-    
+
     template<class Data, class Handler>
     class ConvenientEmbeddedSetIterator;
     template<class Data, class Handler, class Data2, class Handler2, class KeyExtractor>
     class ConvenientEmbeddedSetFilterIterator;
-    
+
     ///A convenience-class for accessing the data in a set managed by the EmbeddedFreeTree algorithms.
     template<class Data, class Handler>
     class ConstantConvenientEmbeddedSet {
@@ -42,39 +40,39 @@ namespace KDevelop {
             }
             ConstantConvenientEmbeddedSet(const Data* data, uint count, int centralFreeItem) : m_data(data), m_dataSize(count), m_centralFreeItem(centralFreeItem) {
             }
-            
+
             ///Returns whether the item is contained in this set
             bool contains(const Data& data) const {
                 return indexOf(data) != -1;
             }
-            
+
             ///Returns the position of the item in the underlying array, or -1 if it is not contained
             int indexOf(const Data& data) const {
                 EmbeddedTreeAlgorithms<Data, Handler> alg(m_data, m_dataSize, m_centralFreeItem);
                 return alg.indexOf(data);
             }
-            
+
             ///Returns the size of the underlying array
             uint dataSize() const {
                 return m_dataSize;
             }
-            
+
             uint countFreeItems() {
                 EmbeddedTreeAlgorithms<Data, Handler> alg(m_data, m_dataSize, m_centralFreeItem);
                 return alg.countFreeItems();
             }
-            
+
             void verify() {
                 EmbeddedTreeAlgorithms<Data, Handler> alg(m_data, m_dataSize, m_centralFreeItem);
                 alg.verifyTreeConsistent();
                 alg.verifyOrder();
             }
-            
+
             ///Returns the underlying array. That array may contain invalid/free items.
             const Data* data() const {
                 return m_data;
             }
-            
+
             ///Returns the first valid index that has a data-value larger or equal to @param data.
             ///Returns -1 if nothing is found.
             int lowerBound(const Data& data) const {
@@ -95,27 +93,27 @@ namespace KDevelop {
             int validMiddle(uint start, uint end) {
                 if(end <= start)
                     return -1;
-                
+
                 int firstTry = ((end-start)/2) + start;
-                
+
                 int thisTry = firstTry;
                 while(thisTry < (int)end && Handler::isFree(m_data[thisTry]))
                     ++thisTry;
-                
+
                 if(thisTry != (int)end)
                     return thisTry;
-                
+
                 //Nothing find on right side of middle, try the other direction
                 thisTry = firstTry-1;
                 while(thisTry >= (int)start && Handler::isFree(m_data[thisTry]))
                     --thisTry;
-                
+
                 if(thisTry >= (int)start)
                     return thisTry;
                 else
                     return -1;
             }
-            
+
             ///Returns the first valid item in the range [pos, end), or -1
             int firstValidItem(int start, int end = -1) const {
                 if(end == -1)
@@ -126,7 +124,7 @@ namespace KDevelop {
 
                 return -1;
             }
-            
+
             ///Returns the last valid item in the range [pos, end), or -1
             int lastValidItem(int start = 0, int end = -1) const {
                 if(end == -1)
@@ -138,17 +136,17 @@ namespace KDevelop {
 
                 return -1;
             }
-            
+
             typedef ConvenientEmbeddedSetIterator<Data, Handler> Iterator;
-            
+
             ConvenientEmbeddedSetIterator<Data, Handler> iterator() const;
-            
+
 //         protected:
             const Data* m_data;
             uint m_dataSize;
             int m_centralFreeItem;
     };
-    
+
     ///Convenient iterator that automatically skips invalid/free items in the array.
     template<class Data, class Handler>
     class ConvenientEmbeddedSetIterator : public ConstantConvenientEmbeddedSet<Data, Handler> {
@@ -157,26 +155,26 @@ namespace KDevelop {
             //Move to first valid position
             moveToValid();
         }
-        
+
         ///Returns true of this iterator has a value to return
         operator bool() const {
             return m_pos != this->m_dataSize;
         }
-        
+
         const Data* operator->() const {
             return &this->m_data[m_pos];
         }
-        
+
         const Data& operator*() const {
             return this->m_data[m_pos];
         }
-        
+
         ConvenientEmbeddedSetIterator& operator++() {
             ++m_pos;
             moveToValid();
             return *this;
         }
-        
+
         protected:
             inline void moveToValid() {
                 while(this->m_pos < this->m_dataSize && (Handler::isFree(this->m_data[this->m_pos])))
@@ -184,8 +182,8 @@ namespace KDevelop {
             }
             uint m_pos;
     };
-    
-    
+
+
     ///An iterator that allows efficient matching between two lists with different data type.
     ///Important: It must be possible to extract the data-type of the second list from the items in the first list
     ///The second list must be sorted by that data.
@@ -201,11 +199,11 @@ namespace KDevelop {
             boundStack.append( qMakePair( qMakePair(0u, this->m_dataSize), qMakePair(0u, rhs.m_dataSize) ) );
             go();
         }
-        
+
         operator bool() const {
             return m_match != -1;
         }
-        
+
         const Data* operator->() const {
             Q_ASSERT(m_match != -1);
             return &this->m_data[m_match];
@@ -215,7 +213,7 @@ namespace KDevelop {
             Q_ASSERT(m_match != -1);
             return this->m_data[m_match];
         }
-        
+
         ConvenientEmbeddedSetFilterIterator& operator++() {
             Q_ASSERT(m_match != -1);
             go();
@@ -226,7 +224,7 @@ namespace KDevelop {
         private:
         void go() {
             m_match = -1;
-            
+
             boundsUp:
             if(boundStack.isEmpty())
                 return;
@@ -240,39 +238,39 @@ namespace KDevelop {
             //This code works, but it doesn't give a speedup
             int ownFirstValid = this->firstValidItem(ownStart, ownEnd), ownLastValid = this->lastValidItem(ownStart, ownEnd);
             int rhsFirstValid = m_rhs.firstValidItem(rhsStart, rhsEnd), rhsLastValid = m_rhs.lastValidItem(rhsStart, rhsEnd);
-            
+
             if(ownFirstValid == -1 || rhsFirstValid == -1)
                 goto boundsUp;
-            
-            
+
+
             Data2 ownFirstValidData = KeyExtractor::extract(this->m_data[ownFirstValid]);
             Data2 ownLastValidData = KeyExtractor::extract(this->m_data[ownLastValid]);
-            
+
             Data2 commonStart = ownFirstValidData;
             Data2 commonLast = ownLastValidData; //commonLast is also still valid
-            
+
             if(commonStart < m_rhs.m_data[rhsFirstValid])
                 commonStart = m_rhs.m_data[rhsFirstValid];
-            
+
             if(m_rhs.m_data[rhsLastValid] < commonLast)
                 commonLast = m_rhs.m_data[rhsLastValid];
-            
+
             if(commonLast < commonStart)
                 goto boundsUp;
 #endif
-            
+
             while(true) {
                 if(ownStart == ownEnd)
                     goto boundsUp;
-                
+
                 int ownMiddle = this->validMiddle(ownStart, ownEnd);
                 Q_ASSERT(ownMiddle < 100000);
                 if(ownMiddle == -1)
                     goto boundsUp; //No valid items in the range
-                
+
                 Data2 currentData2 = KeyExtractor::extract(this->m_data[ownMiddle]);
                 Q_ASSERT(!Handler2::isFree(currentData2));
-                
+
                 int bound = m_rhs.lowerBound(currentData2, rhsStart, rhsEnd);
                 if(bound == -1) {
                     //Release second half of the own range
@@ -294,12 +292,12 @@ namespace KDevelop {
                 if(bound == m_rhs.firstValidItem(rhsStart)) {
                     //The bound is the first valid item of the second range.
                     //Discard left side and the matched left item, and continue.
-                    
+
                     ownStart = ownMiddle+1;
                     rhsStart = bound;
                     continue;
                 }
-                
+
                 //Standard: Split both sides into 2 ranges that will be checked next
                 boundStack.append( qMakePair( qMakePair( (uint)ownMiddle+1, ownEnd ), qMakePair((uint)bound, rhsEnd)) );
 //                 Q_ASSERT(ownMiddle <= ownEnd);
@@ -336,11 +334,11 @@ namespace KDevelop {
             }
             go();
         }
-        
+
         operator bool() const {
             return m_match != -1;
         }
-        
+
         const Data* operator->() const {
             Q_ASSERT(m_match != -1);
             return &this->m_data[m_match];
@@ -350,7 +348,7 @@ namespace KDevelop {
             Q_ASSERT(m_match != -1);
             return this->m_data[m_match];
         }
-        
+
         ConvenientEmbeddedSetTreeFilterIterator& operator++() {
             Q_ASSERT(m_match != -1);
             go();
@@ -374,7 +372,7 @@ namespace KDevelop {
                     return;
             }
             m_match = -1;
-            
+
             boundsUp:
             if(boundStack.isEmpty())
                 return;
@@ -388,16 +386,16 @@ namespace KDevelop {
                 goto boundsUp;
             if(!currentNode.isValid())
                 goto boundsUp;
-            
+
             while(true) {
                 if(ownStart == ownEnd)
                     goto boundsUp;
-                
+
                 if(currentNode.isFinalNode()) {
-//                      kDebug() << ownStart << ownEnd << "final node" << currentNode.start() * extractor_div_with << currentNode.end() * extractor_div_with;
+//                      qCDebug(UTIL) << ownStart << ownEnd << "final node" << currentNode.start() * extractor_div_with << currentNode.end() * extractor_div_with;
                     //Check whether the item is contained
                     int bound = lowerBound(*currentNode, ownStart, ownEnd);
-//                      kDebug() << "bound:" << bound << (KeyExtractor::extract(this->m_data[bound]) == *currentNode);
+//                      qCDebug(UTIL) << "bound:" << bound << (KeyExtractor::extract(this->m_data[bound]) == *currentNode);
                     if(bound != -1 && KeyExtractor::extract(this->m_data[bound]) == *currentNode) {
                         //Got a match
                         m_match = bound;
@@ -409,23 +407,23 @@ namespace KDevelop {
                         goto boundsUp;
                     }
                 }else{
-//                     kDebug() << ownStart << ownEnd << "node" << currentNode.start() * extractor_div_with << currentNode.end() * extractor_div_with;
+//                     qCDebug(UTIL) << ownStart << ownEnd << "node" << currentNode.start() * extractor_div_with << currentNode.end() * extractor_div_with;
                     //This is not a final node, split up the search into the sub-nodes
                     typename TreeSet::Node leftNode = currentNode.leftChild();
                     typename TreeSet::Node rightNode = currentNode.rightChild();
                     Q_ASSERT(leftNode.isValid());
                     Q_ASSERT(rightNode.isValid());
-                    
-                    
+
+
                     Data2 leftLastItem = leftNode.lastItem();
-                    
+
                     int rightSearchStart = lowerBound(rightNode.firstItem(), ownStart, ownEnd);
                     if(rightSearchStart == -1)
                         rightSearchStart = ownEnd;
                     int leftSearchLast = lowerBound(leftLastItem, ownStart, rightSearchStart != -1 ? rightSearchStart : ownEnd);
                     if(leftSearchLast == -1)
                         leftSearchLast = rightSearchStart-1;
-                    
+
                     bool recurseLeft = false;
                     if(leftSearchLast > (int)ownStart) {
                         recurseLeft = true; //There must be something in the range ownStart -> leftSearchLast that matches the range
@@ -434,16 +432,16 @@ namespace KDevelop {
                         Data2 leftFoundStartData = KeyExtractor::extract(this->m_data[ownStart]);
                         recurseLeft = leftFoundStartData < leftLastItem || leftFoundStartData == leftLastItem;
                     }
-                    
+
                     bool recurseRight = false;
                     if(rightSearchStart < (int)ownEnd)
                         recurseRight = true;
-                    
+
                     if(recurseLeft && recurseRight) {
                         //Push the right branch onto the stack, and work in the left one
                         boundStack.append( qMakePair( qMakePair( (uint)rightSearchStart, ownEnd ), rightNode) );
                     }
-                    
+
                     if(recurseLeft) {
                         currentNode = leftNode;
                         if(leftSearchLast != -1)
@@ -457,7 +455,7 @@ namespace KDevelop {
                 }
             }
         }
-        
+
         ///Returns the first valid index that has an extracted data-value larger or equal to @param data.
         ///Returns -1 if nothing is found.
         int lowerBound(const Data2& data, int start, int end) {
@@ -465,16 +463,16 @@ namespace KDevelop {
             while(1) {
                 if(start >= end)
                     return currentBound;
-                
+
                 int center = (start + end)/2;
-                
+
                 //Skip free items, since they cannot be used for ordering
                 for(; center < end; ) {
                     if(!Handler::isFree(this->m_data[center]))
                         break;
                     ++center;
                 }
-                
+
                 if(center == end) {
                     end = (start + end)/2; //No non-free items found in second half, so continue search in the other
                 }else{
@@ -490,7 +488,7 @@ namespace KDevelop {
                 }
             }
         }
-        
+
         //Bounds that yet need to be matched. Always a range in the own vector, and a node that all items in the range are contained in
         KDevVarLengthArray<QPair<QPair<uint, uint>, typename TreeSet::Node > > boundStack;
         TreeSet m_rhs;
@@ -506,9 +504,9 @@ namespace KDevelop {
         public:
         ConvenientEmbeddedSetTreeFilterVisitor() {
         }
-        
+
         typedef QPair<QPair<uint, uint>, typename TreeSet::Node > Bounds;
-        
+
         struct Bound {
             inline Bound(uint s, uint e, const typename TreeSet::Node& n) : start(s), end(e), node(n) {
             }
@@ -518,16 +516,16 @@ namespace KDevelop {
             uint end;
             typename TreeSet::Node node;
         };
-        
+
         ///@param noFiltering whether the given input is pre-filtered. If this is true, base will be iterated without skipping any items.
         ConvenientEmbeddedSetTreeFilterVisitor(Visitor& visitor, const ConvenientEmbeddedSetIterator<Data, Handler>& base, const TreeSet& rhs, bool noFiltering = false) : ConvenientEmbeddedSetIterator<Data, Handler>(base), m_visitor(visitor), m_rhs(rhs), m_noFiltering(noFiltering) {
-            
+
             if(m_noFiltering) {
                 for(uint a = 0; a < this->m_dataSize; ++a)
                     visitor(this->m_data[a]);
                 return;
             }
-            
+
             if(rhs.node().isValid())  {
                 //Correctly initialize the initial bounds
                 int ownStart = lowerBound(rhs.node().firstItem(), 0, this->m_dataSize);
@@ -538,26 +536,26 @@ namespace KDevelop {
                     ownEnd = this->m_dataSize;
                 else
                     ownEnd += 1;
-                
+
                 go( Bound((uint)ownStart, (uint)ownEnd, rhs.node()) );
             }
         }
-        
+
         private:
         void go( Bound bound ) {
 
             KDevVarLengthArray<Bound> bounds;
-            
+
             while(true) {
                 if(bound.start >= bound.end)
                     goto nextBound;
-                
+
                 if(bound.node.isFinalNode()) {
                     //Check whether the item is contained
                     int b = lowerBound(*bound.node, bound.start, bound.end);
                     if(b != -1) {
                         const Data2& matchTo(*bound.node);
-                    
+
                         if(KeyExtractor::extract(this->m_data[b]) == matchTo) {
                             while(1) {
                                 m_visitor(this->m_data[b]);
@@ -576,17 +574,17 @@ namespace KDevelop {
                     typename TreeSet::Node rightNode = bound.node.rightChild();
                     Q_ASSERT(leftNode.isValid());
                     Q_ASSERT(rightNode.isValid());
-                    
-                    
+
+
                     Data2 leftLastItem = leftNode.lastItem();
-                    
+
                     int rightSearchStart = lowerBound(rightNode.firstItem(), bound.start, bound.end);
                     if(rightSearchStart == -1)
                         rightSearchStart = bound.end;
                     int leftSearchLast = lowerBound(leftLastItem, bound.start, rightSearchStart != -1 ? rightSearchStart : bound.end);
                     if(leftSearchLast == -1)
                         leftSearchLast = rightSearchStart-1;
-                    
+
                     bool recurseLeft = false;
                     if(leftSearchLast > (int)bound.start) {
                         recurseLeft = true; //There must be something in the range bound.start -> leftSearchLast that matches the range
@@ -595,14 +593,14 @@ namespace KDevelop {
                         Data2 leftFoundStartData = KeyExtractor::extract(this->m_data[bound.start]);
                         recurseLeft = leftFoundStartData < leftLastItem || leftFoundStartData == leftLastItem;
                     }
-                    
+
                     bool recurseRight = false;
                     if(rightSearchStart < (int)bound.end)
                         recurseRight = true;
-                    
+
                     if(recurseLeft && recurseRight)
                         bounds.append( Bound(rightSearchStart, bound.end, rightNode) );
-                    
+
                     if(recurseLeft) {
                         bound.node = leftNode;
                         if(leftSearchLast != -1)
@@ -624,7 +622,7 @@ namespace KDevelop {
                     }
             }
         }
-        
+
         ///Returns the first valid index that has an extracted data-value larger or equal to @param data.
         ///Returns -1 if nothing is found.
         int lowerBound(const Data2& data, int start, int end) {
@@ -632,16 +630,16 @@ namespace KDevelop {
             while(1) {
                 if(start >= end)
                     return currentBound;
-                
+
                 int center = (start + end)/2;
-                
+
                 //Skip free items, since they cannot be used for ordering
                 for(; center < end; ) {
                     if(!Handler::isFree(this->m_data[center]))
                         break;
                     ++center;
                 }
-                
+
                 if(center == end) {
                     end = (start + end)/2; //No non-free items found in second half, so continue search in the other
                 }else{
@@ -657,13 +655,13 @@ namespace KDevelop {
                 }
             }
         }
-        
+
         //Bounds that yet need to be matched. Always a range in the own vector, and a node that all items in the range are contained in
         Visitor& m_visitor;
         TreeSet m_rhs;
         bool m_noFiltering;
     };
-    
+
     template<class Data, class Handler>
     ConvenientEmbeddedSetIterator<Data, Handler> ConstantConvenientEmbeddedSet<Data, Handler>::iterator() const {
         return ConvenientEmbeddedSetIterator<Data, Handler>(m_data, m_dataSize, m_centralFreeItem);
@@ -680,34 +678,34 @@ namespace KDevelop {
     ///- Can be combined with other embedded-free-list based sets using algorithms in ConstantConvenientEmbeddedSet
     ///Disadvantages:
     ///- Significantly slower insertion
-    
+
     template<class Data, class Handler>
     class ConvenientFreeListSet {
         public:
-            
+
             typedef ConvenientEmbeddedSetIterator<Data, Handler> Iterator;
-            
+
             ConvenientFreeListSet() : m_centralFree(-1) {
             }
-            
+
             ///Re-construct a set from its components
             ConvenientFreeListSet(int centralFreeItem, QVector<Data> data) : m_data(data), m_centralFree(centralFreeItem) {
             }
-            
+
             ///You can use this to store the set to disk and later give it together with data() to the constructor,  thus reconstructing it.
             int centralFreeItem() const {
                 return m_centralFree;
             }
-            
+
             const QVector<Data>& data() const {
                 return m_data;
             }
-            
+
             void insert(const Data& item) {
                 if(contains(item))
                     return;
                 KDevelop::EmbeddedTreeAddItem<Data, Handler> add(m_data.data(), m_data.size(), m_centralFree, item);
-                
+
                 if((int)add.newItemCount() != (int)m_data.size()) {
                     QVector<Data> newData;
                     newData.resize(add.newItemCount());
@@ -715,19 +713,19 @@ namespace KDevelop {
                     m_data = newData;
                 }
             }
-            
+
             Iterator iterator() const {
                 return Iterator(m_data.data(), m_data.size(), m_centralFree);
             }
-            
+
             bool contains(const Data& item) const {
                 KDevelop::EmbeddedTreeAlgorithms<Data, Handler> alg(m_data.data(), m_data.size(), m_centralFree);
                 return alg.indexOf(Data(item)) != -1;
             }
-            
+
             void remove(const Data& item) {
                 KDevelop::EmbeddedTreeRemoveItem<Data, Handler> remove(m_data.data(), m_data.size(), m_centralFree, item);
-                
+
                 if((int)remove.newItemCount() != (int)m_data.size()) {
                     QVector<Data> newData;
                     newData.resize(remove.newItemCount());
@@ -735,7 +733,7 @@ namespace KDevelop {
                     m_data = newData;
                 }
             }
-                 
+
         private:
             int m_centralFree;
             QVector<Data> m_data;
