@@ -19,7 +19,8 @@ Boston, MA 02110-1301, USA.
 #ifndef KDEVPLATFORM_EXECUTECOMPOSITEJOB_H
 #define KDEVPLATFORM_EXECUTECOMPOSITEJOB_H
 
-#include <kcompositejob.h>
+#include <KCompositeJob>
+
 #include "utilexport.h"
 
 template <typename T> class QList;
@@ -31,15 +32,22 @@ class KDEVPLATFORMUTIL_EXPORT ExecuteCompositeJob : public KCompositeJob
 {
 Q_OBJECT
 public:
-    ExecuteCompositeJob(QObject* parent, const QList<KJob*>& jobs);
+    explicit ExecuteCompositeJob(QObject* parent = 0, const QList<KJob*>& jobs = {});
     ~ExecuteCompositeJob();
-    virtual void start();
 
-    const QList<KJob*> &subjobs() const;
+    virtual void start() override;
+    void setAbortOnError(bool abort);
+
 public Q_SLOTS:
-    virtual void slotResult(KJob* job);
+    virtual bool addSubjob(KJob* job) override;
+    virtual void slotResult(KJob* job) override;
+
+protected Q_SLOTS:
+    virtual void slotPercent(KJob* job, unsigned long percent);
+
 protected:
-    virtual bool doKill();
+    virtual bool doKill() override;
+
 private:
     class ExecuteCompositeJobPrivate* const d;
 };
