@@ -22,13 +22,7 @@
 #define KDEVPLATFORM_KDEVVARLENGTHARRAY_H
 
 #include <QtCore/QVarLengthArray>
-
-///Foreach macro that also works with QVarLengthArray or KDevVarLengthArray
-///@warning Unlike the Qt foreach macro, this does not temporarily copy the array, which means its size must not be changed during the iteration.
-#define FOREACH_ARRAY(item, container) \
-        for(int a__ = 0, mustDo__ = 1; a__ < container.size(); ++a__) \
-            if((mustDo__ == 0 || mustDo__ == 1) && (mustDo__ = 2)) \
-                for(item(container[a__]); mustDo__; mustDo__ = 0)
+#include <QtCore/QVector>
 
 /**
  * Extended QVarLengthArray with additional convenience API.
@@ -70,26 +64,6 @@ public:
     ///Removes exactly one occurrence of the given value from the array. Returns false if none was found.
     inline bool removeOne(const T& value);
 
-    ///Returns last item in the array.
-    inline T& back()
-    {
-        Q_ASSERT(!Base::isEmpty());
-        return *(Base::end()-1);
-    }
-
-    ///Returns last item in the array.
-    inline const T& back() const
-    {
-        Q_ASSERT(!Base::isEmpty());
-        return *(Base::constEnd()-1);
-    }
-
-    ///Removes last item from the array but does not return it, use @c back() if required.
-    inline void pop_back()
-    {
-        Base::removeLast();
-    }
-
     /// @return QList of items in this array
     QList<T> toList() const;
 
