@@ -21,12 +21,13 @@ unsigned int extractor_div_with = 0;
 #include <QObject>
 #include <QtTest/QtTest>
 #include <QVector>
+#include <QDebug>
+
 #include <stdlib.h>
 #include <set>
 #include <util/embeddedfreetree.h>
 #include <util/convenientfreelist.h>
 #include <language/util/setrepository.h>
-#include <kdebug.h>
 #include <time.h>
 #include <tests/testcore.h>
 #include <tests/autotestshell.h>
@@ -40,7 +41,7 @@ struct TestItem {
     bool operator==(const TestItem& rhs) const {
         return value == rhs.value;
     }
-    
+
     bool operator<(const TestItem& item) const {
         return value < item.value;
     }
@@ -67,20 +68,20 @@ clock_t std_insertion = 0, std_removal = 0, std_contains = 0, std_iteration = 0,
 QString toString(std::set<uint> set) {
     QString ret;
     for(std::set<uint>::const_iterator it = set.begin(); it != set.end(); ++it)
-        ret += QString("%1 ").arg(*it);
+        ret += QStringLiteral("%1 ").arg(*it);
     return ret;
 }
 
 bool operator==(const std::set<uint> a, const std::set<uint> b) {
     if(a.size() != b.size()) {
-        kDebug() << "size mismatch" << toString(a) << ": " << toString(b);
+        qDebug() << "size mismatch" << toString(a) << ": " << toString(b);
         return false;
     }
     std::set<uint>::const_iterator aIt = a.begin();
     std::set<uint>::const_iterator bIt = b.begin();
     for(; aIt != a.end(); ++aIt, ++bIt)
         if(*aIt != *bIt) {
-            kDebug() << "mismatch" << toString(a) << ": " << toString(b);
+            qDebug() << "mismatch" << toString(a) << ": " << toString(b);
             return false;
         }
     return true;
@@ -110,7 +111,7 @@ bool operator==(const std::set<uint> a, const std::set<uint> b) {
         static inline bool isFree(const TestItem& m_data) {
             return !m_data.value;
         }
-        
+
         static const TestItem& data(const TestItem& m_data) {
             return m_data;
         }
@@ -119,16 +120,16 @@ bool operator==(const std::set<uint> a, const std::set<uint> b) {
             return m_data.value == rhs.value;
         }
     };
-    
+
     class TestItemBasedSet {
         public:
             TestItemBasedSet() : m_centralFree(-1) {
             }
-            
+
             void insert(uint i) {
                 TestItem item(i);
                 KDevelop::EmbeddedTreeAddItem<TestItem, TestItemHandler> add(data.data(), data.size(), m_centralFree, item);
-                
+
                 if((int)add.newItemCount() != (int)data.size()) {
                     QVector<TestItem> newData;
                     newData.resize(add.newItemCount());
@@ -136,16 +137,16 @@ bool operator==(const std::set<uint> a, const std::set<uint> b) {
                     data = newData;
                 }
             }
-            
+
             bool contains(uint item) {
                 KDevelop::EmbeddedTreeAlgorithms<TestItem, TestItemHandler> alg(data.data(), data.size(), m_centralFree);
                 return alg.indexOf(TestItem(item)) != -1;
             }
-            
+
             void remove(uint i) {
                 TestItem item(i);
                 KDevelop::EmbeddedTreeRemoveItem<TestItem, TestItemHandler> remove(data.data(), data.size(), m_centralFree, item);
-                
+
                 if((int)remove.newItemCount() != (int)data.size()) {
                     QVector<TestItem> newData;
                     newData.resize(remove.newItemCount());
@@ -153,24 +154,24 @@ bool operator==(const std::set<uint> a, const std::set<uint> b) {
                     data = newData;
                 }
             }
-            
+
             std::set<uint> toSet() const {
                 std::set<uint> ret;
-                
+
                 for(int a = 0; a < data.size(); ++a)
                     if(data[a].value)
                         ret.insert(data[a].value);
-                
+
                 return ret;
             }
-            
+
             void verify() {
                 //1. verify order
                 uint last = 0;
                 uint freeCount = 0;
                 for(int a = 0; a < data.size(); ++a) {
                     if(data[a].value) {
-                        Q_ASSERT(last < data[a].value);
+                        QVERIFY(last < data[a].value);
                         last = data[a].value;
                     }else{
                         ++freeCount;
@@ -181,7 +182,7 @@ bool operator==(const std::set<uint> a, const std::set<uint> b) {
                 QCOMPARE(freeCount, countFree);
                 algorithms.verifyTreeConsistent();
             }
-            
+
             uint getItem(uint number) const {
                 Q_ASSERT(number < (uint)data.size());
                 uint ret = 0;
@@ -199,7 +200,7 @@ bool operator==(const std::set<uint> a, const std::set<uint> b) {
                 }
                 return ret;
             }
-            
+
         private:
             int m_centralFree;
             QVector<TestItem> data;
@@ -210,63 +211,60 @@ class TestSet {
     public:
     void add(uint i) {
         if(realSet.find(i) != realSet.end()) {
-            Q_ASSERT(set.contains(i));
+            QVERIFY(set.contains(i));
             return;
         }else{
-            Q_ASSERT(!set.contains(i));
+            QVERIFY(!set.contains(i));
         }
         clock_t start = clock();
         realSet.insert(i);
         std_insertion += clock() - start;
-        
+
         start = clock();
         set.insert(i);
         emb_insertion += clock() - start;
-        
+
         start = clock();
-        ///FIXME: what is the expected outcome?
-        ///       turns out that the below is often
-        ///       *not* true - is this what we want?
-        ///       => add proper Q_VERIFY!
-        realSet.find(i) == realSet.end();
+        bool contained = realSet.find(i) != realSet.end();
         std_contains += clock() - start;
-        
+
         start = clock();
         set.contains(i);
         emb_contains += clock() - start;
-        
-        Q_ASSERT(set.contains(i));
+
+        QVERIFY(set.contains(i));
+        QVERIFY(contained);
         set.verify();
     }
-    
+
     void remove(uint i) {
         if(realSet.find(i) != realSet.end()) {
-            Q_ASSERT(set.contains(i));
+            QVERIFY(set.contains(i));
         }else{
-            Q_ASSERT(!set.contains(i));
+            QVERIFY(!set.contains(i));
             return;
         }
         clock_t start = clock();
         set.remove(i);
         emb_removal += clock() - start;
-        
+
         start = clock();
         realSet.erase(i);
         std_removal += clock() - start;
-        
-        
-        Q_ASSERT(!set.contains(i));
+
+
+        QVERIFY(!set.contains(i));
     }
-    
+
     uint size() const {
         return realSet.size();
     }
-    
+
     uint getItem(uint number) const {
         Q_ASSERT(number < size());
         uint current = 0;
         uint ret = 0;
-        
+
         clock_t start = clock();
         for(std::set<uint>::const_iterator it = realSet.begin(); it != realSet.end(); ++it) {
             if(current == number) {
@@ -275,17 +273,17 @@ class TestSet {
             ++current;
         }
         std_iteration += clock() - start;
-        
+
         start = clock();
         set.getItem(number);
         emb_iteration += clock() - start;
-        
+
         Q_ASSERT(ret);
         return ret;
     }
-    
+
     void verify() {
-        Q_ASSERT(realSet == set.toSet());
+        QVERIFY(realSet == set.toSet());
         set.verify();
     }
     private:
@@ -308,7 +306,7 @@ struct UintSetVisitor {
     std::set<uint>& s;
     UintSetVisitor(std::set<uint>& _s) : s(_s) {
     }
-    
+
     inline bool operator() (const TestItem& item) {
         s.insert(item.value);
         return true;
@@ -341,9 +339,9 @@ class TestEmbeddedFreeTree : public QObject {
         srand(time(NULL));
         for(int a = 0; a < cycles; ++a) {
             if(a % (cycles / 10) == 0) {
-                kDebug() << "cycle" << a;
+                qDebug() << "cycle" << a;
             }
-            
+
             bool remove = (rand() % 100) < removeProbability;
             if(remove && set.size()) {
                 set.remove(set.getItem(rand() % set.size()));
@@ -353,47 +351,47 @@ class TestEmbeddedFreeTree : public QObject {
             }
             set.verify();
         }
-        kDebug() << "Performance embedded list: insertion:" << toSeconds(emb_insertion) << "removal:" << toSeconds(emb_removal) << "contains:" << toSeconds(emb_contains) << "iteration:" << toSeconds(emb_iteration);
-        kDebug() << "Performance std::set: insertion:" << toSeconds(std_insertion) << "removal:" << toSeconds(std_removal) << "contains:" << toSeconds(std_contains) << "iteration:" << toSeconds(std_iteration);
+        qDebug() << "Performance embedded list: insertion:" << toSeconds(emb_insertion) << "removal:" << toSeconds(emb_removal) << "contains:" << toSeconds(emb_contains) << "iteration:" << toSeconds(emb_iteration);
+        qDebug() << "Performance std::set: insertion:" << toSeconds(std_insertion) << "removal:" << toSeconds(std_removal) << "contains:" << toSeconds(std_contains) << "iteration:" << toSeconds(std_iteration);
     }
     void sequentialTest() {
         TestSet set;
         set.add(5);
         set.verify();
-        
+
         set.remove(5);
         set.verify();
-        
+
         set.add(3);
         set.verify();
-        
+
         set.add(4);
         set.verify();
-        
+
         set.add(7);
         set.verify();
-        
+
         set.remove(3);
         set.verify();
-        
+
         set.remove(7);
         set.verify();
-        
+
         set.add(6);
         set.verify();
-        
+
         set.add(1);
         set.verify();
-        
+
         set.add(9);
         set.verify();
-    
+
         set.remove(4);
         set.verify();
-    
+
         set.remove(9);
         set.verify();
-        
+
         set.add(1);
         set.verify();
         set.add(2);
@@ -423,37 +421,37 @@ class TestEmbeddedFreeTree : public QObject {
         set.add(9);
         set.verify();
     }
-   
+
     void testFiltering() {
         clock_t stdTime = 0;
         clock_t algoTime = 0;
         clock_t treeAlgoTime = 0;
         clock_t treeAlgoVisitorTime = 0;
-        
+
         clock_t insertionStdTime = 0;
         clock_t insertionAlgoTime = 0;
         clock_t insertionTreeAlgoTime = 0;
-        
+
         typedef Utils::StorableSet<TestItem, TestItemConversion, StaticRepository> RepositorySet;
-        
+
         const uint cycles = 3000;
         const uint setSize = 1500;
-        
+
         uint totalItems = 0, totalFilteredItems = 0;
-        
+
         srand(time(NULL));
         for(uint a = 0; a < cycles; ++a) {
             KDevelop::ConvenientFreeListSet<TestItem, TestItemHandler> set1;
             std::set<uint> testSet1;
-            
+
             KDevelop::ConvenientFreeListSet<TestItem, TestItemHandler> set2;
             std::set<uint> testSet2;
             RepositorySet repSet2;
-            
+
             if(a % (cycles / 10) == 0) {
-                kDebug() << "cycle" << a;
+                qDebug() << "cycle" << a;
             }
-            
+
             //Build the sets
             extractor_div_with = (rand() % 10) + 1;
             for(uint a = 0; a < setSize; ++a) {
@@ -461,54 +459,58 @@ class TestEmbeddedFreeTree : public QObject {
                 uint divValue = value/extractor_div_with;
                 if(!divValue)
                     continue;
-//                 kDebug() << "inserting" << value;
+//                 qDebug() << "inserting" << value;
 
                 std::set<uint>::const_iterator it = testSet1.lower_bound(value);
                 int pos = set1.iterator().lowerBound(TestItem(value));
                 //This tests the upperBound functionality
-
-                Q_ASSERT((pos != -1 && it != testSet1.end() && set1.data()[pos].value == *it) || (pos == -1 && it == testSet1.end()));
+                if (pos != -1) {
+                    QVERIFY(it != testSet1.end());
+                    QVERIFY(set1.data()[pos].value == *it);
+                } else {
+                    QVERIFY(it == testSet1.end());
+                }
 
                 if((rand() % 10) == 0) {
-                
+
                     set1.insert(TestItem(value));
                     testSet1.insert(value);
                 }
-                
+
                 //This is tuned so in the end, about 99% of all declarations are filtered out, like in the symbol table.
                 if((rand() % (extractor_div_with*100)) == 0) {
-                    
+
                     clock_t start = clock();
-                    
+
                     set2.insert(TestItem(divValue));
-                    
+
                     insertionStdTime += clock() - start;
                     start = clock();
-                    
+
                     testSet2.insert(divValue);
-                    
+
                     insertionAlgoTime += clock() - start;
                     start = clock();
-                    
+
                     repSet2.insert(TestItem(divValue));
-                    
+
                     insertionTreeAlgoTime += clock() - start;
                     start = clock();
                 }
             }
-            
+
             std::set<uint> verifySet1;
             for(KDevelop::ConvenientFreeListSet<TestItem, TestItemHandler>::Iterator it = set1.iterator(); it; ++it)
                 verifySet1.insert(it->value);
-            
+
             std::set<uint> verifySet2;
             for(KDevelop::ConvenientFreeListSet<TestItem, TestItemHandler>::Iterator it = set2.iterator(); it; ++it)
                 verifySet2.insert(it->value);
-            
+
             std::set<uint> verifyRepSet2;
             for(RepositorySet::Iterator it = repSet2.iterator(); it; ++it)
                 verifyRepSet2.insert((*it).value);
-            
+
             QCOMPARE(verifySet1, testSet1);
             QCOMPARE(verifySet2, testSet2);
             QCOMPARE(verifyRepSet2, testSet2);
@@ -520,44 +522,42 @@ class TestEmbeddedFreeTree : public QObject {
             {
                 //Do the filtering once without actions on the filtered items, just for calculating the time
                 clock_t start = clock();
-                
+
                 {
                     KDevelop::ConvenientEmbeddedSetFilterIterator<TestItem, TestItemHandler, TestItem, TestItemHandler, Extractor> filterIterator(set1.iterator(), set2.iterator());
                     while(filterIterator)
                         ++filterIterator;
-                    
+
                     algoTime += clock() - start;
                 }
-                
+
                 start = clock();
-                
+
                 {
                     KDevelop::ConvenientEmbeddedSetTreeFilterIterator<TestItem, TestItemHandler, TestItem, RepositorySet, Extractor> filterIterator(set1.iterator(), repSet2);
                     while(filterIterator)
                         ++filterIterator;
-                    
+
                     treeAlgoTime += clock() - start;
                 }
-                
+
                 {
                     start = clock();
-                    
+
                     NothingDoVisitor v;
                     KDevelop::ConvenientEmbeddedSetTreeFilterVisitor<TestItem, TestItemHandler, TestItem, RepositorySet, Extractor, NothingDoVisitor> visit(v, set1.iterator(), repSet2);
-                    
+
                     treeAlgoVisitorTime += clock() - start;
                 }
-                
-                
-                std::set<uint> stdFiltered;
-                
+
+
                 start = clock();
-                
+
                 for(std::set<uint>::const_iterator it = testSet1.begin(); it != testSet1.end(); ++it) {
                     if(testSet2.count((*it) / extractor_div_with) == 1) {
                     }
                 }
-                
+
                 stdTime += clock() - start;
             }
 
@@ -579,31 +579,31 @@ class TestEmbeddedFreeTree : public QObject {
                 UintSetVisitor v(treeAlgoVisitorFiltered);
                 KDevelop::ConvenientEmbeddedSetTreeFilterVisitor<TestItem, TestItemHandler, TestItem, RepositorySet, Extractor, UintSetVisitor> visit(v, set1.iterator(), repSet2);
             }
-            
-            
+
+
             totalItems += testSet1.size();
             totalFilteredItems += algoFiltered.size();
-            
-            
+
+
             std::set<uint> stdFiltered;
-            
+
             for(std::set<uint>::const_iterator it = testSet1.begin(); it != testSet1.end(); ++it) {
                 if(testSet2.count((*it) / extractor_div_with) == 1) {
                     stdFiltered.insert(*it);
                 }
             }
-            
+
             QCOMPARE(algoFiltered, stdFiltered);
             QCOMPARE(treeAlgoFiltered, stdFiltered);
             QCOMPARE(treeAlgoVisitorFiltered, stdFiltered);
-            
+
         }
-        kDebug() << "Filtering performance: embedded-list filtering:" << toSeconds(algoTime) << "set-repository filtering:" << toSeconds(treeAlgoTime) << "set-repository visitor filtering:" << toSeconds(treeAlgoVisitorTime) << "std::set filtering:" << toSeconds(stdTime) << "Normal -> Embedded speedup ratio:" << (toSeconds(stdTime) / toSeconds(algoTime)) << "Normal -> Repository speedup ratio:" << (toSeconds(stdTime) / toSeconds(treeAlgoVisitorTime)) << "total processed items:" << totalItems << "total items after filtering:" << totalFilteredItems;
-        kDebug() << "Insertion: embedded-list:" << toSeconds(insertionAlgoTime) << "set-repository:" << toSeconds(insertionTreeAlgoTime) << "std::set:" << toSeconds(insertionStdTime);
-        
+        qDebug() << "Filtering performance: embedded-list filtering:" << toSeconds(algoTime) << "set-repository filtering:" << toSeconds(treeAlgoTime) << "set-repository visitor filtering:" << toSeconds(treeAlgoVisitorTime) << "std::set filtering:" << toSeconds(stdTime) << "Normal -> Embedded speedup ratio:" << (toSeconds(stdTime) / toSeconds(algoTime)) << "Normal -> Repository speedup ratio:" << (toSeconds(stdTime) / toSeconds(treeAlgoVisitorTime)) << "total processed items:" << totalItems << "total items after filtering:" << totalFilteredItems;
+        qDebug() << "Insertion: embedded-list:" << toSeconds(insertionAlgoTime) << "set-repository:" << toSeconds(insertionTreeAlgoTime) << "std::set:" << toSeconds(insertionStdTime);
+
     }
 };
 
-#include "test_itemrepository.moc"
+#include "test_embeddedfreetree.moc"
 
 QTEST_MAIN(TestEmbeddedFreeTree)
