@@ -1,6 +1,7 @@
 /*
  * This file is part of KDevelop
  * Copyright 2012 Milian Wolff <mail@milianw.de>
+ * Copyright 2015 Kevin Funk <kfunk@kde.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -26,9 +27,9 @@
 #include <tests/autotestshell.h>
 #include <tests/testcore.h>
 
-#include <QtTest>
+#include <KIO/Global>
 
-#include <KUrl>
+#include <QtTest>
 
 QTEST_MAIN(TestPath);
 
@@ -38,14 +39,6 @@ static const int FILES_PER_FOLDER = 10;
 static const int FOLDERS_PER_FOLDER = 5;
 static const int TREE_DEPTH = 5;
 
-namespace QTest {
-    template<>
-    char *toString(const KUrl &url)
-    {
-        return qstrdup(qPrintable(url.pathOrUrl()));
-    }
-}
-
 template<typename T>
 T stringToUrl(const QString& path)
 {
@@ -80,21 +73,13 @@ QUrl childUrl(const QUrl& parent, const QString& child)
     return ret;
 }
 
-template<>
-KUrl childUrl(const KUrl& parent, const QString& child)
-{
-    KUrl ret = parent;
-    ret.addPath(child);
-    return ret;
-}
-
 template<typename T>
 QVector<T> generateData(const T& parent, int level)
 {
     QVector<T> ret;
     // files per folder
     for (int i = 0; i < FILES_PER_FOLDER; ++i) {
-        const QString fileName = QString("file%1.txt").arg(i);
+        const QString fileName = QStringLiteral("file%1.txt").arg(i);
         const T file = childUrl<T>(parent, fileName);
         Q_ASSERT(!ret.contains(file));
         ret << file;
@@ -103,7 +88,7 @@ QVector<T> generateData(const T& parent, int level)
     if (level < TREE_DEPTH) {
         // folders per folder
         for (int i = 0; i < FOLDERS_PER_FOLDER; ++i) {
-            const QString folderName = QString("folder%1").arg(i);
+            const QString folderName = QStringLiteral("folder%1").arg(i);
             const T folder = childUrl<T>(parent, folderName);
             Q_ASSERT(!ret.contains(folder));
             ret << folder;
@@ -124,6 +109,7 @@ void runBenchmark()
 
 void TestPath::initTestCase()
 {
+    // TODO: is this really needed? It doesn't seem like any kdevelop shell is needed
     AutoTestShell::init();
     TestCore::initialize(Core::NoUi);
 }
@@ -133,11 +119,6 @@ void TestPath::cleanupTestCase()
     TestCore::shutdown();
 }
 
-void TestPath::bench_kurl()
-{
-    runBenchmark<KUrl>();
-}
-
 void TestPath::bench_qurl()
 {
     runBenchmark<QUrl>();
@@ -162,21 +143,14 @@ void TestPath::bench_fromLocalPath()
     if (variant == 1) {
         QBENCHMARK {
             for(int i = 0; i < repeat; ++i) {
-                Path path = Path(KUrl(input));
+                Path path = Path(QUrl::fromLocalFile(input));
                 Q_UNUSED(path);
             }
         }
     } else if (variant == 2) {
         QBENCHMARK {
             for(int i = 0; i < repeat; ++i) {
-                Path path = Path(KUrl::fromPath(input));
-                Q_UNUSED(path);
-            }
-        }
-    } else if (variant == 3) {
-        QBENCHMARK {
-            for(int i = 0; i < repeat; ++i) {
-                Path path = Path(QUrl::fromLocalFile(input));
+                Path path = Path(input);
                 Q_UNUSED(path);
             }
         }
@@ -189,9 +163,8 @@ void TestPath::bench_fromLocalPath_data()
 {
     QTest::addColumn<int>("variant");
 
-    QTest::newRow("KUrl::KUrl") << 1;
-    QTest::newRow("KUrl::fromPath") << 2;
-    QTest::newRow("QUrl::fromLocalFile") << 3;
+    QTest::newRow("QUrl::fromLocalFile") << 1;
+    QTest::newRow("QString") << 2;
 }
 
 void TestPath::bench_hash()
@@ -203,38 +176,61 @@ void TestPath::bench_hash()
     }
 }
 
-KUrl comparableUpUrl(const KUrl& url)
+/// Invoke @p op on URL @p base, but preserve drive letter if @p op removes it
+template<typename Func>
+QUrl preserveWindowsDriveLetter(const QUrl& base, Func op)
 {
-    KUrl ret = url.upUrl();
-    ret.adjustPath(KUrl::RemoveTrailingSlash);
-    if (ret.hasPass()) {
-        ret.setPass(QString());
+#ifndef Q_OS_WIN
+    return op(base);
+#else
+    // only apply to local files
+    if (!base.isLocalFile()) {
+        return op(base);
     }
-    return ret;
+
+    // save drive letter
+    const QString windowsDriveLetter = base.toLocalFile().mid(0, 2);
+    QUrl url = op(base);
+    // restore drive letter
+    if (url.toLocalFile().startsWith('/')) {
+        url = QUrl::fromLocalFile(windowsDriveLetter + url.toLocalFile());
+    }
+    return url;
+#endif
+}
+
+QUrl resolvedUrl(const QUrl& base, const QUrl& relative)
+{
+    return preserveWindowsDriveLetter(base, [&](const QUrl& url) { return url.resolved(relative); });
+}
+
+QUrl comparableUpUrl(const QUrl& url)
+{
+    QUrl ret = preserveWindowsDriveLetter(url, [&](const QUrl& url) { return KIO::upUrl(url).adjusted(QUrl::RemovePassword); });
+    return ret.adjusted(QUrl::StripTrailingSlash);
 }
 
 void TestPath::testPath()
 {
     QFETCH(QString, input);
 
-    KUrl url(input);
-    url.cleanPath();
-    url.adjustPath(KUrl::RemoveTrailingSlash);
+    QUrl url = QUrl::fromUserInput(input);
+    url = url.adjusted(QUrl::StripTrailingSlash | QUrl::NormalizePathSegments);
 
     Path optUrl(input);
 
-    if (url.hasPass()) {
-        KUrl urlNoPass = url;
-        urlNoPass.setPass(QString());
+    if (!url.password().isEmpty()) {
+        QUrl urlNoPass = url.adjusted(QUrl::RemovePassword);
         QCOMPARE(optUrl.toUrl(), urlNoPass);
     } else {
         QCOMPARE(optUrl.toUrl(), url);
     }
     QCOMPARE(optUrl.isLocalFile(), url.isLocalFile());
-    QCOMPARE(optUrl.pathOrUrl(), url.pathOrUrl());
+    QCOMPARE(optUrl.pathOrUrl(), toUrlOrLocalFile(url, QUrl::RemovePassword));
     QCOMPARE(optUrl.isValid(), url.isValid());
+    QCOMPARE(optUrl.isEmpty(), url.isEmpty());
     QCOMPARE(optUrl.lastPathSegment(), url.fileName());
-    QCOMPARE(optUrl.path(), url.path());
+    QCOMPARE(optUrl.path(), url.isLocalFile() ? url.toLocalFile() : url.path());
     QCOMPARE(optUrl.parent().toUrl(), comparableUpUrl(url));
     QCOMPARE(optUrl.toLocalFile(), url.toLocalFile());
 
@@ -243,7 +239,7 @@ void TestPath::testPath()
     QVERIFY(optUrl != Path(input + "/asdf"));
 
     if (url.isLocalFile() && !input.startsWith("file://")) {
-        QCOMPARE(optUrl, Path(KUrl::fromPath(input)));
+        QCOMPARE(optUrl, Path(QUrl::fromLocalFile(input)));
     }
 
     QCOMPARE(optUrl, Path(url));
@@ -257,13 +253,15 @@ void TestPath::testPath()
         QVERIFY(optUrl.isParentOf(relativePath));
         QVERIFY(!relativePath.isParentOf(optUrl));
 
+#ifndef Q_OS_WIN
         Path absolutePath(optUrl, "/laa/loo");
         QCOMPARE(absolutePath.path(), QLatin1String("/laa/loo"));
-        QCOMPARE(KUrl(url, "/laa/loo").path(), QLatin1String("/laa/loo"));
+        QCOMPARE(url.resolved(QUrl("/laa/loo")).path(), QLatin1String("/laa/loo"));
 
         Path absolutePath2(optUrl, "/");
         QCOMPARE(absolutePath2.path(), QLatin1String("/"));
-        QCOMPARE(KUrl(url, "/").path(), QLatin1String("/"));
+        QCOMPARE(url.resolved(QUrl("/")).path(), QLatin1String("/"));
+#endif
 
         Path unrelatedPath("https://test@blubasdf.com:12345/");
         QCOMPARE(optUrl.relativePath(unrelatedPath), unrelatedPath.pathOrUrl());
@@ -283,25 +281,32 @@ void TestPath::testPath()
     QCOMPARE(optUrl.isRemote(), optUrl.isValid() && !optUrl.isLocalFile());
     QCOMPARE(optUrl.isRemote(), optUrl.isValid() && !optUrl.remotePrefix().isEmpty());
 
-    url.addPath("test/foo/bar");
+    url.setPath(url.path() + "/test/foo/bar");
+    if (url.scheme().isEmpty()) {
+        url.setScheme("file");
+    }
     optUrl.addPath("test/foo/bar");
     QCOMPARE(optUrl.lastPathSegment(), url.fileName());
-    QCOMPARE(optUrl.path(), url.path());
+    QCOMPARE(optUrl.path(), url.isLocalFile() ? url.toLocalFile() : url.path());
 
-    url.setFileName("lalalala_adsf.txt");
+    url = url.adjusted(QUrl::RemoveFilename);
+    url.setPath(url.path() + "lalalala_adsf.txt");
     optUrl.setLastPathSegment("lalalala_adsf.txt");
     QCOMPARE(optUrl.lastPathSegment(), url.fileName());
-    QCOMPARE(optUrl.path(), url.path());
+    QCOMPARE(optUrl.path(), url.isLocalFile() ? url.toLocalFile() : url.path());
 
     QCOMPARE(optUrl.parent().toUrl(), comparableUpUrl(url));
 
     QVERIFY(optUrl.parent().isDirectParentOf(optUrl));
     QVERIFY(!optUrl.parent().parent().isDirectParentOf(optUrl));
+
+#ifndef Q_OS_WIN
     Path a("/foo/bar/asdf/");
     Path b("/foo/bar/");
     QVERIFY(b.isDirectParentOf(a));
     Path c("/foo/bar");
     QVERIFY(c.isDirectParentOf(a));
+#endif
 
     optUrl.clear();
     url.clear();
@@ -312,18 +317,24 @@ void TestPath::testPath_data()
 {
     QTest::addColumn<QString>("input");
 
-    QTest::ignoreMessage(QtWarningMsg, "Path::init: invalid/unsupported Path encountered: \"\"");
-    QTest::ignoreMessage(QtWarningMsg, "Path::init: invalid/unsupported Path encountered: \"\"");
-    QTest::ignoreMessage(QtWarningMsg, "Path::init: invalid/unsupported Path encountered: \"\"");
+#ifndef Q_OS_WIN
     QTest::newRow("invalid") << "";
     QTest::newRow("path") << "/tmp/foo/asdf.txt";
     QTest::newRow("path-folder") << "/tmp/foo/asdf/";
     QTest::newRow("root") << "/";
     QTest::newRow("clean-path") << "/tmp/..///asdf/";
-    QTest::newRow("remote-root") << "http://www.test.com/";
-    QTest::newRow("http") << "http://www.test.com/tmp/asdf.txt";
     QTest::newRow("file") << "file:///tmp/foo/asdf.txt";
     QTest::newRow("file-folder") << "file:///tmp/foo/bar/";
+#else
+    QTest::newRow("path") << "C:/tmp/foo/asdf.txt";
+    QTest::newRow("path-folder") << "C:/tmp/foo/asdf/";
+    QTest::newRow("root") << "C:/";
+    QTest::newRow("clean-path") << "C:/tmp/..///asdf/";
+    QTest::newRow("file") << "file:///C:/tmp/foo/asdf.txt";
+    QTest::newRow("file-folder") << "file:///C:/tmp/foo/bar/";
+#endif
+    QTest::newRow("remote-root") << "http://www.test.com/";
+    QTest::newRow("http") << "http://www.test.com/tmp/asdf.txt";
     QTest::newRow("ftps") << "ftps://user@host.com/tmp/foo/asdf.txt";
     QTest::newRow("password") << "ftps://user:password@host.com/tmp/asdf.txt";
     QTest::newRow("port") << "http://localhost:8080/foo/bar/test.txt";
@@ -334,31 +345,19 @@ void TestPath::testPathInvalid()
     QFETCH(QString, input);
     Path url(input);
     QVERIFY(!url.isValid());
+    QVERIFY(url.isEmpty());
 }
 
 void TestPath::testPathInvalid_data()
 {
     QTest::addColumn<QString>("input");
 
-    QTest::ignoreMessage(QtWarningMsg, "Path::init: invalid/unsupported Path encountered: \"\"");
     QTest::newRow("empty") << "";
-
-    QTest::ignoreMessage(QtWarningMsg, "Path::init: invalid/unsupported Path encountered: \"http://test.com/#hello\"");
     QTest::newRow("fragment") << "http://test.com/#hello";
-
-    QTest::ignoreMessage(QtWarningMsg, "Path::init: invalid/unsupported Path encountered: \"http://test.com/?hello\"");
     QTest::newRow("query") << "http://test.com/?hello";
-
-    QTest::ignoreMessage(QtWarningMsg, "Path::init: invalid/unsupported Path encountered: \"file:///home/weis/kde.tgz#gzip:/%23tar:/kdebase\"");
     QTest::newRow("suburl") << "file:///home/weis/kde.tgz#gzip:/#tar:/kdebase";
-
-    QTest::ignoreMessage(QtWarningMsg, "Path::init: invalid/unsupported Path encountered: \"../foo/bar\"");
     QTest::newRow("relative") << "../foo/bar";
-
-    QTest::ignoreMessage(QtWarningMsg, "Path::init: invalid/unsupported Path encountered: \"asdfasdf\"");
     QTest::newRow("name") << "asdfasdf";
-
-    QTest::ignoreMessage(QtWarningMsg, "Path::init: invalid/unsupported Path encountered: \"http://www.test.com\"");
     QTest::newRow("remote-nopath") << "http://www.test.com";
 }
 
@@ -414,23 +413,38 @@ void TestPath::testPathAddData()
 {
     QFETCH(QString, pathToAdd);
 
-    const QStringList bases = QStringList()
-        << "/foo/bar/asdf/"
-        << "file:///foo/bar/asdf/"
-        << "http://www.asdf.com/foo/bar/asdf/"
-        << "/"
-        ;
+    const QStringList bases = {
+#ifndef Q_OS_WIN
+        "/",
+        "/foo/bar/asdf/",
+        "file:///foo/bar/asdf/",
+#else
+        "C:/",
+        "C:/foo/bar/asdf/",
+        "file:///C:/foo/bar/asdf/",
+#endif
+        "http://www.asdf.com/foo/bar/asdf/",
+    };
+
     foreach(const QString& base, bases) {
-        KUrl baseUrl(base);
-        baseUrl.addPath(pathToAdd);
-        baseUrl.cleanPath();
-        baseUrl.adjustPath(KUrl::RemoveTrailingSlash);
+        QUrl baseUrl = QUrl::fromUserInput(base);
+        if (QDir::isRelativePath(pathToAdd)) {
+            baseUrl = resolvedUrl(baseUrl, QUrl(pathToAdd));
+        } else {
+            baseUrl.setPath(baseUrl.path() + pathToAdd);
+        }
+
+        baseUrl = baseUrl.adjusted(QUrl::NormalizePathSegments);
+        // QUrl::StripTrailingSlash converts file:/// to file: which is not what we want
+        if (baseUrl.path() != QLatin1String("/")) {
+            baseUrl = baseUrl.adjusted(QUrl::StripTrailingSlash);
+        }
 
         Path basePath(base);
         basePath.addPath(pathToAdd);
 
+        QCOMPARE(basePath.pathOrUrl(), toUrlOrLocalFile(baseUrl));
         QCOMPARE(basePath.toUrl(), baseUrl);
-        QCOMPARE(basePath.pathOrUrl(), baseUrl.pathOrUrl());
     }
 }
 
@@ -461,37 +475,56 @@ void TestPath::testPathBaseCtor()
 {
     QFETCH(QString, base);
     QFETCH(QString, subPath);
+    QFETCH(QString, expected);
 
     const Path basePath(base);
 
     const Path path(basePath, subPath);
 
-    KUrl url(base);
-    if (KUrl(subPath).isRelative()) {
-        url.addPath(subPath);
-    } else {
-        url.setPath(subPath);
-    }
-    url.cleanPath();
-
-    QCOMPARE(path.pathOrUrl(), url.pathOrUrl(KUrl::RemoveTrailingSlash));
+    QCOMPARE(path.pathOrUrl(), expected);
 }
 
 void TestPath::testPathBaseCtor_data()
 {
     QTest::addColumn<QString>("base");
     QTest::addColumn<QString>("subPath");
+    QTest::addColumn<QString>("expected");
 
-    QTest::newRow("empty") << "" << "";
-    QTest::newRow("root-empty") << "/" << "";
-    QTest::newRow("root-root") << "/" << "/";
-    QTest::newRow("root-relative") << "/" << "bar";
-    QTest::newRow("root-relative-dirty") << "/" << "bar//foo/a/..";
-    QTest::newRow("empty-relative") << "" << "bar/foo/";
-    QTest::newRow("path-relative") << "/foo/bar" << "bar/foo";
-    QTest::newRow("path-absolute") << "/foo/bar" << "/bar/foo";
-    QTest::newRow("remote-path-absolute") << "http://foo.com/foo/bar" << "/bar/foo";
-    QTest::newRow("remote-path-relative") << "http://foo.com/foo/bar" << "bar/foo";
+    QTest::newRow("empty") << "" << "" << "";
+    QTest::newRow("empty-relative") << "" << "foo" << "";
+#ifndef Q_OS_WIN
+    QTest::newRow("root-empty") << "/" << "" << "/";
+    QTest::newRow("root-root") << "/" << "/" << "/";
+    QTest::newRow("root-relative") << "/" << "bar" << "/bar";
+    QTest::newRow("root-relative-dirty") << "/" << "bar//foo/a/.." << "/bar/foo";
+    QTest::newRow("path-relative") << "/foo/bar" << "bar/foo" << "/foo/bar/bar/foo";
+    QTest::newRow("path-absolute") << "/foo/bar" << "/bar/foo" << "/bar/foo";
+#else
+    QTest::newRow("root-empty") << "C:/" << "" << "C:";
+    QTest::newRow("root1-empty") << "C:" << "" << "C:";
+    QTest::newRow("root-root") << "C:/" << "C:/" << "C:";
+    QTest::newRow("root-relative") << "C:/" << "bar" << "C:/bar";
+    QTest::newRow("root1-relative") << "C:" << "bar" << "C:/bar";
+    QTest::newRow("root-relative-dirty") << "C:/" << "bar//foo/a/.." << "C:/bar/foo";
+    QTest::newRow("path-relative") << "C:/foo/bar" << "bar/foo" << "C:/foo/bar/bar/foo";
+    QTest::newRow("path-absolute") << "C:/foo/bar" << "C:/bar/foo" << "C:/bar/foo";
+#endif
+    QTest::newRow("remote-path-absolute") << "http://foo.com/foo/bar" << "/bar/foo" << "http://foo.com/bar/foo";
+    QTest::newRow("remote-path-relative") << "http://foo.com/foo/bar" << "bar/foo" << "http://foo.com/foo/bar/bar/foo";
+}
+
+// there is no cd() in QUrl, emulate what KUrl did
+static bool cdQUrl(QUrl& url, const QString& path)
+{
+    if (path.isEmpty() || !url.isValid()) {
+        return false;
+    }
+    // have to append slash otherwise last segment is treated as a file name and not a directory
+    if (!url.path().endsWith('/')) {
+        url.setPath(url.path() + '/');
+    }
+    url = url.resolved(QUrl(path)).adjusted(QUrl::RemoveFragment | QUrl::RemoveQuery);
+    return true;
 }
 
 void TestPath::testPathCd()
@@ -500,15 +533,15 @@ void TestPath::testPathCd()
     QFETCH(QString, change);
 
     Path path = base.isEmpty() ? Path() : Path(base);
-    KUrl url(base);
+    QUrl url = QUrl::fromUserInput(base);
 
     Path changed = path.cd(change);
-    if (url.cd(change)) {
+    if (cdQUrl(url, change)) {
         QVERIFY(changed.isValid());
     }
-    url.cleanPath();
+    url = url.adjusted(QUrl::NormalizePathSegments);
 
-    QCOMPARE(changed.pathOrUrl(), url.pathOrUrl(KUrl::RemoveTrailingSlash));
+    QCOMPARE(changed.pathOrUrl(), toUrlOrLocalFile(url, QUrl::StripTrailingSlash));
 }
 
 void TestPath::testPathCd_data()
@@ -516,7 +549,15 @@ void TestPath::testPathCd_data()
     QTest::addColumn<QString>("base");
     QTest::addColumn<QString>("change");
 
-    const QVector<QString> bases{"", "/foo", "/foo/bar/asdf", "http://foo.com/", "http://foo.com/foo", "http://foo.com/foo/bar/asdf"};
+    const QVector<QString> bases{
+        "",
+#ifndef Q_OS_WIN
+        "/foo", "/foo/bar/asdf",
+#else
+        "C:/foo", "C:/foo/bar/asdf",
+#endif
+        "http://foo.com/", "http://foo.com/foo", "http://foo.com/foo/bar/asdf"
+    };
     foreach (const QString& base, bases) {
         QTest::newRow(qstrdup(qPrintable(base + "-"))) << base << "";
         QTest::newRow(qstrdup(qPrintable(base + "-.."))) << base << "..";
@@ -529,9 +570,56 @@ void TestPath::testPathCd_data()
         QTest::newRow(qstrdup(qPrintable(base + "-foo/.."))) << base << "foo/..";
         QTest::newRow(qstrdup(qPrintable(base + "-foo/"))) << base << "foo/";
         QTest::newRow(qstrdup(qPrintable(base + "-foo/../bar"))) << base << "foo/../bar";
+#ifdef Q_OS_WIN
+        if (!base.startsWith("C:/") ) {
+            // only add next rows for remote URLs on Windows
+#endif
         QTest::newRow(qstrdup(qPrintable(base + "-/foo"))) << base << "/foo";
         QTest::newRow(qstrdup(qPrintable(base + "-/foo/../bar"))) << base << "/foo/../bar";
+#ifdef Q_OS_WIN
+        }
+#endif
     }
 }
 
-#include "test_path.moc"
+void TestPath::testHasParent_data()
+{
+    QTest::addColumn<QString>("input");
+    QTest::addColumn<bool>("hasParent");
+
+    QTest::newRow("empty") << QString() << false;
+    QTest::newRow("/") << QStringLiteral("/") << false;
+    QTest::newRow("/foo") << QStringLiteral("/foo") << true;
+    QTest::newRow("/foo/bar") << QStringLiteral("/foo/bar") << true;
+    QTest::newRow("//foo/bar") << QStringLiteral("//foo/bar") << true;
+    QTest::newRow("http://foo.bar") << QStringLiteral("http://foo.bar") << false;
+    QTest::newRow("http://foo.bar/") << QStringLiteral("http://foo.bar/") << false;
+    QTest::newRow("http://foo.bar/asdf") << QStringLiteral("http://foo.bar/asdf") << true;
+    QTest::newRow("http://foo.bar/asdf/asdf") << QStringLiteral("http://foo.bar/asdf/asdf") << true;
+}
+
+void TestPath::testHasParent()
+{
+    QFETCH(QString, input);
+    Path path(input);
+    QTEST(path.hasParent(), "hasParent");
+}
+
+void TestPath::QUrl_acceptance()
+{
+    const QUrl baseLocal = QUrl("file:///foo.h");
+    QCOMPARE(baseLocal.isValid(), true);
+    QCOMPARE(baseLocal.isRelative(), false);
+    QCOMPARE(baseLocal, QUrl::fromLocalFile("/foo.h"));
+    QCOMPARE(baseLocal, QUrl::fromUserInput("/foo.h"));
+
+    QUrl relative("bar.h");
+    QCOMPARE(relative.isRelative(), true);
+    QCOMPARE(baseLocal.resolved(relative), QUrl("file:///bar.h"));
+    QUrl relative2("/foo/bar.h");
+    QCOMPARE(relative2.isRelative(), true);
+    QCOMPARE(baseLocal.resolved(relative2), QUrl("file:///foo/bar.h"));
+
+    const QUrl baseRemote = QUrl("http://foo.org/asdf/foo/asdf");
+    QCOMPARE(baseRemote.resolved(relative), QUrl("http://foo.org/asdf/foo/bar.h"));
+}
