@@ -25,17 +25,18 @@
  ***************************************************************************/
 
 #include "dvcsjob.h"
+#include "../debug.h"
 
 #include <QtCore/QFile>
 #include <QtCore/QFileInfo>
 #include <QtCore/QList>
 #include <QtCore/QStringList>
 #include <QtCore/QDir>
-#include <QtGui/QStandardItemModel>
+#include <QStandardItemModel>
+#include <QUrl>
 
-#include <KDE/KDebug>
-#include <KDE/KLocale>
-#include <KDE/KUrl>
+#include <KLocalizedString>
+#include <KShell>
 
 #include <interfaces/iplugin.h>
 #include <outputview/outputmodel.h>
@@ -44,7 +45,7 @@ using namespace KDevelop;
 
 struct DVcsJobPrivate
 {
-    DVcsJobPrivate() : childproc(new KProcess), vcsplugin(0)
+    DVcsJobPrivate() : childproc(new KProcess), vcsplugin(0), ignoreError(false)
     {}
 
     ~DVcsJobPrivate() {
@@ -56,9 +57,11 @@ struct DVcsJobPrivate
     QByteArray  output;
     QByteArray  errorOutput;
     IPlugin* vcsplugin;
-    
+
     QVariant results;
     OutputModel* model;
+
+    bool ignoreError;
 };
 
 DVcsJob::DVcsJob(const QDir& workingDir, IPlugin* parent, OutputJob::OutputJobVerbosity verbosity)
@@ -69,17 +72,18 @@ DVcsJob::DVcsJob(const QDir& workingDir, IPlugin* parent, OutputJob::OutputJobVe
     d->vcsplugin = parent;
     d->childproc->setWorkingDirectory(workingDir.absolutePath());
     d->model = new OutputModel;
+    d->ignoreError = false;
     setModel(d->model);
     setCapabilities(Killable);
-    
-    connect(d->childproc, SIGNAL(finished(int,QProcess::ExitStatus)),
-            SLOT(slotProcessExited(int,QProcess::ExitStatus)));
-    connect(d->childproc, SIGNAL(error(QProcess::ProcessError)),
-            SLOT(slotProcessError(QProcess::ProcessError)));
 
-    connect(d->childproc, SIGNAL(readyReadStandardOutput()),
-                SLOT(slotReceivedStdout()));
-    
+    connect(d->childproc, static_cast<void(KProcess::*)(int,QProcess::ExitStatus)>(&KProcess::finished),
+            this, &DVcsJob::slotProcessExited);
+    connect(d->childproc, static_cast<void(KProcess::*)(QProcess::ProcessError)>(&KProcess::error),
+            this, &DVcsJob::slotProcessError);
+
+    connect(d->childproc, &KProcess::readyReadStandardOutput,
+                this, &DVcsJob::slotReceivedStdout);
+
 }
 
 DVcsJob::~DVcsJob()
@@ -136,6 +140,11 @@ QByteArray DVcsJob::errorOutput() const
     return d->errorOutput;
 }
 
+void DVcsJob::setIgnoreError(bool ignore)
+{
+    d->ignoreError = ignore;
+}
+
 void DVcsJob::setResults(const QVariant &res)
 {
     d->results = res;
@@ -148,7 +157,7 @@ QVariant DVcsJob::fetchResults()
 
 void DVcsJob::start()
 {
-    Q_ASSERT_X(!d->status==JobRunning, "DVCSjob::start", "Another proccess was started using this job class");
+    Q_ASSERT_X(d->status != JobRunning, "DVCSjob::start", "Another proccess was started using this job class");
 
     const QDir& workingdir = directory();
     if( !workingdir.exists() ) {
@@ -170,19 +179,20 @@ void DVcsJob::start()
         return;
     }
 
-    kDebug() << "Execute dvcs command:" << dvcsCommand();
+    QString commandDisplay = KShell::joinArgs(dvcsCommand());
+    qCDebug(VCS) << "Execute dvcs command:" << commandDisplay;
 
     QString service;
     if(d->vcsplugin)
         service = d->vcsplugin->objectName();
-    setObjectName(service+": "+dvcsCommand().join(" "));
-    
+    setObjectName(service+": "+commandDisplay);
+
     d->status = JobRunning;
     d->childproc->setOutputChannelMode(KProcess::SeparateChannels);
     //the started() and error() signals may be delayed! It causes crash with deferred deletion!!!
     d->childproc->start();
-    
-    d->model->appendLine(directory().path() + "> " + dvcsCommand().join(" "));
+
+    d->model->appendLine(directory().path() + "> " + commandDisplay);
 }
 
 void DVcsJob::setCommunicationMode(KProcess::OutputChannelMode comm)
@@ -200,8 +210,13 @@ void DVcsJob::slotProcessError( QProcess::ProcessError err )
     d->status = JobFailed;
 
     setError(OutputJob::FailedShownError); //we don't want to trigger a message box
-    setErrorText( i18n("Process '%1' exited with status %2", d->childproc->program().join(" "), d->childproc->exitCode() ) );
-    
+
+    d->errorOutput = d->childproc->readAllStandardError();
+
+    QString displayCommand = KShell::joinArgs(dvcsCommand());
+    QString completeErrorText = i18n("Process '%1' exited with status %2\n%3", displayCommand, d->childproc->exitCode(), QString::fromLocal8Bit(d->errorOutput) );
+    setErrorText( completeErrorText );
+
     QString errorValue;
     //if trolls add Q_ENUMS for QProcess, then we can use better solution than switch:
     //QMetaObject::indexOfEnumerator(char*), QLatin1String(QMetaEnum::valueToKey())...
@@ -226,12 +241,12 @@ void DVcsJob::slotProcessError( QProcess::ProcessError err )
         errorValue = "UnknownError";
         break;
     }
-    kDebug() << "oops, found an error while running" << dvcsCommand() << ":" << errorValue 
+    qCDebug(VCS) << "Found an error while running" << displayCommand << ":" << errorValue
                                                      << "Exit code is:" << d->childproc->exitCode();
-    d->errorOutput = d->childproc->readAllStandardError();
+    qCDebug(VCS) << "Error:" << completeErrorText;
     displayOutput(QString::fromLocal8Bit(d->errorOutput));
     d->model->appendLine(i18n("Command finished with error %1.", errorValue));
-    
+
     if(verbosity()==Silent) {
         setVerbosity(Verbose);
         startOutput();
@@ -242,15 +257,16 @@ void DVcsJob::slotProcessError( QProcess::ProcessError err )
 void DVcsJob::slotProcessExited(int exitCode, QProcess::ExitStatus exitStatus)
 {
     d->status = JobSucceeded;
+    d->model->appendLine(i18n("Command exited with value %1.", exitCode));
 
     if (exitStatus == QProcess::CrashExit)
         slotProcessError(QProcess::Crashed);
 
-    else if (exitCode != 0)
+    else if (exitCode != 0 && !d->ignoreError)
         slotProcessError(QProcess::UnknownError);
 
-    d->model->appendLine(i18n("Command exited with value %1.", exitCode));
-    jobIsReady();
+    else
+        jobIsReady();
 }
 
 void DVcsJob::displayOutput(const QString& data)
@@ -261,10 +277,10 @@ void DVcsJob::displayOutput(const QString& data)
 void DVcsJob::slotReceivedStdout()
 {
     QByteArray output = d->childproc->readAllStandardOutput();
-    
+
     // accumulate output
     d->output.append(output);
-    
+
     displayOutput(QString::fromLocal8Bit(output));
 }
 
@@ -278,15 +294,15 @@ IPlugin* DVcsJob::vcsPlugin() const
     return d->vcsplugin;
 }
 
-DVcsJob& DVcsJob::operator<<(const KUrl& url)
+DVcsJob& DVcsJob::operator<<(const QUrl& url)
 {
     *d->childproc << url.toLocalFile();
     return *this;
 }
 
-DVcsJob& DVcsJob::operator<<(const QList< KUrl >& urls)
+DVcsJob& DVcsJob::operator<<(const QList< QUrl >& urls)
 {
-    foreach(const KUrl &url, urls)
+    foreach(const QUrl &url, urls)
         operator<<(url);
     return *this;
 }
