@@ -30,9 +30,9 @@
 
 #include <QtCore/QStringList>
 #include <QtCore/QVariant>
-#include <KDE/KProcess>
+#include <KProcess>
 
-#include "../vcsexport.h"
+#include <vcs/vcsexport.h>
 #include "../vcsjob.h"
 
 class QDir;
@@ -59,7 +59,7 @@ struct DVcsJobPrivate;
  * 
  * Usage example 1:
  * @code
- * VcsJob* j = add(KUrl::List() << a << b << c, IBasicVersionControl::Recursive);
+ * VcsJob* j = add(QList<QUrl>() << a << b << c, IBasicVersionControl::Recursive);
  * DVcsJob* job = qobject_cast<DVCSjob*>(j);
  * connect(job, SIGNAL(result(KJob*) ),
  *         this, SIGNAL(jobFinished(KJob*) ));
@@ -88,7 +88,7 @@ class KDEVPLATFORMVCS_EXPORT DVcsJob : public KDevelop::VcsJob
 {
     Q_OBJECT
 public:
-    DVcsJob(const QDir& workingDir, KDevelop::IPlugin* parent=0, KDevelop::OutputJob::OutputJobVerbosity verbosity = KDevelop::OutputJob::Verbose);
+    explicit DVcsJob(const QDir& workingDir, KDevelop::IPlugin* parent=0, KDevelop::OutputJob::OutputJobVerbosity verbosity = KDevelop::OutputJob::Verbose);
     virtual ~DVcsJob();
 
     /**
@@ -120,19 +120,19 @@ public:
      * 
      * Override if you need to treat paths beffore adding them as parameters.
      */
-    virtual DVcsJob& operator<<(const KUrl& arg);
+    virtual DVcsJob& operator<<(const QUrl& arg);
     
     /**
-     * @see operator<<(const KUrl& arg).
+     * @see operator<<(const QUrl& arg).
      */
-    DVcsJob& operator<<(const QList<KUrl>& args);
+    DVcsJob& operator<<(const QList<QUrl>& args);
 
     /**
      * Call this method to start this job.
      * @note Default communication mode is KProcess::AllOutput.
      * @see Use setCommunicationMode() to override the default communication mode.
      */
-    virtual void start();
+    virtual void start() override;
 
     /**
      * In some cases it's needed to specify the communication mode between the
@@ -164,6 +164,11 @@ public:
      */
     QByteArray errorOutput() const;
 
+    /**
+     * Ignore a non-zero exit code depending on @p ignore.
+     */
+    void setIgnoreError(bool ignore);
+
     // Begin:  KDevelop::VcsJob
 
     /** 
@@ -178,18 +183,18 @@ public:
      * Mostly used in vcscommitdialog.
      * @see setResults(const QVariant &res)
      */
-    virtual QVariant fetchResults();
+    virtual QVariant fetchResults() override;
 
     /**
      * Returns JobStatus
      * @see KDevelop::VcsJob::JobStatus
      */
-    virtual KDevelop::VcsJob::JobStatus status() const;
+    virtual KDevelop::VcsJob::JobStatus status() const override;
 
     /**
      * Returns pointer to IPlugin (which was used to create a job).
      */
-    virtual KDevelop::IPlugin* vcsPlugin() const;
+    virtual KDevelop::IPlugin* vcsPlugin() const override;
     // End:  KDevelop::VcsJob
     
     KProcess *process();
@@ -213,7 +218,7 @@ private Q_SLOTS:
     void slotReceivedStdout();
 
 protected:
-    virtual bool doKill();
+    virtual bool doKill() override;
 
 private:
     void jobIsReady();
