@@ -12,71 +12,50 @@
 #include "vcspluginhelper.h"
 
 #include <QAction>
-#include <QVariant>
+#include <QApplication>
+#include <QClipboard>
+#include <QDialogButtonBox>
+#include <QFileInfo>
 #include <QMenu>
+#include <QTimer>
+#include <QVBoxLayout>
+#include <QVariant>
 
-#include <kpluginfactory.h>
-#include <kaboutdata.h>
-#include <kpluginloader.h>
-#include <klocale.h>
-#include <kglobal.h>
-#include <kconfig.h>
-#include <kmessagebox.h>
-#include <kconfiggroup.h>
-#include <kaction.h>
-
-#include <ktexteditor/annotationinterface.h>
-#include <ktexteditor/view.h>
-#include <ktexteditor/document.h>
-
-#include <kparts/mainwindow.h>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KParts/MainWindow>
+#include <KTextEditor/AnnotationInterface>
+#include <KTextEditor/Document>
+#include <KTextEditor/ModificationInterface>
+#include <KTextEditor/View>
 
 #include <interfaces/context.h>
+#include <interfaces/contextmenuextension.h>
 #include <interfaces/icore.h>
-#include <interfaces/iplugin.h>
-#include <interfaces/iuicontroller.h>
 #include <interfaces/idocument.h>
 #include <interfaces/idocumentcontroller.h>
+#include <interfaces/ipatchsource.h>
+#include <interfaces/iplugin.h>
 #include <interfaces/iplugincontroller.h>
+#include <interfaces/iproject.h>
 #include <interfaces/iprojectcontroller.h>
 #include <interfaces/iruncontroller.h>
-#include <interfaces/contextmenuextension.h>
-#include <interfaces/iproject.h>
-#include <project/projectmodel.h>
-#include <language/interfaces/codecontext.h>
+#include <interfaces/isession.h>
+#include <interfaces/iuicontroller.h>
+#include <util/path.h>
 #include <vcs/interfaces/ibasicversioncontrol.h>
-#include "interfaces/idistributedversioncontrol.h"
-#include <vcs/widgets/vcscommitdialog.h>
 #include <vcs/models/vcsannotationmodel.h>
+#include <vcs/widgets/vcseventwidget.h>
+#include <vcs/widgets/vcscommitdialog.h>
 #include <vcs/vcsjob.h>
 #include <vcs/vcsrevision.h>
 #include <vcs/vcsdiff.h>
-#include <vcs/widgets/vcseventwidget.h>
-#include <language/duchain/duchainbase.h>
-#include <language/duchain/indexedstring.h>
-#include <language/duchain/duchainlock.h>
-#include <language/duchain/duchain.h>
-#include <language/interfaces/editorcontext.h>
 
-#include <config-kdevplatform.h>
-#ifdef HAVE_KOMPARE
-#include <interfaces/ipatchdocument.h>
-#endif
-#include <interfaces/ipatchsource.h>
-#include <KTemporaryFile>
-#include <qtextedit.h>
+#include "interfaces/idistributedversioncontrol.h"
 #include "vcsstatusinfo.h"
-#include <qboxlayout.h>
-#include <qlabel.h>
+#include "vcsevent.h"
 #include "widgets/vcsdiffpatchsources.h"
 #include "widgets/flexibleaction.h"
-#include <interfaces/isession.h>
-#include "vcsevent.h"
-#include <KCompositeJob>
-#include <QClipboard>
-#include <QApplication>
-#include <ktexteditor/modificationinterface.h>
-#include <QTimer>
 
 namespace KDevelop
 {
@@ -85,68 +64,67 @@ struct VcsPluginHelper::VcsPluginHelperPrivate {
     IPlugin * plugin;
     IBasicVersionControl * vcs;
 
-    KUrl::List ctxUrls;
-    KAction * commitAction;
-    KAction * addAction;
-    KAction * updateAction;
-    KAction * historyAction;
-    KAction * annotationAction;
-    KAction * diffToBaseAction;
-    KAction * revertAction;
-    KAction * diffForRevAction;
-    KAction * diffForRevGlobalAction;
-    KAction * pushAction;
-    KAction * pullAction;
-    
+    QList<QUrl> ctxUrls;
+    QAction* commitAction;
+    QAction* addAction;
+    QAction* updateAction;
+    QAction* historyAction;
+    QAction* annotationAction;
+    QAction* diffToBaseAction;
+    QAction* revertAction;
+    QAction* diffForRevAction;
+    QAction* diffForRevGlobalAction;
+    QAction* pushAction;
+    QAction* pullAction;
+
     void createActions(VcsPluginHelper* parent) {
-        commitAction = new KAction(KIcon("svn-commit"), i18n("Commit..."), parent);
-        updateAction = new KAction(KIcon("svn-update"), i18n("Update"), parent);
-        addAction = new KAction(KIcon("list-add"), i18n("Add"), parent);
-        diffToBaseAction = new KAction(KIcon("text-x-patch"), i18n("Show Differences..."), parent);
-        revertAction = new KAction(KIcon("archive-remove"), i18n("Revert"), parent);
-        historyAction = new KAction(KIcon("view-history"), i18n("History..."), parent);
-        annotationAction = new KAction(KIcon("user-properties"), i18n("Annotation..."), parent);
-        diffForRevAction = new KAction(KIcon("text-x-patch"), i18n("Show Diff..."), parent);
-        diffForRevGlobalAction = new KAction(KIcon("text-x-patch"), i18n("Show Diff (all files)..."), parent);
-        pushAction = new KAction(KIcon("arrow-up-double"), i18n("Push"), parent);
-        pullAction = new KAction(KIcon("arrow-down-double"), i18n("Pull"), parent);
-        
-        connect(commitAction, SIGNAL(triggered()), parent, SLOT(commit()));
-        connect(addAction, SIGNAL(triggered()), parent, SLOT(add()));
-        connect(updateAction, SIGNAL(triggered()), parent, SLOT(update()));
-        connect(diffToBaseAction, SIGNAL(triggered()), parent, SLOT(diffToBase()));
-        connect(revertAction, SIGNAL(triggered()), parent, SLOT(revert()));
-        connect(historyAction, SIGNAL(triggered()), parent, SLOT(history()));
-        connect(annotationAction, SIGNAL(triggered()), parent, SLOT(annotation()));
-        connect(diffForRevAction, SIGNAL(triggered()), parent, SLOT(diffForRev()));
-        connect(diffForRevGlobalAction, SIGNAL(triggered()), parent, SLOT(diffForRevGlobal()));
-        connect(pullAction, SIGNAL(triggered()), parent, SLOT(pull()));
-        connect(pushAction, SIGNAL(triggered()), parent, SLOT(push()));
+        commitAction = new QAction(QIcon::fromTheme("svn-commit"), i18n("Commit..."), parent);
+        updateAction = new QAction(QIcon::fromTheme("svn-update"), i18n("Update"), parent);
+        addAction = new QAction(QIcon::fromTheme("list-add"), i18n("Add"), parent);
+        diffToBaseAction = new QAction(QIcon::fromTheme("text-x-patch"), i18n("Show Differences..."), parent);
+        revertAction = new QAction(QIcon::fromTheme("archive-remove"), i18n("Revert"), parent);
+        historyAction = new QAction(QIcon::fromTheme("view-history"), i18n("History..."), parent);
+        annotationAction = new QAction(QIcon::fromTheme("user-properties"), i18n("Annotation..."), parent);
+        diffForRevAction = new QAction(QIcon::fromTheme("text-x-patch"), i18n("Show Diff..."), parent);
+        diffForRevGlobalAction = new QAction(QIcon::fromTheme("text-x-patch"), i18n("Show Diff (all files)..."), parent);
+        pushAction = new QAction(QIcon::fromTheme("arrow-up-double"), i18n("Push"), parent);
+        pullAction = new QAction(QIcon::fromTheme("arrow-down-double"), i18n("Pull"), parent);
+
+        connect(commitAction, &QAction::triggered, parent, &VcsPluginHelper::commit);
+        connect(addAction, &QAction::triggered, parent, &VcsPluginHelper::add);
+        connect(updateAction, &QAction::triggered, parent, &VcsPluginHelper::update);
+        connect(diffToBaseAction, &QAction::triggered, parent, &VcsPluginHelper::diffToBase);
+        connect(revertAction, &QAction::triggered, parent, &VcsPluginHelper::revert);
+        connect(historyAction, &QAction::triggered, parent, [=] { parent->history(); });
+        connect(annotationAction, &QAction::triggered, parent, &VcsPluginHelper::annotation);
+        connect(diffForRevAction, &QAction::triggered, parent, static_cast<void(VcsPluginHelper::*)()>(&VcsPluginHelper::diffForRev));
+        connect(diffForRevGlobalAction, &QAction::triggered, parent, &VcsPluginHelper::diffForRevGlobal);
+        connect(pullAction, &QAction::triggered, parent, &VcsPluginHelper::pull);
+        connect(pushAction, &QAction::triggered, parent, &VcsPluginHelper::push);
     }
-    
-    bool allLocalFiles(const KUrl::List& urls)
+
+    bool allLocalFiles(const QList<QUrl>& urls)
     {
         bool ret=true;
-        foreach(const KUrl& url, urls) {
+        foreach(const QUrl &url, urls) {
             QFileInfo info(url.toLocalFile());
             ret &= info.isFile();
         }
         return ret;
     }
-    
+
     QMenu* createMenu()
     {
         bool allVersioned=true;
-        foreach(const KUrl& url, ctxUrls) {
+        foreach(const QUrl &url, ctxUrls) {
             allVersioned=allVersioned && vcs->isVersionControlled(url);
-            
+
             if(!allVersioned)
                 break;
         }
-        
-        QMenu* menu=new QMenu(vcs->name());
-        menu->setIcon(KIcon(ICore::self()->pluginController()->pluginInfo(plugin).icon()));
-        
+
+        QMenu* menu = new QMenu(vcs->name());
+        menu->setIcon(QIcon::fromTheme(ICore::self()->pluginController()->pluginInfo(plugin).iconName()));
         menu->addAction(commitAction);
         if(plugin->extension<IDistributedVersionControl>()) {
             menu->addAction(pushAction);
@@ -161,13 +139,13 @@ struct VcsPluginHelper::VcsPluginHelperPrivate {
         menu->addAction(historyAction);
         menu->addAction(annotationAction);
         menu->addAction(diffToBaseAction);
-        
+
         const bool singleVersionedFile = ctxUrls.count() == 1 && allVersioned;
         historyAction->setEnabled(singleVersionedFile);
         annotationAction->setEnabled(singleVersionedFile && allLocalFiles(ctxUrls));
         diffToBaseAction->setEnabled(singleVersionedFile);
         commitAction->setEnabled(singleVersionedFile);
-        
+
         return menu;
     }
 };
@@ -187,38 +165,29 @@ VcsPluginHelper::VcsPluginHelper(KDevelop::IPlugin* parent, KDevelop::IBasicVers
 VcsPluginHelper::~VcsPluginHelper()
 {}
 
-void VcsPluginHelper::setupFromContext(Context* context)
+void VcsPluginHelper::addContextDocument(const QUrl &url)
 {
-    d->ctxUrls.clear();
-    {
-        KDevelop::ProjectItemContext* prjctx = dynamic_cast<KDevelop::ProjectItemContext*>(context);
+    d->ctxUrls.append(url);
+}
 
-        if (prjctx) {
-            foreach(KDevelop::ProjectBaseItem* item, prjctx->items()) {
-                if(!item->target())
-                    d->ctxUrls.append(item->url());
-            }
-        }
-    }
-
-    {
-        KDevelop::EditorContext* editctx = dynamic_cast<KDevelop::EditorContext*>(context);
-
-        if (editctx) {
-            d->ctxUrls.append(editctx->url());
-        }
-    }
-
-    {
-        KDevelop::FileContext* filectx = dynamic_cast<KDevelop::FileContext*>(context);
-
-        if (filectx) {
-            d->ctxUrls = filectx->urls();
-        }
+void VcsPluginHelper::disposeEventually(KTextEditor::View *, bool dont)
+{
+    if ( ! dont ) {
+        deleteLater();
     }
 }
 
-KUrl::List const & VcsPluginHelper::contextUrlList()
+void VcsPluginHelper::disposeEventually(KTextEditor::Document *)
+{
+    deleteLater();
+}
+
+void VcsPluginHelper::setupFromContext(Context* context)
+{
+    d->ctxUrls = context->urls();
+}
+
+QList<QUrl> VcsPluginHelper::contextUrlList() const
 {
     return d->ctxUrls;
 }
@@ -242,17 +211,17 @@ QMenu* VcsPluginHelper::commonActions()
 
 #define SINGLEURL_SETUP_VARS \
     KDevelop::IBasicVersionControl* iface = d->vcs;\
-    const KUrl & url = d->ctxUrls.front();
+    const QUrl &url = d->ctxUrls.front();
 
 
 void VcsPluginHelper::revert()
 {
     VcsJob* job=d->vcs->revert(d->ctxUrls);
-    connect(job, SIGNAL(finished(KJob*)), SLOT(revertDone(KJob*)));
-    
-    foreach(const KUrl& url, d->ctxUrls) {
+    connect(job, &VcsJob::finished, this, &VcsPluginHelper::revertDone);
+
+    foreach(const QUrl &url, d->ctxUrls) {
         IDocument* doc=ICore::self()->documentController()->documentForUrl(url);
-        
+
         if(doc && doc->textDocument()) {
             KTextEditor::ModificationInterface* modif = dynamic_cast<KTextEditor::ModificationInterface*>(doc->textDocument());
             if (modif) {
@@ -261,8 +230,8 @@ void VcsPluginHelper::revert()
             doc->textDocument()->setModified(false);
         }
     }
-    job->setProperty("urls", d->ctxUrls);
-    
+    job->setProperty("urls", QVariant::fromValue(d->ctxUrls));
+
     d->plugin->core()->runController()->registerJob(job);
 }
 
@@ -270,10 +239,10 @@ void VcsPluginHelper::revertDone(KJob* job)
 {
     QTimer* modificationTimer = new QTimer;
     modificationTimer->setInterval(100);
-    connect(modificationTimer, SIGNAL(timeout()), SLOT(delayedModificationWarningOn()));
-    connect(modificationTimer, SIGNAL(timeout()), modificationTimer, SLOT(deleteLater()));
+    connect(modificationTimer, &QTimer::timeout, this, &VcsPluginHelper::delayedModificationWarningOn);
+    connect(modificationTimer, &QTimer::timeout, modificationTimer, &QTimer::deleteLater);
+
 
-    
     modificationTimer->setProperty("urls", job->property("urls"));
     modificationTimer->start();
 }
@@ -281,14 +250,14 @@ void VcsPluginHelper::revertDone(KJob* job)
 void VcsPluginHelper::delayedModificationWarningOn()
 {
     QObject* timer = sender();
-    KUrl::List urls = timer->property("urls").value<KUrl::List>();
-    
-    foreach(const KUrl& url, urls) {
+    QList<QUrl> urls = timer->property("urls").value<QList<QUrl>>();
+
+    foreach(const QUrl &url, urls) {
         IDocument* doc=ICore::self()->documentController()->documentForUrl(url);
-        
+
         if(doc) {
             doc->reload();
-            
+
             KTextEditor::ModificationInterface* modif=dynamic_cast<KTextEditor::ModificationInterface*>(doc->textDocument());
             modif->setModifiedOnDiskWarning(true);
         }
@@ -326,43 +295,60 @@ void VcsPluginHelper::diffToBase()
 }
 
 void VcsPluginHelper::diffForRev()
+{
+    if (d->ctxUrls.isEmpty()) {
+        return;
+    }
+    diffForRev(d->ctxUrls.first());
+}
+
+void VcsPluginHelper::diffForRevGlobal()
+{
+    if (d->ctxUrls.isEmpty()) {
+        return;
+    }
+    QUrl url = d->ctxUrls.first();
+    IProject* project = ICore::self()->projectController()->findProjectForUrl( url );
+    if( project ) {
+        url = project->path().toUrl();
+    }
+
+    diffForRev(url);
+}
+
+void VcsPluginHelper::diffForRev(const QUrl& url)
 {
     QAction* action = qobject_cast<QAction*>( sender() );
     Q_ASSERT(action);
     Q_ASSERT(action->data().canConvert<VcsRevision>());
     VcsRevision rev = action->data().value<VcsRevision>();
 
-    SINGLEURL_SETUP_VARS
     ICore::self()->documentController()->saveAllDocuments();
     VcsRevision prev = KDevelop::VcsRevision::createSpecialRevision(KDevelop::VcsRevision::Previous);
-    KDevelop::VcsJob* job = iface->diff(url, prev, rev );
+    KDevelop::VcsJob* job = d->vcs->diff(url, prev, rev );
 
-    connect(job, SIGNAL(finished(KJob*)), this, SLOT(diffJobFinished(KJob*)));
+    connect(job, &VcsJob::finished, this, &VcsPluginHelper::diffJobFinished);
     d->plugin->core()->runController()->registerJob(job);
 }
 
-void VcsPluginHelper::diffForRevGlobal()
-{
-    for(int a = 0; a < d->ctxUrls.size(); ++a)
-    {
-        KUrl& url(d->ctxUrls[a]);
-        IProject* project = ICore::self()->projectController()->findProjectForUrl( url );
-        if( project )
-            url = project->folder();
-    }
-    diffForRev();
-}
-
 void VcsPluginHelper::history(const VcsRevision& rev)
 {
     SINGLEURL_SETUP_VARS
-    KDialog* dlg = new KDialog(ICore::self()->uiController()->activeMainWindow());
+    QDialog* dlg = new QDialog(ICore::self()->uiController()->activeMainWindow());
     dlg->setAttribute(Qt::WA_DeleteOnClose);
-    dlg->setButtons(KDialog::Close);
-    dlg->setCaption(i18nc("%1: path or URL, %2: name of a version control system",
-                          "%2 History (%1)", url.pathOrUrl(), iface->name()));
+    dlg->setWindowTitle(i18nc("%1: path or URL, %2: name of a version control system",
+                          "%2 History (%1)", url.toDisplayString(QUrl::PreferLocalFile), iface->name()));
+
+    QVBoxLayout *mainLayout = new QVBoxLayout(dlg);
+
     KDevelop::VcsEventWidget* logWidget = new KDevelop::VcsEventWidget(url, rev, iface, dlg);
-    dlg->setMainWidget(logWidget);
+    mainLayout->addWidget(logWidget);
+
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Close);
+    dlg->connect(buttonBox, &QDialogButtonBox::accepted, dlg, &QDialog::accept);
+    dlg->connect(buttonBox, &QDialogButtonBox::rejected, dlg, &QDialog::reject);
+    mainLayout->addWidget(buttonBox);
+
     dlg->show();
 }
 
@@ -374,21 +360,38 @@ void VcsPluginHelper::annotation()
     if (!doc)
         doc = ICore::self()->documentController()->openDocument(url);
 
-    if (doc && doc->textDocument()) {
+    KTextEditor::AnnotationInterface* annotateiface = qobject_cast<KTextEditor::AnnotationInterface*>(doc->textDocument());
+    KTextEditor::AnnotationViewInterface* viewiface = qobject_cast<KTextEditor::AnnotationViewInterface*>(doc->activeTextView());
+    if (viewiface && viewiface->isAnnotationBorderVisible()) {
+        viewiface->setAnnotationBorderVisible(false);
+        return;
+    }
+
+    if (doc && doc->textDocument() && iface) {
         KDevelop::VcsJob* job = iface->annotate(url);
-        if( !job ) 
+        if( !job )
         {
-            kWarning() << "Couldn't create annotate job for:" << url << "with iface:" << iface << dynamic_cast<KDevelop::IPlugin*>( iface );
+            qWarning() << "Couldn't create annotate job for:" << url << "with iface:" << iface << dynamic_cast<KDevelop::IPlugin*>( iface );
             return;
         }
-        KTextEditor::AnnotationInterface* annotateiface = qobject_cast<KTextEditor::AnnotationInterface*>(doc->textDocument());
-        KTextEditor::AnnotationViewInterface* viewiface = qobject_cast<KTextEditor::AnnotationViewInterface*>(doc->textDocument()->activeView());
+
+        QColor foreground(Qt::black);
+        QColor background(Qt::white);
+        if (KTextEditor::View* view = doc->activeTextView()) {
+            KTextEditor::Attribute::Ptr style = view->defaultStyleAttribute(KTextEditor::dsNormal);
+            foreground = style->foreground().color();
+            if (style->hasProperty(QTextFormat::BackgroundBrush)) {
+                background = style->background().color();
+            }
+        }
 
         if (annotateiface && viewiface) {
-            KDevelop::VcsAnnotationModel* model = new KDevelop::VcsAnnotationModel(job, url, doc->textDocument());
+            KDevelop::VcsAnnotationModel* model = new KDevelop::VcsAnnotationModel(job, url, doc->textDocument(),
+                                                                                   foreground, background);
             annotateiface->setAnnotationModel(model);
             viewiface->setAnnotationBorderVisible(true);
-            connect(doc->textDocument()->activeView(),
+            // can't use new signal slot syntax here, AnnotationInterface is not a QObject
+            connect(doc->activeTextView(),
                     SIGNAL(annotationContextMenuAboutToShow(KTextEditor::View*,QMenu*,int)),
                     this, SLOT(annotationContextMenuAboutToShow(KTextEditor::View*,QMenu*,int)));
         } else {
@@ -397,7 +400,7 @@ void VcsPluginHelper::annotation()
         }
     } else {
         KMessageBox::error(0, i18n("Cannot execute annotate action because the "
-                                   "document was not found, or was not a text document:\n%1", url.pathOrUrl()));
+                                   "document was not found, or was not a text document:\n%1", url.toDisplayString(QUrl::PreferLocalFile)));
     }
 }
 
@@ -406,8 +409,8 @@ class CopyFunction : public AbstractFunction
     public:
         CopyFunction(const QString& tocopy)
             : m_tocopy(tocopy) {}
-        
-        void operator()() { QApplication::clipboard()->setText(m_tocopy); }
+
+        void operator()() override { QApplication::clipboard()->setText(m_tocopy); }
     private:
         QString m_tocopy;
 };
@@ -417,9 +420,9 @@ class HistoryFunction : public AbstractFunction
     public:
         HistoryFunction(VcsPluginHelper* helper, const VcsRevision& rev)
             : m_helper(helper), m_rev(rev) {}
-            
-            void operator()() { m_helper->history(m_rev); }
-        
+
+            void operator()() override { m_helper->history(m_rev); }
+
     private:
         VcsPluginHelper* m_helper;
         VcsRevision m_rev;
@@ -445,8 +448,8 @@ void VcsPluginHelper::annotationContextMenuAboutToShow( KTextEditor::View* view,
     menu->addSeparator();
     menu->addAction(d->diffForRevAction);
     menu->addAction(d->diffForRevGlobalAction);
-    menu->addAction(new FlexibleAction(KIcon("edit-copy"), i18n("Copy Revision"), new CopyFunction(rev.revisionValue().toString()), menu));
-    menu->addAction(new FlexibleAction(KIcon("view-history"), i18n("History..."), new HistoryFunction(this, rev), menu));
+    menu->addAction(new FlexibleAction(QIcon::fromTheme("edit-copy"), i18n("Copy Revision"), new CopyFunction(rev.revisionValue().toString()), menu));
+    menu->addAction(new FlexibleAction(QIcon::fromTheme("view-history"), i18n("History..."), new HistoryFunction(this, rev), menu));
 }
 
 void VcsPluginHelper::update()
@@ -464,11 +467,11 @@ void VcsPluginHelper::commit()
     Q_ASSERT(!d->ctxUrls.isEmpty());
     ICore::self()->documentController()->saveAllDocuments();
 
-    KUrl url = d->ctxUrls.first();
-    
+    QUrl url = d->ctxUrls.first();
+
     // We start the commit UI no matter whether there is real differences, as it can also be used to commit untracked files
     VCSCommitDiffPatchSource* patchSource = new VCSCommitDiffPatchSource(new VCSStandardDiffUpdater(d->vcs, url));
-    
+
     bool ret = showVcsDiff(patchSource);
 
     if(!ret) {
@@ -480,7 +483,7 @@ void VcsPluginHelper::commit()
 
 void VcsPluginHelper::push()
 {
-    foreach(const KUrl& url, d->ctxUrls) {
+    foreach(const QUrl &url, d->ctxUrls) {
         VcsJob* job = d->plugin->extension<IDistributedVersionControl>()->push(url, VcsLocation());
         ICore::self()->runController()->registerJob(job);
     }
@@ -488,7 +491,7 @@ void VcsPluginHelper::push()
 
 void VcsPluginHelper::pull()
 {
-    foreach(const KUrl& url, d->ctxUrls) {
+    foreach(const QUrl &url, d->ctxUrls) {
         VcsJob* job = d->plugin->extension<IDistributedVersionControl>()->pull(VcsLocation(), url);
         ICore::self()->runController()->registerJob(job);
     }
@@ -497,4 +500,3 @@ void VcsPluginHelper::pull()
 }
 
 
-#include "vcspluginhelper.moc"
