@@ -1,6 +1,6 @@
 /*
     Copyright 2009 David Nolden <david.nolden.kdevelop@art-master.de>
-    
+
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License version 2 as published by the Free Software Foundation.
@@ -17,21 +17,29 @@
 */
 
 #include "vcsdiffpatchsources.h"
-#include <qboxlayout.h>
-#include <qlabel.h>
-#include <kglobalsettings.h>
-#include <klocalizedstring.h>
-#include <interfaces/iprojectcontroller.h>
-#include <interfaces/icore.h>
-#include <kmessagebox.h>
-#include <interfaces/iruncontroller.h>
-#include "vcsjob.h"
-#include "vcsdiff.h"
-#include <interfaces/iplugincontroller.h>
+
+#include <QBoxLayout>
+#include <QDir>
+#include <QFontDatabase>
+#include <QLabel>
+#include <QTemporaryFile>
+
 #include <KComboBox>
+#include <KConfigGroup>
+#include <KLocalizedString>
+#include <KMessageBox>
 #include <KTextEdit>
-#include <interfaces/isession.h>
+
 #include <interfaces/ibasicversioncontrol.h>
+#include <interfaces/icore.h>
+#include <interfaces/iprojectcontroller.h>
+#include <interfaces/iplugincontroller.h>
+#include <interfaces/iruncontroller.h>
+#include <interfaces/isession.h>
+#include "vcsdiff.h"
+#include "vcsjob.h"
+#include "../debug.h"
+
 
 using namespace KDevelop;
 
@@ -43,28 +51,28 @@ VCSCommitDiffPatchSource::VCSCommitDiffPatchSource(VCSDiffUpdater* updater)
     QVBoxLayout* layout = new QVBoxLayout(m_commitMessageWidget.data());
 
     m_commitMessageEdit = new KTextEdit;
-    m_commitMessageEdit.data()->setFont( KGlobalSettings::fixedFont() );
+    m_commitMessageEdit.data()->setFont(QFontDatabase::systemFont(QFontDatabase::FixedFont));
     m_commitMessageEdit.data()->setLineWrapMode(QTextEdit::NoWrap);
     m_vcs->setupCommitMessageEditor(updater->url(), m_commitMessageEdit.data());
-    
+
     QHBoxLayout* titleLayout = new QHBoxLayout;
     titleLayout->addWidget(new QLabel(i18n("Commit Message:")));
-    
+
     m_oldMessages = new KComboBox(m_commitMessageWidget.data());
-    
+
     m_oldMessages->addItem(i18n("Old Messages"));
-    foreach(QString message, oldMessages())
+    foreach(const QString& message, oldMessages())
         m_oldMessages->addItem(message, message);
     m_oldMessages->setMaximumWidth(200);
-    
-    connect(m_oldMessages, SIGNAL(currentIndexChanged(QString)), this, SLOT(oldMessageChanged(QString)));
-    
+
+    connect(m_oldMessages, static_cast<void(KComboBox::*)(const QString&)>(&KComboBox::currentIndexChanged), this, &VCSCommitDiffPatchSource::oldMessageChanged);
+
     titleLayout->addWidget(m_oldMessages);
-    
+
     layout->addLayout(titleLayout);
     layout->addWidget(m_commitMessageEdit.data());
-    connect(this, SIGNAL(reviewCancelled(QString)), SLOT(addMessageToHistory(QString)));
-    connect(this, SIGNAL(reviewFinished(QString,QList<KUrl>)), SLOT(addMessageToHistory(QString)));
+    connect(this, &VCSCommitDiffPatchSource::reviewCancelled, this, &VCSCommitDiffPatchSource::addMessageToHistory);
+    connect(this, &VCSCommitDiffPatchSource::reviewFinished, this, &VCSCommitDiffPatchSource::addMessageToHistory);
 }
 
 QStringList VCSCommitDiffPatchSource::oldMessages() const
@@ -77,16 +85,16 @@ void VCSCommitDiffPatchSource::addMessageToHistory(const QString& message)
 {
     if(ICore::self()->shuttingDown())
         return;
-    
+
     KConfigGroup vcsGroup(ICore::self()->activeSession()->config(), "VCS");
-    
+
     const int maxMessages = 10;
     QStringList oldMessages = vcsGroup.readEntry("OldCommitMessages", QStringList());
-    
+
     oldMessages.removeAll(message);
     oldMessages.push_front(message);
     oldMessages = oldMessages.mid(0, maxMessages);
-    
+
     vcsGroup.writeEntry("OldCommitMessages", oldMessages);
 }
 
@@ -118,9 +126,9 @@ VCSDiffPatchSource::VCSDiffPatchSource(VCSDiffUpdater* updater)
 {
     update();
     KDevelop::IBasicVersionControl* vcs = m_updater->vcs();
-    KUrl url = m_updater->url();
+    QUrl url = m_updater->url();
 
-    QScopedPointer<VcsJob> statusJob(vcs->status(url));
+    QScopedPointer<VcsJob> statusJob(vcs->status(QList<QUrl>() << url));
     QVariant varlist;
 
     if( statusJob->exec() && statusJob->status() == VcsJob::JobSucceeded )
@@ -129,15 +137,15 @@ VCSDiffPatchSource::VCSDiffPatchSource(VCSDiffUpdater* updater)
 
         foreach( const QVariant &var, varlist.toList() )
         {
-            VcsStatusInfo info = qVariantValue<KDevelop::VcsStatusInfo>( var );
-            
+            VcsStatusInfo info = var.value<KDevelop::VcsStatusInfo>();
+
             m_infos += info;
             if(info.state()!=VcsStatusInfo::ItemUpToDate)
                 m_selectable[info.url()] = info.state();
         }
     }
     else
-        kDebug() << "Couldn't get status for urls: " << url;
+        qCDebug(VCS) << "Couldn't get status for urls: " << url;
 }
 
 VCSDiffPatchSource::VCSDiffPatchSource(const KDevelop::VcsDiff& diff)
@@ -152,11 +160,11 @@ VCSDiffPatchSource::~VCSDiffPatchSource()
     delete m_updater;
 }
 
-KUrl VCSDiffPatchSource::baseDir() const {
+QUrl VCSDiffPatchSource::baseDir() const {
     return m_base;
 }
 
-KUrl VCSDiffPatchSource::file() const {
+QUrl VCSDiffPatchSource::file() const {
     return m_file;
 }
 
@@ -164,18 +172,21 @@ QString VCSDiffPatchSource::name() const {
     return m_name;
 }
 
+uint VCSDiffPatchSource::depth() const {
+    return m_depth;
+}
+
 void VCSDiffPatchSource::updateFromDiff(VcsDiff vcsdiff)
 {
     if(!m_file.isValid())
     {
-        KTemporaryFile temp2;
-        temp2.setSuffix("2.patch");
+        QTemporaryFile temp2(QDir::tempPath() + QLatin1String("/kdevelop_XXXXXX.patch"));
         temp2.setAutoRemove(false);
         temp2.open();
         QTextStream t2(&temp2);
         t2 << vcsdiff.diff();
-        kDebug() << "filename:" << temp2.fileName();
-        m_file = KUrl(temp2.fileName());
+        qCDebug(VCS) << "filename:" << temp2.fileName();
+        m_file = QUrl::fromLocalFile(temp2.fileName());
         temp2.close();
     }else{
         QFile file(m_file.path());
@@ -184,12 +195,12 @@ void VCSDiffPatchSource::updateFromDiff(VcsDiff vcsdiff)
         t2 << vcsdiff.diff();
     }
 
-    kDebug() << "using file" << m_file << vcsdiff.diff() << "base" << vcsdiff.baseDiff();
+    qCDebug(VCS) << "using file" << m_file << vcsdiff.diff() << "base" << vcsdiff.baseDiff();
 
     m_name = "VCS Diff";
     m_base = vcsdiff.baseDiff();
-    m_base.addPath("/");
-    
+    m_depth = vcsdiff.depth();
+
     emit patchChanged();
 }
 
@@ -207,7 +218,7 @@ bool VCSCommitDiffPatchSource::canSelectFiles() const {
     return true;
 }
 
-QMap< KUrl, KDevelop::VcsStatusInfo::State> VCSDiffPatchSource::additionalSelectableFiles() const {
+QMap< QUrl, KDevelop::VcsStatusInfo::State> VCSDiffPatchSource::additionalSelectableFiles() const {
     return m_selectable;
 }
 
@@ -224,27 +235,27 @@ bool VCSCommitDiffPatchSource::canCancel() const {
 }
 
 void VCSCommitDiffPatchSource::cancelReview() {
-    
+
     QString message;
 
     if (m_commitMessageEdit)
         message = m_commitMessageEdit.data()->toPlainText();
 
     emit reviewCancelled(message);
-    
+
     deleteLater();
 }
 
-bool VCSCommitDiffPatchSource::finishReview(QList< KUrl > selection) {
+bool VCSCommitDiffPatchSource::finishReview(QList< QUrl > selection) {
 
     QString message;
 
     if (m_commitMessageEdit)
         message = m_commitMessageEdit.data()->toPlainText();
 
-    kDebug() << "Finishing with selection" << selection;
+    qCDebug(VCS) << "Finishing with selection" << selection;
     QString files;
-    foreach(const KUrl& url, selection)
+    foreach(const QUrl& url, selection)
         files += "<li>"+ICore::self()->projectController()->prettyFileName(url, KDevelop::IProjectController::FormatPlain) + "</li>";
 
     QString text = i18n("<qt>Files will be committed:\n<ul>%1</ul>\nWith message:\n <pre>%2</pre></qt>", files, message);
@@ -263,8 +274,8 @@ bool VCSCommitDiffPatchSource::finishReview(QList< KUrl > selection) {
         return false;
     }
 
-    connect (job, SIGNAL(finished(KJob*)),
-             this, SLOT(jobFinished(KJob*)));
+    connect (job, &VcsJob::finished,
+             this, &VCSCommitDiffPatchSource::jobFinished);
     ICore::self()->runController()->registerJob(job);
     return true;
 }
@@ -277,14 +288,14 @@ bool showVcsDiff(IPatchSource* vcsDiff)
 
     //Only give one VCS diff at a time to the patch review plugin
     delete currentShownDiff;
-    
+
     currentShownDiff = vcsDiff;
-    
+
     if( patchReview ) {
         patchReview->startReview(currentShownDiff);
         return true;
     } else {
-        kWarning() << "Patch review plugin not found";
+        qWarning() << "Patch review plugin not found";
         return false;
     }
 }
@@ -303,7 +314,7 @@ VcsDiff VCSStandardDiffUpdater::update() const
     return diffJob->fetchResults().value<VcsDiff>();
 }
 
-VCSStandardDiffUpdater::VCSStandardDiffUpdater(IBasicVersionControl* vcs, KUrl url) : m_vcs(vcs), m_url(url) {
+VCSStandardDiffUpdater::VCSStandardDiffUpdater(IBasicVersionControl* vcs, QUrl url) : m_vcs(vcs), m_url(url) {
 }
 
 VCSStandardDiffUpdater::~VCSStandardDiffUpdater() {
@@ -312,4 +323,3 @@ VCSStandardDiffUpdater::~VCSStandardDiffUpdater() {
 VCSDiffUpdater::~VCSDiffUpdater() {
 }
 
-#include "vcsdiffpatchsources.moc"
