@@ -23,15 +23,11 @@
 #ifndef KDEVPLATFORM_VCSDIFFPATCHSOURCES_H
 #define KDEVPLATFORM_VCSDIFFPATCHSOURCES_H
 
-#include <ktemporaryfile.h>
-#include <qtextstream.h>
-#include <QSharedPointer>
-#include <kdebug.h>
 #include <interfaces/ipatchsource.h>
 #include "vcs/vcsstatusinfo.h"
 #include "vcs/vcsjob.h"
 
-#include "../vcsexport.h"
+#include <vcs/vcsexport.h>
 
 class KTextEdit;
 class KComboBox;
@@ -48,48 +44,48 @@ public:
     virtual ~VCSDiffUpdater();
     virtual KDevelop::VcsDiff update() const = 0;
     virtual KDevelop::IBasicVersionControl* vcs() const = 0;
-    virtual KUrl url() const = 0;
+    virtual QUrl url() const = 0;
 };
 
 class KDEVPLATFORMVCS_EXPORT VCSStandardDiffUpdater : public VCSDiffUpdater {
 public:
-    VCSStandardDiffUpdater(KDevelop::IBasicVersionControl* vcs, KUrl url);
+    VCSStandardDiffUpdater(KDevelop::IBasicVersionControl* vcs, QUrl url);
     virtual ~VCSStandardDiffUpdater();
-    virtual KDevelop::VcsDiff update() const;
-    virtual KDevelop::IBasicVersionControl* vcs() const { return m_vcs; }
-    virtual KUrl url() const { return m_url; }
+    virtual KDevelop::VcsDiff update() const override;
+    virtual KDevelop::IBasicVersionControl* vcs() const override { return m_vcs; }
+    virtual QUrl url() const override { return m_url; }
 private:
     KDevelop::IBasicVersionControl* m_vcs;
-    KUrl m_url;
+    QUrl m_url;
 };
 
 
 class KDEVPLATFORMVCS_EXPORT VCSDiffPatchSource : public KDevelop::IPatchSource {
     public:
     /// The ownership of the updater is taken
-    VCSDiffPatchSource(VCSDiffUpdater* updater);
-    VCSDiffPatchSource(const KDevelop::VcsDiff& diff);
+    explicit VCSDiffPatchSource(VCSDiffUpdater* updater);
+    explicit VCSDiffPatchSource(const KDevelop::VcsDiff& diff);
     virtual ~VCSDiffPatchSource();
 
-    virtual KUrl baseDir() const ;
+    virtual QUrl baseDir() const override ;
 
-    virtual KUrl file() const ;
+    virtual QUrl file() const override ;
 
-    virtual QString name() const ;
+    virtual QString name() const override ;
 
-    virtual uint depth() const ;
+    virtual uint depth() const override ;
 
-    virtual void update() ;
+    virtual void update() override ;
 
-    virtual bool isAlreadyApplied() const { return true; }
+    virtual bool isAlreadyApplied() const override { return true; }
 
-    QMap<KUrl, KDevelop::VcsStatusInfo::State> additionalSelectableFiles() const ;
+    QMap<QUrl, KDevelop::VcsStatusInfo::State> additionalSelectableFiles() const override ;
 
-    KUrl m_base, m_file;
+    QUrl m_base, m_file;
     QString m_name;
     VCSDiffUpdater* m_updater;
     QList<KDevelop::VcsStatusInfo> m_infos;
-    QMap<KUrl, KDevelop::VcsStatusInfo::State> m_selectable;
+    QMap<QUrl, KDevelop::VcsStatusInfo::State> m_selectable;
     private:
     void updateFromDiff(KDevelop::VcsDiff diff);
     uint m_depth = 0;
@@ -99,29 +95,29 @@ class KDEVPLATFORMVCS_EXPORT VCSCommitDiffPatchSource : public VCSDiffPatchSourc
     Q_OBJECT
     public:
     /// The ownership of the updater is taken
-    VCSCommitDiffPatchSource(VCSDiffUpdater* updater);
+    explicit VCSCommitDiffPatchSource(VCSDiffUpdater* updater);
     ~VCSCommitDiffPatchSource() ;
 
     QStringList oldMessages() const;
 
-    virtual bool canSelectFiles() const ;
+    virtual bool canSelectFiles() const override ;
 
-    virtual QWidget* customWidget() const ;
+    virtual QWidget* customWidget() const override ;
 
-    virtual QString finishReviewCustomText() const ;
+    virtual QString finishReviewCustomText() const override ;
 
-    virtual bool canCancel() const;
+    virtual bool canCancel() const override;
 
-    virtual void cancelReview();
+    virtual void cancelReview() override;
 
-    virtual bool finishReview(QList< KUrl > selection) ;
+    virtual bool finishReview(QList< QUrl > selection) override ;
     QList<KDevelop::VcsStatusInfo> infos() const { return m_infos; }
 Q_SIGNALS:
-    void reviewFinished(QString message, QList<KUrl> selection);
+    void reviewFinished(QString message, QList<QUrl> selection);
     void reviewCancelled(QString message);
 public:
-    QWeakPointer<QWidget> m_commitMessageWidget;
-    QWeakPointer<KTextEdit> m_commitMessageEdit;
+    QPointer<QWidget> m_commitMessageWidget;
+    QPointer<KTextEdit> m_commitMessageEdit;
     KDevelop::IBasicVersionControl* m_vcs;
     KComboBox* m_oldMessages;
 public slots:
