@@ -21,30 +21,32 @@
 
 #include "vcseventwidget.h"
 
-#include <QHeaderView>
 #include <QAction>
 #include <QClipboard>
+#include <QDialog>
+#include <QDialogButtonBox>
+#include <QHeaderView>
+#include <QMenu>
+#include <QPushButton>
+#include <QVBoxLayout>
 
-#include <kdebug.h>
-#include <kmenu.h>
-#include <KAction>
+#include <KLocalizedString>
 
-
-#include <interfaces/iplugin.h>
 #include <interfaces/icore.h>
+#include <interfaces/iplugin.h>
 #include <interfaces/iruncontroller.h>
 
 #include "ui_vcseventwidget.h"
 #include "vcsdiffwidget.h"
 
-#include "../vcsjob.h"
 #include "../interfaces/ibasicversioncontrol.h"
-#include "../vcsrevision.h"
-#include "../vcsevent.h"
-#include "../vcslocation.h"
-
-#include "../models/vcsitemeventmodel.h"
 #include "../models/vcseventmodel.h"
+#include "../models/vcsitemeventmodel.h"
+#include "../debug.h"
+#include "../vcsevent.h"
+#include "../vcsjob.h"
+#include "../vcslocation.h"
+#include "../vcsrevision.h"
 
 
 namespace KDevelop
@@ -56,18 +58,18 @@ public:
     VcsEventWidgetPrivate( VcsEventWidget* w )
         : q( w )
     {
-        m_copyAction = new KAction(KIcon("edit-copy"), i18n("Copy revision number"), q);
+        m_copyAction = new QAction(QIcon::fromTheme("edit-copy"), i18n("Copy revision number"), q);
         m_copyAction->setShortcut(Qt::ControlModifier+Qt::Key_C);
-        QObject::connect(m_copyAction, SIGNAL(triggered(bool)), q, SLOT(copyRevision()));
+        QObject::connect(m_copyAction, &QAction::triggered, q, [&] { copyRevision(); });
     }
 
     Ui::VcsEventWidget* m_ui;
     VcsItemEventModel* m_detailModel;
     VcsEventModel *m_logModel;
-    KUrl m_url;
+    QUrl m_url;
     QModelIndex m_contextIndex;
     VcsEventWidget* q;
-    KAction* m_copyAction;
+    QAction* m_copyAction;
     IBasicVersionControl* m_iface;
     void eventViewCustomContextMenuRequested( const QPoint &point );
     void eventViewClicked( const QModelIndex &index );
@@ -82,11 +84,11 @@ void VcsEventWidgetPrivate::eventViewCustomContextMenuRequested( const QPoint &p
 {
     m_contextIndex = m_ui->eventView->indexAt( point );
     if( !m_contextIndex.isValid() ){
-        kDebug() << "contextMenu is not in TreeView";
+        qCDebug(VCS) << "contextMenu is not in TreeView";
         return;
     }
 
-    KMenu menu( m_ui->eventView );
+    QMenu menu( m_ui->eventView );
     menu.addAction(m_copyAction);
     menu.addAction(i18n("Diff to previous revision"), q, SLOT(diffToPrevious()));
     QAction* action = menu.addAction(i18n("Diff between revisions"), q, SLOT(diffRevisions()));
@@ -106,7 +108,7 @@ void VcsEventWidgetPrivate::eventViewClicked( const QModelIndex &index )
 {
     KDevelop::VcsEvent ev = m_logModel->eventForIndex( index );
     m_detailModel->removeRows(0, m_detailModel->rowCount());
-    
+
     if( ev.revision().revisionType() != KDevelop::VcsRevision::Invalid )
     {
         m_ui->itemEventView->setEnabled(true);
@@ -121,9 +123,8 @@ void VcsEventWidgetPrivate::eventViewClicked( const QModelIndex &index )
     }
 
     QHeaderView* header = m_ui->itemEventView->header();
-    for(int i=0, count=m_detailModel->columnCount(); i<count; i++) {
-        header->setResizeMode( i, (i==m_detailModel->columnCount()-1) ? QHeaderView::Stretch : QHeaderView::ResizeToContents);
-    }
+    header->setSectionResizeMode(QHeaderView::ResizeToContents);
+    header->setStretchLastSection(true);
 }
 
 void VcsEventWidgetPrivate::copyRevision()
@@ -139,13 +140,25 @@ void VcsEventWidgetPrivate::diffToPrevious()
 
     VcsDiffWidget* widget = new VcsDiffWidget( job );
     widget->setRevisions( prev, ev.revision() );
-    KDialog* dlg = new KDialog( q );
-    
-    widget->connect(widget, SIGNAL(destroyed(QObject*)), dlg, SLOT(deleteLater()));
-    
-    dlg->setCaption( i18n("Difference To Previous") );
-    dlg->setButtons( KDialog::Ok );
-    dlg->setMainWidget( widget );
+    QDialog* dlg = new QDialog( q );
+
+    widget->connect(widget, &VcsDiffWidget::destroyed, dlg, &QDialog::deleteLater);
+
+    dlg->setWindowTitle( i18n("Difference To Previous") );
+
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok);
+    auto mainWidget = new QWidget;
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    dlg->setLayout(mainLayout);
+    mainLayout->addWidget(mainWidget);
+    QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
+    okButton->setDefault(true);
+    okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+    dlg->connect(buttonBox, &QDialogButtonBox::accepted, dlg, &QDialog::accept);
+    dlg->connect(buttonBox, &QDialogButtonBox::rejected, dlg, &QDialog::reject);
+    mainLayout->addWidget(widget);
+    mainLayout->addWidget(buttonBox);
+
     dlg->show();
 }
 
@@ -158,14 +171,25 @@ void VcsEventWidgetPrivate::diffRevisions()
 
     VcsDiffWidget* widget = new VcsDiffWidget( job );
     widget->setRevisions( ev1.revision(), ev2.revision() );
-    KDialog* dlg = new KDialog( q );
-    dlg->setCaption( i18n("Difference between Revisions") );
-    dlg->setButtons( KDialog::Ok );
-    dlg->setMainWidget( widget );
+
+    auto dlg = new QDialog( q );
+    dlg->setWindowTitle( i18n("Difference between Revisions") );
+
+    widget->connect(widget, &VcsDiffWidget::destroyed, dlg, &QDialog::deleteLater);
+
+    auto mainLayout = new QVBoxLayout(dlg);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok);
+    auto okButton = buttonBox->button(QDialogButtonBox::Ok);
+    okButton->setDefault(true);
+    okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+    dlg->connect(buttonBox, &QDialogButtonBox::accepted, dlg, &QDialog::accept);
+    dlg->connect(buttonBox, &QDialogButtonBox::rejected, dlg, &QDialog::reject);
+    mainLayout->addWidget(buttonBox);
+    mainLayout->addWidget(widget);
     dlg->show();
 }
 
-VcsEventWidget::VcsEventWidget( const KUrl& url, const VcsRevision& rev, KDevelop::IBasicVersionControl* iface, QWidget* parent )
+VcsEventWidget::VcsEventWidget( const QUrl& url, const VcsRevision& rev, KDevelop::IBasicVersionControl* iface, QWidget* parent )
     : QWidget(parent), d(new VcsEventWidgetPrivate(this) )
 {
     d->m_iface = iface;
@@ -177,21 +201,21 @@ VcsEventWidget::VcsEventWidget( const KUrl& url, const VcsRevision& rev, KDevelo
     d->m_ui->eventView->setModel( d->m_logModel );
     d->m_ui->eventView->sortByColumn(0, Qt::DescendingOrder);
     d->m_ui->eventView->setContextMenuPolicy( Qt::CustomContextMenu );
-    QHeaderView* header = d->m_ui->eventView->horizontalHeader();
-    header->setResizeMode( 0, QHeaderView::ResizeToContents );
-    header->setResizeMode( 1, QHeaderView::ResizeToContents );
-    header->setResizeMode( 2, QHeaderView::ResizeToContents );
-    header->setResizeMode( 3, QHeaderView::Stretch );
+    QHeaderView* header = d->m_ui->eventView->header();
+    header->setSectionResizeMode( 0, QHeaderView::ResizeToContents );
+    header->setSectionResizeMode( 1, QHeaderView::Stretch );
+    header->setSectionResizeMode( 2, QHeaderView::ResizeToContents );
+    header->setSectionResizeMode( 3, QHeaderView::ResizeToContents );
 
     d->m_detailModel = new VcsItemEventModel(this);
     d->m_ui->itemEventView->setModel( d->m_detailModel );
 
-    connect( d->m_ui->eventView, SIGNAL(clicked(QModelIndex)),
-             this, SLOT(eventViewClicked(QModelIndex)) );
-    connect( d->m_ui->eventView->selectionModel(), SIGNAL(currentRowChanged(QModelIndex,QModelIndex)),
-             this, SLOT(currentRowChanged(QModelIndex,QModelIndex)));
-    connect( d->m_ui->eventView, SIGNAL(customContextMenuRequested(QPoint)),
-             this, SLOT(eventViewCustomContextMenuRequested(QPoint)) );
+    connect( d->m_ui->eventView, &QTreeView::clicked,
+             this, [&] (const QModelIndex& index) { d->eventViewClicked(index); } );
+    connect( d->m_ui->eventView->selectionModel(), &QItemSelectionModel::currentRowChanged,
+             this, [&] (const QModelIndex& start, const QModelIndex& end) { d->currentRowChanged(start, end); });
+    connect( d->m_ui->eventView, &QTreeView::customContextMenuRequested,
+             this, [&] (const QPoint& point) { d->eventViewCustomContextMenuRequested(point); } );
 }
 
 VcsEventWidget::~VcsEventWidget()
@@ -203,4 +227,4 @@ VcsEventWidget::~VcsEventWidget()
 }
 
 
-#include "vcseventwidget.moc"
+#include "moc_vcseventwidget.cpp"
